--- This file has been generated by scripts/build_db.py. DO NOT EDIT !

INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5104','Huang Hai 1956','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6125','Samboja P2 exc T9','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6160','Quini-Huao','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6174','Sierra Leone Peninsular 1924','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6211','Genuk','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6218','Bogota','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6222','South Africa','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6227','Levant','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6269','NAD83(1986)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6272','GD49','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6308','Rikets koordinatsystem 1938','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5100','MSL','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5101','ODN','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5102','NGVD29','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5103','NAVD88','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5104','Yellow Sea','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5105','Baltic','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5106','Caspian','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5107','NGF','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5109','NAP','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5111','AHD','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5112','AHD (Tasmania)','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5114','CVD28','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5115','Piraeus86','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5116','N60','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5117','RH70','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5118','NGF - Lallemand','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5119','NGF-IGN69','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5120','NGF-IGN78','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5122','JSLD69','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5123','PHD93','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5127','LN02','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5128','LHN95','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5129','EVRF2000','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6121','GGRS87','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6122','ATS77','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6123','KKJ','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6124','RT90','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6126','LKS94 (ETRS89)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6130','Moznet','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6132','FD58','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6133','EST92','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6134','PSD93','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6140','NAD83(CSRS)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6151','CHTRF95','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6152','NAD83(HARN)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6154','ED50(ED77)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6156','S-JTSK','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6159','ELD79','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6163','YNGN96','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6170','SIRGAS 1995','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6171','RGF93','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6172','POSGAR','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6202','AGD66','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6203','AGD84','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6204','Ain el Abd','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6215','Belge 1950','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6230','ED50','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6231','ED87','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6237','HD72','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6238','ID74','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6242','JAD69','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6246','KOC','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6248','PSAD56','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6258','ETRS89','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6267','NAD27','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6269','NAD83','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6272','NZGD49','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6275','NTF','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6278','OSGB70','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6279','OS(SN)80','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6280','Padang','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6283','GDA94','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6291','SAD69','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6297','Tananarive','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6303','TC(1948)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6308','RT38','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6312','MGI','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6313','Belge 1972','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6314','DHDN','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6318','NGN','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6319','KUDAMS','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6322','WGS 72','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6324','WGS 72BE','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6326','WGS 84','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6608','NAD27(76)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6609','CGQ77','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6901','ATF (Paris)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6902','NDG (Paris)','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1161','DHHN12','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1161','Deutsches Haupthöhennetz 1912','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1162','LAS-2000','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1159','GSK-2011','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1159','GRS-2011','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6181','LUREF','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6180','EST97','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6179','42/58','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6178','42/83','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1031','HR1901','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6818','Systém Jednotné trigonometrické sítě katastrální (Ferro)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6176','AAD98','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6167','NZGD2000','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5119','Nivellement general de la France','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5119','NGF','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5120','IGN78','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5118','NGF','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5120','Nivellement general de la France','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5118','Nivellement general de la France','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6143','Côte d''Ivoire (Ivory Coast)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6142','Côte d''Ivoire (Ivory Coast)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6189','SIRGAS-REGVEN','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6189','REGVEN','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6171','Réseau Géodésique Français 1993','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6172','Posiciones Geodésicas Argentinas','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6190','POSGAR 98','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6190','Posiciones Geodésicas Argentinas 1998','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6182','Observatario Flores','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6182','Azores Occidental 1939','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6183','Graciosa','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6183','Azores Central 1948','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6184','Sao Bras','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6184','Azores Oriental 1940','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6156','Systém Jednotné trigonometrické sítě katastrální','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6123','Kartastokoordinaattijärjestelmä (1966)','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5133','AIOC95','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6199','New Egyptian','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6229','Old Egyptian','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6612','JGD2000','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5137','Huang Hai 1985','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5135','HKPD','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6611','HK80','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5135','Ordnance Datum','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5136','Admiralty Chart Datum','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1164','ODN (Offshore)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6820','Segara (Jakarta)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6613','Segara','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6613','Samboja','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6613','P2 Exc','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6613','P2 Exc-T9','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6614','QND95','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6620','12th Parallel traverse','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5131','Belfast','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5101','Newlyn','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6637','Perroud 1950','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6634','MHNC72','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6627','RGR92','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6624','RGFG95','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6623','CSG67','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6648','ITRF89','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6649','ITRF90','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6650','ITRF91','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6651','ITRF92','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6652','ITRF93','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6653','ITRF94','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6654','ITRF96','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6655','ITRF97','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6656','ITRF2000','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6623','Guyane Francaise','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5151','NGNC69','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6638','St. Pierre et Miquelon 1950','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6647','ITRF88','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6645','RGNC91','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6640','RRAF91','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6659','ISN93','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6300','TM75','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6300','1975 Mapping Adjustment','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5153','NGG1977','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5154','Martinique 1987','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5156','Reunion 1989','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5156','IGN89','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5155','IGN 1988','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5154','IGN87','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6661','LKS92','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6615','Madeira SE Base','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6665','Graciosa','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6665','Azores Central 1995','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6665','Base SW','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6183','Base SW','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6664','Sao Bras','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6664','Azores Oriental 1995','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6615','Base SE','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6663','Base SE','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6663','Madeira SE Base 1995','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6615','Porto Santo','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6667','IKBD-92','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6668','ED79','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6131','Indian (DMA Reduced)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1192','NAD83(CSRS)v1','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1192','NAD83(CSRS96)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1195','NAD83(CSRS)v4','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6265','Rome 1940','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6806','Rome 1940 (Rome)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6670','IGM95','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6673','CI1979','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5172','NG-L','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5174','NN1954','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5173','TNVCN99','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6173','ETRS89','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6281','Old Israeli Datum','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6281','OID','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1146','Abu Dhabi Vertical Datum','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6674','SIRGAS 2000','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6678','Lao 1997','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5182','DHHN85','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5183','SNN76','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5172','NG95','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5176','GHA','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5177','NVN99','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5178','RNGAP','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5180','REDNAP','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5181','DHHN92','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5185','EOMA 1980','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5186','PWD','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5187','WD','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5188','CD','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6152','NAD83 (High Precision Geodetic Network)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6152','NAD83(HPGN)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6625','Fort Desaix','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6622','Sainte Anne','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6626','Piton des Neiges','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5189','NGC','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5192','IGN 1955','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5191','IGN 1950','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5114','Canadian Vertical Datum of 1928','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5114','CGVD28','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6683','PRS92','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6683','Modified Luzon Datum','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6686','MAGNA-SIRGAS','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1133','NAD83(CORS96)','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5105','Baltic Sea','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6687','RGPF','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6688','MHEFO 55','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6628','IGN 1952','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6692','MOP 1983','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6628','Tahiti','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6629','Tahaa','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5195','NGPF','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6694','POSGAR 94','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6694','POSGAR','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6190','POSGAR','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6694','Posiciones Geodésicas Argentinas 1994','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6701','IGCB 1955','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6701','Bas Congo 1955','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6182','Observatorio Meteorologico 1939','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6182','Observatorio 1966','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6616','Selvagem Grande 1938','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6616','Marco Astro','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6703','Mhast 1951','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6705','Mhast','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6704','Mhast','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6259','Mhast','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6699','Le Pouce (Mauritius 94)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6699','Le Pouce (Mauritius PN 94)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6725','Johnston Atoll 1961','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6737','Korea 2000','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6740','PZ-90','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6739','HK63(67)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6738','HK63','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6690','IGN79 Tahiti','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6639','Uvea SHOM 1978','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6706','S-650 TL','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6741','FD54','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6742','GDM2000','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6745','RD/83','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6746','PD/83','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6747','GR96','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6720','FGD 1986','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6720','Fiji 1986','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6752','Viti Levu 1916','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6748','Vanua Levu 1917','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6749','RGNC91-93','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6749','RGNC','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6298','Timbalai 1968','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6298','Borneo Triangulation of 1968','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6298','BT68','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6245','Malaysia Revised Triangulation 1968','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6245','MRT68','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6714','Bellevue (IGN)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6730','Santo (DOS)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6753','FD54a','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6754','LGD2006','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6755','DGN95','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6755','Indonesian Geodetic Datum 1995','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6755','IGD95','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6697','IGC 1962 6th Parallel South','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6756','VN-2000','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6896','ITRF2005','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6647','IERS Terrestrial Reference Frame 1988','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6648','IERS Terrestrial Reference Frame 1989','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6649','IERS Terrestrial Reference Frame 1990','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6650','IERS Terrestrial Reference Frame 1991','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6651','IERS Terrestrial Reference Frame 1992','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6652','IERS Terrestrial Reference Frame 1993','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6653','IERS Terrestrial Reference Frame 1994','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5204','IGLD 1955','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5205','IGLD 1985','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5206','DVR90','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1140','SHD','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6758','JAD2001','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6760','WGS 66','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1034','SREF98','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5207','HVRS71','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6762','BDA2000','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5208','RH2000','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5209','RH00','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6764','RSRGD2000','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5157','Auckland','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5158','Bluff','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5169','Chatham Island 1959','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5159','Dunedin','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5160','Gisborne','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5161','Lyttelton','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5162','Moturiki','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5163','Napier','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5164','Nelson','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5165','One Tree Point','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5170','Stewart Island','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5167','Taranaki','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5166','Tararu','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5168','Wellington','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6765','D96','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6765','Slovenia 1996','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1024','HD1909','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1025','TWD67','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1026','TWD97','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6236','Hu Tzu Shan','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6316','Dealul Piscului 1933','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1107','Cais da Figueirinha - Angra do Heroísmo','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5202','Bora Bora 2001','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5124','Fahud HD','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5132','DNN','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5138','ODN Orkney','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5215','EVRF2007','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6743','Karbala 1979 (Polservice)','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5149','British Vertical Datum','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1029','IGRS','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6191','ALB86','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6127','Tete 1960','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6201','Blue Nile 1958','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1112','CGRS93','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1113','RGTAAF07','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1113','Reseau Geodesique des TAAF 2007','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1147','ONGD14','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1031','D48','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6805','MGI (Ferro)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1033','RGRDC 2005','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6728','Pico de las Nieves','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6728','PN84','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1027','EGM2008','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1152','WGS 84 (G730)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1153','WGS 84 (G873)','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5203','EGM84','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1154','WGS 84 (G1150)','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5171','EGM96','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1155','WGS 84 (G1674)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1156','WGS 84 (G1762)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1157','PZ-90.02','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1158','PZ-90.11','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1160','Kyrg-06','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1165','ITRF2014','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6818','Systém Jednotnej trigonometrickej siete katastrálnej (Ferro)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1167','BGS2005','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1166','WGS 84 (Transit)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6710','ASTRO DOS 71/4','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1168','GDA2020','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1169','NZVD2016','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6710','St. Helena 1971','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1170','DHHN2016','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1170','Deutsches Haupthöhennetz 2016','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1171','POM96','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1172','POM08','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1174','SHGD2015','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1173','WGS 84 Tritan St. Helena','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1177','SHVD2015','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1180','ETRF91','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1178','ETRF89','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1178','EUREF89','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1179','ETRF90','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1181','ETRF92','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1182','ETRF93','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1183','ETRF94','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1184','ETRF96','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1185','ETRF97','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1186','ETRF2000','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1176','MSL Tritan','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1175','MSL 1971','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1176','St. Helena Tritan 2011','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1193','NAD83(CSRS)v2','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1187','ISN2016','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1190','ISH2004','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1190','Landshæðarkerfi Islands 2004','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6156','Systém Jednotnej trigonometrickej siete katastrálnej','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1196','NAD83(CSRS)v5','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1194','NAD83(CSRS)v3','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1197','NAD83(CSRS)v6','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1198','NAD83(CSRS)v7','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1193','NAD83(CSRS98)','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1199','GVR2000','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1200','GVR2016','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6152','Guam Geodetic Network 1993','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1201','S-JTSK [JTSK03]','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1201','Systém Jednotnej trigonometrickej siete katastrálnej [JTSK03]','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5111','AHD71','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1208','Macao 2008','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1204','ETRF2005','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1206','ETRF2014','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5111','AHD-TAS83','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6152','NAD83','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1211','NAD83(FBN)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1212','NAD83(HARN Corrected)','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1213','N43','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1214','STRS00','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1214','SRB_ETRS89','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5177','National Vertical Network 1999','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1215','SVS2010','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1036','RGM04','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1038','RGSPM06','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1216','SRB_VRS12','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6220','Camacupa','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1219','MVGC','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1218','MGD-2000','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1218','MTRF-2000','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1220','Rede Permanentes de Estaciones GNSS de Angola','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1220','RSAO13','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1220','REPANGOL','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1205','Zero Depth Point (ZDP)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1223','RGWF96','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1224','TWVD 2001','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1225','CR14','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1226','DACR52','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1230','SIRGAS-CON DGF02P01','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1227','SIRGAS-CON DGF00P01','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1227','SIRGAS Multi-Year Solution 2000','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1230','SIRGAS Multi-Year Solution 2002','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1239','SIRGAS-CON SIR13P01','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1239','SIRGAS Multi-Year Solution 2013','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1228','SIRGAS-CON DGF01P01','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1228','SIRGAS Multi-Year Solution 2001','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1231','SIRGAS-CON DGF04P01','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1231','SIRGAS Multi-Year Solution 2004','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1229','SIRGAS-CON DGF01P02','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1229','SIRGAS Multi-Year Solution 2001 extended','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1232','SIRGAS-CON DGF05P01','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1232','SIRGAS Multi-Year Solution 2005','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1240','SIRGAS-CON SIR14P01','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1240','SIRGAS Multi-Year Solution 2014','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1233','SIRGAS-CON DGF06P01','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1233','SIRGAS Multi-Year Solution 2006','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1234','SIRGAS-CON DGF07P01','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1234','SIRGAS Multi-Year Solution 2007','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1241','SIRGAS-CON SIR15P01','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1241','SIRGAS Multi-Year Solution 2015','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1235','SIRGAS-CON DGF08P01','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1039','NZVD2009','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1235','SIRGAS Multi-Year Solution 2008','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1236','SIRGAS-CON SIR09P01','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1236','SIRGAS Multi-Year Solution 2009','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1242','SIRGAS-CON SIR17P01','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1242','SIRGAS Multi-Year Solution 2017','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1237','SIRGAS-CON SIR10P01','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1237','SIRGAS Multi-Year Solution 2010','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1238','SIRGAS-CON SIR11P01','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1238','SIRGAS Multi-Year Solution 2011','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1035','REGCAN95','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6761','HTRS96','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1047','RRAF91','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1251','KOSOVAREF12','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6269','NAD83(Original)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1221','NAD83(MARP00)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1249','NAD83(PACP00)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1064','SIRGAS-Chile 2002','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1251','KOSOVAREF01','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1251','KOSOVAREF01 (2012)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1252','SIRGAS-Chile 2013','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1253','SIRGAS-Chile 2016','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1042','Red Geodesica Nacional 1992','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1046','Morro do Papagaio','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1046','Island of Principe datum','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1044','Fortaleza','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1044','Island of Sao Tome datum','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1041','PTRA08','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6301','Tokyo 1918','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1048','Tokyo 1898','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1054','SLVD','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1053','SLD99','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1057','TUREF','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1058','DRUKREF 03','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1056','GDBD2009','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6674','Sistema de Referencia Geocentrico para America del Sur 2000','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6818','S-JTSK (Ferro)','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1059','FVR09','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1052','S-JTSK/05','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1052','Systém Jednotné trigonometrické sítě katastrální/05','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1055','S-JTSK/05 (Ferro)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1055','Systém Jednotné trigonometrické sítě katastrální/05 (Ferro)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1060','ISN2004','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1061','ITRF2008','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6152','NAD83 (High Accuracy Regional Network)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1069','Red Geodésica Básica Nacional de El Salvador','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1067','Sistema Geodésico Nacional','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6309','ROU-USAMS','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1065','CR05','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1063','MARGEN','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1066','MACARIO SOLIS','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1073','RGAF09','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1062','POSGAR 2007','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1062','POSGAR','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1062','Posiciones Geodésicas Argentinas 2007','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1072','Balboa','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1072','Panamá-Colón 1911','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6225','Corrego Alegre','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1076','PNG94','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6674','SIRGAS2000','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5182','Deutsches Haupthöhennetz 1985','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5181','Deutsches Haupthöhennetz 1992','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1078','FEH10','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1079','FCSVR10','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1081','DB_REF','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5113','Sea Level','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1084','HHWLT','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1082','HAT','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1085','ISLW','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1085','Indian Tidal Plane','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1083','LLWLT','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1080','LAT','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1090','MHHW','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1092','MHW','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1088','MHWS','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1088','Spring High Water','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1089','MLLW','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1086','MLLWS','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1091','MLW','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1087','MLWS','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1087','Spring Low Water','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1093','Low tide','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1094','High Tide','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1095','TGD2005','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1098','LCVD61','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1099','CBVD61','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1097','GCVD54','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6723','GCGD59','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6726','SIGD61','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6726','Little Cayman Geodetic Datum 1961','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1100','CIGD11','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1096','NN2000','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','6723','Grand Cayman 1959','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','5110','Oostende','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1116','NAD83(2011)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1117','NAD83(PA11)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1118','NAD83(MA11)','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1042','Mexican Datum of 1993','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1120','Red Geodesica Nacional 2008','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1119','NMVD03','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1122','GUVD63','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1126','GUVD04','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1125','ASVD02','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1121','Tutuila62','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1124','VIVD09','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1123','PRVD02','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1127','CGVD2013','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1128','JGD2011','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1131','JGD2011 (vertical)','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1130','JGD2000 (vertical)','EPSG');
INSERT INTO "alias_name" VALUES('vertical_datum','EPSG','1129','JSLD72','EPSG');
INSERT INTO "alias_name" VALUES('geodetic_datum','EPSG','1132','RDN2008','EPSG');
