--- This file has been generated by scripts/build_db.py. DO NOT EDIT !

INSERT INTO "prime_meridian" VALUES('EPSG','8901','Greenwich',0.0,'EPSG','9102',0);
INSERT INTO "prime_meridian" VALUES('EPSG','8902','Lisbon',-9.0754862,'EPSG','9110',0);
INSERT INTO "prime_meridian" VALUES('EPSG','8903','Paris',2.5969213,'EPSG','9105',0);
INSERT INTO "prime_meridian" VALUES('EPSG','8904','Bogota',-74.04513,'EPSG','9110',0);
INSERT INTO "prime_meridian" VALUES('EPSG','8905','Madrid',-3.411658,'EPSG','9110',0);
INSERT INTO "prime_meridian" VALUES('EPSG','8906','Rome',12.27084,'EPSG','9110',0);
INSERT INTO "prime_meridian" VALUES('EPSG','8907','Bern',7.26225,'EPSG','9110',0);
INSERT INTO "prime_meridian" VALUES('EPSG','8908','Jakarta',106.482779,'EPSG','9110',0);
INSERT INTO "prime_meridian" VALUES('EPSG','8909','Ferro',-17.4,'EPSG','9110',0);
INSERT INTO "prime_meridian" VALUES('EPSG','8910','Brussels',4.220471,'EPSG','9110',0);
INSERT INTO "prime_meridian" VALUES('EPSG','8911','Stockholm',18.03298,'EPSG','9110',0);
INSERT INTO "prime_meridian" VALUES('EPSG','8912','Athens',23.4258815,'EPSG','9110',0);
INSERT INTO "prime_meridian" VALUES('EPSG','8913','Oslo',10.43225,'EPSG','9110',0);
INSERT INTO "prime_meridian" VALUES('EPSG','8914','Paris RGS',2.201395,'EPSG','9110',0);
