--- This file has been generated by scripts/build_db.py. DO NOT EDIT !

INSERT INTO "compound_crs" VALUES('EPSG','3901','KKJ / Finland Uniform Coordinate System + N60 height',NULL,NULL,'EPSG','2393','EPSG','5717','EPSG','3333',0);
INSERT INTO "compound_crs" VALUES('EPSG','3902','ETRS89 / TM35FIN(N,E) + N60 height',NULL,NULL,'EPSG','5048','EPSG','5717','EPSG','3333',0);
INSERT INTO "compound_crs" VALUES('EPSG','3903','ETRS89 / TM35FIN(N,E) + N2000 height',NULL,NULL,'EPSG','5048','EPSG','3900','EPSG','3333',0);
INSERT INTO "compound_crs" VALUES('EPSG','4097','ETRS89 / DKTM1 + DVR90 height',NULL,NULL,'EPSG','4093','EPSG','5799','EPSG','3631',0);
INSERT INTO "compound_crs" VALUES('EPSG','4098','ETRS89 / DKTM2 + DVR90 height',NULL,NULL,'EPSG','4094','EPSG','5799','EPSG','3632',0);
INSERT INTO "compound_crs" VALUES('EPSG','4099','ETRS89 / DKTM3 + DVR90 height',NULL,NULL,'EPSG','4095','EPSG','5799','EPSG','2532',0);
INSERT INTO "compound_crs" VALUES('EPSG','4100','ETRS89 / DKTM4 + DVR90 height',NULL,NULL,'EPSG','4096','EPSG','5799','EPSG','2533',0);
INSERT INTO "compound_crs" VALUES('EPSG','5318','ETRS89 / Faroe TM + FVR09 height',NULL,NULL,'EPSG','5316','EPSG','5317','EPSG','3248',0);
INSERT INTO "compound_crs" VALUES('EPSG','5498','NAD83 + NAVD88 height',NULL,NULL,'EPSG','4269','EPSG','5703','EPSG','3664',0);
INSERT INTO "compound_crs" VALUES('EPSG','5499','NAD83(HARN) + NAVD88 height',NULL,NULL,'EPSG','4152','EPSG','5703','EPSG','1323',0);
INSERT INTO "compound_crs" VALUES('EPSG','5500','NAD83(NSRS2007) + NAVD88 height',NULL,NULL,'EPSG','4759','EPSG','5703','EPSG','1323',0);
INSERT INTO "compound_crs" VALUES('EPSG','5554','ETRS89 / UTM zone 31N + DHHN92 height',NULL,NULL,'EPSG','25831','EPSG','5783','EPSG','3901',0);
INSERT INTO "compound_crs" VALUES('EPSG','5555','ETRS89 / UTM zone 32N + DHHN92 height',NULL,NULL,'EPSG','25832','EPSG','5783','EPSG','3904',0);
INSERT INTO "compound_crs" VALUES('EPSG','5556','ETRS89 / UTM zone 33N + DHHN92 height',NULL,NULL,'EPSG','25833','EPSG','5783','EPSG','3879',0);
INSERT INTO "compound_crs" VALUES('EPSG','5598','FEH2010 / Fehmarnbelt TM + FCSVR10 height',NULL,NULL,'EPSG','5596','EPSG','5597','EPSG','3890',0);
INSERT INTO "compound_crs" VALUES('EPSG','5628','SWEREF99 + RH2000 height',NULL,NULL,'EPSG','4619','EPSG','5613','EPSG','3313',0);
INSERT INTO "compound_crs" VALUES('EPSG','5698','RGF93 / Lambert-93 + NGF-IGN69 height',NULL,NULL,'EPSG','2154','EPSG','5720','EPSG','1326',0);
INSERT INTO "compound_crs" VALUES('EPSG','5699','RGF93 / Lambert-93 + NGF-IGN78 height',NULL,NULL,'EPSG','2154','EPSG','5721','EPSG','1327',0);
INSERT INTO "compound_crs" VALUES('EPSG','5707','NTF (Paris) / Lambert zone I + NGF-IGN69 height',NULL,NULL,'EPSG','27571','EPSG','5720','EPSG','1731',0);
INSERT INTO "compound_crs" VALUES('EPSG','5708','NTF (Paris) / Lambert zone IV + NGF-IGN78 height',NULL,NULL,'EPSG','27574','EPSG','5721','EPSG','1327',0);
INSERT INTO "compound_crs" VALUES('EPSG','5832','DB_REF / 3-degree Gauss-Kruger zone 2 (E-N) + DHHN92 height',NULL,NULL,'EPSG','5682','EPSG','5783','EPSG','1624',0);
INSERT INTO "compound_crs" VALUES('EPSG','5833','DB_REF / 3-degree Gauss-Kruger zone 3 (E-N) + DHHN92 height',NULL,NULL,'EPSG','5683','EPSG','5783','EPSG','3993',0);
INSERT INTO "compound_crs" VALUES('EPSG','5834','DB_REF / 3-degree Gauss-Kruger zone 4 (E-N) + DHHN92 height',NULL,NULL,'EPSG','5684','EPSG','5783','EPSG','3996',0);
INSERT INTO "compound_crs" VALUES('EPSG','5835','DB_REF / 3-degree Gauss-Kruger zone 5 (E-N) + DHHN92 height',NULL,NULL,'EPSG','5685','EPSG','5783','EPSG','3998',0);
INSERT INTO "compound_crs" VALUES('EPSG','5845','SWEREF99 TM + RH2000 height',NULL,NULL,'EPSG','3006','EPSG','5613','EPSG','3313',0);
INSERT INTO "compound_crs" VALUES('EPSG','5846','SWEREF99 12 00 + RH2000 height',NULL,NULL,'EPSG','3007','EPSG','5613','EPSG','2833',0);
INSERT INTO "compound_crs" VALUES('EPSG','5847','SWEREF99 13 30 + RH2000 height',NULL,NULL,'EPSG','3008','EPSG','5613','EPSG','2834',0);
INSERT INTO "compound_crs" VALUES('EPSG','5848','SWEREF99 15 00 + RH2000 height',NULL,NULL,'EPSG','3009','EPSG','5613','EPSG','2835',0);
INSERT INTO "compound_crs" VALUES('EPSG','5849','SWEREF99 16 30 + RH2000 height',NULL,NULL,'EPSG','3010','EPSG','5613','EPSG','2836',0);
INSERT INTO "compound_crs" VALUES('EPSG','5850','SWEREF99 18 00 + RH2000 height',NULL,NULL,'EPSG','3011','EPSG','5613','EPSG','2837',0);
INSERT INTO "compound_crs" VALUES('EPSG','5851','SWEREF99 14 15 + RH2000 height',NULL,NULL,'EPSG','3012','EPSG','5613','EPSG','2838',0);
INSERT INTO "compound_crs" VALUES('EPSG','5852','SWEREF99 15 45 + RH2000 height',NULL,NULL,'EPSG','3013','EPSG','5613','EPSG','2839',0);
INSERT INTO "compound_crs" VALUES('EPSG','5853','SWEREF99 17 15 + RH2000 height',NULL,NULL,'EPSG','3014','EPSG','5613','EPSG','2840',0);
INSERT INTO "compound_crs" VALUES('EPSG','5854','SWEREF99 18 45 + RH2000 height',NULL,NULL,'EPSG','3015','EPSG','5613','EPSG','2841',0);
INSERT INTO "compound_crs" VALUES('EPSG','5855','SWEREF99 20 15 + RH2000 height',NULL,NULL,'EPSG','3016','EPSG','5613','EPSG','2842',0);
INSERT INTO "compound_crs" VALUES('EPSG','5856','SWEREF99 21 45 + RH2000 height',NULL,NULL,'EPSG','3017','EPSG','5613','EPSG','2843',0);
INSERT INTO "compound_crs" VALUES('EPSG','5857','SWEREF99 23 15 + RH2000 height',NULL,NULL,'EPSG','3018','EPSG','5613','EPSG','2844',0);
INSERT INTO "compound_crs" VALUES('EPSG','5942','ETRS89 + NN2000 height',NULL,NULL,'EPSG','4258','EPSG','5941','EPSG','1352',0);
INSERT INTO "compound_crs" VALUES('EPSG','5945','ETRS89 / NTM zone 5 + NN2000 height',NULL,NULL,'EPSG','5105','EPSG','5941','EPSG','3636',0);
INSERT INTO "compound_crs" VALUES('EPSG','5946','ETRS89 / NTM zone 6 + NN2000 height',NULL,NULL,'EPSG','5106','EPSG','5941','EPSG','3639',0);
INSERT INTO "compound_crs" VALUES('EPSG','5947','ETRS89 / NTM zone 7 + NN2000 height',NULL,NULL,'EPSG','5107','EPSG','5941','EPSG','3647',0);
INSERT INTO "compound_crs" VALUES('EPSG','5948','ETRS89 / NTM zone 8 + NN2000 height',NULL,NULL,'EPSG','5108','EPSG','5941','EPSG','3648',0);
INSERT INTO "compound_crs" VALUES('EPSG','5949','ETRS89 / NTM zone 9 + NN2000 height',NULL,NULL,'EPSG','5109','EPSG','5941','EPSG','3649',0);
INSERT INTO "compound_crs" VALUES('EPSG','5950','ETRS89 / NTM zone 10 + NN2000 height',NULL,NULL,'EPSG','5110','EPSG','5941','EPSG','3650',0);
INSERT INTO "compound_crs" VALUES('EPSG','5951','ETRS89 / NTM zone 11 + NN2000 height',NULL,NULL,'EPSG','5111','EPSG','5941','EPSG','3651',0);
INSERT INTO "compound_crs" VALUES('EPSG','5952','ETRS89 / NTM zone 12 + NN2000 height',NULL,NULL,'EPSG','5112','EPSG','5941','EPSG','3653',0);
INSERT INTO "compound_crs" VALUES('EPSG','5953','ETRS89 / NTM zone 13 + NN2000 height',NULL,NULL,'EPSG','5113','EPSG','5941','EPSG','3654',0);
INSERT INTO "compound_crs" VALUES('EPSG','5954','ETRS89 / NTM zone 14 + NN2000 height',NULL,NULL,'EPSG','5114','EPSG','5941','EPSG','3655',0);
INSERT INTO "compound_crs" VALUES('EPSG','5955','ETRS89 / NTM zone 15 + NN2000 height',NULL,NULL,'EPSG','5115','EPSG','5941','EPSG','3656',0);
INSERT INTO "compound_crs" VALUES('EPSG','5956','ETRS89 / NTM zone 16 + NN2000 height',NULL,NULL,'EPSG','5116','EPSG','5941','EPSG','3657',0);
INSERT INTO "compound_crs" VALUES('EPSG','5957','ETRS89 / NTM zone 17 + NN2000 height',NULL,NULL,'EPSG','5117','EPSG','5941','EPSG','3658',0);
INSERT INTO "compound_crs" VALUES('EPSG','5958','ETRS89 / NTM zone 18 + NN2000 height',NULL,NULL,'EPSG','5118','EPSG','5941','EPSG','3660',0);
INSERT INTO "compound_crs" VALUES('EPSG','5959','ETRS89 / NTM zone 19 + NN2000 height',NULL,NULL,'EPSG','5119','EPSG','5941','EPSG','3661',0);
INSERT INTO "compound_crs" VALUES('EPSG','5960','ETRS89 / NTM zone 20 + NN2000 height',NULL,NULL,'EPSG','5120','EPSG','5941','EPSG','3662',0);
INSERT INTO "compound_crs" VALUES('EPSG','5961','ETRS89 / NTM zone 21 + NN2000 height',NULL,NULL,'EPSG','5121','EPSG','5941','EPSG','3663',0);
INSERT INTO "compound_crs" VALUES('EPSG','5962','ETRS89 / NTM zone 22 + NN2000 height',NULL,NULL,'EPSG','5122','EPSG','5941','EPSG','3665',0);
INSERT INTO "compound_crs" VALUES('EPSG','5963','ETRS89 / NTM zone 23 + NN2000 height',NULL,NULL,'EPSG','5123','EPSG','5941','EPSG','3667',0);
INSERT INTO "compound_crs" VALUES('EPSG','5964','ETRS89 / NTM zone 24 + NN2000 height',NULL,NULL,'EPSG','5124','EPSG','5941','EPSG','3668',0);
INSERT INTO "compound_crs" VALUES('EPSG','5965','ETRS89 / NTM zone 25 + NN2000 height',NULL,NULL,'EPSG','5125','EPSG','5941','EPSG','3669',0);
INSERT INTO "compound_crs" VALUES('EPSG','5966','ETRS89 / NTM zone 26 + NN2000 height',NULL,NULL,'EPSG','5126','EPSG','5941','EPSG','3671',0);
INSERT INTO "compound_crs" VALUES('EPSG','5967','ETRS89 / NTM zone 27 + NN2000 height',NULL,NULL,'EPSG','5127','EPSG','5941','EPSG','3672',0);
INSERT INTO "compound_crs" VALUES('EPSG','5968','ETRS89 / NTM zone 28 + NN2000 height',NULL,NULL,'EPSG','5128','EPSG','5941','EPSG','3673',0);
INSERT INTO "compound_crs" VALUES('EPSG','5969','ETRS89 / NTM zone 29 + NN2000 height',NULL,NULL,'EPSG','5129','EPSG','5941','EPSG','3674',0);
INSERT INTO "compound_crs" VALUES('EPSG','5970','ETRS89 / NTM zone 30 + NN2000 height',NULL,NULL,'EPSG','5130','EPSG','5941','EPSG','3676',0);
INSERT INTO "compound_crs" VALUES('EPSG','5971','ETRS89 / UTM zone 31 + NN2000 height',NULL,NULL,'EPSG','25831','EPSG','5941','EPSG','3636',0);
INSERT INTO "compound_crs" VALUES('EPSG','5972','ETRS89 / UTM zone 32 + NN2000 height',NULL,NULL,'EPSG','25832','EPSG','5941','EPSG','4066',0);
INSERT INTO "compound_crs" VALUES('EPSG','5973','ETRS89 / UTM zone 33 + NN2000 height',NULL,NULL,'EPSG','25833','EPSG','5941','EPSG','4067',0);
INSERT INTO "compound_crs" VALUES('EPSG','5974','ETRS89 / UTM zone 34 + NN2000 height',NULL,NULL,'EPSG','25834','EPSG','5941','EPSG','4068',0);
INSERT INTO "compound_crs" VALUES('EPSG','5975','ETRS89 / UTM zone 35 + NN2000 height',NULL,NULL,'EPSG','25835','EPSG','5941','EPSG','4069',0);
INSERT INTO "compound_crs" VALUES('EPSG','5976','ETRS89 / UTM zone 36 + NN2000 height',NULL,NULL,'EPSG','25836','EPSG','5941','EPSG','3676',0);
INSERT INTO "compound_crs" VALUES('EPSG','6144','ETRS89 + NN54 height',NULL,NULL,'EPSG','4258','EPSG','5776','EPSG','1352',0);
INSERT INTO "compound_crs" VALUES('EPSG','6145','ETRS89 / NTM zone 5 + NN54 height',NULL,NULL,'EPSG','5105','EPSG','5776','EPSG','3636',0);
INSERT INTO "compound_crs" VALUES('EPSG','6146','ETRS89 / NTM zone 6 + NN54 height',NULL,NULL,'EPSG','5106','EPSG','5776','EPSG','3639',0);
INSERT INTO "compound_crs" VALUES('EPSG','6147','ETRS89 / NTM zone 7 + NN54 height',NULL,NULL,'EPSG','5107','EPSG','5776','EPSG','3647',0);
INSERT INTO "compound_crs" VALUES('EPSG','6148','ETRS89 / NTM zone 8 + NN54 height',NULL,NULL,'EPSG','5108','EPSG','5776','EPSG','3648',0);
INSERT INTO "compound_crs" VALUES('EPSG','6149','ETRS89 / NTM zone 9 + NN54 height',NULL,NULL,'EPSG','5109','EPSG','5776','EPSG','3649',0);
INSERT INTO "compound_crs" VALUES('EPSG','6150','ETRS89 / NTM zone 10 + NN54 height',NULL,NULL,'EPSG','5110','EPSG','5776','EPSG','3650',0);
INSERT INTO "compound_crs" VALUES('EPSG','6151','ETRS89 / NTM zone 11 + NN54 height',NULL,NULL,'EPSG','5111','EPSG','5776','EPSG','3651',0);
INSERT INTO "compound_crs" VALUES('EPSG','6152','ETRS89 / NTM zone 12 + NN54 height',NULL,NULL,'EPSG','5112','EPSG','5776','EPSG','3653',0);
INSERT INTO "compound_crs" VALUES('EPSG','6153','ETRS89 / NTM zone 13 + NN54 height',NULL,NULL,'EPSG','5113','EPSG','5776','EPSG','3654',0);
INSERT INTO "compound_crs" VALUES('EPSG','6154','ETRS89 / NTM zone 14 + NN54 height',NULL,NULL,'EPSG','5114','EPSG','5776','EPSG','3655',0);
INSERT INTO "compound_crs" VALUES('EPSG','6155','ETRS89 / NTM zone 15 + NN54 height',NULL,NULL,'EPSG','5115','EPSG','5776','EPSG','3656',0);
INSERT INTO "compound_crs" VALUES('EPSG','6156','ETRS89 / NTM zone 16 + NN54 height',NULL,NULL,'EPSG','5116','EPSG','5776','EPSG','3657',0);
INSERT INTO "compound_crs" VALUES('EPSG','6157','ETRS89 / NTM zone 17 + NN54 height',NULL,NULL,'EPSG','5117','EPSG','5776','EPSG','3658',0);
INSERT INTO "compound_crs" VALUES('EPSG','6158','ETRS89 / NTM zone 18 + NN54 height',NULL,NULL,'EPSG','5118','EPSG','5776','EPSG','3660',0);
INSERT INTO "compound_crs" VALUES('EPSG','6159','ETRS89 / NTM zone 19 + NN54 height',NULL,NULL,'EPSG','5119','EPSG','5776','EPSG','3661',0);
INSERT INTO "compound_crs" VALUES('EPSG','6160','ETRS89 / NTM zone 20 + NN54 height',NULL,NULL,'EPSG','5120','EPSG','5776','EPSG','3662',0);
INSERT INTO "compound_crs" VALUES('EPSG','6161','ETRS89 / NTM zone 21 + NN54 height',NULL,NULL,'EPSG','5121','EPSG','5776','EPSG','3663',0);
INSERT INTO "compound_crs" VALUES('EPSG','6162','ETRS89 / NTM zone 22 + NN54 height',NULL,NULL,'EPSG','5122','EPSG','5776','EPSG','3665',0);
INSERT INTO "compound_crs" VALUES('EPSG','6163','ETRS89 / NTM zone 23 + NN54 height',NULL,NULL,'EPSG','5123','EPSG','5776','EPSG','3667',0);
INSERT INTO "compound_crs" VALUES('EPSG','6164','ETRS89 / NTM zone 24 + NN54 height',NULL,NULL,'EPSG','5124','EPSG','5776','EPSG','3668',0);
INSERT INTO "compound_crs" VALUES('EPSG','6165','ETRS89 / NTM zone 25 + NN54 height',NULL,NULL,'EPSG','5125','EPSG','5776','EPSG','3669',0);
INSERT INTO "compound_crs" VALUES('EPSG','6166','ETRS89 / NTM zone 26 + NN54 height',NULL,NULL,'EPSG','5126','EPSG','5776','EPSG','3671',0);
INSERT INTO "compound_crs" VALUES('EPSG','6167','ETRS89 / NTM zone 27 + NN54 height',NULL,NULL,'EPSG','5127','EPSG','5776','EPSG','3672',0);
INSERT INTO "compound_crs" VALUES('EPSG','6168','ETRS89 / NTM zone 28 + NN54 height',NULL,NULL,'EPSG','5128','EPSG','5776','EPSG','3673',0);
INSERT INTO "compound_crs" VALUES('EPSG','6169','ETRS89 / NTM zone 29 + NN54 height',NULL,NULL,'EPSG','5129','EPSG','5776','EPSG','3674',0);
INSERT INTO "compound_crs" VALUES('EPSG','6170','ETRS89 / NTM zone 30 + NN54 height',NULL,NULL,'EPSG','5130','EPSG','5776','EPSG','3676',0);
INSERT INTO "compound_crs" VALUES('EPSG','6171','ETRS89 / UTM zone 31 + NN54 height',NULL,NULL,'EPSG','25831','EPSG','5776','EPSG','3636',0);
INSERT INTO "compound_crs" VALUES('EPSG','6172','ETRS89 / UTM zone 32 + NN54 height',NULL,NULL,'EPSG','25832','EPSG','5776','EPSG','4066',0);
INSERT INTO "compound_crs" VALUES('EPSG','6173','ETRS89 / UTM zone 33 + NN54 height',NULL,NULL,'EPSG','25833','EPSG','5776','EPSG','4067',0);
INSERT INTO "compound_crs" VALUES('EPSG','6174','ETRS89 / UTM zone 34 + NN54 height',NULL,NULL,'EPSG','25834','EPSG','5776','EPSG','4068',0);
INSERT INTO "compound_crs" VALUES('EPSG','6175','ETRS89 / UTM zone 35 + NN54 height',NULL,NULL,'EPSG','25835','EPSG','5776','EPSG','4069',0);
INSERT INTO "compound_crs" VALUES('EPSG','6176','ETRS89 / UTM zone 36 + NN54 height',NULL,NULL,'EPSG','25836','EPSG','5776','EPSG','3676',0);
INSERT INTO "compound_crs" VALUES('EPSG','6190','Belge 1972 / Belgian Lambert 72 + Ostend height',NULL,NULL,'EPSG','31370','EPSG','5710','EPSG','1347',0);
INSERT INTO "compound_crs" VALUES('EPSG','6349','NAD83(2011) + NAVD88 height',NULL,NULL,'EPSG','6318','EPSG','5703','EPSG','3664',0);
INSERT INTO "compound_crs" VALUES('EPSG','6649','NAD83(CSRS) + CGVD2013 height',NULL,NULL,'EPSG','4617','EPSG','6647','EPSG','1061',0);
INSERT INTO "compound_crs" VALUES('EPSG','6650','NAD83(CSRS) / UTM zone 7N + CGVD2013 height',NULL,NULL,'EPSG','3154','EPSG','6647','EPSG','3409',0);
INSERT INTO "compound_crs" VALUES('EPSG','6651','NAD83(CSRS) / UTM zone 8N + CGVD2013 height',NULL,NULL,'EPSG','3155','EPSG','6647','EPSG','3410',0);
INSERT INTO "compound_crs" VALUES('EPSG','6652','NAD83(CSRS) / UTM zone 9N + CGVD2013 height',NULL,NULL,'EPSG','3156','EPSG','6647','EPSG','3411',0);
INSERT INTO "compound_crs" VALUES('EPSG','6653','NAD83(CSRS) / UTM zone 10N + CGVD2013 height',NULL,NULL,'EPSG','3157','EPSG','6647','EPSG','3412',0);
INSERT INTO "compound_crs" VALUES('EPSG','6654','NAD83(CSRS) / UTM zone 11N + CGVD2013 height',NULL,NULL,'EPSG','2955','EPSG','6647','EPSG','3528',0);
INSERT INTO "compound_crs" VALUES('EPSG','6655','NAD83(CSRS) / UTM zone 12N + CGVD2013 height',NULL,NULL,'EPSG','2956','EPSG','6647','EPSG','3527',0);
INSERT INTO "compound_crs" VALUES('EPSG','6656','NAD83(CSRS) / UTM zone 13N + CGVD2013 height',NULL,NULL,'EPSG','2957','EPSG','6647','EPSG','3526',0);
INSERT INTO "compound_crs" VALUES('EPSG','6657','NAD83(CSRS) / UTM zone 14N + CGVD2013 height',NULL,NULL,'EPSG','3158','EPSG','6647','EPSG','3413',0);
INSERT INTO "compound_crs" VALUES('EPSG','6658','NAD83(CSRS) / UTM zone 15N + CGVD2013 height',NULL,NULL,'EPSG','3159','EPSG','6647','EPSG','3414',0);
INSERT INTO "compound_crs" VALUES('EPSG','6659','NAD83(CSRS) / UTM zone 16N + CGVD2013 height',NULL,NULL,'EPSG','3160','EPSG','6647','EPSG','3415',0);
INSERT INTO "compound_crs" VALUES('EPSG','6660','NAD83(CSRS) / UTM zone 17N + CGVD2013 height',NULL,NULL,'EPSG','2958','EPSG','6647','EPSG','3416',0);
INSERT INTO "compound_crs" VALUES('EPSG','6661','NAD83(CSRS) / UTM zone 18N + CGVD2013 height',NULL,NULL,'EPSG','2959','EPSG','6647','EPSG','3417',0);
INSERT INTO "compound_crs" VALUES('EPSG','6662','NAD83(CSRS) / UTM zone 19N + CGVD2013 height',NULL,NULL,'EPSG','2960','EPSG','6647','EPSG','3524',0);
INSERT INTO "compound_crs" VALUES('EPSG','6663','NAD83(CSRS) / UTM zone 20N + CGVD2013 height',NULL,NULL,'EPSG','2961','EPSG','6647','EPSG','3525',0);
INSERT INTO "compound_crs" VALUES('EPSG','6664','NAD83(CSRS) / UTM zone 21N + CGVD2013 height',NULL,NULL,'EPSG','2962','EPSG','6647','EPSG','2151',0);
INSERT INTO "compound_crs" VALUES('EPSG','6665','NAD83(CSRS) / UTM zone 22N + CGVD2013 height',NULL,NULL,'EPSG','3761','EPSG','6647','EPSG','2152',0);
INSERT INTO "compound_crs" VALUES('EPSG','6696','JGD2000 + JGD2000 (vertical) height',NULL,NULL,'EPSG','4612','EPSG','6694','EPSG','3263',0);
INSERT INTO "compound_crs" VALUES('EPSG','6697','JGD2011 + JGD2011 (vertical) height',NULL,NULL,'EPSG','6668','EPSG','6695','EPSG','3263',0);
INSERT INTO "compound_crs" VALUES('EPSG','6700','Tokyo + JSLD72 height',NULL,NULL,'EPSG','4301','EPSG','6693','EPSG','4168',0);
INSERT INTO "compound_crs" VALUES('EPSG','6871','WGS 84 / Pseudo-Mercator +  EGM2008 geoid height',NULL,NULL,'EPSG','3857','EPSG','3855','EPSG','1262',1);
INSERT INTO "compound_crs" VALUES('EPSG','6893','WGS 84 / World Mercator +  EGM2008 height',NULL,NULL,'EPSG','3395','EPSG','3855','EPSG','1262',0);
INSERT INTO "compound_crs" VALUES('EPSG','6917','SVY21 + SHD height',NULL,NULL,'EPSG','4757','EPSG','6916','EPSG','1210',0);
INSERT INTO "compound_crs" VALUES('EPSG','6927','SVY21 / Singapore TM + SHD height',NULL,NULL,'EPSG','3414','EPSG','6916','EPSG','1210',0);
INSERT INTO "compound_crs" VALUES('EPSG','7400','NTF (Paris) + NGF IGN69 height',NULL,NULL,'EPSG','4807','EPSG','5720','EPSG','1326',0);
INSERT INTO "compound_crs" VALUES('EPSG','7401','NTF (Paris) / France II + NGF Lallemand',NULL,NULL,'EPSG','27582','EPSG','5719','EPSG','1326',1);
INSERT INTO "compound_crs" VALUES('EPSG','7402','NTF (Paris) / France II + NGF IGN69',NULL,NULL,'EPSG','27582','EPSG','5720','EPSG','1326',1);
INSERT INTO "compound_crs" VALUES('EPSG','7403','NTF (Paris) / France III + NGF IGN69',NULL,NULL,'EPSG','27583','EPSG','5720','EPSG','1733',1);
INSERT INTO "compound_crs" VALUES('EPSG','7404','RT90 + RH70 height',NULL,NULL,'EPSG','4124','EPSG','5718','EPSG','3313',0);
INSERT INTO "compound_crs" VALUES('EPSG','7405','OSGB 1936 / British National Grid + ODN height',NULL,NULL,'EPSG','27700','EPSG','5701','EPSG','2792',0);
INSERT INTO "compound_crs" VALUES('EPSG','7406','NAD27 + NGVD29 height (ftUS)',NULL,NULL,'EPSG','4267','EPSG','5702','EPSG','1323',0);
INSERT INTO "compound_crs" VALUES('EPSG','7407','NAD27 / Texas North + NGVD29 height (ftUS)',NULL,NULL,'EPSG','32037','EPSG','5702','EPSG','2253',0);
INSERT INTO "compound_crs" VALUES('EPSG','7408','RD/NAP',NULL,NULL,'EPSG','4289','EPSG','5709','EPSG','1275',1);
INSERT INTO "compound_crs" VALUES('EPSG','7409','ETRS89 + EVRF2000 height',NULL,NULL,'EPSG','4258','EPSG','5730','EPSG','1299',0);
INSERT INTO "compound_crs" VALUES('EPSG','7410','PSHD93',NULL,NULL,'EPSG','4134','EPSG','5724','EPSG','3288',0);
INSERT INTO "compound_crs" VALUES('EPSG','7411','NTF (Paris) / Lambert zone II + NGF Lallemand height',NULL,NULL,'EPSG','27572','EPSG','5719','EPSG','1326',0);
INSERT INTO "compound_crs" VALUES('EPSG','7412','NTF (Paris) / Lambert zone II + NGF IGN69',NULL,NULL,'EPSG','27572','EPSG','5719','EPSG','1326',1);
INSERT INTO "compound_crs" VALUES('EPSG','7413','NTF (Paris) / Lambert zone III + NGF IGN69',NULL,NULL,'EPSG','27573','EPSG','5719','EPSG','1733',1);
INSERT INTO "compound_crs" VALUES('EPSG','7414','Tokyo + JSLD69 height',NULL,NULL,'EPSG','4301','EPSG','5723','EPSG','4166',0);
INSERT INTO "compound_crs" VALUES('EPSG','7415','Amersfoort / RD New + NAP height',NULL,NULL,'EPSG','28992','EPSG','5709','EPSG','1275',0);
INSERT INTO "compound_crs" VALUES('EPSG','7416','ETRS89 / UTM zone 32N + DVR90 height',NULL,NULL,'EPSG','25832','EPSG','5799','EPSG','3471',0);
INSERT INTO "compound_crs" VALUES('EPSG','7417','ETRS89 / UTM zone 33N + DVR90 height',NULL,NULL,'EPSG','25833','EPSG','5799','EPSG','3472',0);
INSERT INTO "compound_crs" VALUES('EPSG','7418','ETRS89 / Kp2000 Jutland + DVR90 height',NULL,NULL,'EPSG','2196','EPSG','5799','EPSG','2531',0);
INSERT INTO "compound_crs" VALUES('EPSG','7419','ETRS89 / Kp2000 Zealand + DVR90 height',NULL,NULL,'EPSG','2197','EPSG','5799','EPSG','2532',0);
INSERT INTO "compound_crs" VALUES('EPSG','7420','ETRS89 / Kp2000 Bornholm + DVR90 height',NULL,NULL,'EPSG','2198','EPSG','5799','EPSG','2533',0);
INSERT INTO "compound_crs" VALUES('EPSG','7421','NTF (Paris) / Lambert zone II + NGF-IGN69 height',NULL,NULL,'EPSG','27572','EPSG','5720','EPSG','1326',0);
INSERT INTO "compound_crs" VALUES('EPSG','7422','NTF (Paris) / Lambert zone III + NGF-IGN69 height',NULL,NULL,'EPSG','27573','EPSG','5720','EPSG','1733',0);
INSERT INTO "compound_crs" VALUES('EPSG','7423','ETRS89 + EVRF2007 height',NULL,NULL,'EPSG','4258','EPSG','5621','EPSG','3594',0);
INSERT INTO "compound_crs" VALUES('EPSG','7954','Astro DOS 71 / UTM zone 30S + Jamestown 1971 height',NULL,NULL,'EPSG','7878','EPSG','7888','EPSG','3183',0);
INSERT INTO "compound_crs" VALUES('EPSG','7955','St. Helena Tritan / UTM zone 30S +  Tritan 2011 height',NULL,NULL,'EPSG','7883','EPSG','7889','EPSG','3183',0);
INSERT INTO "compound_crs" VALUES('EPSG','7956','SHMG2015 +  SHVD2015 height',NULL,NULL,'EPSG','7887','EPSG','7890','EPSG','3183',0);
INSERT INTO "compound_crs" VALUES('EPSG','8349','GR96 + GVR2000 height',NULL,NULL,'EPSG','4747','EPSG','8266','EPSG','4461',0);
INSERT INTO "compound_crs" VALUES('EPSG','8350','GR96 + GVR2016 height',NULL,NULL,'EPSG','4747','EPSG','8267','EPSG','4454',0);
INSERT INTO "compound_crs" VALUES('EPSG','8360','ETRS89 + Baltic 1957 height',NULL,NULL,'EPSG','4258','EPSG','8357','EPSG','1306',0);
INSERT INTO "compound_crs" VALUES('EPSG','8370','ETRS89 / Belgian Lambert 2008 + Ostend height',NULL,NULL,'EPSG','3812','EPSG','5710','EPSG','1347',0);
INSERT INTO "compound_crs" VALUES('EPSG','8700','NAD83 / Arizona East (ft) + NAVD88 height (ft)',NULL,NULL,'EPSG','2222','EPSG','8228','EPSG','2167',0);
INSERT INTO "compound_crs" VALUES('EPSG','8701','NAD83 / Arizona Central (ft) + NAVD88 height (ft)',NULL,NULL,'EPSG','2223','EPSG','8228','EPSG','2166',0);
INSERT INTO "compound_crs" VALUES('EPSG','8702','NAD83 / Arizona West (ft) + NAVD88 height (ft)',NULL,NULL,'EPSG','2224','EPSG','8228','EPSG','2168',0);
INSERT INTO "compound_crs" VALUES('EPSG','8703','NAD83 / Michigan North (ft) + NAVD88 height (ft)',NULL,NULL,'EPSG','2251','EPSG','8228','EPSG','1723',0);
INSERT INTO "compound_crs" VALUES('EPSG','8704','NAD83 / Michigan Central (ft) + NAVD88 height (ft)',NULL,NULL,'EPSG','2252','EPSG','8228','EPSG','1724',0);
INSERT INTO "compound_crs" VALUES('EPSG','8705','NAD83 / Michigan South (ft) + NAVD88 height (ft)',NULL,NULL,'EPSG','2253','EPSG','8228','EPSG','1725',0);
INSERT INTO "compound_crs" VALUES('EPSG','8706','NAD83 / Montana (ft) + NAVD88 height (ft)',NULL,NULL,'EPSG','2256','EPSG','8228','EPSG','1395',0);
INSERT INTO "compound_crs" VALUES('EPSG','8707','NAD83 / North Dakota North (ft) + NAVD88 height (ft)',NULL,NULL,'EPSG','2265','EPSG','8228','EPSG','2237',0);
INSERT INTO "compound_crs" VALUES('EPSG','8708','NAD83 / North Dakota South (ft) + NAVD88 height (ft)',NULL,NULL,'EPSG','2266','EPSG','8228','EPSG','2238',0);
INSERT INTO "compound_crs" VALUES('EPSG','8709','NAD83 / Oregon North (ft) + NAVD88 height (ft)',NULL,NULL,'EPSG','2269','EPSG','8228','EPSG','2243',0);
INSERT INTO "compound_crs" VALUES('EPSG','8710','NAD83 / Oregon South (ft) + NAVD88 height (ft)',NULL,NULL,'EPSG','2270','EPSG','8228','EPSG','2244',0);
INSERT INTO "compound_crs" VALUES('EPSG','8711','NAD83 / South Carolina (ft) + NAVD88 height (ft)',NULL,NULL,'EPSG','2273','EPSG','8228','EPSG','1409',0);
INSERT INTO "compound_crs" VALUES('EPSG','8712','NAD83 / Arkansas North (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3433','EPSG','6360','EPSG','2169',0);
INSERT INTO "compound_crs" VALUES('EPSG','8713','NAD83 / Arkansas South (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3434','EPSG','6360','EPSG','2170',0);
INSERT INTO "compound_crs" VALUES('EPSG','8714','NAD83 / California zone 1 (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2225','EPSG','6360','EPSG','2175',0);
INSERT INTO "compound_crs" VALUES('EPSG','8715','NAD83 / California zone 2 (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2226','EPSG','6360','EPSG','2176',0);
INSERT INTO "compound_crs" VALUES('EPSG','8716','NAD83 / California zone 3 (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2227','EPSG','6360','EPSG','2177',0);
INSERT INTO "compound_crs" VALUES('EPSG','8717','NAD83 / California zone 4 (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2228','EPSG','6360','EPSG','2178',0);
INSERT INTO "compound_crs" VALUES('EPSG','8718','NAD83 / California zone 5 (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2229','EPSG','6360','EPSG','2182',0);
INSERT INTO "compound_crs" VALUES('EPSG','8719','NAD83 / California zone 6 (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2230','EPSG','6360','EPSG','2180',0);
INSERT INTO "compound_crs" VALUES('EPSG','8720','NAD83 / Colorado North (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2231','EPSG','6360','EPSG','2184',0);
INSERT INTO "compound_crs" VALUES('EPSG','8721','NAD83 / Colorado Central (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2232','EPSG','6360','EPSG','2183',0);
INSERT INTO "compound_crs" VALUES('EPSG','8722','NAD83 / Colorado South (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2233','EPSG','6360','EPSG','2185',0);
INSERT INTO "compound_crs" VALUES('EPSG','8723','NAD83 / Connecticut (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2234','EPSG','6360','EPSG','1377',0);
INSERT INTO "compound_crs" VALUES('EPSG','8724','NAD83 / Delaware (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2235','EPSG','6360','EPSG','1378',0);
INSERT INTO "compound_crs" VALUES('EPSG','8725','NAD83 / Florida North (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2238','EPSG','6360','EPSG','2187',0);
INSERT INTO "compound_crs" VALUES('EPSG','8726','NAD83 / Florida East (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2236','EPSG','6360','EPSG','2186',0);
INSERT INTO "compound_crs" VALUES('EPSG','8727','NAD83 / Florida West (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2237','EPSG','6360','EPSG','2188',0);
INSERT INTO "compound_crs" VALUES('EPSG','8728','NAD83 / Georgia East (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2239','EPSG','6360','EPSG','2189',0);
INSERT INTO "compound_crs" VALUES('EPSG','8729','NAD83 / Georgia West (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2240','EPSG','6360','EPSG','2190',0);
INSERT INTO "compound_crs" VALUES('EPSG','8730','NAD83 / Idaho East (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2241','EPSG','6360','EPSG','2192',0);
INSERT INTO "compound_crs" VALUES('EPSG','8731','NAD83 / Idaho Central (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2242','EPSG','6360','EPSG','2191',0);
INSERT INTO "compound_crs" VALUES('EPSG','8732','NAD83 / Idaho West (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2243','EPSG','6360','EPSG','2193',0);
INSERT INTO "compound_crs" VALUES('EPSG','8733','NAD83 / Illinois East (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3435','EPSG','6360','EPSG','2194',0);
INSERT INTO "compound_crs" VALUES('EPSG','8734','NAD83 / Illinois West (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3436','EPSG','6360','EPSG','2195',0);
INSERT INTO "compound_crs" VALUES('EPSG','8735','NAD83 / Indiana East (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2965','EPSG','6360','EPSG','2196',0);
INSERT INTO "compound_crs" VALUES('EPSG','8736','NAD83 / Indiana West (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2966','EPSG','6360','EPSG','2197',0);
INSERT INTO "compound_crs" VALUES('EPSG','8737','NAD83 / Iowa North (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3417','EPSG','6360','EPSG','2198',0);
INSERT INTO "compound_crs" VALUES('EPSG','8738','NAD83 / Iowa South (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3418','EPSG','6360','EPSG','2199',0);
INSERT INTO "compound_crs" VALUES('EPSG','8739','NAD83 / Kansas North (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3419','EPSG','6360','EPSG','2200',0);
INSERT INTO "compound_crs" VALUES('EPSG','8740','NAD83 / Kansas South (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3420','EPSG','6360','EPSG','2201',0);
INSERT INTO "compound_crs" VALUES('EPSG','8741','NAD83 / Kentucky North (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2246','EPSG','6360','EPSG','2202',0);
INSERT INTO "compound_crs" VALUES('EPSG','8742','NAD83 / Kentucky South (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2247','EPSG','6360','EPSG','2203',0);
INSERT INTO "compound_crs" VALUES('EPSG','8743','NAD83 / Louisiana North (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3451','EPSG','6360','EPSG','2204',0);
INSERT INTO "compound_crs" VALUES('EPSG','8744','NAD83 / Louisiana South (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3452','EPSG','6360','EPSG','2529',0);
INSERT INTO "compound_crs" VALUES('EPSG','8745','NAD83 / Maine East (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','26847','EPSG','6360','EPSG','2206',0);
INSERT INTO "compound_crs" VALUES('EPSG','8746','NAD83 / Maine West (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','26848','EPSG','6360','EPSG','2207',0);
INSERT INTO "compound_crs" VALUES('EPSG','8747','NAD83 / Maryland (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2248','EPSG','6360','EPSG','1389',0);
INSERT INTO "compound_crs" VALUES('EPSG','8748','NAD83 / Massachusetts Mainland (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2249','EPSG','6360','EPSG','2209',0);
INSERT INTO "compound_crs" VALUES('EPSG','8749','NAD83 / Massachusetts Island (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2250','EPSG','6360','EPSG','2208',0);
INSERT INTO "compound_crs" VALUES('EPSG','8750','NAD83 / Minnesota North (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','26849','EPSG','6360','EPSG','2214',0);
INSERT INTO "compound_crs" VALUES('EPSG','8751','NAD83 / Minnesota Central (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','26850','EPSG','6360','EPSG','2213',0);
INSERT INTO "compound_crs" VALUES('EPSG','8752','NAD83 / Minnesota South (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','26851','EPSG','6360','EPSG','2215',0);
INSERT INTO "compound_crs" VALUES('EPSG','8753','NAD83 / Mississippi East (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2254','EPSG','6360','EPSG','2216',0);
INSERT INTO "compound_crs" VALUES('EPSG','8754','NAD83 / Mississippi West (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2255','EPSG','6360','EPSG','2217',0);
INSERT INTO "compound_crs" VALUES('EPSG','8755','NAD83 / Nebraska (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','26852','EPSG','6360','EPSG','1396',0);
INSERT INTO "compound_crs" VALUES('EPSG','8756','NAD83 / Nevada East (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3421','EPSG','6360','EPSG','2224',0);
INSERT INTO "compound_crs" VALUES('EPSG','8757','NAD83 / Nevada Central (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3422','EPSG','6360','EPSG','2223',0);
INSERT INTO "compound_crs" VALUES('EPSG','8758','NAD83 / Nevada West (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3423','EPSG','6360','EPSG','2225',0);
INSERT INTO "compound_crs" VALUES('EPSG','8759','NAD83 / New Hampshire (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3437','EPSG','6360','EPSG','1398',0);
INSERT INTO "compound_crs" VALUES('EPSG','8760','NAD83 / New Jersey (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3424','EPSG','6360','EPSG','1399',0);
INSERT INTO "compound_crs" VALUES('EPSG','8761','NAD83 / New Mexico East (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2257','EPSG','6360','EPSG','2228',0);
INSERT INTO "compound_crs" VALUES('EPSG','8762','NAD83 / New Mexico Central (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2258','EPSG','6360','EPSG','2231',0);
INSERT INTO "compound_crs" VALUES('EPSG','8763','NAD83 / New Mexico West (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2259','EPSG','6360','EPSG','2232',0);
INSERT INTO "compound_crs" VALUES('EPSG','8764','NAD83 / New York East (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2260','EPSG','6360','EPSG','2234',0);
INSERT INTO "compound_crs" VALUES('EPSG','8765','NAD83 / New York Central (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2261','EPSG','6360','EPSG','2233',0);
INSERT INTO "compound_crs" VALUES('EPSG','8766','NAD83 / New York West (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2262','EPSG','6360','EPSG','2236',0);
INSERT INTO "compound_crs" VALUES('EPSG','8767','NAD83 / New York Long Island (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2263','EPSG','6360','EPSG','2235',0);
INSERT INTO "compound_crs" VALUES('EPSG','8768','NAD83 / North Carolina (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2264','EPSG','6360','EPSG','1402',0);
INSERT INTO "compound_crs" VALUES('EPSG','8769','NAD83 / Ohio North (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3734','EPSG','6360','EPSG','2239',0);
INSERT INTO "compound_crs" VALUES('EPSG','8770','NAD83 / Ohio South (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3735','EPSG','6360','EPSG','2240',0);
INSERT INTO "compound_crs" VALUES('EPSG','8771','NAD83 / Oklahoma North (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2267','EPSG','6360','EPSG','2241',0);
INSERT INTO "compound_crs" VALUES('EPSG','8772','NAD83 / Oklahoma South (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2268','EPSG','6360','EPSG','2242',0);
INSERT INTO "compound_crs" VALUES('EPSG','8773','NAD83 / Pennsylvania North (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2271','EPSG','6360','EPSG','2245',0);
INSERT INTO "compound_crs" VALUES('EPSG','8774','NAD83 / Pennsylvania South (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2272','EPSG','6360','EPSG','2246',0);
INSERT INTO "compound_crs" VALUES('EPSG','8775','NAD83 / Rhode Island (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3438','EPSG','6360','EPSG','1408',0);
INSERT INTO "compound_crs" VALUES('EPSG','8776','NAD83 / South Dakota North (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','4457','EPSG','6360','EPSG','2249',0);
INSERT INTO "compound_crs" VALUES('EPSG','8777','NAD83 / South Dakota South (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3455','EPSG','6360','EPSG','2250',0);
INSERT INTO "compound_crs" VALUES('EPSG','8778','NAD83 / Tennessee (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2274','EPSG','6360','EPSG','1411',0);
INSERT INTO "compound_crs" VALUES('EPSG','8779','NAD83 / Texas North (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2275','EPSG','6360','EPSG','2253',0);
INSERT INTO "compound_crs" VALUES('EPSG','8780','NAD83 / Texas North Central (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2276','EPSG','6360','EPSG','2254',0);
INSERT INTO "compound_crs" VALUES('EPSG','8781','NAD83 / Texas Central (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2277','EPSG','6360','EPSG','2252',0);
INSERT INTO "compound_crs" VALUES('EPSG','8782','NAD83 / Texas South Central (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2278','EPSG','6360','EPSG','2527',0);
INSERT INTO "compound_crs" VALUES('EPSG','8783','NAD83 / Texas South (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2279','EPSG','6360','EPSG','2528',0);
INSERT INTO "compound_crs" VALUES('EPSG','8784','NAD83 / Utah North (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3560','EPSG','6360','EPSG','2258',0);
INSERT INTO "compound_crs" VALUES('EPSG','8785','NAD83 / Utah Central (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3566','EPSG','6360','EPSG','2257',0);
INSERT INTO "compound_crs" VALUES('EPSG','8786','NAD83 / Utah South (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3567','EPSG','6360','EPSG','2259',0);
INSERT INTO "compound_crs" VALUES('EPSG','8787','NAD83 / Vermont (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','5646','EPSG','6360','EPSG','1414',0);
INSERT INTO "compound_crs" VALUES('EPSG','8788','NAD83 / Virginia North (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2283','EPSG','6360','EPSG','2260',0);
INSERT INTO "compound_crs" VALUES('EPSG','8789','NAD83 / Virginia South (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2284','EPSG','6360','EPSG','2261',0);
INSERT INTO "compound_crs" VALUES('EPSG','8790','NAD83 / Washington North (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2285','EPSG','6360','EPSG','2273',0);
INSERT INTO "compound_crs" VALUES('EPSG','8791','NAD83 / Washington South (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2286','EPSG','6360','EPSG','2274',0);
INSERT INTO "compound_crs" VALUES('EPSG','8792','NAD83 / West Virginia North (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','26853','EPSG','6360','EPSG','2264',0);
INSERT INTO "compound_crs" VALUES('EPSG','8793','NAD83 / West Virginia South (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','26854','EPSG','6360','EPSG','2265',0);
INSERT INTO "compound_crs" VALUES('EPSG','8794','NAD83 / Wisconsin North (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2287','EPSG','6360','EPSG','2267',0);
INSERT INTO "compound_crs" VALUES('EPSG','8795','NAD83 / Wisconsin Central (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2288','EPSG','6360','EPSG','2266',0);
INSERT INTO "compound_crs" VALUES('EPSG','8796','NAD83 / Wisconsin South (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','2289','EPSG','6360','EPSG','2268',0);
INSERT INTO "compound_crs" VALUES('EPSG','8797','NAD83 / Wyoming East (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3736','EPSG','6360','EPSG','2269',0);
INSERT INTO "compound_crs" VALUES('EPSG','8798','NAD83 / Wyoming East Central (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3737','EPSG','6360','EPSG','2270',0);
INSERT INTO "compound_crs" VALUES('EPSG','8799','NAD83 / Wyoming West Central (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3738','EPSG','6360','EPSG','2272',0);
INSERT INTO "compound_crs" VALUES('EPSG','8800','NAD83 / Wyoming West (ftUS) + NAVD88 height (ftUS)',NULL,NULL,'EPSG','3739','EPSG','6360','EPSG','2271',0);
INSERT INTO "compound_crs" VALUES('EPSG','8801','NAD83 / Alabama East + NAVD88 height',NULL,NULL,'EPSG','26929','EPSG','5703','EPSG','2154',0);
INSERT INTO "compound_crs" VALUES('EPSG','8802','NAD83 / Alabama West + NAVD88 height',NULL,NULL,'EPSG','26930','EPSG','5703','EPSG','2155',0);
INSERT INTO "compound_crs" VALUES('EPSG','8803','NAD83 / Alaska zone 1 + NAVD88 height',NULL,NULL,'EPSG','26931','EPSG','5703','EPSG','2156',0);
INSERT INTO "compound_crs" VALUES('EPSG','8804','NAD83 / Alaska zone 2 + NAVD88 height',NULL,NULL,'EPSG','26932','EPSG','5703','EPSG','2158',0);
INSERT INTO "compound_crs" VALUES('EPSG','8805','NAD83 / Alaska zone 3 + NAVD88 height',NULL,NULL,'EPSG','26933','EPSG','5703','EPSG','2159',0);
INSERT INTO "compound_crs" VALUES('EPSG','8806','NAD83 / Alaska zone 4 + NAVD88 height',NULL,NULL,'EPSG','26934','EPSG','5703','EPSG','2160',0);
INSERT INTO "compound_crs" VALUES('EPSG','8807','NAD83 / Alaska zone 5 + NAVD88 height',NULL,NULL,'EPSG','26935','EPSG','5703','EPSG','2161',0);
INSERT INTO "compound_crs" VALUES('EPSG','8808','NAD83 / Alaska zone 6 + NAVD88 height',NULL,NULL,'EPSG','26936','EPSG','5703','EPSG','2162',0);
INSERT INTO "compound_crs" VALUES('EPSG','8809','NAD83 / Alaska zone 7 + NAVD88 height',NULL,NULL,'EPSG','26937','EPSG','5703','EPSG','2163',0);
INSERT INTO "compound_crs" VALUES('EPSG','8810','NAD83 / Alaska zone 8 + NAVD88 height',NULL,NULL,'EPSG','26938','EPSG','5703','EPSG','2164',0);
INSERT INTO "compound_crs" VALUES('EPSG','8811','NAD83 / Alaska zone 9 + NAVD88 height',NULL,NULL,'EPSG','26939','EPSG','5703','EPSG','2165',0);
INSERT INTO "compound_crs" VALUES('EPSG','8812','NAD83 / Alaska zone 10 + NAVD88 height',NULL,NULL,'EPSG','26940','EPSG','5703','EPSG','2157',0);
INSERT INTO "compound_crs" VALUES('EPSG','8813','NAD83 / Missouri East + NAVD88 height',NULL,NULL,'EPSG','26996','EPSG','5703','EPSG','2219',0);
INSERT INTO "compound_crs" VALUES('EPSG','8814','NAD83 / Missouri Central + NAVD88 height',NULL,NULL,'EPSG','26997','EPSG','5703','EPSG','2218',0);
INSERT INTO "compound_crs" VALUES('EPSG','8815','NAD83 / Missouri West + NAVD88 height',NULL,NULL,'EPSG','26998','EPSG','5703','EPSG','2220',0);
INSERT INTO "compound_crs" VALUES('EPSG','8912','CR-SIRGAS / CRTM05 + DACR52 height',NULL,NULL,'EPSG','8908','EPSG','8911','EPSG','3232',0);
