--- This file has been generated by scripts/build_db.py. DO NOT EDIT !

INSERT INTO "coordinate_system" VALUES('EPSG','1024','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','1025','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','1026','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','1027','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','1028','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','1029','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','1030','vertical',1);
INSERT INTO "coordinate_system" VALUES('EPSG','1031','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','1032','Cartesian',3);
INSERT INTO "coordinate_system" VALUES('EPSG','1033','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','1034','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','1035','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','1036','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','1037','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','1038','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','1039','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','1040','Cartesian',3);
INSERT INTO "coordinate_system" VALUES('EPSG','1041','Cartesian',3);
INSERT INTO "coordinate_system" VALUES('EPSG','1042','Cartesian',3);
INSERT INTO "coordinate_system" VALUES('EPSG','1043','vertical',1);
INSERT INTO "coordinate_system" VALUES('EPSG','1044','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','1045','Cartesian',3);
INSERT INTO "coordinate_system" VALUES('EPSG','1047','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','1048','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','1049','vertical',1);
INSERT INTO "coordinate_system" VALUES('EPSG','1050','vertical',1);
INSERT INTO "coordinate_system" VALUES('EPSG','4400','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4401','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4402','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4403','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4404','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4405','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4406','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4407','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4408','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4409','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4410','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4460','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4461','Cartesian',3);
INSERT INTO "coordinate_system" VALUES('EPSG','4462','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4463','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4464','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4465','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4466','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4467','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4468','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4469','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4470','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4471','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4472','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4473','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4474','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4475','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4476','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4477','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4478','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4479','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4480','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4481','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4482','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4483','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4484','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4485','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4486','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4487','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4488','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4489','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4490','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4491','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4492','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4493','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4494','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4495','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4496','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4497','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4498','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4499','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4500','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4501','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4502','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4530','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4531','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4532','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4533','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','4534','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6401','ellipsoidal',3);
INSERT INTO "coordinate_system" VALUES('EPSG','6402','ellipsoidal',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6403','ellipsoidal',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6404','spherical',3);
INSERT INTO "coordinate_system" VALUES('EPSG','6405','ellipsoidal',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6406','ellipsoidal',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6407','ellipsoidal',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6408','ellipsoidal',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6409','ellipsoidal',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6410','ellipsoidal',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6411','ellipsoidal',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6412','ellipsoidal',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6413','ellipsoidal',3);
INSERT INTO "coordinate_system" VALUES('EPSG','6414','ellipsoidal',3);
INSERT INTO "coordinate_system" VALUES('EPSG','6415','ellipsoidal',3);
INSERT INTO "coordinate_system" VALUES('EPSG','6416','ellipsoidal',3);
INSERT INTO "coordinate_system" VALUES('EPSG','6417','ellipsoidal',3);
INSERT INTO "coordinate_system" VALUES('EPSG','6418','ellipsoidal',3);
INSERT INTO "coordinate_system" VALUES('EPSG','6419','ellipsoidal',3);
INSERT INTO "coordinate_system" VALUES('EPSG','6420','ellipsoidal',3);
INSERT INTO "coordinate_system" VALUES('EPSG','6421','ellipsoidal',3);
INSERT INTO "coordinate_system" VALUES('EPSG','6422','ellipsoidal',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6423','ellipsoidal',3);
INSERT INTO "coordinate_system" VALUES('EPSG','6424','ellipsoidal',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6425','ellipsoidal',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6426','ellipsoidal',3);
INSERT INTO "coordinate_system" VALUES('EPSG','6427','ellipsoidal',3);
INSERT INTO "coordinate_system" VALUES('EPSG','6428','ellipsoidal',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6429','ellipsoidal',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6430','ellipsoidal',3);
INSERT INTO "coordinate_system" VALUES('EPSG','6431','ellipsoidal',3);
INSERT INTO "coordinate_system" VALUES('EPSG','6495','vertical',1);
INSERT INTO "coordinate_system" VALUES('EPSG','6496','vertical',1);
INSERT INTO "coordinate_system" VALUES('EPSG','6497','vertical',1);
INSERT INTO "coordinate_system" VALUES('EPSG','6498','vertical',1);
INSERT INTO "coordinate_system" VALUES('EPSG','6499','vertical',1);
INSERT INTO "coordinate_system" VALUES('EPSG','6500','Cartesian',3);
INSERT INTO "coordinate_system" VALUES('EPSG','6501','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6502','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6503','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6504','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6505','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6506','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6507','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6508','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6509','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6510','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6511','Cartesian',2);
INSERT INTO "coordinate_system" VALUES('EPSG','6512','Cartesian',3);
