--- This file has been generated by scripts/build_db.py. DO NOT EDIT !

INSERT INTO "vertical_crs" VALUES('EPSG','3855','EGM2008 height',NULL,NULL,'EPSG','6499','EPSG','1027','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','3886','Fao 1979 height',NULL,NULL,'EPSG','6499','EPSG','1028','EPSG','3625',0);
INSERT INTO "vertical_crs" VALUES('EPSG','3900','N2000 height',NULL,NULL,'EPSG','6499','EPSG','1030','EPSG','3333',0);
INSERT INTO "vertical_crs" VALUES('EPSG','4440','NZVD2009 height',NULL,NULL,'EPSG','6499','EPSG','1039','EPSG','1175',0);
INSERT INTO "vertical_crs" VALUES('EPSG','4458','Dunedin-Bluff 1960 height',NULL,NULL,'EPSG','6499','EPSG','1040','EPSG','3806',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5193','Incheon height',NULL,NULL,'EPSG','6499','EPSG','1049','EPSG','3739',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5195','Trieste height',NULL,NULL,'EPSG','6499','EPSG','1050','EPSG','2370',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5214','Genoa height',NULL,NULL,'EPSG','6499','EPSG','1051','EPSG','3736',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5237','SLVD height',NULL,NULL,'EPSG','6499','EPSG','1054','EPSG','3310',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5317','FVR09 height',NULL,NULL,'EPSG','6499','EPSG','1059','EPSG','3248',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5336','Black Sea depth',NULL,NULL,'EPSG','6498','EPSG','5134','EPSG','3251',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5597','FCSVR10 height',NULL,NULL,'EPSG','6499','EPSG','1079','EPSG','3890',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5600','NGPF height',NULL,NULL,'EPSG','6499','EPSG','5195','EPSG','3134',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5601','IGN 1966 height',NULL,NULL,'EPSG','6499','EPSG','5196','EPSG','3124',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5602','Moorea SAU 1981 height',NULL,NULL,'EPSG','6499','EPSG','5197','EPSG','3125',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5603','Raiatea SAU 2001 height',NULL,NULL,'EPSG','6499','EPSG','5198','EPSG','3136',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5604','Maupiti SAU 2001 height',NULL,NULL,'EPSG','6499','EPSG','5199','EPSG','3126',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5605','Huahine SAU 2001 height',NULL,NULL,'EPSG','6499','EPSG','5200','EPSG','3135',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5606','Tahaa SAU 2001 height',NULL,NULL,'EPSG','6499','EPSG','5201','EPSG','3138',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5607','Bora Bora SAU 2001 height',NULL,NULL,'EPSG','6499','EPSG','5202','EPSG','3137',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5608','IGLD 1955 height',NULL,NULL,'EPSG','6499','EPSG','5204','EPSG','3468',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5609','IGLD 1985 height',NULL,NULL,'EPSG','6499','EPSG','5205','EPSG','3468',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5610','HVRS71 height',NULL,NULL,'EPSG','6499','EPSG','5207','EPSG','3234',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5611','Caspian height',NULL,NULL,'EPSG','6499','EPSG','5106','EPSG','1291',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5612','Baltic 1977 depth',NULL,NULL,'EPSG','6498','EPSG','5105','EPSG','2423',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5613','RH2000 height',NULL,NULL,'EPSG','6499','EPSG','5208','EPSG','3313',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5614','KOC WD depth (ft)',NULL,NULL,'EPSG','6495','EPSG','5187','EPSG','3267',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5615','RH00 height',NULL,NULL,'EPSG','6499','EPSG','5209','EPSG','3313',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5616','IGN 1988 LS height',NULL,NULL,'EPSG','6499','EPSG','5210','EPSG','2895',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5617','IGN 1988 MG height',NULL,NULL,'EPSG','6499','EPSG','5211','EPSG','2894',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5618','IGN 1992 LD height',NULL,NULL,'EPSG','6499','EPSG','5212','EPSG','2893',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5619','IGN 1988 SB height',NULL,NULL,'EPSG','6499','EPSG','5213','EPSG','2891',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5620','IGN 1988 SM height',NULL,NULL,'EPSG','6499','EPSG','5214','EPSG','2890',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5621','EVRF2007 height',NULL,NULL,'EPSG','6499','EPSG','5215','EPSG','3594',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5701','ODN height',NULL,NULL,'EPSG','6499','EPSG','5101','EPSG','2792',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5702','NGVD29 height (ftUS)',NULL,NULL,'EPSG','6497','EPSG','5102','EPSG','1323',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5703','NAVD88 height',NULL,NULL,'EPSG','6499','EPSG','5103','EPSG','4161',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5704','Yellow Sea',NULL,NULL,'EPSG','6499','EPSG','5104','EPSG','1067',1);
INSERT INTO "vertical_crs" VALUES('EPSG','5705','Baltic 1977 height',NULL,NULL,'EPSG','6499','EPSG','5105','EPSG','2423',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5706','Caspian depth',NULL,NULL,'EPSG','6498','EPSG','5106','EPSG','1291',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5709','NAP height',NULL,NULL,'EPSG','6499','EPSG','5109','EPSG','1275',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5710','Ostend height',NULL,NULL,'EPSG','6499','EPSG','5110','EPSG','1347',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5711','AHD height',NULL,NULL,'EPSG','6499','EPSG','5111','EPSG','4493',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5712','AHD (Tasmania) height',NULL,NULL,'EPSG','6499','EPSG','5112','EPSG','2947',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5713','CGVD28 height',NULL,NULL,'EPSG','6499','EPSG','5114','EPSG','1289',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5714','MSL height',NULL,NULL,'EPSG','6499','EPSG','5100','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5715','MSL depth',NULL,NULL,'EPSG','6498','EPSG','5100','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5716','Piraeus height',NULL,NULL,'EPSG','6499','EPSG','5115','EPSG','3254',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5717','N60 height',NULL,NULL,'EPSG','6499','EPSG','5116','EPSG','3333',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5718','RH70 height',NULL,NULL,'EPSG','6499','EPSG','5117','EPSG','3313',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5719','NGF Lallemand height',NULL,NULL,'EPSG','6499','EPSG','5118','EPSG','1326',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5720','NGF-IGN69 height',NULL,NULL,'EPSG','6499','EPSG','5119','EPSG','1326',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5721','NGF-IGN78 height',NULL,NULL,'EPSG','6499','EPSG','5120','EPSG','1327',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5722','Maputo height',NULL,NULL,'EPSG','6499','EPSG','5121','EPSG','3281',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5723','JSLD69 height',NULL,NULL,'EPSG','6499','EPSG','5122','EPSG','4166',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5724','PHD93 height',NULL,NULL,'EPSG','6499','EPSG','5123','EPSG','3288',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5725','Fahud HD height',NULL,NULL,'EPSG','6499','EPSG','5124','EPSG','4009',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5726','Ha Tien 1960 height',NULL,NULL,'EPSG','6499','EPSG','5125','EPSG','1302',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5727','Hon Dau 1992 height',NULL,NULL,'EPSG','6499','EPSG','5126','EPSG','4015',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5728','LN02 height',NULL,NULL,'EPSG','6499','EPSG','5127','EPSG','1286',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5729','LHN95 height',NULL,NULL,'EPSG','6499','EPSG','5128','EPSG','1286',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5730','EVRF2000 height',NULL,NULL,'EPSG','6499','EPSG','5129','EPSG','1299',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5731','Malin Head height',NULL,NULL,'EPSG','6499','EPSG','5130','EPSG','1305',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5732','Belfast height',NULL,NULL,'EPSG','6499','EPSG','5131','EPSG','2530',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5733','DNN height',NULL,NULL,'EPSG','6499','EPSG','5132','EPSG','3237',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5734','AIOC95 depth',NULL,NULL,'EPSG','6498','EPSG','5133','EPSG','2592',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5735','Black Sea height',NULL,NULL,'EPSG','6499','EPSG','5134','EPSG','3251',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5736','Yellow Sea 1956 height',NULL,NULL,'EPSG','6499','EPSG','5104','EPSG','3228',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5737','Yellow Sea 1985 height',NULL,NULL,'EPSG','6499','EPSG','5137','EPSG','3228',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5738','HKPD height',NULL,NULL,'EPSG','6499','EPSG','5135','EPSG','3334',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5739','HKCD depth',NULL,NULL,'EPSG','6498','EPSG','5136','EPSG','3335',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5740','ODN Orkney height',NULL,NULL,'EPSG','6499','EPSG','5138','EPSG','2793',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5741','Fair Isle height',NULL,NULL,'EPSG','6499','EPSG','5139','EPSG','2794',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5742','Lerwick height',NULL,NULL,'EPSG','6499','EPSG','5140','EPSG','2795',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5743','Foula height',NULL,NULL,'EPSG','6499','EPSG','5141','EPSG','2796',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5744','Sule Skerry height',NULL,NULL,'EPSG','6499','EPSG','5142','EPSG','2797',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5745','North Rona height',NULL,NULL,'EPSG','6499','EPSG','5143','EPSG','2798',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5746','Stornoway height',NULL,NULL,'EPSG','6499','EPSG','5144','EPSG','2799',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5747','St Kilda height',NULL,NULL,'EPSG','6499','EPSG','5145','EPSG','2800',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5748','Flannan Isles height',NULL,NULL,'EPSG','6499','EPSG','5146','EPSG','2801',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5749','St Marys height',NULL,NULL,'EPSG','6499','EPSG','5147','EPSG','2802',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5750','Douglas height',NULL,NULL,'EPSG','6499','EPSG','5148','EPSG','2803',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5751','Fao height',NULL,NULL,'EPSG','6499','EPSG','5149','EPSG','3390',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5752','Bandar Abbas height',NULL,NULL,'EPSG','6499','EPSG','5150','EPSG','3336',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5753','NGNC height',NULL,NULL,'EPSG','6499','EPSG','5151','EPSG','2822',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5754','Poolbeg height (ft(Br36))',NULL,NULL,'EPSG','6496','EPSG','5152','EPSG','1305',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5755','NGG1977 height',NULL,NULL,'EPSG','6499','EPSG','5153','EPSG','3146',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5756','Martinique 1987 height',NULL,NULL,'EPSG','6499','EPSG','5154','EPSG','3276',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5757','Guadeloupe 1988 height',NULL,NULL,'EPSG','6499','EPSG','5155','EPSG','2892',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5758','Reunion 1989 height',NULL,NULL,'EPSG','6499','EPSG','5156','EPSG','3337',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5759','Auckland 1946 height',NULL,NULL,'EPSG','6499','EPSG','5157','EPSG','3764',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5760','Bluff 1955 height',NULL,NULL,'EPSG','6499','EPSG','5158','EPSG','3801',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5761','Dunedin 1958 height',NULL,NULL,'EPSG','6499','EPSG','5159','EPSG','3803',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5762','Gisborne 1926 height',NULL,NULL,'EPSG','6499','EPSG','5160','EPSG','3771',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5763','Lyttelton 1937 height',NULL,NULL,'EPSG','6499','EPSG','5161','EPSG','3804',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5764','Moturiki 1953 height',NULL,NULL,'EPSG','6499','EPSG','5162','EPSG','3768',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5765','Napier 1962 height',NULL,NULL,'EPSG','6499','EPSG','5163','EPSG','3772',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5766','Nelson 1955 height',NULL,NULL,'EPSG','6499','EPSG','5164','EPSG','3802',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5767','One Tree Point 1964 height',NULL,NULL,'EPSG','6499','EPSG','5165','EPSG','3762',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5768','Tararu 1952 height',NULL,NULL,'EPSG','6499','EPSG','5166','EPSG','3818',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5769','Taranaki 1970 height',NULL,NULL,'EPSG','6499','EPSG','5167','EPSG','3769',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5770','Wellington 1953 height',NULL,NULL,'EPSG','6499','EPSG','5168','EPSG','3773',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5771','Chatham Island 1959 height',NULL,NULL,'EPSG','6499','EPSG','5169','EPSG','3894',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5772','Stewart Island 1977 height',NULL,NULL,'EPSG','6499','EPSG','5170','EPSG','3338',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5773','EGM96 height',NULL,NULL,'EPSG','6499','EPSG','5171','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5774','NG-L height',NULL,NULL,'EPSG','6499','EPSG','5172','EPSG','1146',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5775','Antalya height',NULL,NULL,'EPSG','6499','EPSG','5173','EPSG','3322',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5776','NN54 height',NULL,NULL,'EPSG','6499','EPSG','5174','EPSG','1352',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5777','Durres height',NULL,NULL,'EPSG','6499','EPSG','5175','EPSG','3212',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5778','GHA height',NULL,NULL,'EPSG','6499','EPSG','5176','EPSG','1037',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5779','SVS2000 height',NULL,NULL,'EPSG','6499','EPSG','5177','EPSG','3307',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5780','Cascais height',NULL,NULL,'EPSG','6499','EPSG','5178','EPSG','1294',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5781','Constanta height',NULL,NULL,'EPSG','6499','EPSG','5179','EPSG','3295',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5782','Alicante height',NULL,NULL,'EPSG','6499','EPSG','5180','EPSG','4188',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5783','DHHN92 height',NULL,NULL,'EPSG','6499','EPSG','5181','EPSG','3339',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5784','DHHN85 height',NULL,NULL,'EPSG','6499','EPSG','5182','EPSG','2326',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5785','SNN76 height',NULL,NULL,'EPSG','6499','EPSG','5183','EPSG','1343',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5786','Baltic 1982 height',NULL,NULL,'EPSG','6499','EPSG','5184','EPSG','3224',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5787','EOMA 1980 height',NULL,NULL,'EPSG','6499','EPSG','5185','EPSG','1119',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5788','Kuwait PWD height',NULL,NULL,'EPSG','6499','EPSG','5186','EPSG','3267',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5789','KOC WD depth',NULL,NULL,'EPSG','6498','EPSG','5187','EPSG','3267',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5790','KOC CD height',NULL,NULL,'EPSG','6499','EPSG','5188','EPSG','3267',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5791','NGC 1948 height',NULL,NULL,'EPSG','6499','EPSG','5189','EPSG','1327',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5792','Danger 1950 height',NULL,NULL,'EPSG','6499','EPSG','5190','EPSG','3299',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5793','Mayotte 1950 height',NULL,NULL,'EPSG','6499','EPSG','5191','EPSG','3340',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5794','Martinique 1955 height',NULL,NULL,'EPSG','6499','EPSG','5192','EPSG','3276',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5795','Guadeloupe 1951 height',NULL,NULL,'EPSG','6499','EPSG','5193','EPSG','2892',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5796','Lagos 1955 height',NULL,NULL,'EPSG','6499','EPSG','5194','EPSG','3287',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5797','AIOC95 height',NULL,NULL,'EPSG','6499','EPSG','5133','EPSG','2592',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5798','EGM84 height',NULL,NULL,'EPSG','6499','EPSG','5203','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5799','DVR90 height',NULL,NULL,'EPSG','6499','EPSG','5206','EPSG','3237',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5829','Instantaneous Water Level height',NULL,NULL,'EPSG','6499','EPSG','5113','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5831','Instantaneous Water Level depth',NULL,NULL,'EPSG','6498','EPSG','5113','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5843','Ras Ghumays height',NULL,NULL,'EPSG','6499','EPSG','1146','EPSG','4225',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5861','LAT depth',NULL,NULL,'EPSG','6498','EPSG','1080','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5862','LLWLT depth',NULL,NULL,'EPSG','6498','EPSG','1083','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5863','ISLW depth',NULL,NULL,'EPSG','6498','EPSG','1085','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5864','MLLWS depth',NULL,NULL,'EPSG','6498','EPSG','1086','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5865','MLWS depth',NULL,NULL,'EPSG','6498','EPSG','1087','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5866','MLLW depth',NULL,NULL,'EPSG','6498','EPSG','1089','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5867','MLW depth',NULL,NULL,'EPSG','6498','EPSG','1091','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5868','MHW height',NULL,NULL,'EPSG','6499','EPSG','1092','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5869','MHHW height',NULL,NULL,'EPSG','6499','EPSG','1090','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5870','MHWS height',NULL,NULL,'EPSG','6499','EPSG','1088','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5871','HHWLT height',NULL,NULL,'EPSG','6499','EPSG','1084','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5872','HAT height',NULL,NULL,'EPSG','6499','EPSG','1082','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5873','Low Water depth',NULL,NULL,'EPSG','6498','EPSG','1093','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5874','High Water height',NULL,NULL,'EPSG','6499','EPSG','1094','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','5941','NN2000 height',NULL,NULL,'EPSG','6499','EPSG','1096','EPSG','1352',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6130','GCVD54 height (ft)',NULL,NULL,'EPSG','1030','EPSG','1097','EPSG','3185',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6131','LCVD61 height (ft)',NULL,NULL,'EPSG','1030','EPSG','1098','EPSG','4121',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6132','CBVD61 height (ft)',NULL,NULL,'EPSG','1030','EPSG','1099','EPSG','3207',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6178','Cais da Pontinha - Funchal height',NULL,NULL,'EPSG','6499','EPSG','1101','EPSG','4125',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6179','Cais da Vila - Porto Santo height',NULL,NULL,'EPSG','6499','EPSG','1102','EPSG','3680',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6180','Cais das Velas height',NULL,NULL,'EPSG','6499','EPSG','1103','EPSG','2875',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6181','Horta height',NULL,NULL,'EPSG','6499','EPSG','1104','EPSG','2873',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6182','Cais da Madalena height',NULL,NULL,'EPSG','6499','EPSG','1105','EPSG','2874',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6183','Santa Cruz da Graciosa height',NULL,NULL,'EPSG','6499','EPSG','1106','EPSG','3681',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6184','Cais da Figueirinha - Angra do Heroismo height',NULL,NULL,'EPSG','6499','EPSG','1107','EPSG','2872',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6185','Santa Cruz das Flores height',NULL,NULL,'EPSG','6499','EPSG','1108','EPSG','1344',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6186','Cais da Vila do Porto height',NULL,NULL,'EPSG','6499','EPSG','1109','EPSG','4126',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6187','Ponta Delgada height',NULL,NULL,'EPSG','6499','EPSG','1110','EPSG','2871',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6357','NAVD88 depth',NULL,NULL,'EPSG','6498','EPSG','5103','EPSG','4161',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6358','NAVD88 depth (ftUS)',NULL,NULL,'EPSG','1043','EPSG','5103','EPSG','3664',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6359','NGVD29 depth (ftUS)',NULL,NULL,'EPSG','1043','EPSG','5102','EPSG','1323',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6360','NAVD88 height (ftUS)',NULL,NULL,'EPSG','6497','EPSG','5103','EPSG','3664',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6638','Tutuila 1962 height',NULL,NULL,'EPSG','6499','EPSG','1121','EPSG','2288',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6639','Guam 1963 height',NULL,NULL,'EPSG','6499','EPSG','1122','EPSG','3255',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6640','NMVD03 height',NULL,NULL,'EPSG','6499','EPSG','1119','EPSG','4171',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6641','PRVD02 height',NULL,NULL,'EPSG','6499','EPSG','1123','EPSG','3294',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6642','VIVD09 height',NULL,NULL,'EPSG','6499','EPSG','1124','EPSG','3330',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6643','ASVD02 height',NULL,NULL,'EPSG','6499','EPSG','1125','EPSG','2288',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6644','GUVD04 height',NULL,NULL,'EPSG','6499','EPSG','1126','EPSG','3255',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6647','CGVD2013 height',NULL,NULL,'EPSG','6499','EPSG','1127','EPSG','1061',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6693','JSLD72 height',NULL,NULL,'EPSG','6499','EPSG','1129','EPSG','4168',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6694','JGD2000 (vertical) height',NULL,NULL,'EPSG','6499','EPSG','1130','EPSG','3263',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6695','JGD2011 (vertical) height',NULL,NULL,'EPSG','6499','EPSG','1131','EPSG','3263',0);
INSERT INTO "vertical_crs" VALUES('EPSG','6916','SHD height',NULL,NULL,'EPSG','6499','EPSG','1140','EPSG','1210',0);
INSERT INTO "vertical_crs" VALUES('EPSG','7446','Famagusta 1960 height',NULL,NULL,'EPSG','6499','EPSG','1148','EPSG','3236',0);
INSERT INTO "vertical_crs" VALUES('EPSG','7447','PNG08 height',NULL,NULL,'EPSG','6499','EPSG','1149','EPSG','4384',0);
INSERT INTO "vertical_crs" VALUES('EPSG','7651','Kumul 34 height',NULL,NULL,'EPSG','6499','EPSG','1150','EPSG','4013',0);
INSERT INTO "vertical_crs" VALUES('EPSG','7652','Kiunga height',NULL,NULL,'EPSG','6499','EPSG','1151','EPSG','4383',0);
INSERT INTO "vertical_crs" VALUES('EPSG','7699','DHHN12 height',NULL,NULL,'EPSG','6499','EPSG','1161','EPSG','3339',0);
INSERT INTO "vertical_crs" VALUES('EPSG','7700','Latvia 2000 height',NULL,NULL,'EPSG','6499','EPSG','1162','EPSG','3268',0);
INSERT INTO "vertical_crs" VALUES('EPSG','7707','ODN (Offshore) height',NULL,NULL,'EPSG','6499','EPSG','1164','EPSG','4391',0);
INSERT INTO "vertical_crs" VALUES('EPSG','7832','POM96 height',NULL,NULL,'EPSG','6499','EPSG','1171','EPSG','4425',0);
INSERT INTO "vertical_crs" VALUES('EPSG','7837','DHHN2016 height',NULL,NULL,'EPSG','6499','EPSG','1170','EPSG','3339',0);
INSERT INTO "vertical_crs" VALUES('EPSG','7839','NZVD2016 height',NULL,NULL,'EPSG','6499','EPSG','1169','EPSG','1175',0);
INSERT INTO "vertical_crs" VALUES('EPSG','7841','POM08 height',NULL,NULL,'EPSG','6499','EPSG','1172','EPSG','4425',0);
INSERT INTO "vertical_crs" VALUES('EPSG','7888','Jamestown 1971 height',NULL,NULL,'EPSG','6499','EPSG','1175','EPSG','3183',0);
INSERT INTO "vertical_crs" VALUES('EPSG','7889','St. Helena Tritan 2011 height',NULL,NULL,'EPSG','6499','EPSG','1176','EPSG','3183',0);
INSERT INTO "vertical_crs" VALUES('EPSG','7890','SHVD2015 height',NULL,NULL,'EPSG','6499','EPSG','1177','EPSG','3183',0);
INSERT INTO "vertical_crs" VALUES('EPSG','7962','Poolbeg height (m)',NULL,NULL,'EPSG','6499','EPSG','5152','EPSG','1305',0);
INSERT INTO "vertical_crs" VALUES('EPSG','7968','NGVD29 height (m)',NULL,NULL,'EPSG','6499','EPSG','5102','EPSG','1323',0);
INSERT INTO "vertical_crs" VALUES('EPSG','7976','HKPD depth',NULL,NULL,'EPSG','6498','EPSG','5135','EPSG','3334',0);
INSERT INTO "vertical_crs" VALUES('EPSG','7979','KOC WD height',NULL,NULL,'EPSG','6499','EPSG','5187','EPSG','3267',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8050','MSL height (ft)',NULL,NULL,'EPSG','1030','EPSG','5100','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8051','MSL depth (ft)',NULL,NULL,'EPSG','6495','EPSG','5100','EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8052','MSL height (ftUS)',NULL,NULL,'EPSG','6497','EPSG','5100','EPSG','1245',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8053','MSL depth (ftUS)',NULL,NULL,'EPSG','1043','EPSG','5100','EPSG','1245',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8089','ISH2004 height',NULL,NULL,'EPSG','6499','EPSG','1190','EPSG','3262',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8228','NAVD88 height (ft)',NULL,NULL,'EPSG','1030','EPSG','5103','EPSG','4464',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8266','GVR2000 height',NULL,NULL,'EPSG','6499','EPSG','1199','EPSG','4461',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8267','GVR2016 height',NULL,NULL,'EPSG','6499','EPSG','1200','EPSG','4454',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8357','Baltic 1957 height',NULL,NULL,'EPSG','6499','EPSG','1202','EPSG','1306',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8358','Baltic 1957 depth',NULL,NULL,'EPSG','6498','EPSG','1202','EPSG','1306',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8378','EPSG example wellbore local vertical CRS',NULL,NULL,'EPSG','1049','EPSG','1205','EPSG','4393',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8434','Macao height',NULL,NULL,'EPSG','6499','EPSG','1210','EPSG','1147',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8675','N43 height',NULL,NULL,'EPSG','6499','EPSG','1213','EPSG','4522',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8690','SVS2010 height',NULL,NULL,'EPSG','6499','EPSG','1215','EPSG','3307',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8691','SRB_VRS12 height',NULL,NULL,'EPSG','6499','EPSG','1216','EPSG','4543',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8841','MVGC height',NULL,NULL,'EPSG','6499','EPSG','1219','EPSG','3303',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8897','EPSG example wellbore local vertical CRS (ft)',NULL,NULL,'EPSG','1050','EPSG','1205','EPSG','4393',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8904','TWVD 2001 height',NULL,NULL,'EPSG','6499','EPSG','1224','EPSG','3982',0);
INSERT INTO "vertical_crs" VALUES('EPSG','8911','DACR52 height',NULL,NULL,'EPSG','6499','EPSG','1226','EPSG','3232',0);
INSERT INTO "vertical_crs" VALUES('EPSG','9130','IGN 2008 LD height',NULL,NULL,'EPSG','6499','EPSG','1250','EPSG','2893',0);
