--- This file has been generated by scripts/build_db.py. DO NOT EDIT !

INSERT INTO "conversion" VALUES('EPSG','3811','Belgian Lambert 2008',NULL,NULL,'EPSG','1347','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',50.4752134,'EPSG','9110','EPSG','8822','Longitude of false origin',4.2133177,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',49.5,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',51.1,'EPSG','9110','EPSG','8826','Easting at false origin',649328.0,'EPSG','9001','EPSG','8827','Northing at false origin',665262.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3813','Mississippi Transverse Mercator',NULL,NULL,'EPSG','1393','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',32.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9998335,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',1300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3818','Taiwan 2-degree TM zone 119',NULL,NULL,'EPSG','3563','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',119.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3820','Taiwan 2-degree TM zone 121',NULL,NULL,'EPSG','3562','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',121.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3831','Pacific Disaster Center Mercator',NULL,NULL,'EPSG','3172','EPSG','9804','Mercator (variant A)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',150.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3853','County ST74',NULL,NULL,'EPSG','3608','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',18.0328332,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99999506,'EPSG','9201','EPSG','8806','False easting',100182.7406,'EPSG','9001','EPSG','8807','False northing',-6500620.1207,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3856','Popular Visualisation Pseudo-Mercator',NULL,NULL,'EPSG','1262','EPSG','1024','Popular Visualisation Pseudo Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3860','Finland Gauss-Kruger zone 19',NULL,NULL,'EPSG','3595','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',19.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',19500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3861','Finland Gauss-Kruger zone 20',NULL,NULL,'EPSG','3596','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',20.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',20500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3862','Finland Gauss-Kruger zone 21',NULL,NULL,'EPSG','3597','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',21500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3863','Finland Gauss-Kruger zone 22',NULL,NULL,'EPSG','3598','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',22.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',22500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3864','Finland Gauss-Kruger zone 23',NULL,NULL,'EPSG','3599','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',23.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',23500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3865','Finland Gauss-Kruger zone 24',NULL,NULL,'EPSG','3600','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',24.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',24500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3866','Finland Gauss-Kruger zone 25',NULL,NULL,'EPSG','3601','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',25.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',25500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3867','Finland Gauss-Kruger zone 26',NULL,NULL,'EPSG','3602','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',26.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',26500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3868','Finland Gauss-Kruger zone 27',NULL,NULL,'EPSG','3603','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',27500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3869','Finland Gauss-Kruger zone 28',NULL,NULL,'EPSG','3604','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',28.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',28500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3870','Finland Gauss-Kruger zone 29',NULL,NULL,'EPSG','3605','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',29.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',29500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3871','Finland Gauss-Kruger zone 30',NULL,NULL,'EPSG','3606','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',30.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',30500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3872','Finland Gauss-Kruger zone 31',NULL,NULL,'EPSG','3607','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',31.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',31500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3897','US NSIDC Equal Area north projection',NULL,NULL,'EPSG','3475','EPSG','1027','Lambert Azimuthal Equal Area (Spherical)','EPSG','8801','Latitude of natural origin',90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3898','US NSIDC Equal Area south projection',NULL,NULL,'EPSG','3474','EPSG','1027','Lambert Azimuthal Equal Area (Spherical)','EPSG','8801','Latitude of natural origin',-90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3899','US National Atlas Equal Area',NULL,NULL,'EPSG','1245','EPSG','1027','Lambert Azimuthal Equal Area (Spherical)','EPSG','8801','Latitude of natural origin',45.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-100.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3967','Virginia Lambert Conic Conformal',NULL,NULL,'EPSG','1415','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-79.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.5,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3977','Canada Atlas Lambert',NULL,NULL,'EPSG','1061','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',49.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',49.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3980','Katanga Lambert',NULL,NULL,'EPSG','3147','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',9.0,'EPSG','9102','EPSG','8822','Longitude of false origin',26.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-6.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-11.5,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','3981','Katanga Gauss zone A',NULL,NULL,'EPSG','3612','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-9.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',30.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3982','Katanga Gauss zone B',NULL,NULL,'EPSG','3611','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-9.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',28.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3983','Katanga Gauss zone C',NULL,NULL,'EPSG','3610','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-9.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',26.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3984','Katanga Gauss zone D',NULL,NULL,'EPSG','3609','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-9.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',24.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','3999','Moldova Transverse Mercator',NULL,NULL,'EPSG','1162','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',28.24,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99994,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',-5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4085','World Equidistant Cylindrical',NULL,NULL,'EPSG','1262','EPSG','1028','Equidistant Cylindrical','EPSG','8823','Latitude of 1st standard parallel',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4086','World Equidistant Cylindrical (Sphere)',NULL,NULL,'EPSG','1262','EPSG','1029','Equidistant Cylindrical (Spherical)','EPSG','8823','Latitude of 1st standard parallel',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4089','DKTM1',NULL,NULL,'EPSG','3631','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99998,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',-5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4090','DKTM2',NULL,NULL,'EPSG','3632','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',10.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99998,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',-5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4091','DKTM3',NULL,NULL,'EPSG','2532','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',11.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99998,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',-5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4092','DKTM4',NULL,NULL,'EPSG','2533','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',800000.0,'EPSG','9001','EPSG','8807','False northing',-5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4101','BLM zone 1N (US survey feet)',NULL,NULL,'EPSG','3374','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4102','BLM zone 2N (US survey feet)',NULL,NULL,'EPSG','3375','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-171.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4103','BLM zone 3N (US survey feet)',NULL,NULL,'EPSG','2133','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4104','BLM zone 4N (US survey feet)',NULL,NULL,'EPSG','2134','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-159.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4105','BLM zone 5N (US survey feet)',NULL,NULL,'EPSG','2135','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4106','BLM zone 6N (US survey feet)',NULL,NULL,'EPSG','2136','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4107','BLM zone 7N (US survey feet)',NULL,NULL,'EPSG','3494','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4108','BLM zone 8N (US survey feet)',NULL,NULL,'EPSG','3495','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-135.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4109','BLM zone 9N (US survey feet)',NULL,NULL,'EPSG','3496','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-129.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4110','BLM zone 10N (US survey feet)',NULL,NULL,'EPSG','3497','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-123.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4111','BLM zone 11N (US survey feet)',NULL,NULL,'EPSG','3498','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-117.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4112','BLM zone 12N (US survey feet)',NULL,NULL,'EPSG','3499','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-111.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4113','BLM zone 13N (US survey feet)',NULL,NULL,'EPSG','3500','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-105.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4114','Johor Cassini Grid',NULL,NULL,'EPSG','3376','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',2.02333,'EPSG','9110','EPSG','8802','Longitude of natural origin',103.334593,'EPSG','9110','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4115','Sembilan and Melaka Cassini Grid',NULL,NULL,'EPSG','3377','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',2.424422,'EPSG','9110','EPSG','8802','Longitude of natural origin',101.56282,'EPSG','9110','EPSG','8806','False easting',-242.005,'EPSG','9001','EPSG','8807','False northing',-948.547,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4116','Pahang Cassini Grid',NULL,NULL,'EPSG','3378','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',3.42395,'EPSG','9110','EPSG','8802','Longitude of natural origin',102.261024,'EPSG','9110','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4117','Selangor Cassini Grid',NULL,NULL,'EPSG','3379','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',3.404924,'EPSG','9110','EPSG','8802','Longitude of natural origin',101.302968,'EPSG','9110','EPSG','8806','False easting',-21759.438,'EPSG','9001','EPSG','8807','False northing',55960.906,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4118','BLM zone 18N (US survey feet)',NULL,NULL,'EPSG','3505','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-75.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4119','BLM zone 19N (US survey feet)',NULL,NULL,'EPSG','3506','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-69.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4177','Terengganu Cassini Grid',NULL,NULL,'EPSG','3380','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',4.564611,'EPSG','9110','EPSG','8802','Longitude of natural origin',102.534275,'EPSG','9110','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4186','BLM zone 59N (US survey feet)',NULL,NULL,'EPSG','3372','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',171.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4187','BLM zone 60N (US survey feet)',NULL,NULL,'EPSG','3373','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4305','Pinang Cassini Grid',NULL,NULL,'EPSG','3381','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',5.251677,'EPSG','9110','EPSG','8802','Longitude of natural origin',100.204513,'EPSG','9110','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4320','Kedah and Perlis Cassini Grid',NULL,NULL,'EPSG','3382','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',5.575453,'EPSG','9110','EPSG','8802','Longitude of natural origin',100.381534,'EPSG','9110','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4321','Perak Revised Cassini Grid',NULL,NULL,'EPSG','3383','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',4.513377,'EPSG','9110','EPSG','8802','Longitude of natural origin',100.490036,'EPSG','9110','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',133453.669,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4323','Kelantan Cassini Grid',NULL,NULL,'EPSG','3384','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',5.533812,'EPSG','9110','EPSG','8802','Longitude of natural origin',102.103825,'EPSG','9110','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4325','Guam Map Grid',NULL,NULL,'EPSG','3255','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',13.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',144.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4416','Katanga Lambert',NULL,NULL,'EPSG','3147','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-9.0,'EPSG','9102','EPSG','8822','Longitude of false origin',26.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-6.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-11.5,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4436','Pennsylvania CS27 South zone',NULL,NULL,'EPSG','2246','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-77.45,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',40.58,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',39.56,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4454','New York CS27 Long Island zone',NULL,NULL,'EPSG','2235','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-74.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.02,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.4,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4460','Australian Centre for Remote Sensing Lambert Conformal Projection',NULL,NULL,'EPSG','2575','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-27.0,'EPSG','9102','EPSG','8822','Longitude of false origin',132.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-18.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-36.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4648','UTM zone 32N with prefix',NULL,NULL,'EPSG','2861','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',32500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4825','Cape Verde National',NULL,NULL,'EPSG','1062','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',15.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-24.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',15.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',16.4,'EPSG','9110','EPSG','8826','Easting at false origin',161587.83,'EPSG','9001','EPSG','8827','Northing at false origin',128511.202,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4838','LCC Germany',NULL,NULL,'EPSG','3339','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',51.0,'EPSG','9102','EPSG','8822','Longitude of false origin',10.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',48.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',53.4,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','4841','Norway TM zone 15',NULL,NULL,'EPSG','3656','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',15.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','4842','Norway TM zone 16',NULL,NULL,'EPSG','3657','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',16.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','4843','Norway TM zone 17',NULL,NULL,'EPSG','3658','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',17.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','4844','Norway TM zone 18',NULL,NULL,'EPSG','3660','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',18.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','4845','Norway TM zone 5',NULL,NULL,'EPSG','3636','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',5.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','4846','Norway TM zone 6',NULL,NULL,'EPSG','3639','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',6.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','4847','Norway TM zone 7',NULL,NULL,'EPSG','3647','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',7.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','4848','Norway TM zone 8',NULL,NULL,'EPSG','3648','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',8.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','4849','Norway TM zone 9',NULL,NULL,'EPSG','3649','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',9.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','4850','Norway TM zone 10',NULL,NULL,'EPSG','3650','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',10.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','4851','Norway TM zone 11',NULL,NULL,'EPSG','3651','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',11.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','4852','Norway TM zone 12',NULL,NULL,'EPSG','3653','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',12.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','4853','Norway TM zone 13',NULL,NULL,'EPSG','3654','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',13.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','4854','Norway TM zone 14',NULL,NULL,'EPSG','3655','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',14.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','4881','Norway TM zone 19',NULL,NULL,'EPSG','3661','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',19.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','5000','Norway TM zone 20',NULL,NULL,'EPSG','3662','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',20.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','5001','Norway TM zone 21',NULL,NULL,'EPSG','3663','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',21.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','5002','Norway TM zone 22',NULL,NULL,'EPSG','3665','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',22.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','5003','Norway TM zone 23',NULL,NULL,'EPSG','3667','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',23.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','5004','Norway TM zone 24',NULL,NULL,'EPSG','3668','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',24.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','5005','Norway TM zone 25',NULL,NULL,'EPSG','3669','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',25.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','5006','Norway TM zone 26',NULL,NULL,'EPSG','3671','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',26.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','5007','Norway TM zone 27',NULL,NULL,'EPSG','3672','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',27.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','5008','Norway TM zone 28',NULL,NULL,'EPSG','3673','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',28.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','5009','Norway TM zone 29',NULL,NULL,'EPSG','3674','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',29.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','5010','Norway TM zone 30',NULL,NULL,'EPSG','3676','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',30.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','5019','Portugal Bonne New',NULL,NULL,'EPSG','1294','EPSG','9828','Bonne (South Orientated)','EPSG','8801','Latitude of natural origin',39.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-8.0754862,'EPSG','9110','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5020','Portuguese Grid New',NULL,NULL,'EPSG','1294','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-8.0754862,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5049','Korea East Sea Belt',NULL,NULL,'EPSG','3727','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',131.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5068','Conus Albers',NULL,NULL,'EPSG','1323','EPSG','9822','Albers Equal Area','EPSG','8821','Latitude of false origin',23.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',29.3,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',45.3,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5100','Korea Unified Belt',NULL,NULL,'EPSG','1135','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',127.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5101','Korea West Belt 2010',NULL,NULL,'EPSG','1498','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',125.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',600000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5102','Korea Central Belt 2010',NULL,NULL,'EPSG','1497','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',127.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',600000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5103','Korea East Belt 2010',NULL,NULL,'EPSG','1496','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',129.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',600000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5104','Korea East Sea Belt 2010',NULL,NULL,'EPSG','3720','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',131.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',600000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5131','Korea Central Belt Jeju',NULL,NULL,'EPSG','3721','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',127.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',550000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5135','Norway TM zone 5',NULL,NULL,'EPSG','3636','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',5.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5136','Norway TM zone 6',NULL,NULL,'EPSG','3639','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',6.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5137','Norway TM zone 7',NULL,NULL,'EPSG','3647','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',7.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5138','Norway TM zone 8',NULL,NULL,'EPSG','3648','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',8.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5139','Norway TM zone 9',NULL,NULL,'EPSG','3649','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',9.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5140','Norway TM zone 10',NULL,NULL,'EPSG','3650','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',10.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5141','Norway TM zone 11',NULL,NULL,'EPSG','3651','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',11.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5142','Norway TM zone 12',NULL,NULL,'EPSG','3653','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',12.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5143','Norway TM zone 13',NULL,NULL,'EPSG','3654','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',13.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5144','Norway TM zone 14',NULL,NULL,'EPSG','3655','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',14.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5145','Norway TM zone 15',NULL,NULL,'EPSG','3656','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',15.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5146','Norway TM zone 16',NULL,NULL,'EPSG','3657','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',16.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5147','Norway TM zone 17',NULL,NULL,'EPSG','3658','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',17.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5148','Norway TM zone 18',NULL,NULL,'EPSG','3660','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',18.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5149','Norway TM zone 19',NULL,NULL,'EPSG','3661','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',19.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5150','Norway TM zone 20',NULL,NULL,'EPSG','3662','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',20.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5151','Norway TM zone 21',NULL,NULL,'EPSG','3663','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',21.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5152','Norway TM zone 22',NULL,NULL,'EPSG','3665','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',22.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5153','Norway TM zone 23',NULL,NULL,'EPSG','3667','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',23.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5154','Norway TM zone 24',NULL,NULL,'EPSG','3668','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',24.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5155','Norway TM zone 25',NULL,NULL,'EPSG','3669','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',25.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5156','Norway TM zone 26',NULL,NULL,'EPSG','3671','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',26.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5157','Norway TM zone 27',NULL,NULL,'EPSG','3672','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',27.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5158','Norway TM zone 28',NULL,NULL,'EPSG','3673','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',28.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5159','Norway TM zone 29',NULL,NULL,'EPSG','3674','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',29.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5160','Norway TM zone 30',NULL,NULL,'EPSG','3676','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',30.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5161','Korea Modified West Belt',NULL,NULL,'EPSG','1498','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',125.0010405,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5162','Korea Modified Central Belt',NULL,NULL,'EPSG','1497','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',127.0010405,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5163','Korea Modified Central Belt Jeju',NULL,NULL,'EPSG','3721','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',127.0010405,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',550000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5164','Korea Modified East Belt',NULL,NULL,'EPSG','1496','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',129.0010405,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5165','Korea Modified East Sea Belt',NULL,NULL,'EPSG','3720','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',131.0010405,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5218','Krovak East North',NULL,NULL,'EPSG','1306','EPSG','1041','Krovak (North Orientated)','EPSG','8811','Latitude of projection centre',49.3,'EPSG','9110','EPSG','8833','Longitude of origin',42.3,'EPSG','9110','EPSG','1036','Co-latitude of cone axis',30.171730311,'EPSG','9110','EPSG','8818','Latitude of pseudo standard parallel',78.3,'EPSG','9110','EPSG','8819','Scale factor on pseudo standard parallel',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','5219','Modified Krovak',NULL,NULL,'EPSG','1079','EPSG','1042','Krovak Modified','EPSG','8811','Latitude of projection centre',49.3,'EPSG','9110','EPSG','8833','Longitude of origin',42.3,'EPSG','9110','EPSG','1036','Co-latitude of cone axis',30.1717303,'EPSG','9110','EPSG','8818','Latitude of pseudo standard parallel',78.3,'EPSG','9110','EPSG','8819','Scale factor on pseudo standard parallel',0.9999,'EPSG','9201','EPSG','8806','False easting',5000000.0,'EPSG','9001','EPSG','8807','False northing',5000000.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','5220','Modified Krovak East North',NULL,NULL,'EPSG','1079','EPSG','1043','Krovak Modified (North Orientated)','EPSG','8811','Latitude of projection centre',49.3,'EPSG','9110','EPSG','8833','Longitude of origin',42.3,'EPSG','9110','EPSG','1036','Co-latitude of cone axis',30.1717303,'EPSG','9110','EPSG','8818','Latitude of pseudo standard parallel',78.3,'EPSG','9110','EPSG','8819','Scale factor on pseudo standard parallel',0.9999,'EPSG','9201','EPSG','8806','False easting',5000000.0,'EPSG','9001','EPSG','8807','False northing',5000000.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','5222','Gabon Transverse Mercator',NULL,NULL,'EPSG','3249','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',12.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5231','Sri Lanka Grid',NULL,NULL,'EPSG','3310','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',7.0001729,'EPSG','9110','EPSG','8802','Longitude of natural origin',80.461816,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999238418,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5232','Sri Lanka Grid 1999',NULL,NULL,'EPSG','3310','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',7.00016975,'EPSG','9110','EPSG','8802','Longitude of natural origin',80.46181671,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999238418,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5265','Bhutan National Grid',NULL,NULL,'EPSG','1048','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',90.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5268','Bumthang TM',NULL,NULL,'EPSG','3734','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',90.44,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5276','Chhukha TM',NULL,NULL,'EPSG','3737','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',89.33,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5277','Dagana TM',NULL,NULL,'EPSG','3738','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',89.51,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5278','Gasa TM',NULL,NULL,'EPSG','3740','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',90.02,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5279','Ha TM',NULL,NULL,'EPSG','3742','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',90.09,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5280','Lhuentse TM',NULL,NULL,'EPSG','3743','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',91.08,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5281','Mongar TM',NULL,NULL,'EPSG','3745','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',91.14,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5282','Paro TM',NULL,NULL,'EPSG','3746','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',89.21,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5283','Pemagatshel TM',NULL,NULL,'EPSG','3747','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',91.21,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5284','Tsirang TM',NULL,NULL,'EPSG','3757','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',90.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5285','Samdrup Jongkhar TM',NULL,NULL,'EPSG','3750','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',91.34,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5286','Samtse TM',NULL,NULL,'EPSG','3751','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',89.04,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5287','Sarpang TM',NULL,NULL,'EPSG','3752','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',90.16,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5288','Wangdue Phodrang TM',NULL,NULL,'EPSG','3758','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',90.07,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5289','Trashigang TM',NULL,NULL,'EPSG','3754','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',91.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5290','Trongsa TM',NULL,NULL,'EPSG','3755','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',90.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5291','Zhemgang TM',NULL,NULL,'EPSG','3761','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',90.52,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5312','Thimphu TM',NULL,NULL,'EPSG','3753','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',89.33,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5313','Punakha TM',NULL,NULL,'EPSG','3749','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',89.51,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5314','Yangtse TM',NULL,NULL,'EPSG','3760','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',91.34,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',-2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5315','Faroe Transverse Mercator',NULL,NULL,'EPSG','1093','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-7.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999997,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',-6000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5319','Teranet Ontario Lambert',NULL,NULL,'EPSG','1367','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',0.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.3,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',54.3,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5326','Iceland Lambert 2004',NULL,NULL,'EPSG','1120','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',65.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-19.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',64.15,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',65.45,'EPSG','9110','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5328','Netherlands East Indies Equatorial Zone (Jkt)',NULL,NULL,'EPSG','4020','EPSG','9804','Mercator (variant A)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',3.113221,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.997,'EPSG','9201','EPSG','8806','False easting',3900000.0,'EPSG','9001','EPSG','8807','False northing',900000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5366','Costa Rica TM 2005',NULL,NULL,'EPSG','3849','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-84.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5390','Costa Rica Norte',NULL,NULL,'EPSG','3869','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',10.28,'EPSG','9110','EPSG','8802','Longitude of natural origin',-84.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99995696,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',271820.522,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5394','Costa Rica Sur',NULL,NULL,'EPSG','3870','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',9.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-83.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99995696,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',327987.436,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5397','Honduras Norte',NULL,NULL,'EPSG','3848','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',15.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99993273,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',296917.439,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5398','Honduras Sur',NULL,NULL,'EPSG','3850','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',13.47,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999514,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',296215.903,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5399','El Salvador Lambert',NULL,NULL,'EPSG','3243','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',13.47,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99996704,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',295809.184,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5439','Nicaragua Norte',NULL,NULL,'EPSG','3844','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',13.52,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99990314,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',359891.816,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5444','Nicaragua Sur',NULL,NULL,'EPSG','3847','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',11.44,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99992228,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',288876.327,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5465','Belize Colony Grid',NULL,NULL,'EPSG','3219','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',17.0340471,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.3754687,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',217259.26,'EPSG','9005','EPSG','8807','False northing',445474.83,'EPSG','9005',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5468','Panama Lambert',NULL,NULL,'EPSG','3290','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',8.25,'EPSG','9110','EPSG','8802','Longitude of natural origin',-80.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99989909,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',294865.303,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5471','Panama Polyconic',NULL,NULL,'EPSG','3290','EPSG','9818','American Polyconic','EPSG','8801','Latitude of natural origin',8.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-81.0,'EPSG','9110','EPSG','8806','False easting',1000000.0,'EPSG','9037','EPSG','8807','False northing',1092972.1,'EPSG','9037',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5475','McMurdo Sound Lambert Conformal 2000',NULL,NULL,'EPSG','3853','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-78.0,'EPSG','9110','EPSG','8822','Longitude of false origin',163.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',-76.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-79.2,'EPSG','9110','EPSG','8826','Easting at false origin',7000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5476','Borchgrevink Coast Lambert Conformal 2000',NULL,NULL,'EPSG','3854','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-74.3,'EPSG','9110','EPSG','8822','Longitude of false origin',165.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',-73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',5000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5477','Pennell Coast Lambert Conformal 2000',NULL,NULL,'EPSG','3855','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-71.3,'EPSG','9110','EPSG','8822','Longitude of false origin',166.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',-70.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-72.2,'EPSG','9110','EPSG','8826','Easting at false origin',3000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5478','Ross Sea Polar Stereographic 2000',NULL,NULL,'EPSG','3856','EPSG','9810','Polar Stereographic (variant A)','EPSG','8801','Latitude of natural origin',-90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',180.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.994,'EPSG','9201','EPSG','8806','False easting',5000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5509','Krovak (Greenwich)',NULL,NULL,'EPSG','1306','EPSG','9819','Krovak','EPSG','8811','Latitude of projection centre',49.3,'EPSG','9110','EPSG','8833','Longitude of origin',24.5,'EPSG','9110','EPSG','1036','Co-latitude of cone axis',30.171730311,'EPSG','9110','EPSG','8818','Latitude of pseudo standard parallel',78.3,'EPSG','9110','EPSG','8819','Scale factor on pseudo standard parallel',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','5510','Krovak East North (Greenwich)',NULL,NULL,'EPSG','1306','EPSG','1041','Krovak (North Orientated)','EPSG','8811','Latitude of projection centre',49.3,'EPSG','9110','EPSG','8833','Longitude of origin',24.5,'EPSG','9110','EPSG','1036','Co-latitude of cone axis',30.171730311,'EPSG','9110','EPSG','8818','Latitude of pseudo standard parallel',78.3,'EPSG','9110','EPSG','8819','Scale factor on pseudo standard parallel',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','5511','Modified Krovak (Greenwich)',NULL,NULL,'EPSG','1079','EPSG','1042','Krovak Modified','EPSG','8811','Latitude of projection centre',49.3,'EPSG','9110','EPSG','8833','Longitude of origin',24.5,'EPSG','9110','EPSG','1036','Co-latitude of cone axis',30.1717303,'EPSG','9110','EPSG','8818','Latitude of pseudo standard parallel',78.3,'EPSG','9110','EPSG','8819','Scale factor on pseudo standard parallel',0.9999,'EPSG','9201','EPSG','8806','False easting',5000000.0,'EPSG','9001','EPSG','8807','False northing',5000000.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','5512','Modified Krovak East North (Greenwich)',NULL,NULL,'EPSG','1079','EPSG','1043','Krovak Modified (North Orientated)','EPSG','8811','Latitude of projection centre',49.3,'EPSG','9110','EPSG','8833','Longitude of origin',24.5,'EPSG','9110','EPSG','1036','Co-latitude of cone axis',30.1717303,'EPSG','9110','EPSG','8818','Latitude of pseudo standard parallel',78.3,'EPSG','9110','EPSG','8819','Scale factor on pseudo standard parallel',0.9999,'EPSG','9201','EPSG','8806','False easting',5000000.0,'EPSG','9001','EPSG','8807','False northing',5000000.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','5517','Chatham Islands Map Grid',NULL,NULL,'EPSG','2889','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-44.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-176.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',350000.0,'EPSG','9001','EPSG','8807','False northing',650000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5522','Gabon Transverse Mercator 2011',NULL,NULL,'EPSG','1100','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',11.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1500000.0,'EPSG','9001','EPSG','8807','False northing',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5547','Papua New Guinea Map Grid 1994 zone 54',NULL,NULL,'EPSG','3882','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5548','Papua New Guinea Map Grid 1994 zone 55',NULL,NULL,'EPSG','3885','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5549','Papua New Guinea Map Grid 1994 zone 56',NULL,NULL,'EPSG','3885','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5587','New Brunswick Stereographic (NAD27)',NULL,NULL,'EPSG','1447','EPSG','9809','Oblique Stereographic','EPSG','8801','Latitude of natural origin',46.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-66.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999912,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9002','EPSG','8807','False northing',1000000.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5595','Fehmarnbelt TM',NULL,NULL,'EPSG','3889','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',11.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5640','Petrobras Mercator',NULL,NULL,'EPSG','3896','EPSG','9805','Mercator (variant B)','EPSG','8823','Latitude of 1st standard parallel',-2.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-43.0,'EPSG','9102','EPSG','8806','False easting',5000000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5642','Southern Permian Basin Atlas Lambert',NULL,NULL,'EPSG','3899','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',48.0,'EPSG','9102','EPSG','8822','Longitude of false origin',10.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',52.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',54.2,'EPSG','9110','EPSG','8826','Easting at false origin',815000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5645','SPCS83 Vermont zone (US Survey feet)',NULL,NULL,'EPSG','1414','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-72.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999964286,'EPSG','9201','EPSG','8806','False easting',1640416.6667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5647','UTM zone 31N with prefix',NULL,NULL,'EPSG','2860','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',31500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5648','UTM zone 33N with prefix',NULL,NULL,'EPSG','2862','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',33500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5658','TM Emilia-Romagna',NULL,NULL,'EPSG','4035','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500053.0,'EPSG','9001','EPSG','8807','False northing',-3999820.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5824','ACT Standard Grid',NULL,NULL,'EPSG','2283','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-35.19038506,'EPSG','9110','EPSG','8802','Longitude of natural origin',149.003346139,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000086,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',600000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5883','Tonga Map Grid',NULL,NULL,'EPSG','1234','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1500000.0,'EPSG','9001','EPSG','8807','False northing',5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5889','JAXA Snow Depth Polar Stereographic North',NULL,NULL,'EPSG','1996','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',70.0,'EPSG','9102','EPSG','8833','Longitude of origin',90.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5892','Vietnam TM-3 zone 481',NULL,NULL,'EPSG','4193','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',102.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5893','Vietnam TM-3 zone 482',NULL,NULL,'EPSG','4215','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',105.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5894','Vietnam TM-3 zone 491',NULL,NULL,'EPSG','4217','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',108.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5895','Vietnam TM-3 107-45',NULL,NULL,'EPSG','4218','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',107.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5901','EPSG Alaska Polar Stereographic',NULL,NULL,'EPSG','1996','EPSG','9810','Polar Stereographic (variant A)','EPSG','8801','Latitude of natural origin',90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-150.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.994,'EPSG','9201','EPSG','8806','False easting',2000000.0,'EPSG','9001','EPSG','8807','False northing',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5902','EPSG Canada Polar Stereographic',NULL,NULL,'EPSG','1996','EPSG','9810','Polar Stereographic (variant A)','EPSG','8801','Latitude of natural origin',90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-100.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.994,'EPSG','9201','EPSG','8806','False easting',2000000.0,'EPSG','9001','EPSG','8807','False northing',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5903','EPSG Greenland Polar Stereographic',NULL,NULL,'EPSG','1996','EPSG','9810','Polar Stereographic (variant A)','EPSG','8801','Latitude of natural origin',90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.994,'EPSG','9201','EPSG','8806','False easting',2000000.0,'EPSG','9001','EPSG','8807','False northing',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5904','EPSG Norway Polar Stereographic',NULL,NULL,'EPSG','1996','EPSG','9810','Polar Stereographic (variant A)','EPSG','8801','Latitude of natural origin',90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',18.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.994,'EPSG','9201','EPSG','8806','False easting',2000000.0,'EPSG','9001','EPSG','8807','False northing',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5905','EPSG Russia Polar Stereographic',NULL,NULL,'EPSG','1996','EPSG','9810','Polar Stereographic (variant A)','EPSG','8801','Latitude of natural origin',90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',105.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.994,'EPSG','9201','EPSG','8806','False easting',2000000.0,'EPSG','9001','EPSG','8807','False northing',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5906','EPSG Arctic Regional LCC zone A1',NULL,NULL,'EPSG','4019','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',81.19020136,'EPSG','9110','EPSG','8822','Longitude of false origin',-111.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',85.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5907','EPSG Arctic Regional LCC zone A2',NULL,NULL,'EPSG','4027','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',81.19020136,'EPSG','9110','EPSG','8822','Longitude of false origin',-39.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',85.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5908','EPSG Arctic Regional LCC zone A3',NULL,NULL,'EPSG','4028','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',81.19020136,'EPSG','9110','EPSG','8822','Longitude of false origin',33.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',85.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5909','EPSG Arctic Regional LCC zone A4',NULL,NULL,'EPSG','4029','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',81.19020136,'EPSG','9110','EPSG','8822','Longitude of false origin',105.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',85.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5910','EPSG Arctic Regional LCC zone A5',NULL,NULL,'EPSG','4031','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',81.19020136,'EPSG','9110','EPSG','8822','Longitude of false origin',177.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',85.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5911','EPSG Arctic Regional LCC zone B1',NULL,NULL,'EPSG','4032','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',73.09206671,'EPSG','9110','EPSG','8822','Longitude of false origin',-111.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',69.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5912','EPSG Arctic Regional LCC zone B2',NULL,NULL,'EPSG','4033','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',73.09206671,'EPSG','9110','EPSG','8822','Longitude of false origin',-39.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',69.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5913','EPSG Arctic Regional LCC zone B3',NULL,NULL,'EPSG','4034','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',73.09206671,'EPSG','9110','EPSG','8822','Longitude of false origin',33.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',69.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5914','EPSG Arctic Regional LCC zone B4',NULL,NULL,'EPSG','4037','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',73.09206671,'EPSG','9110','EPSG','8822','Longitude of false origin',105.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',69.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5915','EPSG Arctic Regional LCC zone B5',NULL,NULL,'EPSG','4038','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',73.09206671,'EPSG','9110','EPSG','8822','Longitude of false origin',177.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',69.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5916','EPSG Arctic Regional LCC zone C1',NULL,NULL,'EPSG','4040','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',65.06045752,'EPSG','9110','EPSG','8822','Longitude of false origin',-111.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',69.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',61.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5917','EPSG Arctic Regional LCC zone C2',NULL,NULL,'EPSG','4041','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',65.06045752,'EPSG','9110','EPSG','8822','Longitude of false origin',-39.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',69.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',61.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5918','EPSG Arctic Regional LCC zone C3',NULL,NULL,'EPSG','4042','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',65.06045752,'EPSG','9110','EPSG','8822','Longitude of false origin',33.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',69.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',61.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5919','EPSG Arctic Regional LCC zone C4',NULL,NULL,'EPSG','4043','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',65.06045752,'EPSG','9110','EPSG','8822','Longitude of false origin',105.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',69.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',61.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5920','EPSG Arctic Regional LCC zone C5',NULL,NULL,'EPSG','4045','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',65.06045752,'EPSG','9110','EPSG','8822','Longitude of false origin',177.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',69.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',61.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5943','EPSG Arctic LCC zone 8-20',NULL,NULL,'EPSG','4123','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',62.00551048,'EPSG','9110','EPSG','8822','Longitude of false origin',-52.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',63.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',60.2,'EPSG','9110','EPSG','8826','Easting at false origin',20500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',8500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5944','EPSG Arctic LCC zone 8-22',NULL,NULL,'EPSG','4124','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',62.00551048,'EPSG','9110','EPSG','8822','Longitude of false origin',-37.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',63.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',60.2,'EPSG','9110','EPSG','8826','Easting at false origin',22500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',8500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5977','EPSG Arctic LCC zone 1-21',NULL,NULL,'EPSG','4044','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',85.2613626,'EPSG','9110','EPSG','8822','Longitude of false origin',-150.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',87.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',83.4,'EPSG','9110','EPSG','8826','Easting at false origin',21500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5978','EPSG Arctic LCC zone 1-23',NULL,NULL,'EPSG','4047','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',85.2613626,'EPSG','9110','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',87.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',83.4,'EPSG','9110','EPSG','8826','Easting at false origin',23500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5979','EPSG Arctic LCC zone 1-25',NULL,NULL,'EPSG','4048','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',85.2613626,'EPSG','9110','EPSG','8822','Longitude of false origin',-30.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',87.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',83.4,'EPSG','9110','EPSG','8826','Easting at false origin',25500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5980','EPSG Arctic LCC zone 1-27',NULL,NULL,'EPSG','4049','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',85.2613626,'EPSG','9110','EPSG','8822','Longitude of false origin',30.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',87.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',83.4,'EPSG','9110','EPSG','8826','Easting at false origin',27500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5981','EPSG Arctic LCC zone 1-29',NULL,NULL,'EPSG','4050','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',85.2613626,'EPSG','9110','EPSG','8822','Longitude of false origin',90.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',87.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',83.4,'EPSG','9110','EPSG','8826','Easting at false origin',29500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5982','EPSG Arctic LCC zone 1-31',NULL,NULL,'EPSG','4051','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',85.2613626,'EPSG','9110','EPSG','8822','Longitude of false origin',150.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',87.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',83.4,'EPSG','9110','EPSG','8826','Easting at false origin',31500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5983','EPSG Arctic LCC zone 2-10',NULL,NULL,'EPSG','4057','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',82.03303296,'EPSG','9110','EPSG','8822','Longitude of false origin',166.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',83.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',80.2,'EPSG','9110','EPSG','8826','Easting at false origin',10500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5984','EPSG Arctic LCC zone 2-12',NULL,NULL,'EPSG','4052','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',82.03303296,'EPSG','9110','EPSG','8822','Longitude of false origin',-154.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',83.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',80.2,'EPSG','9110','EPSG','8826','Easting at false origin',12500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5985','EPSG Arctic LCC zone 2-14',NULL,NULL,'EPSG','4030','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',82.03303296,'EPSG','9110','EPSG','8822','Longitude of false origin',-115.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',83.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',80.2,'EPSG','9110','EPSG','8826','Easting at false origin',14500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5986','EPSG Arctic LCC zone 2-16',NULL,NULL,'EPSG','4036','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',82.03303296,'EPSG','9110','EPSG','8822','Longitude of false origin',-75.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',83.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',80.2,'EPSG','9110','EPSG','8826','Easting at false origin',16500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5987','EPSG Arctic LCC zone 2-18',NULL,NULL,'EPSG','4039','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',82.03303296,'EPSG','9110','EPSG','8822','Longitude of false origin',-52.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',83.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',80.2,'EPSG','9110','EPSG','8826','Easting at false origin',18500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5988','EPSG Arctic LCC zone 2-20',NULL,NULL,'EPSG','4046','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',82.03303296,'EPSG','9110','EPSG','8822','Longitude of false origin',-12.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',83.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',80.2,'EPSG','9110','EPSG','8826','Easting at false origin',20500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5989','EPSG Arctic LCC zone 2-22',NULL,NULL,'EPSG','4053','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',82.03303296,'EPSG','9110','EPSG','8822','Longitude of false origin',16.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',83.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',80.2,'EPSG','9110','EPSG','8826','Easting at false origin',22500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5990','EPSG Arctic LCC zone 2-24',NULL,NULL,'EPSG','4054','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',82.03303296,'EPSG','9110','EPSG','8822','Longitude of false origin',53.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',83.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',80.2,'EPSG','9110','EPSG','8826','Easting at false origin',24500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5991','EPSG Arctic LCC zone 2-26',NULL,NULL,'EPSG','4055','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',82.03303296,'EPSG','9110','EPSG','8822','Longitude of false origin',93.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',83.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',80.2,'EPSG','9110','EPSG','8826','Easting at false origin',26500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5992','EPSG Arctic LCC zone 2-28',NULL,NULL,'EPSG','4056','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',82.03303296,'EPSG','9110','EPSG','8822','Longitude of false origin',133.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',83.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',80.2,'EPSG','9110','EPSG','8826','Easting at false origin',28500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5993','EPSG Arctic LCC zone 3-11',NULL,NULL,'EPSG','4058','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',78.42264151,'EPSG','9110','EPSG','8822','Longitude of false origin',21.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',80.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9110','EPSG','8826','Easting at false origin',11500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5994','EPSG Arctic LCC zone 3-13',NULL,NULL,'EPSG','4059','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',78.42264151,'EPSG','9110','EPSG','8822','Longitude of false origin',52.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',80.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9110','EPSG','8826','Easting at false origin',13500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5995','EPSG Arctic LCC zone 3-15',NULL,NULL,'EPSG','4060','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',78.42264151,'EPSG','9110','EPSG','8822','Longitude of false origin',83.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',80.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9110','EPSG','8826','Easting at false origin',15500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5996','EPSG Arctic LCC zone 3-17',NULL,NULL,'EPSG','4061','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',78.42264151,'EPSG','9110','EPSG','8822','Longitude of false origin',114.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',80.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9110','EPSG','8826','Easting at false origin',17500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5997','EPSG Arctic LCC zone 3-19',NULL,NULL,'EPSG','4062','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',78.42264151,'EPSG','9110','EPSG','8822','Longitude of false origin',145.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',80.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9110','EPSG','8826','Easting at false origin',19500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5998','EPSG Arctic LCC zone 3-21',NULL,NULL,'EPSG','4063','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',78.42264151,'EPSG','9110','EPSG','8822','Longitude of false origin',176.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',80.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9110','EPSG','8826','Easting at false origin',21500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','5999','EPSG Arctic LCC zone 3-23',NULL,NULL,'EPSG','4064','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',78.42264151,'EPSG','9110','EPSG','8822','Longitude of false origin',-153.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',80.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9110','EPSG','8826','Easting at false origin',23500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6000','EPSG Arctic LCC zone 3-25',NULL,NULL,'EPSG','4065','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',78.42264151,'EPSG','9110','EPSG','8822','Longitude of false origin',-129.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',80.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9110','EPSG','8826','Easting at false origin',25500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6001','EPSG Arctic LCC zone 3-27',NULL,NULL,'EPSG','4070','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',78.42264151,'EPSG','9110','EPSG','8822','Longitude of false origin',-99.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',80.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9110','EPSG','8826','Easting at false origin',27500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6002','EPSG Arctic LCC zone 3-29',NULL,NULL,'EPSG','4071','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',78.42264151,'EPSG','9110','EPSG','8822','Longitude of false origin',-69.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',80.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9110','EPSG','8826','Easting at false origin',29500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6003','EPSG Arctic LCC zone 3-31',NULL,NULL,'EPSG','4074','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',78.42264151,'EPSG','9110','EPSG','8822','Longitude of false origin',-39.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',80.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9110','EPSG','8826','Easting at false origin',31500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6004','EPSG Arctic LCC zone 3-33',NULL,NULL,'EPSG','4075','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',78.42264151,'EPSG','9110','EPSG','8822','Longitude of false origin',-10.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',80.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9110','EPSG','8826','Easting at false origin',33500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6005','EPSG Arctic LCC zone 4-12',NULL,NULL,'EPSG','4076','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',75.21518519,'EPSG','9110','EPSG','8822','Longitude of false origin',-155.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',73.4,'EPSG','9110','EPSG','8826','Easting at false origin',12500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6006','EPSG Arctic LCC zone 4-14',NULL,NULL,'EPSG','4077','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',75.21518519,'EPSG','9110','EPSG','8822','Longitude of false origin',-129.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',73.4,'EPSG','9110','EPSG','8826','Easting at false origin',14500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6007','EPSG Arctic LCC zone 4-16',NULL,NULL,'EPSG','4078','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',75.21518519,'EPSG','9110','EPSG','8822','Longitude of false origin',-104.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',73.4,'EPSG','9110','EPSG','8826','Easting at false origin',16500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6008','EPSG Arctic LCC zone 4-18',NULL,NULL,'EPSG','4079','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',75.21518519,'EPSG','9110','EPSG','8822','Longitude of false origin',-79.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',73.4,'EPSG','9110','EPSG','8826','Easting at false origin',18500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6009','EPSG Arctic LCC zone 4-20',NULL,NULL,'EPSG','4080','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',75.21518519,'EPSG','9110','EPSG','8822','Longitude of false origin',-64.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',73.4,'EPSG','9110','EPSG','8826','Easting at false origin',20500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6010','EPSG Arctic LCC zone 4-22',NULL,NULL,'EPSG','4081','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',75.21518519,'EPSG','9110','EPSG','8822','Longitude of false origin',-39.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',73.4,'EPSG','9110','EPSG','8826','Easting at false origin',22500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6011','EPSG Arctic LCC zone 4-24',NULL,NULL,'EPSG','4082','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',75.21518519,'EPSG','9110','EPSG','8822','Longitude of false origin',-14.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',73.4,'EPSG','9110','EPSG','8826','Easting at false origin',24500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6012','EPSG Arctic LCC zone 4-26',NULL,NULL,'EPSG','4083','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',75.21518519,'EPSG','9110','EPSG','8822','Longitude of false origin',10.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',73.4,'EPSG','9110','EPSG','8826','Easting at false origin',26500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6013','EPSG Arctic LCC zone 4-28',NULL,NULL,'EPSG','4084','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',75.21518519,'EPSG','9110','EPSG','8822','Longitude of false origin',34.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',73.4,'EPSG','9110','EPSG','8826','Easting at false origin',28500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6014','EPSG Arctic LCC zone 4-30',NULL,NULL,'EPSG','4085','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',75.21518519,'EPSG','9110','EPSG','8822','Longitude of false origin',58.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',73.4,'EPSG','9110','EPSG','8826','Easting at false origin',30500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6015','EPSG Arctic LCC zone 4-32',NULL,NULL,'EPSG','4086','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',75.21518519,'EPSG','9110','EPSG','8822','Longitude of false origin',82.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',73.4,'EPSG','9110','EPSG','8826','Easting at false origin',32500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6016','EPSG Arctic LCC zone 4-34',NULL,NULL,'EPSG','4087','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',75.21518519,'EPSG','9110','EPSG','8822','Longitude of false origin',106.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',73.4,'EPSG','9110','EPSG','8826','Easting at false origin',34500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6017','EPSG Arctic LCC zone 4-36',NULL,NULL,'EPSG','4088','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',75.21518519,'EPSG','9110','EPSG','8822','Longitude of false origin',130.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',73.4,'EPSG','9110','EPSG','8826','Easting at false origin',36500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6018','EPSG Arctic LCC zone 4-38',NULL,NULL,'EPSG','4089','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',75.21518519,'EPSG','9110','EPSG','8822','Longitude of false origin',154.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',73.4,'EPSG','9110','EPSG','8826','Easting at false origin',38500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6019','EPSG Arctic LCC zone 4-40',NULL,NULL,'EPSG','4090','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',75.21518519,'EPSG','9110','EPSG','8822','Longitude of false origin',179.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',77.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',73.4,'EPSG','9110','EPSG','8826','Easting at false origin',40500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6020','EPSG Arctic LCC zone 5-11',NULL,NULL,'EPSG','4091','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',14.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',11500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6021','EPSG Arctic LCC zone 5-13',NULL,NULL,'EPSG','4092','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',34.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',13500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6022','EPSG Arctic LCC zone 5-15',NULL,NULL,'EPSG','4093','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',54.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',15500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6023','EPSG Arctic LCC zone 5-17',NULL,NULL,'EPSG','4094','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',74.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',17500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6024','EPSG Arctic LCC zone 5-19',NULL,NULL,'EPSG','4095','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',95.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',19500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6025','EPSG Arctic LCC zone 5-21',NULL,NULL,'EPSG','4096','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',116.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',21500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6026','EPSG Arctic LCC zone 5-23',NULL,NULL,'EPSG','4097','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',137.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',23500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6027','EPSG Arctic LCC zone 5-25',NULL,NULL,'EPSG','4098','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',158.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',25500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6028','EPSG Arctic LCC zone 5-27',NULL,NULL,'EPSG','4099','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',179.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',27500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6029','EPSG Arctic LCC zone 5-29',NULL,NULL,'EPSG','4100','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',-163.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',29500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6030','EPSG Arctic LCC zone 5-31',NULL,NULL,'EPSG','4101','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',-147.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',31500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6031','EPSG Arctic LCC zone 5-33',NULL,NULL,'EPSG','4102','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',-131.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',33500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6032','EPSG Arctic LCC zone 5-35',NULL,NULL,'EPSG','4103','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',-111.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',35500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6033','EPSG Arctic LCC zone 5-37',NULL,NULL,'EPSG','4104','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',-91.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',37500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6034','EPSG Arctic LCC zone 5-39',NULL,NULL,'EPSG','4105','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',-71.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',39500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6035','EPSG Arctic LCC zone 5-41',NULL,NULL,'EPSG','4106','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',-62.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',41500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6036','EPSG Arctic LCC zone 5-43',NULL,NULL,'EPSG','4107','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',-42.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',43500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6037','EPSG Arctic LCC zone 5-45',NULL,NULL,'EPSG','4108','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',-22.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',45500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6038','EPSG Arctic LCC zone 5-47',NULL,NULL,'EPSG','4109','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',72.01300331,'EPSG','9110','EPSG','8822','Longitude of false origin',-5.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',73.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',70.2,'EPSG','9110','EPSG','8826','Easting at false origin',47500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6039','EPSG Arctic LCC zone 6-14',NULL,NULL,'EPSG','4110','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',68.4114912,'EPSG','9110','EPSG','8822','Longitude of false origin',-165.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',70.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',67.0,'EPSG','9110','EPSG','8826','Easting at false origin',14500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',6500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6040','EPSG Arctic LCC zone 6-16',NULL,NULL,'EPSG','4111','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',68.4114912,'EPSG','9110','EPSG','8822','Longitude of false origin',-147.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',70.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',67.0,'EPSG','9110','EPSG','8826','Easting at false origin',16500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',6500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6041','EPSG Arctic LCC zone 6-18',NULL,NULL,'EPSG','4112','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',68.4114912,'EPSG','9110','EPSG','8822','Longitude of false origin',-132.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',70.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',67.0,'EPSG','9110','EPSG','8826','Easting at false origin',18500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',6500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6042','EPSG Arctic LCC zone 6-20',NULL,NULL,'EPSG','4113','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',68.4114912,'EPSG','9110','EPSG','8822','Longitude of false origin',-113.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',70.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',67.0,'EPSG','9110','EPSG','8826','Easting at false origin',20500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',6500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6043','EPSG Arctic LCC zone 6-22',NULL,NULL,'EPSG','4114','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',68.4114912,'EPSG','9110','EPSG','8822','Longitude of false origin',-94.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',70.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',67.0,'EPSG','9110','EPSG','8826','Easting at false origin',22500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',6500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6044','EPSG Arctic LCC zone 6-24',NULL,NULL,'EPSG','4115','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',68.4114912,'EPSG','9110','EPSG','8822','Longitude of false origin',-75.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',70.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',67.0,'EPSG','9110','EPSG','8826','Easting at false origin',24500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',6500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6045','EPSG Arctic LCC zone 6-26',NULL,NULL,'EPSG','4116','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',68.4114912,'EPSG','9110','EPSG','8822','Longitude of false origin',-56.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',70.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',67.0,'EPSG','9110','EPSG','8826','Easting at false origin',26500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',6500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6046','EPSG Arctic LCC zone 6-28',NULL,NULL,'EPSG','4117','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',68.4114912,'EPSG','9110','EPSG','8822','Longitude of false origin',-38.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',70.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',67.0,'EPSG','9110','EPSG','8826','Easting at false origin',28500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',6500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6047','EPSG Arctic LCC zone 6-30',NULL,NULL,'EPSG','4118','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',68.4114912,'EPSG','9110','EPSG','8822','Longitude of false origin',-20.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',70.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',67.0,'EPSG','9110','EPSG','8826','Easting at false origin',30500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',6500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6048','EPSG Arctic LCC zone 7-11',NULL,NULL,'EPSG','4119','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',65.21037415,'EPSG','9110','EPSG','8822','Longitude of false origin',-51.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',67.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',63.4,'EPSG','9110','EPSG','8826','Easting at false origin',11500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',7500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6049','EPSG Arctic LCC zone 7-13',NULL,NULL,'EPSG','4120','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',65.21037415,'EPSG','9110','EPSG','8822','Longitude of false origin',-34.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',67.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',63.4,'EPSG','9110','EPSG','8826','Easting at false origin',13500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',7500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6126','Cayman Islands LCC (ft)',NULL,NULL,'EPSG','1063','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',19.2,'EPSG','9110','EPSG','8822','Longitude of false origin',80.34,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',19.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',19.42,'EPSG','9110','EPSG','8826','Easting at false origin',2950000.0,'EPSG','9002','EPSG','8827','Northing at false origin',1900000.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','6127','Cayman Islands TM (ft)',NULL,NULL,'EPSG','1063','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-81.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640419.9475,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6197','Michigan CS27 North zone',NULL,NULL,'EPSG','1723','EPSG','1051','Lambert Conic Conformal (2SP Michigan)','EPSG','8821','Latitude of false origin',44.87,'EPSG','9110','EPSG','8822','Longitude of false origin',-87.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',45.29,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',47.05,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003','EPSG','1038','Ellipsoid scaling factor',1.0000382,'EPSG','9201',1);
INSERT INTO "conversion" VALUES('EPSG','6198','Michigan CS27 Central zone',NULL,NULL,'EPSG','1724','EPSG','1051','Lambert Conic Conformal (2SP Michigan)','EPSG','8821','Latitude of false origin',43.19,'EPSG','9110','EPSG','8822','Longitude of false origin',-84.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',44.11,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',45.42,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003','EPSG','1038','Ellipsoid scaling factor',1.0000382,'EPSG','9201',0);
INSERT INTO "conversion" VALUES('EPSG','6199','Michigan CS27 South zone',NULL,NULL,'EPSG','1725','EPSG','1051','Lambert Conic Conformal (2SP Michigan)','EPSG','8821','Latitude of false origin',41.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-84.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',42.06,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',43.4,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003','EPSG','1038','Ellipsoid scaling factor',1.0000382,'EPSG','9201',0);
INSERT INTO "conversion" VALUES('EPSG','6203','Macedonia Gauss-Kruger',NULL,NULL,'EPSG','1148','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6212','Arauca urban grid',NULL,NULL,'EPSG','4122','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',7.051538301,'EPSG','9110','EPSG','8802','Longitude of natural origin',-70.452991476,'EPSG','9110','EPSG','8806','False easting',1035263.443,'EPSG','9001','EPSG','8807','False northing',1275526.621,'EPSG','9001','EPSG','1039','Projection plane origin height',100.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6213','Armenia urban grid',NULL,NULL,'EPSG','4132','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',4.315637,'EPSG','9110','EPSG','8802','Longitude of natural origin',-75.4024561,'EPSG','9110','EPSG','8806','False easting',1155824.666,'EPSG','9001','EPSG','8807','False northing',993087.465,'EPSG','9001','EPSG','1039','Projection plane origin height',1470.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6214','Barranquilla urban grid',NULL,NULL,'EPSG','4134','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',10.55234591,'EPSG','9110','EPSG','8802','Longitude of natural origin',-74.50035928,'EPSG','9110','EPSG','8806','False easting',917264.406,'EPSG','9001','EPSG','8807','False northing',1699839.935,'EPSG','9001','EPSG','1039','Projection plane origin height',100.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6215','Bogota urban grid',NULL,NULL,'EPSG','4135','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',4.404975,'EPSG','9110','EPSG','8802','Longitude of natural origin',-74.084773,'EPSG','9110','EPSG','8806','False easting',92334.879,'EPSG','9001','EPSG','8807','False northing',109320.965,'EPSG','9001','EPSG','1039','Projection plane origin height',2550.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6216','Bucaramanga urban grid',NULL,NULL,'EPSG','4136','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',7.044399371,'EPSG','9110','EPSG','8802','Longitude of natural origin',-73.11504356,'EPSG','9110','EPSG','8806','False easting',1097241.305,'EPSG','9001','EPSG','8807','False northing',1274642.278,'EPSG','9001','EPSG','1039','Projection plane origin height',931.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6217','Cali urban grid',NULL,NULL,'EPSG','4137','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',3.263078,'EPSG','9110','EPSG','8802','Longitude of natural origin',-76.3114025,'EPSG','9110','EPSG','8806','False easting',1061900.18,'EPSG','9001','EPSG','8807','False northing',872364.63,'EPSG','9001','EPSG','1039','Projection plane origin height',1000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6218','Cartagena urban grid',NULL,NULL,'EPSG','4138','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',10.2349371,'EPSG','9110','EPSG','8802','Longitude of natural origin',-75.3040345,'EPSG','9110','EPSG','8806','False easting',842981.41,'EPSG','9001','EPSG','8807','False northing',1641887.09,'EPSG','9001','EPSG','1039','Projection plane origin height',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6219','Cucuta urban grid',NULL,NULL,'EPSG','4139','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',7.532017225,'EPSG','9110','EPSG','8802','Longitude of natural origin',-72.301033542,'EPSG','9110','EPSG','8806','False easting',842805.406,'EPSG','9001','EPSG','8807','False northing',1364404.57,'EPSG','9001','EPSG','1039','Projection plane origin height',308.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6220','Florencia urban grid',NULL,NULL,'EPSG','4140','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',1.371564426,'EPSG','9110','EPSG','8802','Longitude of natural origin',-75.370882337,'EPSG','9110','EPSG','8806','False easting',1162300.348,'EPSG','9001','EPSG','8807','False northing',671068.716,'EPSG','9001','EPSG','1039','Projection plane origin height',300.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6221','Ibague urban grid',NULL,NULL,'EPSG','4141','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',4.250988618,'EPSG','9110','EPSG','8802','Longitude of natural origin',-75.104773336,'EPSG','9110','EPSG','8806','False easting',877634.33,'EPSG','9001','EPSG','8807','False northing',980541.348,'EPSG','9001','EPSG','1039','Projection plane origin height',1100.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6222','Inirida urban grid',NULL,NULL,'EPSG','4142','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',3.504357746,'EPSG','9110','EPSG','8802','Longitude of natural origin',-67.541883552,'EPSG','9110','EPSG','8806','False easting',1019177.687,'EPSG','9001','EPSG','8807','False northing',491791.326,'EPSG','9001','EPSG','1039','Projection plane origin height',96.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6223','Leticia urban grid',NULL,NULL,'EPSG','4143','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',-4.115166257,'EPSG','9110','EPSG','8802','Longitude of natural origin',-69.563411981,'EPSG','9110','EPSG','8806','False easting',25978.217,'EPSG','9001','EPSG','8807','False northing',27501.365,'EPSG','9001','EPSG','1039','Projection plane origin height',89.7,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6224','Manizales urban grid',NULL,NULL,'EPSG','4144','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',5.0405354,'EPSG','9110','EPSG','8802','Longitude of natural origin',-75.3039941,'EPSG','9110','EPSG','8806','False easting',1173727.04,'EPSG','9001','EPSG','8807','False northing',1052391.13,'EPSG','9001','EPSG','1039','Projection plane origin height',2100.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6225','Medellin urban grid',NULL,NULL,'EPSG','4145','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',6.1345152,'EPSG','9110','EPSG','8802','Longitude of natural origin',-75.3353593,'EPSG','9110','EPSG','8806','False easting',835378.647,'EPSG','9001','EPSG','8807','False northing',1180816.875,'EPSG','9001','EPSG','1039','Projection plane origin height',1510.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6226','Mitu urban grid',NULL,NULL,'EPSG','4146','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',1.145988972,'EPSG','9110','EPSG','8802','Longitude of natural origin',-70.140766196,'EPSG','9110','EPSG','8806','False easting',1093717.398,'EPSG','9001','EPSG','8807','False northing',629997.236,'EPSG','9001','EPSG','1039','Projection plane origin height',170.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6227','Mocoa urban grid',NULL,NULL,'EPSG','4147','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',1.082408409,'EPSG','9110','EPSG','8802','Longitude of natural origin',-76.390367639,'EPSG','9110','EPSG','8806','False easting',1047467.388,'EPSG','9001','EPSG','8807','False northing',617828.474,'EPSG','9001','EPSG','1039','Projection plane origin height',655.2,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6228','Monteria urban grid',NULL,NULL,'EPSG','4148','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',8.462310872,'EPSG','9110','EPSG','8802','Longitude of natural origin',-75.524639199,'EPSG','9110','EPSG','8806','False easting',1131814.934,'EPSG','9001','EPSG','8807','False northing',1462131.119,'EPSG','9001','EPSG','1039','Projection plane origin height',15.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6229','Neiva urban grid',NULL,NULL,'EPSG','4149','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',2.56326942,'EPSG','9110','EPSG','8802','Longitude of natural origin',-75.17471722,'EPSG','9110','EPSG','8806','False easting',864476.923,'EPSG','9001','EPSG','8807','False northing',817199.827,'EPSG','9001','EPSG','1039','Projection plane origin height',430.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6230','Pasto urban grid',NULL,NULL,'EPSG','4150','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',1.120356225,'EPSG','9110','EPSG','8802','Longitude of natural origin',-77.151125228,'EPSG','9110','EPSG','8806','False easting',980469.695,'EPSG','9001','EPSG','8807','False northing',624555.332,'EPSG','9001','EPSG','1039','Projection plane origin height',2530.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6231','Pereira urban grid',NULL,NULL,'EPSG','4151','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',4.4848937,'EPSG','9110','EPSG','8802','Longitude of natural origin',-75.4138225,'EPSG','9110','EPSG','8806','False easting',1153492.012,'EPSG','9001','EPSG','8807','False northing',1024195.255,'EPSG','9001','EPSG','1039','Projection plane origin height',1500.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6232','Popayan urban grid',NULL,NULL,'EPSG','4152','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',2.272217558,'EPSG','9110','EPSG','8802','Longitude of natural origin',-76.362192989,'EPSG','9110','EPSG','8806','False easting',1052430.525,'EPSG','9001','EPSG','8807','False northing',763366.548,'EPSG','9001','EPSG','1039','Projection plane origin height',1740.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6233','Puerto Carreno urban grid',NULL,NULL,'EPSG','4153','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',6.105059709,'EPSG','9110','EPSG','8802','Longitude of natural origin',-67.300270089,'EPSG','9110','EPSG','8806','False easting',1063834.703,'EPSG','9001','EPSG','8807','False northing',1175257.481,'EPSG','9001','EPSG','1039','Projection plane origin height',51.58,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6234','Quibdo urban grid',NULL,NULL,'EPSG','4154','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',5.413929158,'EPSG','9110','EPSG','8802','Longitude of natural origin',-76.390271389,'EPSG','9110','EPSG','8806','False easting',1047273.617,'EPSG','9001','EPSG','8807','False northing',1121443.09,'EPSG','9001','EPSG','1039','Projection plane origin height',44.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6235','Riohacha urban grid',NULL,NULL,'EPSG','4155','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',11.321288798,'EPSG','9110','EPSG','8802','Longitude of natural origin',-72.540996793,'EPSG','9110','EPSG','8806','False easting',1128154.73,'EPSG','9001','EPSG','8807','False northing',1767887.914,'EPSG','9001','EPSG','1039','Projection plane origin height',6.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6236','San Andres urban grid',NULL,NULL,'EPSG','4156','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',12.312565957,'EPSG','9110','EPSG','8802','Longitude of natural origin',-81.434575342,'EPSG','9110','EPSG','8806','False easting',820439.298,'EPSG','9001','EPSG','8807','False northing',1877357.828,'EPSG','9001','EPSG','1039','Projection plane origin height',6.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6237','San Jose del Guaviare urban grid',NULL,NULL,'EPSG','4157','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',2.335068419,'EPSG','9110','EPSG','8802','Longitude of natural origin',-72.382411997,'EPSG','9110','EPSG','8806','False easting',1159876.62,'EPSG','9001','EPSG','8807','False northing',775380.342,'EPSG','9001','EPSG','1039','Projection plane origin height',185.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6238','Santa Marta urban grid',NULL,NULL,'EPSG','4128','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',11.1310715,'EPSG','9110','EPSG','8802','Longitude of natural origin',-74.1330019,'EPSG','9110','EPSG','8806','False easting',983892.409,'EPSG','9001','EPSG','8807','False northing',1732533.518,'EPSG','9001','EPSG','1039','Projection plane origin height',29.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6239','Sucre urban grid',NULL,NULL,'EPSG','4130','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',8.483798132,'EPSG','9110','EPSG','8802','Longitude of natural origin',-74.432088057,'EPSG','9110','EPSG','8806','False easting',929043.607,'EPSG','9001','EPSG','8807','False northing',1466125.658,'EPSG','9001','EPSG','1039','Projection plane origin height',20.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6240','Tunja urban grid',NULL,NULL,'EPSG','4131','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',5.320310106,'EPSG','9110','EPSG','8802','Longitude of natural origin',-73.210698004,'EPSG','9110','EPSG','8806','False easting',1080514.91,'EPSG','9001','EPSG','8807','False northing',1103772.028,'EPSG','9001','EPSG','1039','Projection plane origin height',2800.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6241','Valledupar urban grid',NULL,NULL,'EPSG','4158','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',10.265014,'EPSG','9110','EPSG','8802','Longitude of natural origin',-73.1447657,'EPSG','9110','EPSG','8806','False easting',1090979.66,'EPSG','9001','EPSG','8807','False northing',1647208.93,'EPSG','9001','EPSG','1039','Projection plane origin height',200.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6242','Villavicencio urban grid',NULL,NULL,'EPSG','4159','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',4.091935036,'EPSG','9110','EPSG','8802','Longitude of natural origin',-73.372814955,'EPSG','9110','EPSG','8806','False easting',1050678.757,'EPSG','9001','EPSG','8807','False northing',950952.124,'EPSG','9001','EPSG','1039','Projection plane origin height',427.19,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6243','Yopal urban grid',NULL,NULL,'EPSG','4160','EPSG','1052','Colombia Urban','EPSG','8801','Latitude of natural origin',5.2114138,'EPSG','9110','EPSG','8802','Longitude of natural origin',-72.2512145,'EPSG','9110','EPSG','8806','False easting',851184.177,'EPSG','9001','EPSG','8807','False northing',1083954.137,'EPSG','9001','EPSG','1039','Projection plane origin height',300.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6308','Cyprus Transverse Mercator',NULL,NULL,'EPSG','3236','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',-3500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6361','Mexico LCC',NULL,NULL,'EPSG','1160','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',12.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-102.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',17.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',29.5,'EPSG','9102','EPSG','8826','Easting at false origin',2500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6374','Ukraine TM zone 7',NULL,NULL,'EPSG','3906','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6375','Ukraine TM zone 8',NULL,NULL,'EPSG','3907','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',24.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6376','Ukraine TM zone 9',NULL,NULL,'EPSG','3908','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6377','Ukraine TM zone 10',NULL,NULL,'EPSG','3909','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',30.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6378','Ukraine TM zone 11',NULL,NULL,'EPSG','3910','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6379','Ukraine TM zone 12',NULL,NULL,'EPSG','3912','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',36.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6380','Ukraine TM zone 13',NULL,NULL,'EPSG','3913','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',39.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6390','Cayman Islands LCC (ft)',NULL,NULL,'EPSG','1063','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',19.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-80.34,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',19.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',19.42,'EPSG','9110','EPSG','8826','Easting at false origin',2950000.0,'EPSG','9002','EPSG','8827','Northing at false origin',1900000.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6645','Quebec Albers Projection',NULL,NULL,'EPSG','1368','EPSG','9822','Albers Equal Area','EPSG','8821','Latitude of false origin',44.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-68.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',60.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',46.0,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6702','TM 60 SW',NULL,NULL,'EPSG','4172','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-60.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6716','Christmas Island Grid 1992',NULL,NULL,'EPSG','4169','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',105.373,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000024,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',1300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6717','Christmas Island Grid 1994',NULL,NULL,'EPSG','4169','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',105.373,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00002514,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',1300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6718','Cocos Island Grid 1992',NULL,NULL,'EPSG','1069','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',96.523,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',1400000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6719','Cocos Island Grid 1994',NULL,NULL,'EPSG','1069','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',96.523,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99999387,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6725','Map Grid of Australia zone 41',NULL,NULL,'EPSG','4173','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',63.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','6726','Map Grid of Australia zone 42',NULL,NULL,'EPSG','4181','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',69.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','6727','Map Grid of Australia zone 43',NULL,NULL,'EPSG','4184','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',75.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','6728','Map Grid of Australia zone 44',NULL,NULL,'EPSG','4185','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',81.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','6729','Map Grid of Australia zone 46',NULL,NULL,'EPSG','4189','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',93.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6730','Map Grid of Australia zone 47',NULL,NULL,'EPSG','4190','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',99.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6731','Map Grid of Australia zone 59',NULL,NULL,'EPSG','4179','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',171.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6741','Oregon Baker zone (meters)',NULL,NULL,'EPSG','4180','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-117.5,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00016,'EPSG','9201','EPSG','8806','False easting',40000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6742','Oregon Baker zone (International feet)',NULL,NULL,'EPSG','4180','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-117.5,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00016,'EPSG','9201','EPSG','8806','False easting',131233.5958,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6743','Oregon Bend-Klamath Falls zone (meters)',NULL,NULL,'EPSG','4192','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-121.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0002,'EPSG','9201','EPSG','8806','False easting',80000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6744','Oregon Bend-Klamath Falls zone (International feet)',NULL,NULL,'EPSG','4192','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-121.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0002,'EPSG','9201','EPSG','8806','False easting',262467.1916,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6745','Oregon Bend-Redmond-Prineville zone (meters)',NULL,NULL,'EPSG','4195','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-121.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00012,'EPSG','9201','EPSG','8806','False easting',80000.0,'EPSG','9001','EPSG','8807','False northing',130000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6746','Oregon Bend-Redmond-Prineville zone (International feet)',NULL,NULL,'EPSG','4195','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-121.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00012,'EPSG','9201','EPSG','8806','False easting',262467.1916,'EPSG','9002','EPSG','8807','False northing',426509.1864,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6747','Oregon Bend-Burns zone (meters)',NULL,NULL,'EPSG','4182','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-119.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0002,'EPSG','9201','EPSG','8806','False easting',120000.0,'EPSG','9001','EPSG','8807','False northing',60000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6748','Oregon Bend-Burns zone (International feet)',NULL,NULL,'EPSG','4182','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-119.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0002,'EPSG','9201','EPSG','8806','False easting',393700.7874,'EPSG','9002','EPSG','8807','False northing',196850.3937,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6749','Oregon Canyonville-Grants Pass zone (meters)',NULL,NULL,'EPSG','4199','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-123.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00007,'EPSG','9201','EPSG','8806','False easting',40000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6750','Oregon Canyonville-Grants Pass zone (International feet)',NULL,NULL,'EPSG','4199','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-123.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00007,'EPSG','9201','EPSG','8806','False easting',131233.5958,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6751','Oregon Columbia River East zone (meters)',NULL,NULL,'EPSG','4200','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-120.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000008,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',30000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6752','Oregon Columbia River East zone (International feet)',NULL,NULL,'EPSG','4200','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-120.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000008,'EPSG','9201','EPSG','8806','False easting',492125.9843,'EPSG','9002','EPSG','8807','False northing',98425.1969,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6753','Oregon Columbia River West zone (meters)',NULL,NULL,'EPSG','4202','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',45.55,'EPSG','9110','EPSG','8812','Longitude of projection centre',-123.0,'EPSG','9110','EPSG','8813','Azimuth of initial line',295.0,'EPSG','9102','EPSG','8814','Angle from Rectified to Skew Grid',295.0,'EPSG','9102','EPSG','8815','Scale factor on initial line',1.0,'EPSG','9201','EPSG','8806','False easting',7000000.0,'EPSG','9001','EPSG','8807','False northing',-3000000.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','6754','Oregon Columbia River West zone (International feet)',NULL,NULL,'EPSG','4202','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',45.55,'EPSG','9110','EPSG','8812','Longitude of projection centre',-123.0,'EPSG','9110','EPSG','8813','Azimuth of initial line',295.0,'EPSG','9102','EPSG','8814','Angle from Rectified to Skew Grid',295.0,'EPSG','9102','EPSG','8815','Scale factor on initial line',1.0,'EPSG','9201','EPSG','8806','False easting',22965879.2651,'EPSG','9002','EPSG','8807','False northing',-9842519.685,'EPSG','9002',0);
INSERT INTO "conversion" VALUES('EPSG','6755','Oregon Cottage Grove-Canyonville zone (meters)',NULL,NULL,'EPSG','4203','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-123.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000023,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6756','Oregon Cottage Grove-Canyonville zone (International feet)',NULL,NULL,'EPSG','4203','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-123.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000023,'EPSG','9201','EPSG','8806','False easting',164041.9948,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6757','Oregon Dufur-Madras zone (meters)',NULL,NULL,'EPSG','4204','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-121.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00011,'EPSG','9201','EPSG','8806','False easting',80000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6758','Oregon Dufur-Madras zone (International feet)',NULL,NULL,'EPSG','4204','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-121.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00011,'EPSG','9201','EPSG','8806','False easting',262467.1916,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6759','Oregon Eugene zone (meters)',NULL,NULL,'EPSG','4197','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-123.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000015,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6760','Oregon Eugene zone (International feet)',NULL,NULL,'EPSG','4197','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-123.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000015,'EPSG','9201','EPSG','8806','False easting',164041.9948,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6761','Oregon Grants Pass-Ashland zone (meters)',NULL,NULL,'EPSG','4198','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-123.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000043,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6762','Oregon Grants Pass-Ashland zone (International feet)',NULL,NULL,'EPSG','4198','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-123.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000043,'EPSG','9201','EPSG','8806','False easting',164041.9948,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6763','Oregon Gresham-Warm Springs zone (meters)',NULL,NULL,'EPSG','4201','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-122.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00005,'EPSG','9201','EPSG','8806','False easting',10000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6764','Oregon Gresham-Warm Springs zone (International feet)',NULL,NULL,'EPSG','4201','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-122.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00005,'EPSG','9201','EPSG','8806','False easting',32808.399,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6765','Oregon La Grande zone (meters)',NULL,NULL,'EPSG','4206','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-118.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00013,'EPSG','9201','EPSG','8806','False easting',40000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6766','Oregon La Grande zone (International feet)',NULL,NULL,'EPSG','4206','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-118.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00013,'EPSG','9201','EPSG','8806','False easting',131233.5958,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6767','Oregon Ontario zone (meters)',NULL,NULL,'EPSG','4207','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-117.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0001,'EPSG','9201','EPSG','8806','False easting',80000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6768','Oregon Ontario zone (International feet)',NULL,NULL,'EPSG','4207','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-117.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0001,'EPSG','9201','EPSG','8806','False easting',262467.1916,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6769','Oregon Coast zone (meters)',NULL,NULL,'EPSG','4208','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',44.45,'EPSG','9110','EPSG','8812','Longitude of projection centre',-124.03,'EPSG','9110','EPSG','8813','Azimuth of initial line',5.0,'EPSG','9102','EPSG','8814','Angle from Rectified to Skew Grid',5.0,'EPSG','9102','EPSG','8815','Scale factor on initial line',1.0,'EPSG','9201','EPSG','8806','False easting',-300000.0,'EPSG','9001','EPSG','8807','False northing',-4600000.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','6770','Oregon Coast zone (International feet)',NULL,NULL,'EPSG','4208','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',44.45,'EPSG','9110','EPSG','8812','Longitude of projection centre',-124.03,'EPSG','9110','EPSG','8813','Azimuth of initial line',5.0,'EPSG','9102','EPSG','8814','Angle from Rectified to Skew Grid',5.0,'EPSG','9102','EPSG','8815','Scale factor on initial line',1.0,'EPSG','9201','EPSG','8806','False easting',-984251.9685,'EPSG','9002','EPSG','8807','False northing',-15091863.5171,'EPSG','9002',0);
INSERT INTO "conversion" VALUES('EPSG','6771','Oregon Pendleton zone (meters)',NULL,NULL,'EPSG','4209','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-119.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000045,'EPSG','9201','EPSG','8806','False easting',60000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6772','Oregon Pendleton zone (International feet)',NULL,NULL,'EPSG','4209','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-119.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000045,'EPSG','9201','EPSG','8806','False easting',196850.3937,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6773','Oregon Pendleton-La Grande zone (meters)',NULL,NULL,'EPSG','4210','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.05,'EPSG','9110','EPSG','8802','Longitude of natural origin',-118.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000175,'EPSG','9201','EPSG','8806','False easting',30000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6774','Oregon Pendleton-La Grande zone (International feet)',NULL,NULL,'EPSG','4210','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.05,'EPSG','9110','EPSG','8802','Longitude of natural origin',-118.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000175,'EPSG','9201','EPSG','8806','False easting',98425.1969,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6775','Oregon Portland zone (meters)',NULL,NULL,'EPSG','4211','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-122.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000002,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',50000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6776','Oregon Portland zone (International feet)',NULL,NULL,'EPSG','4211','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-122.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000002,'EPSG','9201','EPSG','8806','False easting',328083.9895,'EPSG','9002','EPSG','8807','False northing',164041.9948,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6777','Oregon Salem zone (meters)',NULL,NULL,'EPSG','4212','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.2,'EPSG','9110','EPSG','8802','Longitude of natural origin',-123.05,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00001,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6778','Oregon Salem zone (International feet)',NULL,NULL,'EPSG','4212','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.2,'EPSG','9110','EPSG','8802','Longitude of natural origin',-123.05,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00001,'EPSG','9201','EPSG','8806','False easting',164041.9948,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6779','Oregon Santiam Pass zone (meters)',NULL,NULL,'EPSG','4213','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.05,'EPSG','9110','EPSG','8802','Longitude of natural origin',-122.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000155,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6780','Oregon Santiam Pass zone (International feet)',NULL,NULL,'EPSG','4213','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.05,'EPSG','9110','EPSG','8802','Longitude of natural origin',-122.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000155,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6869','Albania TM 2010',NULL,NULL,'EPSG','3212','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',20.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6877','Italy zone',NULL,NULL,'EPSG','1127','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',12.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9985,'EPSG','9201','EPSG','8806','False easting',7000000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6878','Italy zone 12',NULL,NULL,'EPSG','1127','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',12.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',3000000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6920','Kansas DOT Lambert (meters)',NULL,NULL,'EPSG','1385','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.15,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.3,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.3,'EPSG','9110','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6921','Kansas DOT Lambert (US Survey feet)',NULL,NULL,'EPSG','1385','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.15,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.3,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.3,'EPSG','9110','EPSG','8826','Easting at false origin',1312333.3333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6928','US NSIDC EASE-Grid 2.0 Global',NULL,NULL,'EPSG','3463','EPSG','9835','Lambert Cylindrical Equal Area','EPSG','8823','Latitude of 1st standard parallel',30.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6929','US NSIDC EASE-Grid 2.0 North',NULL,NULL,'EPSG','3475','EPSG','9820','Lambert Azimuthal Equal Area','EPSG','8801','Latitude of natural origin',90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6930','US NSIDC EASE-Grid 2.0 South',NULL,NULL,'EPSG','3474','EPSG','9820','Lambert Azimuthal Equal Area','EPSG','8801','Latitude of natural origin',-90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6952','Vietnam TM-3 zone 481',NULL,NULL,'EPSG','4193','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',102.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','6953','Vietnam TM-3 zone 482',NULL,NULL,'EPSG','4215','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',105.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','6954','Vietnam TM-3 zone 491',NULL,NULL,'EPSG','4217','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',108.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','6955','Vietnam TM-3 Da Nang zone',NULL,NULL,'EPSG','4218','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',107.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','6961','Albania LCC 2010',NULL,NULL,'EPSG','1025','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.0,'EPSG','9102','EPSG','8822','Longitude of false origin',20.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',39.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','6965','Michigan CS27 North zone',NULL,NULL,'EPSG','1723','EPSG','1051','Lambert Conic Conformal (2SP Michigan)','EPSG','8821','Latitude of false origin',44.47,'EPSG','9110','EPSG','8822','Longitude of false origin',-87.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',45.29,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',47.05,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003','EPSG','1038','Ellipsoid scaling factor',1.0000382,'EPSG','9201',0);
INSERT INTO "conversion" VALUES('EPSG','6994','City and County of San Francisco CS13 (meters)',NULL,NULL,'EPSG','4228','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-122.45,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000007,'EPSG','9202','EPSG','8806','False easting',48000.0,'EPSG','9001','EPSG','8807','False northing',24000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','6995','City and County of San Francisco CS13 (US Survey feet)',NULL,NULL,'EPSG','4228','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-122.45,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000007,'EPSG','9202','EPSG','8806','False easting',157480.0,'EPSG','9003','EPSG','8807','False northing',78740.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','7043','Iowa regional zone 1 Spencer',NULL,NULL,'EPSG','4164','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.12,'EPSG','9110','EPSG','8802','Longitude of natural origin',-95.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000052,'EPSG','9201','EPSG','8806','False easting',11500000.0,'EPSG','9003','EPSG','8807','False northing',9600000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7044','Iowa regional zone 2 Mason City',NULL,NULL,'EPSG','4219','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.1,'EPSG','9110','EPSG','8802','Longitude of natural origin',-92.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000043,'EPSG','9201','EPSG','8806','False easting',12500000.0,'EPSG','9003','EPSG','8807','False northing',9800000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7045','Iowa regional zone 3 Elkader',NULL,NULL,'EPSG','4230','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.12,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000035,'EPSG','9201','EPSG','8806','False easting',13500000.0,'EPSG','9003','EPSG','8807','False northing',8300000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7046','Iowa regional zone 4 Sioux City-Iowa Falls',NULL,NULL,'EPSG','4233','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',42.32,'EPSG','9110','EPSG','8802','Longitude of natural origin',-94.5,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000045,'EPSG','9201','EPSG','8806','False easting',14500000.0,'EPSG','9003','EPSG','8807','False northing',8600000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7047','Iowa regional zone 5 Waterloo',NULL,NULL,'EPSG','4234','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',42.39,'EPSG','9110','EPSG','8802','Longitude of natural origin',-92.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000032,'EPSG','9201','EPSG','8806','False easting',15500000.0,'EPSG','9003','EPSG','8807','False northing',8900000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7048','Iowa regional zone 6 Council Bluffs',NULL,NULL,'EPSG','4235','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-95.44,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000039,'EPSG','9201','EPSG','8806','False easting',16500000.0,'EPSG','9003','EPSG','8807','False northing',6600000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7049','Iowa regional zone 7 Carroll-Atlantic',NULL,NULL,'EPSG','4236','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-94.38,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000045,'EPSG','9201','EPSG','8806','False easting',17500000.0,'EPSG','9003','EPSG','8807','False northing',6800000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7050','Iowa regional zone 8 Ames-Des Moines',NULL,NULL,'EPSG','4237','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-93.43,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000033,'EPSG','9201','EPSG','8806','False easting',18500000.0,'EPSG','9003','EPSG','8807','False northing',7000000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7051','Iowa regional zone 9 Newton',NULL,NULL,'EPSG','4239','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-92.49,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000027,'EPSG','9201','EPSG','8806','False easting',19500000.0,'EPSG','9003','EPSG','8807','False northing',7200000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7052','Iowa regional zone 10 Cedar Rapids',NULL,NULL,'EPSG','4240','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',41.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00002,'EPSG','9201','EPSG','8806','False easting',20500000.0,'EPSG','9003','EPSG','8807','False northing',8000000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7053','Iowa regional zone 11 Dubuque-Davenport',NULL,NULL,'EPSG','4241','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.32,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000027,'EPSG','9201','EPSG','8806','False easting',21500000.0,'EPSG','9003','EPSG','8807','False northing',7600000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7054','Iowa regional zone 12 Red Oak-Ottumwa',NULL,NULL,'EPSG','4242','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',40.55,'EPSG','9110','EPSG','8802','Longitude of natural origin',-93.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000037,'EPSG','9201','EPSG','8806','False easting',22500000.0,'EPSG','9003','EPSG','8807','False northing',6200000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7055','Iowa regional zone 13 Fairfield',NULL,NULL,'EPSG','4243','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.55,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00002,'EPSG','9201','EPSG','8806','False easting',23500000.0,'EPSG','9003','EPSG','8807','False northing',6400000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7056','Iowa regional zone 14 Burlington',NULL,NULL,'EPSG','4244','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000018,'EPSG','9201','EPSG','8806','False easting',24500000.0,'EPSG','9003','EPSG','8807','False northing',6200000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7089','Montana Blackfeet St Mary Valley (meters)',NULL,NULL,'EPSG','4310','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',48.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-112.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00016,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7090','Montana Blackfeet St Mary Valley (International feet)',NULL,NULL,'EPSG','4310','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',48.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-112.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00016,'EPSG','9201','EPSG','8806','False easting',492125.9843,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7091','Montana Blackfeet (meters)',NULL,NULL,'EPSG','4311','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',48.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-112.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00019,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7092','Montana Blackfeet (International feet)',NULL,NULL,'EPSG','4311','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',48.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-112.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00019,'EPSG','9201','EPSG','8806','False easting',328083.9895,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7093','Montana Milk River (meters)',NULL,NULL,'EPSG','4312','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',48.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-111.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000145,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7094','Montana Milk River (International feet)',NULL,NULL,'EPSG','4312','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',48.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-111.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000145,'EPSG','9201','EPSG','8806','False easting',492125.9843,'EPSG','9002','EPSG','8807','False northing',656167.979,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7095','Montana Fort Belknap (meters)',NULL,NULL,'EPSG','4313','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',48.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-108.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00012,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',150000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7096','Montana Fort Belknap (International feet)',NULL,NULL,'EPSG','4313','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',48.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-108.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00012,'EPSG','9201','EPSG','8806','False easting',656167.979,'EPSG','9002','EPSG','8807','False northing',492125.9843,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7097','Montana Fort Peck Assiniboine (meters)',NULL,NULL,'EPSG','4314','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',48.2,'EPSG','9110','EPSG','8802','Longitude of natural origin',-105.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00012,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7098','Montana Fort Peck Assiniboine (International feet)',NULL,NULL,'EPSG','4314','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',48.2,'EPSG','9110','EPSG','8802','Longitude of natural origin',-105.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00012,'EPSG','9201','EPSG','8806','False easting',656167.979,'EPSG','9002','EPSG','8807','False northing',328083.9895,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7099','Montana Fort Peck Sioux (meters)',NULL,NULL,'EPSG','4315','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',48.2,'EPSG','9110','EPSG','8802','Longitude of natural origin',-105.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00009,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',50000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7100','Montana Fort Peck Sioux (International feet)',NULL,NULL,'EPSG','4315','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',48.2,'EPSG','9110','EPSG','8802','Longitude of natural origin',-105.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00009,'EPSG','9201','EPSG','8806','False easting',328083.9895,'EPSG','9002','EPSG','8807','False northing',164041.9938,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7101','Montana Crow (meters)',NULL,NULL,'EPSG','4316','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-107.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000148,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7102','Montana Crow (International feet)',NULL,NULL,'EPSG','4316','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-107.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000148,'EPSG','9201','EPSG','8806','False easting',656167.979,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7103','Montana Bobcat (meters)',NULL,NULL,'EPSG','4317','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-111.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000185,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7104','Montana Bobcat (International feet)',NULL,NULL,'EPSG','4317','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-111.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000185,'EPSG','9201','EPSG','8806','False easting',328083.9895,'EPSG','9002','EPSG','8807','False northing',328083.9895,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7105','Montana Billings (meters)',NULL,NULL,'EPSG','4318','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.47,'EPSG','9110','EPSG','8802','Longitude of natural origin',-108.25,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0001515,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',50000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7106','Montana Billings (International feet)',NULL,NULL,'EPSG','4318','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.47,'EPSG','9110','EPSG','8802','Longitude of natural origin',-108.25,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0001515,'EPSG','9201','EPSG','8806','False easting',656167.979,'EPSG','9002','EPSG','8807','False northing',164041.9948,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7107','Wyoming Wind River (meters)',NULL,NULL,'EPSG','4319','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-108.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00024,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7108','Wyoming Wind River (US Survey feet)',NULL,NULL,'EPSG','4319','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-108.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00024,'EPSG','9201','EPSG','8806','False easting',328083.3333,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7129','City and County of San Francisco CS13 (meters)',NULL,NULL,'EPSG','4228','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-122.45,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000007,'EPSG','9201','EPSG','8806','False easting',48000.0,'EPSG','9001','EPSG','8807','False northing',24000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7130','City and County of San Francisco CS13 (US Survey feet)',NULL,NULL,'EPSG','4228','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-122.45,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000007,'EPSG','9201','EPSG','8806','False easting',157480.0,'EPSG','9003','EPSG','8807','False northing',78740.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7141','Palestine Grid modified',NULL,NULL,'EPSG','1356','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.4402749,'EPSG','9110','EPSG','8802','Longitude of natural origin',35.124349,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',170251.555,'EPSG','9001','EPSG','8807','False northing',126867.909,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7143','InGCS Adams (m)',NULL,NULL,'EPSG','4289','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.33,'EPSG','9110','EPSG','8802','Longitude of natural origin',-84.57,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000034,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7144','InGCS Adams (ftUS)',NULL,NULL,'EPSG','4289','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.33,'EPSG','9110','EPSG','8802','Longitude of natural origin',-84.57,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000034,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7145','InGCS Allen (m)',NULL,NULL,'EPSG','4285','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.54,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.03,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000031,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7146','InGCS Allen (ftUS)',NULL,NULL,'EPSG','4285','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.54,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.03,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000031,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7147','InGCS Bartholomew (m)',NULL,NULL,'EPSG','4302','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.51,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000026,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7148','InGCS Bartholomew (ftUS)',NULL,NULL,'EPSG','4302','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.51,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000026,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7149','InGCS Benton (m)',NULL,NULL,'EPSG','4256','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.27,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.18,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000029,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7150','InGCS Benton (ftUS)',NULL,NULL,'EPSG','4256','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.27,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.18,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000029,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7151','InGCS Blackford-Delaware (m)',NULL,NULL,'EPSG','4291','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.03,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.24,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000038,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7152','InGCS Blackford-Delaware (ftUS)',NULL,NULL,'EPSG','4291','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.03,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.24,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000038,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7153','InGCS Boone-Hendricks (m)',NULL,NULL,'EPSG','4263','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.36,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000036,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7154','InGCS Boone-Hendricks (ftUS)',NULL,NULL,'EPSG','4263','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.36,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000036,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7155','InGCS Brown (m)',NULL,NULL,'EPSG','4301','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.18,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00003,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7156','InGCS Brown (ftUS)',NULL,NULL,'EPSG','4301','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.18,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00003,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7157','InGCS Carroll (m)',NULL,NULL,'EPSG','4258','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.24,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.39,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000026,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7158','InGCS Carroll (ftUS)',NULL,NULL,'EPSG','4258','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.24,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.39,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000026,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7159','InGCS Cass (m)',NULL,NULL,'EPSG','4286','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.33,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.24,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000028,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7160','InGCS Cass (ftUS)',NULL,NULL,'EPSG','4286','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.33,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.24,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000028,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7161','InGCS Clark-Floyd-Scott (m)',NULL,NULL,'EPSG','4308','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.09,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.36,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000021,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7162','InGCS Clark-Floyd-Scott (ftUS)',NULL,NULL,'EPSG','4308','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.09,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.36,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000021,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7163','InGCS Clay (m)',NULL,NULL,'EPSG','4265','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.09,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.09,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000024,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7164','InGCS Clay (ftUS)',NULL,NULL,'EPSG','4265','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.09,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.09,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000024,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7165','InGCS Clinton (m)',NULL,NULL,'EPSG','4260','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.09,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.36,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000032,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7166','InGCS Clinton (ftUS)',NULL,NULL,'EPSG','4260','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.09,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.36,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000032,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7167','InGCS Crawford-Lawrence-Orange (m)',NULL,NULL,'EPSG','4272','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.06,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000025,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7168','InGCS Crawford-Lawrence-Orange (ftUS)',NULL,NULL,'EPSG','4272','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.06,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000025,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7169','InGCS Daviess-Greene (m)',NULL,NULL,'EPSG','4269','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.27,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.06,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000018,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7170','InGCS Daviess-Greene (ftUS)',NULL,NULL,'EPSG','4269','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.27,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.06,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000018,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7171','InGCS Dearborn-Ohio-Switzerland (m)',NULL,NULL,'EPSG','4306','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.39,'EPSG','9110','EPSG','8802','Longitude of natural origin',-84.54,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000029,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7172','InGCS Dearborn-Ohio-Switzerland (ftUS)',NULL,NULL,'EPSG','4306','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.39,'EPSG','9110','EPSG','8802','Longitude of natural origin',-84.54,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000029,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7173','InGCS Decatur-Rush (m)',NULL,NULL,'EPSG','4299','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.06,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.39,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000036,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7174','InGCS Decatur-Rush (ftUS)',NULL,NULL,'EPSG','4299','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.06,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.39,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000036,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7175','InGCS DeKalb (m)',NULL,NULL,'EPSG','4283','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-84.57,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000036,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7176','InGCS DeKalb (ftUS)',NULL,NULL,'EPSG','4283','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-84.57,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000036,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7177','InGCS Dubois-Martin (m)',NULL,NULL,'EPSG','4271','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.12,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.57,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00002,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7178','InGCS Dubois-Martin (ftUS)',NULL,NULL,'EPSG','4271','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.12,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.57,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00002,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7179','InGCS Elkhart-Kosciusko-Wabash (m)',NULL,NULL,'EPSG','4280','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.39,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.51,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000033,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7180','InGCS Elkhart-Kosciusko-Wabash (ftUS)',NULL,NULL,'EPSG','4280','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.39,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.51,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000033,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7181','InGCS Fayette-Franklin-Union (m)',NULL,NULL,'EPSG','4300','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.03,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000038,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7182','InGCS Fayette-Franklin-Union (ftUS)',NULL,NULL,'EPSG','4300','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.03,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000038,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7183','InGCS Fountain-Warren (m)',NULL,NULL,'EPSG','4259','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.57,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.18,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000025,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7184','InGCS Fountain-Warren (ftUS)',NULL,NULL,'EPSG','4259','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.57,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.18,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000025,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7185','InGCS Fulton-Marshall-St. Joseph (m)',NULL,NULL,'EPSG','4279','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.54,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.18,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000031,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7186','InGCS Fulton-Marshall-St. Joseph (ftUS)',NULL,NULL,'EPSG','4279','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.54,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.18,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000031,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7187','InGCS Gibson (m)',NULL,NULL,'EPSG','4273','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.09,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.39,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000013,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7188','InGCS Gibson (ftUS)',NULL,NULL,'EPSG','4273','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.09,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.39,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000013,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7189','InGCS Grant (m)',NULL,NULL,'EPSG','4290','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.21,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.42,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000034,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7190','InGCS Grant (ftUS)',NULL,NULL,'EPSG','4290','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.21,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.42,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000034,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7191','InGCS Hamilton-Tipton (m)',NULL,NULL,'EPSG','4293','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.54,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000034,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7192','InGCS Hamilton-Tipton (ftUS)',NULL,NULL,'EPSG','4293','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.54,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000034,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7193','InGCS Hancock-Madison (m)',NULL,NULL,'EPSG','4294','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.39,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.48,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000036,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7194','InGCS Hancock-Madison (ftUS)',NULL,NULL,'EPSG','4294','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.39,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.48,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000036,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7195','InGCS Harrison-Washington (m)',NULL,NULL,'EPSG','4307','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.57,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.09,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000027,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7196','InGCS Harrison-Washington (ftUS)',NULL,NULL,'EPSG','4307','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.57,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.09,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000027,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7197','InGCS Henry (m)',NULL,NULL,'EPSG','4296','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.27,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000043,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7198','InGCS Henry (ftUS)',NULL,NULL,'EPSG','4296','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.27,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000043,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7199','InGCS Howard-Miami (m)',NULL,NULL,'EPSG','4287','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.21,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.09,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000031,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7200','InGCS Howard-Miami (ftUS)',NULL,NULL,'EPSG','4287','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.21,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.09,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000031,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7201','InGCS Huntington-Whitley (m)',NULL,NULL,'EPSG','4284','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.39,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000034,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7202','InGCS Huntington-Whitley (ftUS)',NULL,NULL,'EPSG','4284','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.39,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000034,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7203','InGCS Jackson (m)',NULL,NULL,'EPSG','4303','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.42,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.57,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000022,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7204','InGCS Jackson (ftUS)',NULL,NULL,'EPSG','4303','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.42,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.57,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000022,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7205','InGCS Jasper-Porter (m)',NULL,NULL,'EPSG','4254','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.42,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.06,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000027,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7206','InGCS Jasper-Porter (ftUS)',NULL,NULL,'EPSG','4254','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.42,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.06,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000027,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7207','InGCS Jay (m)',NULL,NULL,'EPSG','4292','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.18,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000038,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7208','InGCS Jay (ftUS)',NULL,NULL,'EPSG','4292','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.18,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000038,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7209','InGCS Jefferson (m)',NULL,NULL,'EPSG','4309','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.33,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.21,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000028,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7210','InGCS Jefferson (ftUS)',NULL,NULL,'EPSG','4309','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.33,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.21,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000028,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7211','InGCS Jennings (m)',NULL,NULL,'EPSG','4304','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.48,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.48,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000025,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7212','InGCS Jennings (ftUS)',NULL,NULL,'EPSG','4304','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.48,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.48,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000025,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7213','InGCS Johnson-Marion (m)',NULL,NULL,'EPSG','4297','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.18,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.09,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000031,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7214','InGCS Johnson-Marion (ftUS)',NULL,NULL,'EPSG','4297','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.18,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.09,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000031,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7215','InGCS Knox (m)',NULL,NULL,'EPSG','4270','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.24,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.27,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000015,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7216','InGCS Knox (ftUS)',NULL,NULL,'EPSG','4270','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.24,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.27,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000015,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7217','InGCS LaGrange-Noble (m)',NULL,NULL,'EPSG','4281','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.27,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000037,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7218','InGCS LaGrange-Noble (ftUS)',NULL,NULL,'EPSG','4281','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.27,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000037,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7219','InGCS Lake-Newton (m)',NULL,NULL,'EPSG','4253','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.42,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.24,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000026,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7220','InGCS Lake-Newton (ftUS)',NULL,NULL,'EPSG','4253','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.42,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.24,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000026,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7221','InGCS LaPorte-Pulaski-Starke (m)',NULL,NULL,'EPSG','4255','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.54,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000027,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7222','InGCS LaPorte-Pulaski-Starke (ftUS)',NULL,NULL,'EPSG','4255','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.54,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000027,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7223','InGCS Monroe-Morgan (m)',NULL,NULL,'EPSG','4267','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.57,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000028,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7224','InGCS Monroe-Morgan (ftUS)',NULL,NULL,'EPSG','4267','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.57,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000028,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7225','InGCS Montgomery-Putnam (m)',NULL,NULL,'EPSG','4262','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.27,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.57,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000031,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7226','InGCS Montgomery-Putnam (ftUS)',NULL,NULL,'EPSG','4262','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.27,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.57,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000031,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7227','InGCS Owen (m)',NULL,NULL,'EPSG','4266','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.09,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.54,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000026,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7228','InGCS Owen (ftUS)',NULL,NULL,'EPSG','4266','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.09,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.54,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000026,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7229','InGCS Parke-Vermillion (m)',NULL,NULL,'EPSG','4261','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.36,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.21,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000022,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7230','InGCS Parke-Vermillion (ftUS)',NULL,NULL,'EPSG','4261','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.36,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.21,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000022,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7231','InGCS Perry (m)',NULL,NULL,'EPSG','4278','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.48,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.42,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00002,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7232','InGCS Perry (ftUS)',NULL,NULL,'EPSG','4278','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.48,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.42,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00002,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7233','InGCS Pike-Warrick (m)',NULL,NULL,'EPSG','4274','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.51,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.18,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000015,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7234','InGCS Pike-Warrick (ftUS)',NULL,NULL,'EPSG','4274','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.51,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.18,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000015,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7235','InGCS Posey (m)',NULL,NULL,'EPSG','4275','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.57,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000013,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7236','InGCS Posey (ftUS)',NULL,NULL,'EPSG','4275','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.57,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000013,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7237','InGCS Randolph-Wayne (m)',NULL,NULL,'EPSG','4295','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.42,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.03,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000044,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7238','InGCS Randolph-Wayne (ftUS)',NULL,NULL,'EPSG','4295','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.42,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.03,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000044,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7239','InGCS Ripley (m)',NULL,NULL,'EPSG','4305','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.54,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.18,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000038,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7240','InGCS Ripley (ftUS)',NULL,NULL,'EPSG','4305','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.54,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.18,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000038,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7241','InGCS Shelby (m)',NULL,NULL,'EPSG','4298','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.18,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.54,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00003,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7242','InGCS Shelby (ftUS)',NULL,NULL,'EPSG','4298','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.18,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.54,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00003,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7243','InGCS Spencer (m)',NULL,NULL,'EPSG','4277','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.03,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000014,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7244','InGCS Spencer (ftUS)',NULL,NULL,'EPSG','4277','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.03,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000014,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7245','InGCS Steuben (m)',NULL,NULL,'EPSG','4282','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000041,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7246','InGCS Steuben (ftUS)',NULL,NULL,'EPSG','4282','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000041,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7247','InGCS Sullivan (m)',NULL,NULL,'EPSG','4268','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.54,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000017,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7248','InGCS Sullivan (ftUS)',NULL,NULL,'EPSG','4268','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.54,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000017,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7249','InGCS Tippecanoe-White (m)',NULL,NULL,'EPSG','4257','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.12,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.54,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000026,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7250','InGCS Tippecanoe-White (ftUS)',NULL,NULL,'EPSG','4257','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.12,'EPSG','9110','EPSG','8802','Longitude of natural origin',-86.54,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000026,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7251','InGCS Vanderburgh (m)',NULL,NULL,'EPSG','4276','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.48,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.33,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000015,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7252','InGCS Vanderburgh (ftUS)',NULL,NULL,'EPSG','4276','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.48,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.33,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000015,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7253','InGCS Vigo (m)',NULL,NULL,'EPSG','4264','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.27,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00002,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7254','InGCS Vigo (ftUS)',NULL,NULL,'EPSG','4264','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.27,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00002,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7255','InGCS Wells (m)',NULL,NULL,'EPSG','4288','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.33,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000034,'EPSG','9201','EPSG','8806','False easting',240000.0,'EPSG','9001','EPSG','8807','False northing',36000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7256','InGCS Wells (ftUS)',NULL,NULL,'EPSG','4288','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.33,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000034,'EPSG','9201','EPSG','8806','False easting',787400.0,'EPSG','9003','EPSG','8807','False northing',118110.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7378','WISCRS Ashland County (m)',NULL,NULL,'EPSG','4320','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.4222,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.372,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000495683,'EPSG','9201','EPSG','8806','False easting',172821.9461,'EPSG','9001','EPSG','8807','False northing',0.0017,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7379','WISCRS Ashland County (ftUS)',NULL,NULL,'EPSG','4320','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.4222,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.372,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000495683,'EPSG','9201','EPSG','8806','False easting',567000.001,'EPSG','9003','EPSG','8807','False northing',0.006,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7380','WISCRS Bayfield County (m)',NULL,NULL,'EPSG','4321','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.4010734158,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.091,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000331195,'EPSG','9201','EPSG','8806','False easting',228600.4575,'EPSG','9001','EPSG','8807','False northing',148551.4837,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7381','WISCRS Bayfield County (ftUS)',NULL,NULL,'EPSG','4321','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.4010734158,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.091,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000331195,'EPSG','9201','EPSG','8806','False easting',750000.001,'EPSG','9003','EPSG','8807','False northing',487372.659,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7382','WISCRS Burnett County (m)',NULL,NULL,'EPSG','4325','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.5355373517,'EPSG','9110','EPSG','8802','Longitude of natural origin',-92.2728,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000383841,'EPSG','9201','EPSG','8806','False easting',64008.1276,'EPSG','9001','EPSG','8807','False northing',59445.9043,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7383','WISCRS Burnett County (ftUS)',NULL,NULL,'EPSG','4325','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.5355373517,'EPSG','9110','EPSG','8802','Longitude of natural origin',-92.2728,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000383841,'EPSG','9201','EPSG','8806','False easting',209999.999,'EPSG','9003','EPSG','8807','False northing',195032.104,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7384','WISCRS Douglas County (m)',NULL,NULL,'EPSG','4326','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.53,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.55,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000385418,'EPSG','9201','EPSG','8806','False easting',59131.3183,'EPSG','9001','EPSG','8807','False northing',0.0041,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7385','WISCRS Douglas County (ftUS)',NULL,NULL,'EPSG','4326','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.53,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.55,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000385418,'EPSG','9201','EPSG','8806','False easting',194000.0,'EPSG','9003','EPSG','8807','False northing',0.013,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7386','WISCRS Florence County (m)',NULL,NULL,'EPSG','4327','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.262,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.083,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000552095,'EPSG','9201','EPSG','8806','False easting',133502.6683,'EPSG','9001','EPSG','8807','False northing',0.0063,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7387','WISCRS Florence County (ftUS)',NULL,NULL,'EPSG','4327','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.262,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.083,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000552095,'EPSG','9201','EPSG','8806','False easting',438000.004,'EPSG','9003','EPSG','8807','False northing',0.021,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7388','WISCRS Forest County (m)',NULL,NULL,'EPSG','4328','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.002,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.38,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000673004,'EPSG','9201','EPSG','8806','False easting',275844.5533,'EPSG','9001','EPSG','8807','False northing',0.0157,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7389','WISCRS Forest County (ftUS)',NULL,NULL,'EPSG','4328','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.002,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.38,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000673004,'EPSG','9201','EPSG','8806','False easting',905000.005,'EPSG','9003','EPSG','8807','False northing',0.052,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7390','WISCRS Iron County (m)',NULL,NULL,'EPSG','4329','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.26,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.152,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000677153,'EPSG','9201','EPSG','8806','False easting',220980.4419,'EPSG','9001','EPSG','8807','False northing',0.0085,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7391','WISCRS Iron County (ftUS)',NULL,NULL,'EPSG','4329','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.26,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.152,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000677153,'EPSG','9201','EPSG','8806','False easting',725000.0,'EPSG','9003','EPSG','8807','False northing',0.028,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7392','WISCRS Oneida County (m)',NULL,NULL,'EPSG','4330','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.4215205573,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.324,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000686968,'EPSG','9201','EPSG','8806','False easting',70104.1401,'EPSG','9001','EPSG','8807','False northing',57588.0346,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7393','WISCRS Oneida County (ftUS)',NULL,NULL,'EPSG','4330','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.4215205573,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.324,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000686968,'EPSG','9201','EPSG','8806','False easting',230000.0,'EPSG','9003','EPSG','8807','False northing',188936.744,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7394','WISCRS Price County (m)',NULL,NULL,'EPSG','4332','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.332,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.292,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000649554,'EPSG','9201','EPSG','8806','False easting',227990.8546,'EPSG','9001','EPSG','8807','False northing',0.0109,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7395','WISCRS Price County (ftUS)',NULL,NULL,'EPSG','4332','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.332,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.292,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000649554,'EPSG','9201','EPSG','8806','False easting',747999.995,'EPSG','9003','EPSG','8807','False northing',0.036,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7396','WISCRS Sawyer County (m)',NULL,NULL,'EPSG','4333','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.5400356873,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.07,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000573461,'EPSG','9201','EPSG','8806','False easting',216713.2336,'EPSG','9001','EPSG','8807','False northing',120734.1631,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7397','WISCRS Sawyer County (ftUS)',NULL,NULL,'EPSG','4333','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.5400356873,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.07,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000573461,'EPSG','9201','EPSG','8806','False easting',711000.001,'EPSG','9003','EPSG','8807','False northing',396108.667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7398','WISCRS Vilas County (m)',NULL,NULL,'EPSG','4334','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.0440238726,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.292,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000730142,'EPSG','9201','EPSG','8806','False easting',134417.0689,'EPSG','9001','EPSG','8807','False northing',50337.1092,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7399','WISCRS Vilas County (ftUS)',NULL,NULL,'EPSG','4334','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.0440238726,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.292,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000730142,'EPSG','9201','EPSG','8806','False easting',441000.0,'EPSG','9003','EPSG','8807','False northing',165147.666,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7424','WISCRS Washburn County (m)',NULL,NULL,'EPSG','4335','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.57403914,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.47,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000475376,'EPSG','9201','EPSG','8806','False easting',234086.8682,'EPSG','9001','EPSG','8807','False northing',188358.6058,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7425','WISCRS Washburn County (ftUS)',NULL,NULL,'EPSG','4335','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.57403914,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.47,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000475376,'EPSG','9201','EPSG','8806','False easting',768000.0,'EPSG','9003','EPSG','8807','False northing',617973.193,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7426','WISCRS Barron County (m)',NULL,NULL,'EPSG','4331','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.08,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.51,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000486665,'EPSG','9201','EPSG','8806','False easting',93150.0,'EPSG','9001','EPSG','8807','False northing',0.0029,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7427','WISCRS Barron County (ftUS)',NULL,NULL,'EPSG','4331','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.08,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.51,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000486665,'EPSG','9201','EPSG','8806','False easting',305609.625,'EPSG','9003','EPSG','8807','False northing',0.01,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7428','WISCRS Brown County (m)',NULL,NULL,'EPSG','4336','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00002,'EPSG','9201','EPSG','8806','False easting',31600.0,'EPSG','9001','EPSG','8807','False northing',4600.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7429','WISCRS Brown County (ftUS)',NULL,NULL,'EPSG','4336','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00002,'EPSG','9201','EPSG','8806','False easting',103674.333,'EPSG','9003','EPSG','8807','False northing',15091.833,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7430','WISCRS Buffalo County (m)',NULL,NULL,'EPSG','4337','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.2853,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.475,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000382778,'EPSG','9201','EPSG','8806','False easting',175260.3502,'EPSG','9001','EPSG','8807','False northing',0.0048,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7431','WISCRS Buffalo County (ftUS)',NULL,NULL,'EPSG','4337','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.2853,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.475,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000382778,'EPSG','9201','EPSG','8806','False easting',574999.999,'EPSG','9003','EPSG','8807','False northing',0.016,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7432','WISCRS Chippewa County (m)',NULL,NULL,'EPSG','4338','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.5840284835,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.174,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000391127,'EPSG','9201','EPSG','8806','False easting',60045.72,'EPSG','9001','EPSG','8807','False northing',44091.4346,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7433','WISCRS Chippewa County (ftUS)',NULL,NULL,'EPSG','4338','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.5840284835,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.174,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000391127,'EPSG','9201','EPSG','8806','False easting',197000.0,'EPSG','9003','EPSG','8807','False northing',144656.648,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7434','WISCRS Clark County (m)',NULL,NULL,'EPSG','4339','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.36,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.423,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000463003,'EPSG','9201','EPSG','8806','False easting',199949.1989,'EPSG','9001','EPSG','8807','False northing',0.0086,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7435','WISCRS Clark County (ftUS)',NULL,NULL,'EPSG','4339','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.36,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.423,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000463003,'EPSG','9201','EPSG','8806','False easting',655999.997,'EPSG','9003','EPSG','8807','False northing',0.028,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7436','WISCRS Door County (m)',NULL,NULL,'EPSG','4340','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.24,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.162,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000187521,'EPSG','9201','EPSG','8806','False easting',158801.1176,'EPSG','9001','EPSG','8807','False northing',0.0023,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7437','WISCRS Door County (ftUS)',NULL,NULL,'EPSG','4340','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.24,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.162,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000187521,'EPSG','9201','EPSG','8806','False easting',521000.0,'EPSG','9003','EPSG','8807','False northing',0.008,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7438','WISCRS Dunn County (m)',NULL,NULL,'EPSG','4341','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.243,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.534,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000410324,'EPSG','9201','EPSG','8806','False easting',51816.104,'EPSG','9001','EPSG','8807','False northing',0.003,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7439','WISCRS Dunn County (ftUS)',NULL,NULL,'EPSG','4341','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.243,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.534,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000410324,'EPSG','9201','EPSG','8806','False easting',170000.001,'EPSG','9003','EPSG','8807','False northing',0.01,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7440','WISCRS Eau Claire County (m)',NULL,NULL,'EPSG','4342','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.5220212055,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.172,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000035079,'EPSG','9201','EPSG','8806','False easting',120091.4402,'EPSG','9001','EPSG','8807','False northing',91687.9239,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7441','WISCRS Eau Claire County (ftUS)',NULL,NULL,'EPSG','4342','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.5220212055,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.172,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000035079,'EPSG','9201','EPSG','8806','False easting',394000.0,'EPSG','9003','EPSG','8807','False northing',300812.797,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7450','WISCRS Jackson County (m)',NULL,NULL,'EPSG','4343','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.151200646,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.503946747,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000353,'EPSG','9201','EPSG','8806','False easting',27000.0,'EPSG','9001','EPSG','8807','False northing',25000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7451','WISCRS Jackson County (ftUS)',NULL,NULL,'EPSG','4343','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.151200646,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.503946747,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000353,'EPSG','9201','EPSG','8806','False easting',88582.5,'EPSG','9003','EPSG','8807','False northing',82020.833,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7452','WISCRS Langlade County (m)',NULL,NULL,'EPSG','4344','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.0915253579,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.02,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000627024,'EPSG','9201','EPSG','8806','False easting',198425.197,'EPSG','9001','EPSG','8807','False northing',105279.7829,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7453','WISCRS Langlade County (ftUS)',NULL,NULL,'EPSG','4344','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.0915253579,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.02,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000627024,'EPSG','9201','EPSG','8806','False easting',651000.0,'EPSG','9003','EPSG','8807','False northing',345405.421,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7454','WISCRS Lincoln County (m)',NULL,NULL,'EPSG','4345','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.504,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.44,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000599003,'EPSG','9201','EPSG','8806','False easting',116129.0323,'EPSG','9001','EPSG','8807','False northing',0.0058,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7455','WISCRS Lincoln County (ftUS)',NULL,NULL,'EPSG','4345','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.504,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.44,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000599003,'EPSG','9201','EPSG','8806','False easting',381000.0,'EPSG','9003','EPSG','8807','False northing',0.019,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7456','WISCRS Marathon County (m)',NULL,NULL,'EPSG','4346','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.5403255925,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.4612,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000053289,'EPSG','9201','EPSG','8806','False easting',74676.1493,'EPSG','9001','EPSG','8807','False northing',55049.2669,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7457','WISCRS Marathon County (ftUS)',NULL,NULL,'EPSG','4346','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.5403255925,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.4612,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000053289,'EPSG','9201','EPSG','8806','False easting',245000.0,'EPSG','9003','EPSG','8807','False northing',180607.47,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7458','WISCRS Marinette County (m)',NULL,NULL,'EPSG','4347','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.413,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.424,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000234982,'EPSG','9201','EPSG','8806','False easting',238658.8794,'EPSG','9001','EPSG','8807','False northing',0.0032,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7459','WISCRS Marinette County (ftUS)',NULL,NULL,'EPSG','4347','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.413,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.424,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000234982,'EPSG','9201','EPSG','8806','False easting',783000.007,'EPSG','9003','EPSG','8807','False northing',0.01,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7460','WISCRS Menominee County (m)',NULL,NULL,'EPSG','4348','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.43,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.25,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000362499,'EPSG','9201','EPSG','8806','False easting',105461.0121,'EPSG','9001','EPSG','8807','False northing',0.0029,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7461','WISCRS Menominee County (ftUS)',NULL,NULL,'EPSG','4348','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.43,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.25,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000362499,'EPSG','9201','EPSG','8806','False easting',346000.004,'EPSG','9003','EPSG','8807','False northing',0.01,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7462','WISCRS Oconto County (m)',NULL,NULL,'EPSG','4349','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.235,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.543,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000236869,'EPSG','9201','EPSG','8806','False easting',182880.3676,'EPSG','9001','EPSG','8807','False northing',0.0033,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7463','WISCRS Oconto County (ftUS)',NULL,NULL,'EPSG','4349','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.235,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.543,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000236869,'EPSG','9201','EPSG','8806','False easting',600000.006,'EPSG','9003','EPSG','8807','False northing',0.011,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7464','WISCRS Pepin and Pierce Counties (m)',NULL,NULL,'EPSG','4350','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.3810135939,'EPSG','9110','EPSG','8802','Longitude of natural origin',-92.134,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000362977,'EPSG','9201','EPSG','8806','False easting',167640.3354,'EPSG','9001','EPSG','8807','False northing',86033.0876,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7465','WISCRS Pepin and Pierce Counties (ftUS)',NULL,NULL,'EPSG','4350','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.3810135939,'EPSG','9110','EPSG','8802','Longitude of natural origin',-92.134,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000362977,'EPSG','9201','EPSG','8806','False easting',550000.0,'EPSG','9003','EPSG','8807','False northing',282260.222,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7466','WISCRS Polk County (m)',NULL,NULL,'EPSG','4351','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.394,'EPSG','9110','EPSG','8802','Longitude of natural origin',-92.38,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000433849,'EPSG','9201','EPSG','8806','False easting',141732.2823,'EPSG','9001','EPSG','8807','False northing',0.0059,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7467','WISCRS Polk County (ftUS)',NULL,NULL,'EPSG','4351','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.394,'EPSG','9110','EPSG','8802','Longitude of natural origin',-92.38,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000433849,'EPSG','9201','EPSG','8806','False easting',464999.996,'EPSG','9003','EPSG','8807','False northing',0.019,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7468','WISCRS Portage County (m)',NULL,NULL,'EPSG','4352','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.2500566311,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000039936,'EPSG','9201','EPSG','8806','False easting',56388.1128,'EPSG','9001','EPSG','8807','False northing',50022.1874,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7469','WISCRS Portage County (ftUS)',NULL,NULL,'EPSG','4352','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.2500566311,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000039936,'EPSG','9201','EPSG','8806','False easting',185000.0,'EPSG','9003','EPSG','8807','False northing',164114.46,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7470','WISCRS Rusk County (m)',NULL,NULL,'EPSG','4353','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.551,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.04,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000495976,'EPSG','9201','EPSG','8806','False easting',250546.1013,'EPSG','9001','EPSG','8807','False northing',0.0234,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7471','WISCRS Rusk County (ftUS)',NULL,NULL,'EPSG','4353','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.551,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.04,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000495976,'EPSG','9201','EPSG','8806','False easting',822000.001,'EPSG','9003','EPSG','8807','False northing',0.077,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7472','WISCRS Shawano County (m)',NULL,NULL,'EPSG','4354','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.021,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.362,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000032144,'EPSG','9201','EPSG','8806','False easting',262433.3253,'EPSG','9001','EPSG','8807','False northing',0.0096,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7473','WISCRS Shawano County (ftUS)',NULL,NULL,'EPSG','4354','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.021,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.362,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000032144,'EPSG','9201','EPSG','8806','False easting',861000.001,'EPSG','9003','EPSG','8807','False northing',0.031,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7474','WISCRS St. Croix County (m)',NULL,NULL,'EPSG','4355','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.021,'EPSG','9110','EPSG','8802','Longitude of natural origin',-92.38,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000381803,'EPSG','9201','EPSG','8806','False easting',165506.7302,'EPSG','9001','EPSG','8807','False northing',0.0103,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7475','WISCRS St. Croix County (ftUS)',NULL,NULL,'EPSG','4355','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.021,'EPSG','9110','EPSG','8802','Longitude of natural origin',-92.38,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000381803,'EPSG','9201','EPSG','8806','False easting',542999.997,'EPSG','9003','EPSG','8807','False northing',0.034,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7476','WISCRS Taylor County (m)',NULL,NULL,'EPSG','4356','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.1040159509,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.29,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000597566,'EPSG','9201','EPSG','8806','False easting',187147.5744,'EPSG','9001','EPSG','8807','False northing',107746.7522,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7477','WISCRS Taylor County (ftUS)',NULL,NULL,'EPSG','4356','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.1040159509,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.29,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000597566,'EPSG','9201','EPSG','8806','False easting',614000.0,'EPSG','9003','EPSG','8807','False northing',353499.136,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7478','WISCRS Trempealeau County (m)',NULL,NULL,'EPSG','4357','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.094,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.22,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000361538,'EPSG','9201','EPSG','8806','False easting',256946.9138,'EPSG','9001','EPSG','8807','False northing',0.0041,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7479','WISCRS Trempealeau County (ftUS)',NULL,NULL,'EPSG','4357','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.094,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.22,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000361538,'EPSG','9201','EPSG','8806','False easting',843000.0,'EPSG','9003','EPSG','8807','False northing',0.013,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7480','WISCRS Waupaca County (m)',NULL,NULL,'EPSG','4358','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.2513,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.49,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000333645,'EPSG','9201','EPSG','8806','False easting',185013.9709,'EPSG','9001','EPSG','8807','False northing',0.007,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7481','WISCRS Waupaca County (ftUS)',NULL,NULL,'EPSG','4358','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.2513,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.49,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000333645,'EPSG','9201','EPSG','8806','False easting',607000.003,'EPSG','9003','EPSG','8807','False northing',0.023,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7482','WISCRS Wood County (m)',NULL,NULL,'EPSG','4359','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.214534369,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000421209,'EPSG','9201','EPSG','8806','False easting',208483.6173,'EPSG','9001','EPSG','8807','False northing',134589.754,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7483','WISCRS Wood County (ftUS)',NULL,NULL,'EPSG','4359','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.214534369,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000421209,'EPSG','9201','EPSG','8806','False easting',684000.001,'EPSG','9003','EPSG','8807','False northing',441566.551,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7484','WISCRS Adams and Juneau Counties (m)',NULL,NULL,'EPSG','4360','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.22,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000365285,'EPSG','9201','EPSG','8806','False easting',147218.6942,'EPSG','9001','EPSG','8807','False northing',0.0037,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7485','WISCRS Adams and Juneau Counties (ftUS)',NULL,NULL,'EPSG','4360','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.22,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000365285,'EPSG','9201','EPSG','8806','False easting',482999.999,'EPSG','9003','EPSG','8807','False northing',0.012,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7486','WISCRS Calumet, Fond du Lac, Outagamie and Winnebago Counties (m)',NULL,NULL,'EPSG','4361','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.431,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000286569,'EPSG','9201','EPSG','8806','False easting',244754.8893,'EPSG','9001','EPSG','8807','False northing',0.0049,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7487','WISCRS Calumet, Fond du Lac, Outagamie and Winnebago Counties (ftUS)',NULL,NULL,'EPSG','4361','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.431,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000286569,'EPSG','9201','EPSG','8806','False easting',802999.999,'EPSG','9003','EPSG','8807','False northing',0.016,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7488','WISCRS Columbia County (m)',NULL,NULL,'EPSG','4362','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.2745167925,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.234,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00003498,'EPSG','9201','EPSG','8806','False easting',169164.3381,'EPSG','9001','EPSG','8807','False northing',111569.6134,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7489','WISCRS Columbia County (ftUS)',NULL,NULL,'EPSG','4362','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.2745167925,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.234,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00003498,'EPSG','9201','EPSG','8806','False easting',554999.999,'EPSG','9003','EPSG','8807','False northing',366041.307,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7490','WISCRS Crawford County (m)',NULL,NULL,'EPSG','4363','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.1200200178,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.562,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000349151,'EPSG','9201','EPSG','8806','False easting',113690.6274,'EPSG','9001','EPSG','8807','False northing',53703.1201,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7491','WISCRS Crawford County (ftUS)',NULL,NULL,'EPSG','4363','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.1200200178,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.562,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000349151,'EPSG','9201','EPSG','8806','False easting',373000.0,'EPSG','9003','EPSG','8807','False northing',176190.987,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7492','WISCRS Dane County (m)',NULL,NULL,'EPSG','4364','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.0410257735,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.252,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000384786,'EPSG','9201','EPSG','8806','False easting',247193.2944,'EPSG','9001','EPSG','8807','False northing',146591.9896,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7493','WISCRS Dane County (ftUS)',NULL,NULL,'EPSG','4364','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.0410257735,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.252,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000384786,'EPSG','9201','EPSG','8806','False easting',811000.0,'EPSG','9003','EPSG','8807','False northing',480943.886,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7494','WISCRS Dodge and Jefferson Counties (m)',NULL,NULL,'EPSG','4365','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.282,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.463,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000346418,'EPSG','9201','EPSG','8806','False easting',263347.7263,'EPSG','9001','EPSG','8807','False northing',0.0076,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7495','WISCRS Dodge and Jefferson Counties (ftUS)',NULL,NULL,'EPSG','4365','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.282,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.463,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000346418,'EPSG','9201','EPSG','8806','False easting',863999.999,'EPSG','9003','EPSG','8807','False northing',0.025,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7496','WISCRS Grant County (m)',NULL,NULL,'EPSG','4366','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.244,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.48,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000349452,'EPSG','9201','EPSG','8806','False easting',242316.4841,'EPSG','9001','EPSG','8807','False northing',0.01,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7497','WISCRS Grant County (ftUS)',NULL,NULL,'EPSG','4366','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.244,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.48,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000349452,'EPSG','9201','EPSG','8806','False easting',794999.998,'EPSG','9003','EPSG','8807','False northing',0.033,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7498','WISCRS Green and Lafayette Counties (m)',NULL,NULL,'EPSG','4367','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',42.3815224197,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.502,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000390487,'EPSG','9201','EPSG','8806','False easting',170078.7403,'EPSG','9001','EPSG','8807','False northing',45830.2947,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7499','WISCRS Green and Lafayette Counties (ftUS)',NULL,NULL,'EPSG','4367','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',42.3815224197,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.502,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000390487,'EPSG','9201','EPSG','8806','False easting',558000.0,'EPSG','9003','EPSG','8807','False northing',150361.559,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7500','WISCRS Green Lake and Marquette Counties (m)',NULL,NULL,'EPSG','4368','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.4825200424,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.143,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000344057,'EPSG','9201','EPSG','8806','False easting',150876.3018,'EPSG','9001','EPSG','8807','False northing',79170.7795,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7501','WISCRS Green Lake and Marquette Counties (ftUS)',NULL,NULL,'EPSG','4368','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.4825200424,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.143,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000344057,'EPSG','9201','EPSG','8806','False easting',495000.0,'EPSG','9003','EPSG','8807','False northing',259746.132,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7502','WISCRS Iowa County (m)',NULL,NULL,'EPSG','4369','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.322,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.094,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000394961,'EPSG','9201','EPSG','8806','False easting',113081.0261,'EPSG','9001','EPSG','8807','False northing',0.0045,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7503','WISCRS Iowa County (ftUS)',NULL,NULL,'EPSG','4369','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.322,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.094,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000394961,'EPSG','9201','EPSG','8806','False easting',371000.0,'EPSG','9003','EPSG','8807','False northing',0.015,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7504','WISCRS Kenosha, Milwaukee, Ozaukee and Racine Counties (m)',NULL,NULL,'EPSG','4370','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.13,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.534,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000260649,'EPSG','9201','EPSG','8806','False easting',185928.3728,'EPSG','9001','EPSG','8807','False northing',0.0009,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7505','WISCRS Kenosha, Milwaukee, Ozaukee and Racine Counties (ftUS)',NULL,NULL,'EPSG','4370','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.13,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.534,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000260649,'EPSG','9201','EPSG','8806','False easting',610000.003,'EPSG','9003','EPSG','8807','False northing',0.003,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7506','WISCRS Kewaunee, Manitowoc and Sheboygan Counties (m)',NULL,NULL,'EPSG','4371','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.16,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.33,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000233704,'EPSG','9201','EPSG','8806','False easting',79857.7614,'EPSG','9001','EPSG','8807','False northing',0.0012,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7507','WISCRS Kewaunee, Manitowoc and Sheboygan Counties (ftUS)',NULL,NULL,'EPSG','4371','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.16,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.33,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000233704,'EPSG','9201','EPSG','8806','False easting',262000.006,'EPSG','9003','EPSG','8807','False northing',0.004,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7508','WISCRS La Crosse County (m)',NULL,NULL,'EPSG','4372','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.2704,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.19,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000319985,'EPSG','9201','EPSG','8806','False easting',130454.6598,'EPSG','9001','EPSG','8807','False northing',0.0033,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7509','WISCRS La Crosse County (ftUS)',NULL,NULL,'EPSG','4372','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.2704,'EPSG','9110','EPSG','8802','Longitude of natural origin',-91.19,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000319985,'EPSG','9201','EPSG','8806','False easting',427999.996,'EPSG','9003','EPSG','8807','False northing',0.011,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7510','WISCRS Monroe County (m)',NULL,NULL,'EPSG','4373','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.0000266143,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.383,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000434122,'EPSG','9201','EPSG','8806','False easting',204521.209,'EPSG','9001','EPSG','8807','False northing',121923.9861,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7511','WISCRS Monroe County (ftUS)',NULL,NULL,'EPSG','4373','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.0000266143,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.383,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000434122,'EPSG','9201','EPSG','8806','False easting',671000.0,'EPSG','9003','EPSG','8807','False northing',400012.278,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7512','WISCRS Richland County (m)',NULL,NULL,'EPSG','4374','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.1920326539,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.255,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000375653,'EPSG','9201','EPSG','8806','False easting',202387.6048,'EPSG','9001','EPSG','8807','False northing',134255.4253,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7513','WISCRS Richland County (ftUS)',NULL,NULL,'EPSG','4374','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.1920326539,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.255,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000375653,'EPSG','9201','EPSG','8806','False easting',664000.0,'EPSG','9003','EPSG','8807','False northing',440469.675,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7514','WISCRS Rock County (m)',NULL,NULL,'EPSG','4375','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.564,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.042,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000337311,'EPSG','9201','EPSG','8806','False easting',146304.2926,'EPSG','9001','EPSG','8807','False northing',0.0068,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7515','WISCRS Rock County (ftUS)',NULL,NULL,'EPSG','4375','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.564,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.042,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000337311,'EPSG','9201','EPSG','8806','False easting',480000.0,'EPSG','9003','EPSG','8807','False northing',0.022,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7516','WISCRS Sauk County (m)',NULL,NULL,'EPSG','4376','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.491,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.54,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000373868,'EPSG','9201','EPSG','8806','False easting',185623.5716,'EPSG','9001','EPSG','8807','False northing',0.0051,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7517','WISCRS Sauk County (ftUS)',NULL,NULL,'EPSG','4376','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.491,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.54,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000373868,'EPSG','9201','EPSG','8806','False easting',609000.001,'EPSG','9003','EPSG','8807','False northing',0.017,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7518','WISCRS Vernon County (m)',NULL,NULL,'EPSG','4377','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.3430118583,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.47,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000408158,'EPSG','9201','EPSG','8806','False easting',222504.4451,'EPSG','9001','EPSG','8807','False northing',47532.0602,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7519','WISCRS Vernon County (ftUS)',NULL,NULL,'EPSG','4377','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.3430118583,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.47,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000408158,'EPSG','9201','EPSG','8806','False easting',730000.0,'EPSG','9003','EPSG','8807','False northing',155944.768,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7520','WISCRS Walworth County (m)',NULL,NULL,'EPSG','4378','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',42.4010063549,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.323,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000367192,'EPSG','9201','EPSG','8806','False easting',232562.8651,'EPSG','9001','EPSG','8807','False northing',111088.2224,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7521','WISCRS Walworth County (ftUS)',NULL,NULL,'EPSG','4378','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',42.4010063549,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.323,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000367192,'EPSG','9201','EPSG','8806','False easting',763000.0,'EPSG','9003','EPSG','8807','False northing',364461.943,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7522','WISCRS Washington County (m)',NULL,NULL,'EPSG','4379','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.5505,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.035,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00003738,'EPSG','9201','EPSG','8806','False easting',120091.4415,'EPSG','9001','EPSG','8807','False northing',0.003,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7523','WISCRS Washington County (ftUS)',NULL,NULL,'EPSG','4379','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.5505,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.035,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00003738,'EPSG','9201','EPSG','8806','False easting',394000.004,'EPSG','9003','EPSG','8807','False northing',0.01,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7524','WISCRS Waukesha County (m)',NULL,NULL,'EPSG','4380','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.341,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.133,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000346179,'EPSG','9201','EPSG','8806','False easting',208788.418,'EPSG','9001','EPSG','8807','False northing',0.0034,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7525','WISCRS Waukesha County (ftUS)',NULL,NULL,'EPSG','4380','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.341,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.133,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000346179,'EPSG','9201','EPSG','8806','False easting',685000.001,'EPSG','9003','EPSG','8807','False northing',0.011,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7526','WISCRS Waushara County (m)',NULL,NULL,'EPSG','4381','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.0650198565,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.143,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000392096,'EPSG','9201','EPSG','8806','False easting',120091.4402,'EPSG','9001','EPSG','8807','False northing',45069.7587,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7527','WISCRS Waushara County (ftUS)',NULL,NULL,'EPSG','4381','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.0650198565,'EPSG','9110','EPSG','8802','Longitude of natural origin',-89.143,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000392096,'EPSG','9201','EPSG','8806','False easting',394000.0,'EPSG','9003','EPSG','8807','False northing',147866.367,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7687','Kyrgyzstan zone 1',NULL,NULL,'EPSG','4385','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',68.31,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1300000.0,'EPSG','9001','EPSG','8807','False northing',14743.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7688','Kyrgyzstan zone 2',NULL,NULL,'EPSG','4386','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',71.31,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',2300000.0,'EPSG','9001','EPSG','8807','False northing',14743.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7689','Kyrgyzstan zone 3',NULL,NULL,'EPSG','4387','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',74.31,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',3300000.0,'EPSG','9001','EPSG','8807','False northing',14743.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7690','Kyrgyzstan zone 4',NULL,NULL,'EPSG','4388','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',77.31,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',4300000.0,'EPSG','9001','EPSG','8807','False northing',14743.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7691','Kyrgyzstan zone 5',NULL,NULL,'EPSG','4389','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',80.31,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',5300000.0,'EPSG','9001','EPSG','8807','False northing',14743.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7722','Survey of India Lambert',NULL,NULL,'EPSG','1121','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',24.0,'EPSG','9102','EPSG','8822','Longitude of false origin',80.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',12.2822638,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',35.1022096,'EPSG','9110','EPSG','8826','Easting at false origin',4000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7723','Andhra Pradesh NSF LCC',NULL,NULL,'EPSG','4394','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',16.25543298,'EPSG','9102','EPSG','8822','Longitude of false origin',80.875,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',13.75,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',18.75,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7724','Arunachal Pradesh NSF LCC',NULL,NULL,'EPSG','4395','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',28.00157897,'EPSG','9102','EPSG','8822','Longitude of false origin',94.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',27.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',29.0,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7725','Assam NSF LCC',NULL,NULL,'EPSG','4396','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',26.00257703,'EPSG','9102','EPSG','8822','Longitude of false origin',92.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',24.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',27.2,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7726','Bihar NSF LCC',NULL,NULL,'EPSG','4397','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',25.87725247,'EPSG','9102','EPSG','8822','Longitude of false origin',85.875,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',24.625,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',27.125,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7727','Delhi NSF LCC',NULL,NULL,'EPSG','4422','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',28.62510126,'EPSG','9102','EPSG','8822','Longitude of false origin',77.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',28.223,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',28.523,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7728','Gujarat NSF LCC',NULL,NULL,'EPSG','4400','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',22.37807121,'EPSG','9102','EPSG','8822','Longitude of false origin',71.375,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',20.473,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',23.573,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7729','Haryana NSF LCC',NULL,NULL,'EPSG','4401','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',29.25226266,'EPSG','9102','EPSG','8822','Longitude of false origin',76.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',28.05,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',30.25,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7730','Himachal Pradesh NSF LCC',NULL,NULL,'EPSG','4402','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.75183497,'EPSG','9102','EPSG','8822','Longitude of false origin',77.375,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',30.75,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',32.75,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7731','Jammu and Kashmir NSF LCC',NULL,NULL,'EPSG','4403','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.75570874,'EPSG','9102','EPSG','8822','Longitude of false origin',76.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',33.05,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',36.25,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7732','Jharkhand NSF LCC',NULL,NULL,'EPSG','4404','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',23.62652682,'EPSG','9102','EPSG','8822','Longitude of false origin',85.625,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',22.323,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',24.423,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7733','Madhya Pradesh NSF LCC',NULL,NULL,'EPSG','4407','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',24.00529821,'EPSG','9102','EPSG','8822','Longitude of false origin',78.375,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',22.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',26.0,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7734','Maharashtra NSF LCC',NULL,NULL,'EPSG','4408','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',18.88015774,'EPSG','9102','EPSG','8822','Longitude of false origin',76.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',16.373,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',21.073,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7735','Manipur NSF LCC',NULL,NULL,'EPSG','4409','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',24.75060911,'EPSG','9102','EPSG','8822','Longitude of false origin',94.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',24.05,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',25.25,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7736','Meghalaya NSF LCC',NULL,NULL,'EPSG','4410','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',25.62524747,'EPSG','9102','EPSG','8822','Longitude of false origin',91.375,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',25.123,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',26.023,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7737','Nagaland NSF LCC',NULL,NULL,'EPSG','4412','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',26.12581974,'EPSG','9102','EPSG','8822','Longitude of false origin',94.375,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',25.223,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',26.523,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7738','Northeast India NSF LCC',NULL,NULL,'EPSG','4392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',25.63452135,'EPSG','9102','EPSG','8822','Longitude of false origin',93.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',23.023,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',28.123,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7739','Orissa NSF LCC',NULL,NULL,'EPSG','4413','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',20.25305174,'EPSG','9102','EPSG','8822','Longitude of false origin',84.375,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',18.35,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',21.55,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7740','Punjab NSF LCC',NULL,NULL,'EPSG','4414','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.00178226,'EPSG','9102','EPSG','8822','Longitude of false origin',75.375,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',30.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',32.0,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7741','Rajasthan NSF LCC',NULL,NULL,'EPSG','4415','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',26.88505546,'EPSG','9102','EPSG','8822','Longitude of false origin',73.875,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',24.173,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',29.273,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7742','Uttar Pradesh NSF LCC',NULL,NULL,'EPSG','4419','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',27.13270823,'EPSG','9102','EPSG','8822','Longitude of false origin',80.875,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',24.523,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',29.223,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7743','Uttaranchal NSF LCC',NULL,NULL,'EPSG','4420','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',30.0017132,'EPSG','9102','EPSG','8822','Longitude of false origin',79.375,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',29.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',31.0,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7744','Andaman and Nicobar NSF TM',NULL,NULL,'EPSG','4423','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',10.25,'EPSG','9102','EPSG','8802','Longitude of natural origin',93.25,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999428,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7745','Chhattisgarh NSF TM',NULL,NULL,'EPSG','4398','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',21.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',82.25,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9998332,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7746','Goa NSF TM',NULL,NULL,'EPSG','4399','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',15.375,'EPSG','9102','EPSG','8802','Longitude of natural origin',74.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999913,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7747','Karnataka NSF TM',NULL,NULL,'EPSG','4405','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',15.125,'EPSG','9102','EPSG','8802','Longitude of natural origin',76.375,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9998012,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7748','Kerala NSF TM',NULL,NULL,'EPSG','4406','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',10.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',76.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999177,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7749','Lakshadweep NSF TM',NULL,NULL,'EPSG','4424','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',10.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',73.125,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999536,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7750','Mizoram NSF TM',NULL,NULL,'EPSG','4411','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',23.125,'EPSG','9102','EPSG','8802','Longitude of natural origin',92.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999821,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7751','Sikkim NSF TM',NULL,NULL,'EPSG','4416','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',27.625,'EPSG','9102','EPSG','8802','Longitude of natural origin',88.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999926,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7752','Tamil Nadu NSF TM',NULL,NULL,'EPSG','4417','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',10.875,'EPSG','9102','EPSG','8802','Longitude of natural origin',78.375,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9997942,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7753','Tripura NSF TM',NULL,NULL,'EPSG','4418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',23.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',91.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999822,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7754','West Bengal NSF TM',NULL,NULL,'EPSG','4421','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',24.375,'EPSG','9102','EPSG','8802','Longitude of natural origin',87.875,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9998584,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7802','Cadastral Coordinate System 2005',NULL,NULL,'EPSG','3224','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.400435246,'EPSG','9110','EPSG','8822','Longitude of false origin',25.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',42.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',43.2,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4725824.3591,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7812','Height <> Depth Conversion',NULL,NULL,'EPSG','1262','EPSG','1068','Height Depth Reversal',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7813','Vertical Axis Unit Conversion',NULL,NULL,'EPSG','1262','EPSG','1069','Change of Vertical Unit','EPSG','1051','Unit conversion scalar',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7818','CS63 zone X1',NULL,NULL,'EPSG','4435','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.05,'EPSG','9110','EPSG','8802','Longitude of natural origin',23.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7819','CS63 zone X2',NULL,NULL,'EPSG','4429','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.05,'EPSG','9110','EPSG','8802','Longitude of natural origin',26.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',2300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7820','CS63 zone X3',NULL,NULL,'EPSG','4430','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.05,'EPSG','9110','EPSG','8802','Longitude of natural origin',29.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',3300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7821','CS63 zone X4',NULL,NULL,'EPSG','4431','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.05,'EPSG','9110','EPSG','8802','Longitude of natural origin',32.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',4300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7822','CS63 zone X5',NULL,NULL,'EPSG','4432','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.05,'EPSG','9110','EPSG','8802','Longitude of natural origin',35.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',5300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7823','CS63 zone X6',NULL,NULL,'EPSG','4433','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.05,'EPSG','9110','EPSG','8802','Longitude of natural origin',38.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',6300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7824','CS63 zone X7',NULL,NULL,'EPSG','4434','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.05,'EPSG','9110','EPSG','8802','Longitude of natural origin',41.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',7300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7875','St. Helena Local Grid 1971',NULL,NULL,'EPSG','3183','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-15.58,'EPSG','9110','EPSG','8802','Longitude of natural origin',-5.43,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7876','St. Helena Local Grid (Tritan)',NULL,NULL,'EPSG','3183','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-15.58,'EPSG','9110','EPSG','8802','Longitude of natural origin',-5.43,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',299483.737,'EPSG','9001','EPSG','8807','False northing',2000527.879,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7963','Poolbeg height (ft(Br36)) to Poolbeg height (m)',NULL,NULL,'EPSG','1305','EPSG','1069','Change of Vertical Unit','EPSG','1051','Unit conversion scalar',0.3048007491,'EPSG','9201',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7972','NGVD29 height (ftUS) to NGVD29 height (m)',NULL,NULL,'EPSG','1323','EPSG','1069','Change of Vertical Unit','EPSG','1051','Unit conversion scalar',0.304800609601219,'EPSG','9201',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7978','NGVD29 height (ftUS) to NGVD29 depth (ftUS)',NULL,NULL,'EPSG','1323','EPSG','1068','Height Depth Reversal',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7982','HKPD height to HKPD depth',NULL,NULL,'EPSG','3334','EPSG','1068','Height Depth Reversal',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7984','KOC WD height to KOC WD depth',NULL,NULL,'EPSG','3267','EPSG','1068','Height Depth Reversal',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7985','KOC WD depth to KOC WD depth (ft)',NULL,NULL,'EPSG','3267','EPSG','1069','Change of Vertical Unit','EPSG','1051','Unit conversion scalar',3.28083989501312,'EPSG','9201',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7988','NAVD88 height to NAVD88 height (ftUS)',NULL,NULL,'EPSG','3664','EPSG','1069','Change of Vertical Unit','EPSG','1051','Unit conversion scalar',3.28083333333333,'EPSG','9201',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7989','NAVD88 height to NAVD88 depth',NULL,NULL,'EPSG','4161','EPSG','1068','Height Depth Reversal',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7990','NAVD88 height (ftUS) to NAVD88 depth (ftUS)',NULL,NULL,'EPSG','3664','EPSG','1068','Height Depth Reversal',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7993','Albany Grid 2020',NULL,NULL,'EPSG','4439','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',117.53,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000044,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',4100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7994','Barrow Island Grid 2020',NULL,NULL,'EPSG','4438','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',115.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000022,'EPSG','9201','EPSG','8806','False easting',60000.0,'EPSG','9001','EPSG','8807','False northing',2700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7995','Broome Grid 2020',NULL,NULL,'EPSG','4441','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',122.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00000298,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',2300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7996','Busselton Coastal Grid',NULL,NULL,'EPSG','4437','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',115.26,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99999592,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',4000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7997','Carnarvon Grid 2020',NULL,NULL,'EPSG','4442','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',113.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99999796,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',3050000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7998','Christmas Island Grid 2020',NULL,NULL,'EPSG','4169','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',105.373,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00002514,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',1400000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','7999','Cocos Island Grid 2020',NULL,NULL,'EPSG','1069','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',96.523,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99999387,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',1600000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8000','Collie Grid 2020',NULL,NULL,'EPSG','4443','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',115.56,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000019,'EPSG','9201','EPSG','8806','False easting',40000.0,'EPSG','9001','EPSG','8807','False northing',4100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8001','Esperance Grid 2020',NULL,NULL,'EPSG','4445','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',121.53,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000055,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',4050000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8002','Exmouth Grid 2020',NULL,NULL,'EPSG','4448','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',114.04,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00000236,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',2750000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8003','Geraldton Coastal Grid',NULL,NULL,'EPSG','4449','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',114.35,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00000628,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',3450000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8004','Goldfields Grid 2020',NULL,NULL,'EPSG','4436','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',121.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00004949,'EPSG','9201','EPSG','8806','False easting',60000.0,'EPSG','9001','EPSG','8807','False northing',3800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8005','Jurien Coastal Grid',NULL,NULL,'EPSG','4440','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',114.59,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00000314,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',3650000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8006','Kalbarri Grid 2020',NULL,NULL,'EPSG','4444','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',114.1855,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000014,'EPSG','9201','EPSG','8806','False easting',55000.0,'EPSG','9001','EPSG','8807','False northing',3700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8007','Karratha Grid 2020',NULL,NULL,'EPSG','4451','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',116.56,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999989,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',2550000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8008','Kununurra Grid 2020',NULL,NULL,'EPSG','4452','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',128.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000165,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',2100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8009','Lancelin Coastal Grid',NULL,NULL,'EPSG','4453','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',115.22,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00000157,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',3750000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8010','Margaret River Coastal Grid',NULL,NULL,'EPSG','4457','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',115.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000055,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',4050000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8011','Perth Coastal Grid',NULL,NULL,'EPSG','4462','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',115.49,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99999906,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',3900000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8012','Port Hedland Grid 2020',NULL,NULL,'EPSG','4466','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',118.36,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00000135,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8033','TM Zone 20N (US survey feet)',NULL,NULL,'EPSG','4467','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-63.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8034','TM Zone 21N (US survey feet)',NULL,NULL,'EPSG','4468','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-57.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8038','Instantaneous Water Level height to Instantaneous Water Level depth',NULL,NULL,'EPSG','1262','EPSG','1068','Height Depth Reversal',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8039','MSL height to MSL depth',NULL,NULL,'EPSG','1262','EPSG','1068','Height Depth Reversal',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8040','Gusterberg Grid',NULL,NULL,'EPSG','4455','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',48.021847,'EPSG','9110','EPSG','8802','Longitude of natural origin',31.481505,'EPSG','9110','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8041','St. Stephen Grid',NULL,NULL,'EPSG','4456','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',48.123154,'EPSG','9110','EPSG','8802','Longitude of natural origin',34.022732,'EPSG','9110','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8054','MSL height to MSL height (ft)',NULL,NULL,'EPSG','1262','EPSG','1069','Change of Vertical Unit','EPSG','1051','Unit conversion scalar',3.28083989501312,'EPSG','9201',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8055','MSL height to MSL height (ftUS)',NULL,NULL,'EPSG','1245','EPSG','1069','Change of Vertical Unit','EPSG','1051','Unit conversion scalar',3.28083333333333,'EPSG','9201',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8056','MSL depth to MSL depth (ft)',NULL,NULL,'EPSG','1262','EPSG','1069','Change of Vertical Unit','EPSG','1051','Unit conversion scalar',3.28083989501312,'EPSG','9201',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8057','MSL depth to MSL depth (ftUS)',NULL,NULL,'EPSG','1245','EPSG','1069','Change of Vertical Unit','EPSG','1051','Unit conversion scalar',3.28083333333333,'EPSG','9201',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8060','Baltic 1977 height to Baltic 1977 depth',NULL,NULL,'EPSG','2423','EPSG','1068','Height Depth Reversal',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8061','Pima County zone 1 East (ft)',NULL,NULL,'EPSG','4472','EPSG','9815','Hotine Oblique Mercator (variant B)','EPSG','8811','Latitude of projection centre',32.15,'EPSG','9110','EPSG','8812','Longitude of projection centre',-111.24,'EPSG','9110','EPSG','8813','Azimuth of initial line',45.0,'EPSG','9102','EPSG','8814','Angle from Rectified to Skew Grid',45.0,'EPSG','9102','EPSG','8815','Scale factor on initial line',1.00011,'EPSG','9201','EPSG','8816','Easting at projection centre',160000.0,'EPSG','9002','EPSG','8817','Northing at projection centre',800000.0,'EPSG','9002',0);
INSERT INTO "conversion" VALUES('EPSG','8062','Pima County zone 2 Central (ft)',NULL,NULL,'EPSG','4460','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-112.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00009,'EPSG','9201','EPSG','8806','False easting',1800000.0,'EPSG','9002','EPSG','8807','False northing',1000000.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8063','Pima County zone 3 West (ft)',NULL,NULL,'EPSG','4450','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-113.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000055,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8064','Pima County zone 4 Mt. Lemmon (ft)',NULL,NULL,'EPSG','4473','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',30.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-110.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9998,'EPSG','9201','EPSG','8806','False easting',30000.0,'EPSG','9002','EPSG','8807','False northing',-620000.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8080','MTM Nova Scotia zone 4 v2',NULL,NULL,'EPSG','1534','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-61.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',24500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8081','MTM Nova Scotia zone 5 v2',NULL,NULL,'EPSG','1535','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-64.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',25500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8087','Iceland Lambert 2016',NULL,NULL,'EPSG','1120','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',65.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-19.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',64.15,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',65.45,'EPSG','9110','EPSG','8826','Easting at false origin',2700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8229','NAVD88 height to NAVD88 height (ft)',NULL,NULL,'EPSG','4464','EPSG','1069','Change of Vertical Unit','EPSG','1051','Unit conversion scalar',3.28083989501312,'EPSG','9201',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8273','Oregon Burns-Harper zone (meters)',NULL,NULL,'EPSG','4459','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-117.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00014,'EPSG','9201','EPSG','8806','False easting',90000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8274','Oregon Burns-Harper zone (International feet)',NULL,NULL,'EPSG','4459','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-117.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00014,'EPSG','9201','EPSG','8806','False easting',295275.5906,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8275','Oregon Canyon City-Burns zone (meters)',NULL,NULL,'EPSG','4465','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-119.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00022,'EPSG','9201','EPSG','8806','False easting',20000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8276','Oregon Canyon City-Burns zone (International feet)',NULL,NULL,'EPSG','4465','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-119.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00022,'EPSG','9201','EPSG','8806','False easting',65616.7979,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8277','Oregon Coast Range North zone (meters)',NULL,NULL,'EPSG','4471','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.35,'EPSG','9110','EPSG','8802','Longitude of natural origin',-123.25,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000045,'EPSG','9201','EPSG','8806','False easting',30000.0,'EPSG','9001','EPSG','8807','False northing',20000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8278','Oregon Coast Range North zone (International feet)',NULL,NULL,'EPSG','4471','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.35,'EPSG','9110','EPSG','8802','Longitude of natural origin',-123.25,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000045,'EPSG','9201','EPSG','8806','False easting',98425.1969,'EPSG','9002','EPSG','8807','False northing',65616.7979,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8279','Oregon Dayville-Prairie City zone (meters)',NULL,NULL,'EPSG','4474','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-119.38,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00012,'EPSG','9201','EPSG','8806','False easting',20000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8280','Oregon Dayville-Prairie City zone (International feet)',NULL,NULL,'EPSG','4474','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-119.38,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00012,'EPSG','9201','EPSG','8806','False easting',65616.7979,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8281','Oregon Denio-Burns zone (meters)',NULL,NULL,'EPSG','4475','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-118.25,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00019,'EPSG','9201','EPSG','8806','False easting',80000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8282','Oregon Denio-Burns zone (International feet)',NULL,NULL,'EPSG','4475','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-118.25,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00019,'EPSG','9201','EPSG','8806','False easting',262467.1916,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8283','Oregon Halfway zone (meters)',NULL,NULL,'EPSG','4476','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-117.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000085,'EPSG','9201','EPSG','8806','False easting',40000.0,'EPSG','9001','EPSG','8807','False northing',70000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8284','Oregon Halfway zone (International feet)',NULL,NULL,'EPSG','4476','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-117.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000085,'EPSG','9201','EPSG','8806','False easting',131233.5958,'EPSG','9002','EPSG','8807','False northing',229658.7927,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8285','Oregon Medford-Diamond Lake zone (meters)',NULL,NULL,'EPSG','4477','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',42.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-122.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00004,'EPSG','9201','EPSG','8806','False easting',60000.0,'EPSG','9001','EPSG','8807','False northing',-60000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8286','Oregon Medford-Diamond Lake zone (International feet)',NULL,NULL,'EPSG','4477','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',42.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-122.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00004,'EPSG','9201','EPSG','8806','False easting',196850.3937,'EPSG','9002','EPSG','8807','False northing',-196850.3937,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8287','Oregon Mitchell zone (meters)',NULL,NULL,'EPSG','4478','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',47.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-120.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99927,'EPSG','9201','EPSG','8806','False easting',30000.0,'EPSG','9001','EPSG','8807','False northing',290000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8288','Oregon Mitchell zone (International feet)',NULL,NULL,'EPSG','4478','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',47.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-120.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99927,'EPSG','9201','EPSG','8806','False easting',98425.1969,'EPSG','9002','EPSG','8807','False northing',951443.5696,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8289','Oregon North Central zone (meters)',NULL,NULL,'EPSG','4479','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.1,'EPSG','9110','EPSG','8802','Longitude of natural origin',-120.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',140000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8290','Oregon North Central zone (International feet)',NULL,NULL,'EPSG','4479','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.1,'EPSG','9110','EPSG','8802','Longitude of natural origin',-120.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',328083.9895,'EPSG','9002','EPSG','8807','False northing',459317.5853,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8291','Oregon Ochoco Summit zone (meters)',NULL,NULL,'EPSG','4481','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-120.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00006,'EPSG','9201','EPSG','8806','False easting',40000.0,'EPSG','9001','EPSG','8807','False northing',-80000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8292','Oregon Ochoco Summit zone (International feet)',NULL,NULL,'EPSG','4481','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-120.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00006,'EPSG','9201','EPSG','8806','False easting',131233.5958,'EPSG','9002','EPSG','8807','False northing',-262467.1916,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8293','Oregon Owyhee zone (meters)',NULL,NULL,'EPSG','4482','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-117.35,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00018,'EPSG','9201','EPSG','8806','False easting',70000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8294','Oregon Owyhee zone (International feet)',NULL,NULL,'EPSG','4482','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-117.35,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00018,'EPSG','9201','EPSG','8806','False easting',229658.7927,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8295','Oregon Pilot Rock-Ukiah zone (meters)',NULL,NULL,'EPSG','4483','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.1,'EPSG','9110','EPSG','8802','Longitude of natural origin',-119.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000025,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',130000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8296','Oregon Pilot Rock-Ukiah zone (International feet)',NULL,NULL,'EPSG','4483','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.1,'EPSG','9110','EPSG','8802','Longitude of natural origin',-119.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000025,'EPSG','9201','EPSG','8806','False easting',164041.9948,'EPSG','9002','EPSG','8807','False northing',426509.1864,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8297','Oregon Prairie City-Brogan zone (meters)',NULL,NULL,'EPSG','4484','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-118.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00017,'EPSG','9201','EPSG','8806','False easting',60000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8298','Oregon Prairie City-Brogan zone (International feet)',NULL,NULL,'EPSG','4484','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-118.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00017,'EPSG','9201','EPSG','8806','False easting',196850.3937,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8299','Oregon Riley-Lakeview zone (meters)',NULL,NULL,'EPSG','4458','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-120.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000215,'EPSG','9201','EPSG','8806','False easting',70000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8300','Oregon Riley-Lakeview zone (International feet)',NULL,NULL,'EPSG','4458','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-120.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000215,'EPSG','9201','EPSG','8806','False easting',229658.7927,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8301','Oregon Siskiyou Pass zone (meters)',NULL,NULL,'EPSG','4463','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',42.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-122.35,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00015,'EPSG','9201','EPSG','8806','False easting',10000.0,'EPSG','9001','EPSG','8807','False northing',60000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8302','Oregon Siskiyou Pass zone (International feet)',NULL,NULL,'EPSG','4463','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',42.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-122.35,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00015,'EPSG','9201','EPSG','8806','False easting',32808.399,'EPSG','9002','EPSG','8807','False northing',196850.3937,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8303','Oregon Ukiah-Fox zone (meters)',NULL,NULL,'EPSG','4470','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-119.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00014,'EPSG','9201','EPSG','8806','False easting',30000.0,'EPSG','9001','EPSG','8807','False northing',90000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8304','Oregon Ukiah-Fox zone (International feet)',NULL,NULL,'EPSG','4470','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-119.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00014,'EPSG','9201','EPSG','8806','False easting',98425.1969,'EPSG','9002','EPSG','8807','False northing',295275.5906,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8305','Oregon Wallowa zone (meters)',NULL,NULL,'EPSG','4480','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-117.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000195,'EPSG','9201','EPSG','8806','False easting',60000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8306','Oregon Wallowa zone (International feet)',NULL,NULL,'EPSG','4480','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-117.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000195,'EPSG','9201','EPSG','8806','False easting',196850.3937,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8307','Oregon Warner Highway zone (meters)',NULL,NULL,'EPSG','4486','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',42.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-120.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000245,'EPSG','9201','EPSG','8806','False easting',40000.0,'EPSG','9001','EPSG','8807','False northing',60000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8308','Oregon Warner Highway zone (International feet)',NULL,NULL,'EPSG','4486','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',42.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-120.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000245,'EPSG','9201','EPSG','8806','False easting',131233.5958,'EPSG','9002','EPSG','8807','False northing',196850.3937,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8309','Oregon Willamette Pass zone (meters)',NULL,NULL,'EPSG','4488','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-122.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000223,'EPSG','9201','EPSG','8806','False easting',20000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8310','Oregon Willamette Pass zone (International feet)',NULL,NULL,'EPSG','4488','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-122.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000223,'EPSG','9201','EPSG','8806','False easting',65616.7979,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8354','Black Sea height to Black Sea depth',NULL,NULL,'EPSG','3251','EPSG','1068','Height Depth Reversal',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8355','AIOC95 height to AIOC95 depth',NULL,NULL,'EPSG','2592','EPSG','1068','Height Depth Reversal',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8356','Caspian height to Caspian depth',NULL,NULL,'EPSG','1291','EPSG','1068','Height Depth Reversal',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8359','Baltic 1957 height to Baltic 1957 depth',NULL,NULL,'EPSG','1306','EPSG','1068','Height Depth Reversal',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8373','NCRS Las Vegas zone (m)',NULL,NULL,'EPSG','4485','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-114.58,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0001,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8374','NCRS Las Vegas zone (ftUS)',NULL,NULL,'EPSG','4485','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-114.58,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0001,'EPSG','9201','EPSG','8806','False easting',328083.3333,'EPSG','9003','EPSG','8807','False northing',656166.6667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8375','NCRS Las Vegas high elevation zone (m)',NULL,NULL,'EPSG','4487','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-114.58,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000135,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',400000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8376','NCRS Las Vegas high elevation zone (ftUS)',NULL,NULL,'EPSG','4487','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-114.58,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000135,'EPSG','9201','EPSG','8806','False easting',984250.0,'EPSG','9003','EPSG','8807','False northing',1312333.3333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8389','WEIPA94',NULL,NULL,'EPSG','4491','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999929,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8432','Macau Grid',NULL,NULL,'EPSG','1147','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',22.124463,'EPSG','9110','EPSG','8802','Longitude of natural origin',113.321129,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',20000.0,'EPSG','9001','EPSG','8807','False northing',20000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8440','Laborde Grid (Greenwich)',NULL,NULL,'EPSG','1149','EPSG','9813','Laborde Oblique Mercator','EPSG','8811','Latitude of projection centre',-18.54,'EPSG','9110','EPSG','8812','Longitude of projection centre',46.2614025,'EPSG','9110','EPSG','8813','Azimuth of initial line',18.54,'EPSG','9110','EPSG','8815','Scale factor on initial line',0.9995,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8458','Kansas regional zone 1 Goodland (ftUS)',NULL,NULL,'EPSG','4495','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-101.36,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000156,'EPSG','9201','EPSG','8806','False easting',1500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8459','Kansas regional zone 2 Colby (ftUS)',NULL,NULL,'EPSG','4496','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-100.57,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000134,'EPSG','9201','EPSG','8806','False easting',2500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8490','Kansas regional zone 3 Oberlin (ftUS)',NULL,NULL,'EPSG','4497','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-100.21,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000116,'EPSG','9201','EPSG','8806','False easting',3500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8491','Kansas regional zone 4 Hays (ftUS)',NULL,NULL,'EPSG','4494','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-99.27,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000082,'EPSG','9201','EPSG','8806','False easting',4500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8492','Kansas regional zone 5 Great Bend (ftUS)',NULL,NULL,'EPSG','4498','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-98.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000078,'EPSG','9201','EPSG','8806','False easting',5500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8493','Kansas regional zone 6 Beliot (ftUS)',NULL,NULL,'EPSG','4499','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-98.09,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000068,'EPSG','9201','EPSG','8806','False easting',6500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8494','Kansas regional zone 7 Salina (ftUS)',NULL,NULL,'EPSG','4500','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-97.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000049,'EPSG','9201','EPSG','8806','False easting',7500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8495','Kansas regional zone 8 Manhattan (ftUS)',NULL,NULL,'EPSG','4501','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',39.1,'EPSG','9110','EPSG','8802','Longitude of natural origin',-96.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000044,'EPSG','9201','EPSG','8806','False easting',8500000.0,'EPSG','9003','EPSG','8807','False northing',600000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8498','Kansas regional zone 9 Emporia (ftUS)',NULL,NULL,'EPSG','4502','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',38.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-96.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00005,'EPSG','9201','EPSG','8806','False easting',9500000.0,'EPSG','9003','EPSG','8807','False northing',300000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8499','Kansas regional zone 10 Atchison (ftUS)',NULL,NULL,'EPSG','4503','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',39.38,'EPSG','9110','EPSG','8802','Longitude of natural origin',-95.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00004,'EPSG','9201','EPSG','8806','False easting',10500000.0,'EPSG','9003','EPSG','8807','False northing',700000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8500','Kansas regional zone 11 Kansas City (ftUS)',NULL,NULL,'EPSG','4504','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',39.06,'EPSG','9110','EPSG','8802','Longitude of natural origin',-95.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000033,'EPSG','9201','EPSG','8806','False easting',11500000.0,'EPSG','9003','EPSG','8807','False northing',600000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8501','Kansas regional zone 12 Ulysses (ftUS)',NULL,NULL,'EPSG','4505','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-101.25,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00014,'EPSG','9201','EPSG','8806','False easting',12500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8502','Kansas regional zone 13 Garden City (ftUS)',NULL,NULL,'EPSG','4506','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-100.24,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000109,'EPSG','9201','EPSG','8806','False easting',13500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8503','Kansas regional zone 14 Dodge City (ftUS)',NULL,NULL,'EPSG','4507','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-99.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000097,'EPSG','9201','EPSG','8806','False easting',14500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8504','Kansas regional zone 15 Larned (ftUS)',NULL,NULL,'EPSG','4508','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-99.12,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000087,'EPSG','9201','EPSG','8806','False easting',15500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8505','Kansas regional zone 16 Pratt (ftUS)',NULL,NULL,'EPSG','4509','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-98.33,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000069,'EPSG','9201','EPSG','8806','False easting',16500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8506','Kansas regional zone 17 Wichita (ftUS)',NULL,NULL,'EPSG','4510','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',37.46,'EPSG','9110','EPSG','8802','Longitude of natural origin',-97.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000059,'EPSG','9201','EPSG','8806','False easting',17500000.0,'EPSG','9003','EPSG','8807','False northing',400000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8507','Kansas regional zone 18 Arkansas City (ftUS)',NULL,NULL,'EPSG','4511','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',37.11,'EPSG','9110','EPSG','8802','Longitude of natural origin',-97.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000055,'EPSG','9201','EPSG','8806','False easting',18500000.0,'EPSG','9003','EPSG','8807','False northing',200000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8515','Kansas regional zone 19 Coffeyville (ftUS)',NULL,NULL,'EPSG','4512','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-95.58,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000034,'EPSG','9201','EPSG','8806','False easting',19500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8516','Kansas regional zone 20 Pittsburg (ftUS)',NULL,NULL,'EPSG','4513','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-95.05,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000031,'EPSG','9201','EPSG','8806','False easting',20500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8825','Idaho Transverse Mercator',NULL,NULL,'EPSG','1381','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-114.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',2500000.0,'EPSG','9001','EPSG','8807','False northing',1200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8854','Equal Earth Greenwich',NULL,NULL,'EPSG','1262','EPSG','1078','Equal Earth','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8855','Equal Earth Americas',NULL,NULL,'EPSG','1262','EPSG','1078','Equal Earth','EPSG','8802','Longitude of natural origin',-90.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','8856','Equal Earth Asia-Pacific',NULL,NULL,'EPSG','1262','EPSG','1078','Equal Earth','EPSG','8802','Longitude of natural origin',150.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','9058','Vietnam TM-3 103-00',NULL,NULL,'EPSG','4541','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',103.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','9190','NIWA Albers',NULL,NULL,'EPSG','3508','EPSG','9822','Albers Equal Area','EPSG','8821','Latitude of false origin',-40.0,'EPSG','9102','EPSG','8822','Longitude of false origin',175.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-30.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-50.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','9192','Vietnam TM-3 104-00',NULL,NULL,'EPSG','4538','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',104.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','9193','Vietnam TM-3 104-30',NULL,NULL,'EPSG','4545','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',104.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','9194','Vietnam TM-3 104-45',NULL,NULL,'EPSG','4546','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',104.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','9195','Vietnam TM-3 105-30',NULL,NULL,'EPSG','4548','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',105.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','9196','Vietnam TM-3 105-45',NULL,NULL,'EPSG','4549','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',105.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','9197','Vietnam TM-3 106-00',NULL,NULL,'EPSG','4550','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',106.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','9198','Vietnam TM-3 106-15',NULL,NULL,'EPSG','4552','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',106.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','9199','Vietnam TM-3 106-30',NULL,NULL,'EPSG','4553','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',106.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','9200','Vietnam TM-3 107-00',NULL,NULL,'EPSG','4554','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',107.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','9201','Vietnam TM-3 107-15',NULL,NULL,'EPSG','4556','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',107.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','9202','Vietnam TM-3 107-30',NULL,NULL,'EPSG','4557','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',107.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','9203','Vietnam TM-3 108-15',NULL,NULL,'EPSG','4559','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',108.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','9204','Vietnam TM-3 108-30',NULL,NULL,'EPSG','4560','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',108.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','9219','South Africa Basic Survey Unit Albers 25E',NULL,NULL,'EPSG','4567','EPSG','9822','Albers Equal Area','EPSG','8821','Latitude of false origin',-30.0,'EPSG','9102','EPSG','8822','Longitude of false origin',25.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-22.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-38.0,'EPSG','9102','EPSG','8826','Easting at false origin',1400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','9220','South Africa Basic Survey Unit Albers 44E',NULL,NULL,'EPSG','4568','EPSG','9822','Albers Equal Area','EPSG','8821','Latitude of false origin',-42.0,'EPSG','9102','EPSG','8822','Longitude of false origin',44.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-34.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-50.0,'EPSG','9102','EPSG','8826','Easting at false origin',1200000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10101','Alabama CS27 East zone',NULL,NULL,'EPSG','2154','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.5,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10102','Alabama CS27 West zone',NULL,NULL,'EPSG','2155','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999933333,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10131','SPCS83 Alabama East zone (meters)',NULL,NULL,'EPSG','2154','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.5,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99996,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10132','SPCS83 Alabama West zone (meters)',NULL,NULL,'EPSG','2155','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999933333,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10201','Arizona Coordinate System East zone',NULL,NULL,'EPSG','2167','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-110.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10202','Arizona Coordinate System Central zone',NULL,NULL,'EPSG','2166','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-111.55,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10203','Arizona Coordinate System West zone',NULL,NULL,'EPSG','2168','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-113.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999933333,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10231','SPCS83 Arizona East zone (meters)',NULL,NULL,'EPSG','2167','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-110.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',213360.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10232','SPCS83 Arizona Central zone (meters)',NULL,NULL,'EPSG','2166','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-111.55,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',213360.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10233','SPCS83 Arizona West zone (meters)',NULL,NULL,'EPSG','2168','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-113.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999933333,'EPSG','9201','EPSG','8806','False easting',213360.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10301','Arkansas CS27 North',NULL,NULL,'EPSG','2169','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-92.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',36.14,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',34.56,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10302','Arkansas CS27 South',NULL,NULL,'EPSG','2170','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',32.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-92.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',34.46,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',33.18,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10331','SPCS83 Arkansas North zone (meters)',NULL,NULL,'EPSG','2169','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-92.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',36.14,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',34.56,'EPSG','9110','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10332','SPCS83 Arkansas South zone (meters)',NULL,NULL,'EPSG','2170','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',32.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-92.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',34.46,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',33.18,'EPSG','9110','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',400000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10401','California CS27 zone I',NULL,NULL,'EPSG','2175','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-122.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.0,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10402','California CS27 zone II',NULL,NULL,'EPSG','2176','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-122.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.5,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.2,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10403','California CS27 zone III',NULL,NULL,'EPSG','2177','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-120.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',38.26,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.04,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10404','California CS27 zone IV',NULL,NULL,'EPSG','2178','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',35.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-119.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',37.15,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',36.0,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10405','California CS27 zone V',NULL,NULL,'EPSG','2179','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-118.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',35.28,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',34.02,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10406','California CS27 zone VI',NULL,NULL,'EPSG','2180','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',32.1,'EPSG','9110','EPSG','8822','Longitude of false origin',-116.15,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',33.53,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',32.47,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10407','California CS27 zone VII',NULL,NULL,'EPSG','2181','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.08,'EPSG','9110','EPSG','8822','Longitude of false origin',-118.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',34.25,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',33.52,'EPSG','9110','EPSG','8826','Easting at false origin',4186692.58,'EPSG','9003','EPSG','8827','Northing at false origin',416926.74,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','10408','California CS27 zone VII',NULL,NULL,'EPSG','2181','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.08,'EPSG','9110','EPSG','8822','Longitude of false origin',-118.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',34.25,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',33.52,'EPSG','9110','EPSG','8826','Easting at false origin',4186692.58,'EPSG','9003','EPSG','8827','Northing at false origin',4160926.74,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10420','California Albers',NULL,NULL,'EPSG','1375','EPSG','9822','Albers Equal Area','EPSG','8821','Latitude of false origin',0.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.5,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',-4000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10431','SPCS83 California zone 1 (meters)',NULL,NULL,'EPSG','2175','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-122.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.0,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10432','SPCS83 California zone 2 (meters)',NULL,NULL,'EPSG','2176','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-122.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.5,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.2,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10433','SPCS83 California zone 3 (meters)',NULL,NULL,'EPSG','2177','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-120.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',38.26,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.04,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10434','SPCS83 California zone 4 (meters)',NULL,NULL,'EPSG','2178','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',35.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-119.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',37.15,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',36.0,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10435','SPCS83 California zone 5 (meters)',NULL,NULL,'EPSG','2182','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-118.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',35.28,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',34.02,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10436','SPCS83 California zone 6 (meters)',NULL,NULL,'EPSG','2180','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',32.1,'EPSG','9110','EPSG','8822','Longitude of false origin',-116.15,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',33.53,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',32.47,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10501','Colorado CS27 North zone',NULL,NULL,'EPSG','2184','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-105.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.43,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.47,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10502','Colorado CS27 Central zone',NULL,NULL,'EPSG','2183','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-105.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.45,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.27,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10503','Colorado CS27 South zone',NULL,NULL,'EPSG','2185','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-105.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',38.26,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.14,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10531','SPCS83 Colorado North zone (meters)',NULL,NULL,'EPSG','2184','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-105.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',40.47,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',39.43,'EPSG','9110','EPSG','8826','Easting at false origin',914401.8289,'EPSG','9001','EPSG','8827','Northing at false origin',304800.6096,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10532','SPCS83 Colorado Central zone (meters)',NULL,NULL,'EPSG','2183','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-105.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.45,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.27,'EPSG','9110','EPSG','8826','Easting at false origin',914401.8289,'EPSG','9001','EPSG','8827','Northing at false origin',304800.6096,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10533','SPCS83 Colorado South zone (meters)',NULL,NULL,'EPSG','2185','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-105.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',38.26,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.14,'EPSG','9110','EPSG','8826','Easting at false origin',914401.8289,'EPSG','9001','EPSG','8827','Northing at false origin',304800.6096,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10600','Connecticut CS27',NULL,NULL,'EPSG','1377','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-72.45,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.52,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',41.12,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10630','SPCS83 Connecticut zone (meters)',NULL,NULL,'EPSG','1377','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-72.45,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.52,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',41.12,'EPSG','9110','EPSG','8826','Easting at false origin',304800.6096,'EPSG','9001','EPSG','8827','Northing at false origin',152400.3048,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10700','Delaware CS27',NULL,NULL,'EPSG','1378','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-75.25,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999995,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10730','SPCS83 Delaware zone (meters)',NULL,NULL,'EPSG','1378','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-75.25,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999995,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10901','Florida CS27 East zone',NULL,NULL,'EPSG','2186','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',24.2,'EPSG','9110','EPSG','8802','Longitude of natural origin',-81.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999941177,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10902','Florida CS27 West zone',NULL,NULL,'EPSG','2188','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',24.2,'EPSG','9110','EPSG','8802','Longitude of natural origin',-82.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999941177,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10903','Florida CS27 North zone',NULL,NULL,'EPSG','2187','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',29.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-84.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',30.45,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',29.35,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10931','SPCS83 Florida East zone (meters)',NULL,NULL,'EPSG','2186','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',24.2,'EPSG','9110','EPSG','8802','Longitude of natural origin',-81.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999941177,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10932','SPCS83 Florida West zone (meters)',NULL,NULL,'EPSG','2188','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',24.2,'EPSG','9110','EPSG','8802','Longitude of natural origin',-82.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999941177,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10933','SPCS83 Florida North zone (meters)',NULL,NULL,'EPSG','2187','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',29.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-84.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',30.45,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',29.35,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','10934','Florida GDL Albers (meters)',NULL,NULL,'EPSG','1379','EPSG','9822','Albers Equal Area','EPSG','8821','Latitude of false origin',24.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-84.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',24.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',31.3,'EPSG','9110','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11001','Georgia CS27 East zone',NULL,NULL,'EPSG','2189','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-82.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11002','Georgia CS27 West zone',NULL,NULL,'EPSG','2190','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-84.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11031','SPCS83 Georgia East zone (meters)',NULL,NULL,'EPSG','2189','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-82.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11032','SPCS83 Georgia West zone (meters)',NULL,NULL,'EPSG','2190','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-84.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11101','Idaho CS27 East zone',NULL,NULL,'EPSG','2192','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-112.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999947368,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11102','Idaho CS27 Central zone',NULL,NULL,'EPSG','2191','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-114.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999947368,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11103','Idaho CS27 West zone',NULL,NULL,'EPSG','2193','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-115.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999933333,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11131','SPCS83 Idaho East zone (meters)',NULL,NULL,'EPSG','2192','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-112.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999947368,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11132','SPCS83 Idaho Central zone (meters)',NULL,NULL,'EPSG','2191','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-114.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999947368,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11133','SPCS83 Idaho West zone (meters)',NULL,NULL,'EPSG','2193','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-115.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999933333,'EPSG','9201','EPSG','8806','False easting',800000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11201','Illinois CS27 East zone',NULL,NULL,'EPSG','2194','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999975,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11202','Illinois CS27 West zone',NULL,NULL,'EPSG','2195','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999941177,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11231','SPCS83 Illinois East zone (meters)',NULL,NULL,'EPSG','2194','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999975,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11232','SPCS83 Illinois West zone (meters)',NULL,NULL,'EPSG','2195','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999941177,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11301','Indiana CS27 East zone',NULL,NULL,'EPSG','2196','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11302','Indiana CS27 West zone',NULL,NULL,'EPSG','2197','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.05,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11331','SPCS83 Indiana East zone (meters)',NULL,NULL,'EPSG','2196','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',250000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11332','SPCS83 Indiana West zone (meters)',NULL,NULL,'EPSG','2197','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.05,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',900000.0,'EPSG','9001','EPSG','8807','False northing',250000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11401','Iowa CS27 North zone',NULL,NULL,'EPSG','2198','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-93.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',43.16,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',42.04,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11402','Iowa CS27 South zone',NULL,NULL,'EPSG','2199','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-93.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.47,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.37,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11431','SPCS83 Iowa North zone (meters)',NULL,NULL,'EPSG','2198','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-93.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',43.16,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',42.04,'EPSG','9110','EPSG','8826','Easting at false origin',1500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11432','SPCS83 Iowa South zone (meters)',NULL,NULL,'EPSG','2199','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-93.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.47,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.37,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11501','Kansas CS27 North zone',NULL,NULL,'EPSG','2200','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.47,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.43,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11502','Kansas CS27 South zone',NULL,NULL,'EPSG','2201','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',38.34,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.16,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11531','SPCS83 Kansas North zone (meters)',NULL,NULL,'EPSG','2200','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.47,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.43,'EPSG','9110','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11532','SPCS83 Kansas South zone (meters)',NULL,NULL,'EPSG','2201','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',38.34,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.16,'EPSG','9110','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',400000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11601','Kentucky CS27 North zone',NULL,NULL,'EPSG','2202','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-84.15,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',37.58,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.58,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11602','Kentucky CS27 South zone',NULL,NULL,'EPSG','2203','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-85.45,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',36.44,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.56,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11630','SPCS83 Kentucky Single Zone (meters)',NULL,NULL,'EPSG','1386','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-85.45,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',37.05,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.4,'EPSG','9110','EPSG','8826','Easting at false origin',1500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11631','Kentucky CS83 North zone',NULL,NULL,'EPSG','2202','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-84.15,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',37.58,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.58,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','11632','SPCS83 Kentucky South zone (meters)',NULL,NULL,'EPSG','2203','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-85.45,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',37.56,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',36.44,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11701','Louisiana CS27 North zone',NULL,NULL,'EPSG','2204','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',30.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-92.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',31.1,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',32.4,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11702','Louisiana CS27 South zone',NULL,NULL,'EPSG','2205','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',28.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-91.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',29.18,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',30.42,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11703','Louisiana CS27 Offshore zone',NULL,NULL,'EPSG','1387','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',25.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-91.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',27.5,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',26.1,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11731','SPCS83 Louisiana North zone (meters)',NULL,NULL,'EPSG','2204','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',30.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-92.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',32.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',31.1,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11732','SPCS83 Louisiana South zone (meters)',NULL,NULL,'EPSG','2529','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',28.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-91.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',30.42,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',29.18,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11733','SPCS83 Louisiana Offshore zone (meters)',NULL,NULL,'EPSG','1387','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',25.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-91.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',27.5,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',26.1,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11801','Maine CS27 East zone',NULL,NULL,'EPSG','2206','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-68.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11802','Maine CS27 West zone',NULL,NULL,'EPSG','2207','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-70.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11831','SPCS83 Maine East zone (meters)',NULL,NULL,'EPSG','2206','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-68.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11832','SPCS83 Maine West zone (meters)',NULL,NULL,'EPSG','2207','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-70.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',900000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11833','SPCS83 Maine East zone (US Survey feet)',NULL,NULL,'EPSG','2206','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-68.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',984250.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11834','SPCS83 Maine West zone (US Survey feet)',NULL,NULL,'EPSG','2207','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-70.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',2952750.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11851','Maine CS2000 East zone (meters)',NULL,NULL,'EPSG','2960','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-67.523,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99998,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11852','Maine CS2000 Central zone',NULL,NULL,'EPSG','2959','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-69.073,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99998,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','11853','Maine CS2000 West zone (meters)',NULL,NULL,'EPSG','2958','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-70.223,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99998,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11854','Maine CS2000 Central zone (meters)',NULL,NULL,'EPSG','2959','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-69.073,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99998,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11900','Maryland CS27',NULL,NULL,'EPSG','1389','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-77.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',38.18,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',39.27,'EPSG','9110','EPSG','8826','Easting at false origin',800000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','11930','SPCS83 Maryland zone (meters)',NULL,NULL,'EPSG','1389','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-77.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.27,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.18,'EPSG','9110','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12001','Massachusetts CS27 Mainland zone',NULL,NULL,'EPSG','2209','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-71.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.43,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',42.41,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12002','Massachusetts CS27 Island zone',NULL,NULL,'EPSG','2208','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-70.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.17,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',41.29,'EPSG','9110','EPSG','8826','Easting at false origin',200000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12031','SPCS83 Massachusetts Mainland zone (meters)',NULL,NULL,'EPSG','2209','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-71.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',42.41,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',41.43,'EPSG','9110','EPSG','8826','Easting at false origin',200000.0,'EPSG','9001','EPSG','8827','Northing at false origin',750000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12032','SPCS83 Massachusetts Island zone (meters)',NULL,NULL,'EPSG','2208','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-70.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.29,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',41.17,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12101','Michigan State Plane East zone',NULL,NULL,'EPSG','1720','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-83.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999942857,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12102','Michigan State Plane Old Central zone',NULL,NULL,'EPSG','1721','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999909091,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12103','Michigan State Plane West zone',NULL,NULL,'EPSG','3652','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999909091,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12111','Michigan CS27 North zone',NULL,NULL,'EPSG','1723','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.47,'EPSG','9110','EPSG','8822','Longitude of false origin',-87.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',45.29,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',47.05,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','12112','Michigan CS27 Central zone',NULL,NULL,'EPSG','1724','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.19,'EPSG','9110','EPSG','8822','Longitude of false origin',-84.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',44.11,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',45.42,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','12113','Michigan CS27 South zone',NULL,NULL,'EPSG','1725','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-84.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',42.06,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',43.4,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','12141','SPCS83 Michigan North zone (meters)',NULL,NULL,'EPSG','1723','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.47,'EPSG','9110','EPSG','8822','Longitude of false origin',-87.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',47.05,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',45.29,'EPSG','9110','EPSG','8826','Easting at false origin',8000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12142','SPCS83 Michigan Central zone (meters)',NULL,NULL,'EPSG','1724','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.19,'EPSG','9110','EPSG','8822','Longitude of false origin',-84.22,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',45.42,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',44.11,'EPSG','9110','EPSG','8826','Easting at false origin',6000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12143','SPCS83 Michigan South zone (meters)',NULL,NULL,'EPSG','1725','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-84.22,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',43.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',42.06,'EPSG','9110','EPSG','8826','Easting at false origin',4000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12150','Michigan Oblique Mercator (meters)',NULL,NULL,'EPSG','1391','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',45.1833,'EPSG','9110','EPSG','8812','Longitude of projection centre',-86.0,'EPSG','9110','EPSG','8813','Azimuth of initial line',337.25556,'EPSG','9102','EPSG','8814','Angle from Rectified to Skew Grid',337.25556,'EPSG','9102','EPSG','8815','Scale factor on initial line',0.9996,'EPSG','9201','EPSG','8806','False easting',2546731.496,'EPSG','9001','EPSG','8807','False northing',-4354009.816,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','12201','Minnesota CS27 North zone',NULL,NULL,'EPSG','2214','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-93.06,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',47.02,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',48.38,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12202','Minnesota CS27 Central zone',NULL,NULL,'EPSG','2213','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-94.15,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',45.37,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',47.03,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12203','Minnesota CS27 South zone',NULL,NULL,'EPSG','2215','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-94.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',43.47,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',45.13,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12231','SPCS83 Minnesota North zone (meters)',NULL,NULL,'EPSG','2214','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-93.06,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',48.38,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',47.02,'EPSG','9110','EPSG','8826','Easting at false origin',800000.0,'EPSG','9001','EPSG','8827','Northing at false origin',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12232','SPCS83 Minnesota Central zone (meters)',NULL,NULL,'EPSG','2213','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-94.15,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',47.03,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',45.37,'EPSG','9110','EPSG','8826','Easting at false origin',800000.0,'EPSG','9001','EPSG','8827','Northing at false origin',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12233','SPCS83 Minnesota South zone (meters)',NULL,NULL,'EPSG','2215','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-94.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',45.13,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',43.47,'EPSG','9110','EPSG','8826','Easting at false origin',800000.0,'EPSG','9001','EPSG','8827','Northing at false origin',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12234','SPCS83 Minnesota North zone (US Survey feet)',NULL,NULL,'EPSG','2214','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-93.06,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',48.38,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',47.02,'EPSG','9110','EPSG','8826','Easting at false origin',2624666.6667,'EPSG','9003','EPSG','8827','Northing at false origin',328083.3333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12235','SPCS83 Minnesota Central zone (US Survey feet)',NULL,NULL,'EPSG','2213','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-94.15,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',47.03,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',45.37,'EPSG','9110','EPSG','8826','Easting at false origin',2624666.6667,'EPSG','9003','EPSG','8827','Northing at false origin',328083.3333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12236','SPCS83 Minnesota South zone (US Survey feet)',NULL,NULL,'EPSG','2215','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-94.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',45.13,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',43.47,'EPSG','9110','EPSG','8826','Easting at false origin',2624666.6667,'EPSG','9003','EPSG','8827','Northing at false origin',328083.3333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12301','Mississippi CS27 East zone',NULL,NULL,'EPSG','2216','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',29.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.5,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12302','Mississippi CS27 West zone',NULL,NULL,'EPSG','2217','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999941177,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12331','SPCS83 Mississippi East zone (meters)',NULL,NULL,'EPSG','2216','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',29.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.5,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12332','SPCS83 Mississippi West zone (meters)',NULL,NULL,'EPSG','2217','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',29.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12401','Missouri CS27 East zone',NULL,NULL,'EPSG','2219','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',35.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999933333,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12402','Missouri CS27 Central zone',NULL,NULL,'EPSG','2218','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',35.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-92.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999933333,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12403','Missouri CS27 West zone',NULL,NULL,'EPSG','2220','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.1,'EPSG','9110','EPSG','8802','Longitude of natural origin',-94.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999941177,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12431','SPCS83 Missouri East zone (meters)',NULL,NULL,'EPSG','2219','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',35.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999933333,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12432','SPCS83 Missouri Central zone (meters)',NULL,NULL,'EPSG','2218','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',35.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-92.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999933333,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12433','SPCS83 Missouri West zone (meters)',NULL,NULL,'EPSG','2220','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.1,'EPSG','9110','EPSG','8802','Longitude of natural origin',-94.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999941177,'EPSG','9201','EPSG','8806','False easting',850000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12501','Montana CS27 North zone',NULL,NULL,'EPSG','2211','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-109.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',48.43,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',47.51,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12502','Montana CS27 Central zone',NULL,NULL,'EPSG','2210','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-109.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',47.53,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',46.27,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12503','Montana CS27 South zone',NULL,NULL,'EPSG','2212','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-109.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',46.24,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',44.52,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12530','SPCS83 Montana zone (meters)',NULL,NULL,'EPSG','1395','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.15,'EPSG','9110','EPSG','8822','Longitude of false origin',-109.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',49.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',45.0,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12601','Nebraska CS27 North zone',NULL,NULL,'EPSG','2221','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.51,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',42.49,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12602','Nebraska CS27 South zone',NULL,NULL,'EPSG','2222','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-99.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',40.17,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',41.43,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12630','SPCS83 Nebraska zone (meters)',NULL,NULL,'EPSG','1396','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',43.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.0,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12701','Nevada CS27 East zone',NULL,NULL,'EPSG','2224','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-115.35,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12702','Nevada CS27 Central zone',NULL,NULL,'EPSG','2223','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-116.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12703','Nevada CS27 West zone',NULL,NULL,'EPSG','2225','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-118.35,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12731','SPCS83 Nevada East zone (meters)',NULL,NULL,'EPSG','2224','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-115.35,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',8000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12732','SPCS83 Nevada Central zone (meters)',NULL,NULL,'EPSG','2223','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-116.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',6000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12733','SPCS83 Nevada West zone (meters)',NULL,NULL,'EPSG','2225','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-118.35,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',800000.0,'EPSG','9001','EPSG','8807','False northing',4000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12800','New Hampshire CS27',NULL,NULL,'EPSG','1398','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-71.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12830','SPCS83 New Hampshire zone (meters)',NULL,NULL,'EPSG','1398','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-71.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12900','New Jersey CS27',NULL,NULL,'EPSG','1399','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-74.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999975,'EPSG','9201','EPSG','8806','False easting',2000000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','12930','SPCS83 New Jersey zone (meters)',NULL,NULL,'EPSG','1399','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-74.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13001','New Mexico CS27 East zone',NULL,NULL,'EPSG','2228','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-104.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999909091,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13002','New Mexico CS27 Central zone',NULL,NULL,'EPSG','2229','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-106.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13003','New Mexico CS27 West zone',NULL,NULL,'EPSG','2230','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-107.5,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999916667,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13031','SPCS83 New Mexico East zone (meters)',NULL,NULL,'EPSG','2228','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-104.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999909091,'EPSG','9201','EPSG','8806','False easting',165000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13032','SPCS83 New Mexico Central zone (meters)',NULL,NULL,'EPSG','2231','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-106.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13033','SPCS83 New Mexico West zone (meters)',NULL,NULL,'EPSG','2232','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-107.5,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999916667,'EPSG','9201','EPSG','8806','False easting',830000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13101','New York CS27 East zone',NULL,NULL,'EPSG','2234','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-74.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13102','New York CS27 Central zone',NULL,NULL,'EPSG','2233','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-76.35,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13103','New York CS27 West zone',NULL,NULL,'EPSG','2236','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-78.35,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13104','New York CS27 Long Island zone',NULL,NULL,'EPSG','2235','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-74.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.02,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.4,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','13131','SPCS83 New York East zone (meters)',NULL,NULL,'EPSG','2234','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-74.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13132','SPCS83 New York Central zone (meters)',NULL,NULL,'EPSG','2233','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-76.35,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13133','SPCS83 New York West zone (meters)',NULL,NULL,'EPSG','2236','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-78.35,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',350000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13134','SPCS83 New York Long Island zone (meters)',NULL,NULL,'EPSG','2235','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.1,'EPSG','9110','EPSG','8822','Longitude of false origin',-74.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.02,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.4,'EPSG','9110','EPSG','8826','Easting at false origin',300000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13200','North Carolina CS27',NULL,NULL,'EPSG','1402','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.45,'EPSG','9110','EPSG','8822','Longitude of false origin',-79.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',34.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',36.1,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13230','SPCS83 North Carolina zone (meters)',NULL,NULL,'EPSG','1402','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.45,'EPSG','9110','EPSG','8822','Longitude of false origin',-79.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',36.1,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',34.2,'EPSG','9110','EPSG','8826','Easting at false origin',609601.22,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13301','North Dakota CS27 North zone',NULL,NULL,'EPSG','2237','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',47.26,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',48.44,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13302','North Dakota CS27 South zone',NULL,NULL,'EPSG','2238','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',46.11,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',47.29,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13331','SPCS83 North Dakota North zone (meters)',NULL,NULL,'EPSG','2237','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',48.44,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',47.26,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13332','SPCS83 North Dakota South zone (meters)',NULL,NULL,'EPSG','2238','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',47.29,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',46.11,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13401','Ohio CS27 North zone',NULL,NULL,'EPSG','2239','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-82.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',40.26,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',41.42,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13402','Ohio CS27 South zone',NULL,NULL,'EPSG','2240','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-82.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',38.44,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.02,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13431','SPCS83 Ohio North zone (meters)',NULL,NULL,'EPSG','2239','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-82.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.42,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.26,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13432','SPCS83 Ohio South zone (meters)',NULL,NULL,'EPSG','2240','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-82.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',40.02,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.44,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13433','SPCS83 Ohio North zone (US Survey feet)',NULL,NULL,'EPSG','2239','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-82.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.42,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.26,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13434','SPCS83 Ohio South zone (US Survey feet)',NULL,NULL,'EPSG','2240','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-82.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',40.02,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.44,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13501','Oklahoma CS27 North zone',NULL,NULL,'EPSG','2241','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',35.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',35.34,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',36.46,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13502','Oklahoma CS27 South zone',NULL,NULL,'EPSG','2242','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',33.56,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',35.14,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13531','SPCS83 Oklahoma North zone (meters)',NULL,NULL,'EPSG','2241','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',35.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',36.46,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',35.34,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13532','SPCS83 Oklahoma South zone (meters)',NULL,NULL,'EPSG','2242','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',35.14,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',33.56,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13601','Oregon CS27 North zone',NULL,NULL,'EPSG','2243','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-120.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',44.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',46.0,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13602','Oregon CS27 South zone',NULL,NULL,'EPSG','2244','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-120.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',42.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',44.0,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13631','SPCS83 Oregon North zone (meters)',NULL,NULL,'EPSG','2243','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-120.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',46.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',44.2,'EPSG','9110','EPSG','8826','Easting at false origin',2500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13632','SPCS83 Oregon South zone (meters)',NULL,NULL,'EPSG','2244','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-120.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',44.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',42.2,'EPSG','9110','EPSG','8826','Easting at false origin',1500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13633','Oregon Lambert (meters)',NULL,NULL,'EPSG','1406','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.45,'EPSG','9110','EPSG','8822','Longitude of false origin',-120.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',43.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',45.3,'EPSG','9110','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13701','Pennsylvania CS27 North zone',NULL,NULL,'EPSG','2245','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.1,'EPSG','9110','EPSG','8822','Longitude of false origin',-77.45,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',40.53,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',41.57,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13702','Pennsylvania CS27 South zone',NULL,NULL,'EPSG','2246','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-77.45,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.56,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.48,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','13731','SPCS83 Pennsylvania North zone (meters)',NULL,NULL,'EPSG','2245','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.1,'EPSG','9110','EPSG','8822','Longitude of false origin',-77.45,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.57,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.53,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13732','SPCS83 Pennsylvania South zone (meters)',NULL,NULL,'EPSG','2246','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-77.45,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',40.58,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',39.56,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13800','Rhode Island CS27',NULL,NULL,'EPSG','1408','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.05,'EPSG','9110','EPSG','8802','Longitude of natural origin',-71.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999938,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13830','SPCS83 Rhode Island zone (meters)',NULL,NULL,'EPSG','1408','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.05,'EPSG','9110','EPSG','8802','Longitude of natural origin',-71.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99999375,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13901','South Carolina CS27 North zone',NULL,NULL,'EPSG','2247','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',33.46,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',34.58,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13902','South Carolina CS27 South zone',NULL,NULL,'EPSG','2248','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',32.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',33.4,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','13930','SPCS83 South Carolina zone (meters)',NULL,NULL,'EPSG','1409','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',34.5,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',32.3,'EPSG','9110','EPSG','8826','Easting at false origin',609600.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14001','South Dakota CS27 North zone',NULL,NULL,'EPSG','2249','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',44.25,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',45.41,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14002','South Dakota CS27 South zone',NULL,NULL,'EPSG','2250','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',42.5,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',44.24,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14031','SPCS83 South Dakota North zone (meters)',NULL,NULL,'EPSG','2249','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',45.41,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',44.25,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14032','SPCS83 South Dakota South zone (meters)',NULL,NULL,'EPSG','2250','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',44.24,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',42.5,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14100','Tennessee CS27',NULL,NULL,'EPSG','1411','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-86.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',35.15,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',36.25,'EPSG','9110','EPSG','8826','Easting at false origin',100000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','14130','SPCS83 Tennessee zone (meters)',NULL,NULL,'EPSG','1411','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-86.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',36.25,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',35.15,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14201','Texas CS27 North zone',NULL,NULL,'EPSG','2253','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-101.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',34.39,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',36.11,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14202','Texas CS27 North Central zone',NULL,NULL,'EPSG','2254','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-97.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',32.08,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',33.58,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14203','Texas CS27 Central zone',NULL,NULL,'EPSG','2252','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',29.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',30.07,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',31.53,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14204','Texas CS27 South Central zone',NULL,NULL,'EPSG','2256','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',27.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-99.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',28.23,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',30.17,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14205','Texas CS27 South zone',NULL,NULL,'EPSG','2255','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',25.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',26.1,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',27.5,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14231','SPCS83 Texas North zone (meters)',NULL,NULL,'EPSG','2253','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-101.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',36.11,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',34.39,'EPSG','9110','EPSG','8826','Easting at false origin',200000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14232','SPCS83 Texas North Central zone (meters)',NULL,NULL,'EPSG','2254','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',33.58,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',32.08,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14233','SPCS83 Texas Central zone (meters)',NULL,NULL,'EPSG','2252','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',29.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',31.53,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',30.07,'EPSG','9110','EPSG','8826','Easting at false origin',700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14234','SPCS83 Texas South Central zone (meters)',NULL,NULL,'EPSG','2527','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',27.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-99.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',30.17,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',28.23,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14235','SPCS83 Texas South zone (meters)',NULL,NULL,'EPSG','2528','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',25.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',27.5,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',26.1,'EPSG','9110','EPSG','8826','Easting at false origin',300000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14251','Texas State Mapping System (meters)',NULL,NULL,'EPSG','1412','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.1,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',27.25,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',34.55,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14252','Shackleford',NULL,NULL,'EPSG','1412','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.1,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',27.25,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',34.55,'EPSG','9110','EPSG','8826','Easting at false origin',3000000.0,'EPSG','9002','EPSG','8827','Northing at false origin',3000000.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14253','Texas Centric Lambert Conformal',NULL,NULL,'EPSG','1412','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',18.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',27.3,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',35.0,'EPSG','9110','EPSG','8826','Easting at false origin',1500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14254','Texas Centric Albers Equal Area',NULL,NULL,'EPSG','1412','EPSG','9822','Albers Equal Area','EPSG','8821','Latitude of false origin',18.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',27.3,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',35.0,'EPSG','9110','EPSG','8826','Easting at false origin',1500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',6000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14301','Utah CS27 North zone',NULL,NULL,'EPSG','2258','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-111.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',40.43,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',41.47,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14302','Utah CS27 Central zone',NULL,NULL,'EPSG','2257','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-111.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.01,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.39,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14303','Utah CS27 South zone',NULL,NULL,'EPSG','2259','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-111.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',37.13,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.21,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14331','SPCS83 Utah North zone (meters)',NULL,NULL,'EPSG','2258','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-111.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.47,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.43,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14332','SPCS83 Utah Central zone (meters)',NULL,NULL,'EPSG','2257','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-111.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',40.39,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',39.01,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14333','SPCS83 Utah South zone (meters)',NULL,NULL,'EPSG','2259','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-111.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',38.21,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.13,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14400','Vermont CS27',NULL,NULL,'EPSG','1414','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-72.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999964286,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14430','SPCS83 Vermont zone (meters)',NULL,NULL,'EPSG','1414','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-72.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999964286,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14501','Virginia CS27 North zone',NULL,NULL,'EPSG','2260','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-78.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',38.02,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',39.12,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14502','Virginia CS27 South zone',NULL,NULL,'EPSG','2261','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-78.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',36.46,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.58,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14531','SPCS83 Virginia North zone (meters)',NULL,NULL,'EPSG','2260','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-78.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.12,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.02,'EPSG','9110','EPSG','8826','Easting at false origin',3500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14532','SPCS83 Virginia South zone (meters)',NULL,NULL,'EPSG','2261','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-78.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',37.58,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',36.46,'EPSG','9110','EPSG','8826','Easting at false origin',3500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14601','Washington CS27 North zone',NULL,NULL,'EPSG','2262','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',47.3,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',48.44,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14602','Washington CS27 South zone',NULL,NULL,'EPSG','2263','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-120.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',45.5,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',47.2,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14631','SPCS83 Washington North zone (meters)',NULL,NULL,'EPSG','2273','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',48.44,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',47.3,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14632','SPCS83 Washington South zone (meters)',NULL,NULL,'EPSG','2274','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-120.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',47.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',45.5,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14701','West Virginia CS27 North zone',NULL,NULL,'EPSG','2264','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-79.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.15,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14702','West Virginia CS27 South zone',NULL,NULL,'EPSG','2265','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',37.29,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.53,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14731','SPCS83 West Virginia North zone (meters)',NULL,NULL,'EPSG','2264','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-79.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',40.15,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',39.0,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14732','SPCS83 West Virginia South zone (meters)',NULL,NULL,'EPSG','2265','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',38.53,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.29,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14733','SPCS83 West Virginia North zone (US Survey feet)',NULL,NULL,'EPSG','2264','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-79.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',40.15,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',39.0,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','14734','SPCS83 West Virginia South zone (US Survey feet)',NULL,NULL,'EPSG','2265','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',38.53,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.29,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','14735','SPCS83 West Virginia North zone (US Survey feet)',NULL,NULL,'EPSG','2264','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-79.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',40.15,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',39.0,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14736','SPCS83 West Virginia South zone (US Survey feet)',NULL,NULL,'EPSG','2265','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',38.53,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.29,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14801','Wisconsin CS27 North zone',NULL,NULL,'EPSG','2267','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.1,'EPSG','9110','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',45.34,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',46.46,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14802','Wisconsin CS27 Central zone',NULL,NULL,'EPSG','2266','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',44.15,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',45.3,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14803','Wisconsin CS27 South zone',NULL,NULL,'EPSG','2268','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',42.44,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',44.04,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14811','Wisconsin Transverse Mercator 27',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',-4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14831','SPCS83 Wisconsin North zone (meters)',NULL,NULL,'EPSG','2267','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.1,'EPSG','9110','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',46.46,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',45.34,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14832','SPCS83 Wisconsin Central zone (meters)',NULL,NULL,'EPSG','2266','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',45.3,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',44.15,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14833','SPCS83 Wisconsin South zone (meters)',NULL,NULL,'EPSG','2268','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',44.04,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',42.44,'EPSG','9110','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14841','Wisconsin Transverse Mercator 83',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',520000.0,'EPSG','9001','EPSG','8807','False northing',-4480000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14901','Wyoming CS27 East zone',NULL,NULL,'EPSG','2269','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-105.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999941177,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14902','Wyoming CS27 East Central zone',NULL,NULL,'EPSG','2270','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-107.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999941177,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14903','Wyoming CS27 West Central zone',NULL,NULL,'EPSG','2272','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-108.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999941177,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14904','Wyoming CS27 West zone',NULL,NULL,'EPSG','2271','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-110.05,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999941177,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14931','SPCS83 Wyoming East zone (meters)',NULL,NULL,'EPSG','2269','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-105.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14932','SPCS83 Wyoming East Central zone (meters)',NULL,NULL,'EPSG','2270','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-107.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14933','SPCS83 Wyoming West Central zone (meters)',NULL,NULL,'EPSG','2272','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-108.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14934','SPCS83 Wyoming West zone (meters)',NULL,NULL,'EPSG','2271','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-110.05,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',800000.0,'EPSG','9001','EPSG','8807','False northing',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14935','SPCS83 Wyoming East zone (US Survey feet)',NULL,NULL,'EPSG','2269','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-105.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',656166.6667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14936','SPCS83 Wyoming East Central zone (US Survey feet)',NULL,NULL,'EPSG','2270','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-107.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',1312333.3333,'EPSG','9003','EPSG','8807','False northing',328083.3333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14937','SPCS83 Wyoming West Central zone (US Survey feet)',NULL,NULL,'EPSG','2272','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-108.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',1968500.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','14938','SPCS83 Wyoming West zone (US Survey feet)',NULL,NULL,'EPSG','2271','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-110.05,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',2624666.6667,'EPSG','9003','EPSG','8807','False northing',328083.3333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15001','Alaska CS27 zone 1',NULL,NULL,'EPSG','2156','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',57.0,'EPSG','9110','EPSG','8812','Longitude of projection centre',-133.4,'EPSG','9110','EPSG','8813','Azimuth of initial line',323.07483685,'EPSG','9110','EPSG','8814','Angle from Rectified to Skew Grid',323.07483685,'EPSG','9110','EPSG','8815','Scale factor on initial line',0.9999,'EPSG','9201','EPSG','8806','False easting',16404166.67,'EPSG','9003','EPSG','8807','False northing',-16404166.67,'EPSG','9003',0);
INSERT INTO "conversion" VALUES('EPSG','15002','Alaska CS27 zone 2',NULL,NULL,'EPSG','2158','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-142.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15003','Alaska CS27 zone 3',NULL,NULL,'EPSG','2159','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-146.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15004','Alaska CS27 zone 4',NULL,NULL,'EPSG','2160','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-150.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15005','Alaska CS27 zone 5',NULL,NULL,'EPSG','2161','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-154.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15006','Alaska CS27 zone 6',NULL,NULL,'EPSG','2162','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-158.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15007','Alaska CS27 zone 7',NULL,NULL,'EPSG','2163','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-162.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15008','Alaska CS27 zone 8',NULL,NULL,'EPSG','2164','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-166.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15009','Alaska CS27 zone 9',NULL,NULL,'EPSG','2165','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-170.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15010','Alaska CS27 zone 10',NULL,NULL,'EPSG','2157','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',51.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-176.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',53.5,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',51.5,'EPSG','9110','EPSG','8826','Easting at false origin',3000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15020','Alaska Albers',NULL,NULL,'EPSG','1330','EPSG','9822','Albers Equal Area','EPSG','8821','Latitude of false origin',50.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-154.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',55.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',65.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15021','Alaska Albers (meters)',NULL,NULL,'EPSG','1330','EPSG','9822','Albers Equal Area','EPSG','8821','Latitude of false origin',50.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-154.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',55.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',65.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15031','SPCS83 Alaska zone 1 (meters)',NULL,NULL,'EPSG','2156','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',57.0,'EPSG','9110','EPSG','8812','Longitude of projection centre',-133.4,'EPSG','9110','EPSG','8813','Azimuth of initial line',323.07483685,'EPSG','9110','EPSG','8814','Angle from Rectified to Skew Grid',323.07483685,'EPSG','9110','EPSG','8815','Scale factor on initial line',0.9999,'EPSG','9201','EPSG','8806','False easting',5000000.0,'EPSG','9001','EPSG','8807','False northing',-5000000.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','15032','SPCS83 Alaska zone 2 (meters)',NULL,NULL,'EPSG','2158','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-142.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15033','SPCS83 Alaska zone 3 (meters)',NULL,NULL,'EPSG','2159','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-146.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15034','SPCS83 Alaska zone 4 (meters)',NULL,NULL,'EPSG','2160','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-150.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15035','SPCS83 Alaska zone 5 (meters)',NULL,NULL,'EPSG','2161','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-154.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15036','SPCS83 Alaska zone 6 (meters)',NULL,NULL,'EPSG','2162','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-158.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15037','SPCS83 Alaska zone 7 (meters)',NULL,NULL,'EPSG','2163','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-162.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15038','SPCS83 Alaska zone 8 (meters)',NULL,NULL,'EPSG','2164','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-166.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15039','SPCS83 Alaska zone 9 (meters)',NULL,NULL,'EPSG','2165','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-170.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15040','SPCS83 Alaska zone 10 (meters)',NULL,NULL,'EPSG','2157','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',51.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-176.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',53.5,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',51.5,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15101','Hawaii CS27 zone 1',NULL,NULL,'EPSG','1546','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',18.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-155.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15102','Hawaii CS27 zone 2',NULL,NULL,'EPSG','1547','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',20.2,'EPSG','9110','EPSG','8802','Longitude of natural origin',-156.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15103','Hawaii CS27 zone 3',NULL,NULL,'EPSG','1548','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',21.1,'EPSG','9110','EPSG','8802','Longitude of natural origin',-158.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15104','Hawaii CS27 zone 4',NULL,NULL,'EPSG','1549','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',21.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-159.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15105','Hawaii CS27 zone 5',NULL,NULL,'EPSG','1550','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',21.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-160.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15131','SPCS83 Hawaii zone 1 (meters)',NULL,NULL,'EPSG','1546','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',18.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-155.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15132','SPCS83 Hawaii zone 2 (meters)',NULL,NULL,'EPSG','1547','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',20.2,'EPSG','9110','EPSG','8802','Longitude of natural origin',-156.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15133','SPCS83 Hawaii zone 3 (meters)',NULL,NULL,'EPSG','1548','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',21.1,'EPSG','9110','EPSG','8802','Longitude of natural origin',-158.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15134','SPCS83 Hawaii zone 4 (meters)',NULL,NULL,'EPSG','1549','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',21.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-159.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15135','SPCS83 Hawaii zone 5 (meters)',NULL,NULL,'EPSG','1550','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',21.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-160.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15138','SPCS83 Hawaii zone 3 (US Survey feet)',NULL,NULL,'EPSG','1548','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',21.1,'EPSG','9110','EPSG','8802','Longitude of natural origin',-158.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99999,'EPSG','9201','EPSG','8806','False easting',1640416.6667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15201','Puerto Rico CS27',NULL,NULL,'EPSG','3294','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',17.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-66.26,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',18.26,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',18.02,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15202','St. Croix CS27',NULL,NULL,'EPSG','3330','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',17.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-66.26,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',18.26,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',18.02,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15230','SPCS83 Puerto Rico & Virgin Islands zone (meters)',NULL,NULL,'EPSG','3634','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',17.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-66.26,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',18.26,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',18.02,'EPSG','9110','EPSG','8826','Easting at false origin',200000.0,'EPSG','9001','EPSG','8827','Northing at false origin',200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15297','SPCS83 Utah North zone (US Survey feet)',NULL,NULL,'EPSG','2258','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-111.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.47,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.43,'EPSG','9110','EPSG','8826','Easting at false origin',1640416.6667,'EPSG','9003','EPSG','8827','Northing at false origin',3280833.3333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15298','SPCS83 Utah Central zone (US Survey feet)',NULL,NULL,'EPSG','2257','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-111.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',40.39,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',39.01,'EPSG','9110','EPSG','8826','Easting at false origin',1640416.6667,'EPSG','9003','EPSG','8827','Northing at false origin',6561666.6667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15299','SPCS83 Utah South zone (US Survey feet)',NULL,NULL,'EPSG','2259','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-111.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',38.21,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.13,'EPSG','9110','EPSG','8826','Easting at false origin',1640416.6667,'EPSG','9003','EPSG','8827','Northing at false origin',9842500.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15300','American Samoa Lambert',NULL,NULL,'EPSG','1027','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',-14.16,'EPSG','9110','EPSG','8802','Longitude of natural origin',170.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15301','American Samoa Lambert',NULL,NULL,'EPSG','1027','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',-14.16,'EPSG','9110','EPSG','8802','Longitude of natural origin',-170.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15302','Tennessee CS27',NULL,NULL,'EPSG','1411','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-86.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',35.15,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',36.25,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15303','SPCS83 Kentucky North zone (meters)',NULL,NULL,'EPSG','2202','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-84.15,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',37.58,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.58,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15304','SPCS83 Arizona East zone (International feet)',NULL,NULL,'EPSG','2167','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-110.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15305','SPCS83 Arizona Central zone (International feet)',NULL,NULL,'EPSG','2166','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-111.55,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15306','SPCS83 Arizona West zone (International feet)',NULL,NULL,'EPSG','2168','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-113.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999933333,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15307','SPCS83 California zone 1 (US Survey feet)',NULL,NULL,'EPSG','2175','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-122.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.0,'EPSG','9110','EPSG','8826','Easting at false origin',6561666.667,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15308','SPCS83 California zone 2 (US Survey feet)',NULL,NULL,'EPSG','2176','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-122.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.5,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.2,'EPSG','9110','EPSG','8826','Easting at false origin',6561666.667,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15309','SPCS83 California zone 3 (US Survey feet)',NULL,NULL,'EPSG','2177','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-120.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',38.26,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.04,'EPSG','9110','EPSG','8826','Easting at false origin',6561666.667,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15310','SPCS83 California zone 4 (US Survey feet)',NULL,NULL,'EPSG','2178','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',35.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-119.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',37.15,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',36.0,'EPSG','9110','EPSG','8826','Easting at false origin',6561666.667,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15311','SPCS83 California zone 5 (US Survey feet)',NULL,NULL,'EPSG','2182','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-118.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',35.28,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',34.02,'EPSG','9110','EPSG','8826','Easting at false origin',6561666.667,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15312','SPCS83 California zone 6 (US Survey feet)',NULL,NULL,'EPSG','2180','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',32.1,'EPSG','9110','EPSG','8822','Longitude of false origin',-116.15,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',33.53,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',32.47,'EPSG','9110','EPSG','8826','Easting at false origin',6561666.667,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15313','SPCS83 Colorado North zone (US Survey feet)',NULL,NULL,'EPSG','2184','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-105.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',40.47,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',39.43,'EPSG','9110','EPSG','8826','Easting at false origin',3000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15314','SPCS83 Colorado Central zone (US Survey feet)',NULL,NULL,'EPSG','2183','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-105.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.45,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.27,'EPSG','9110','EPSG','8826','Easting at false origin',3000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15315','SPCS83 Colorado South zone (US Survey feet)',NULL,NULL,'EPSG','2185','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-105.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',38.26,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.14,'EPSG','9110','EPSG','8826','Easting at false origin',3000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15316','SPCS83 Connecticut zone (US Survey feet)',NULL,NULL,'EPSG','1377','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-72.45,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.52,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',41.12,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',500000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15317','SPCS83 Delaware zone (US Survey feet)',NULL,NULL,'EPSG','1378','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-75.25,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999995,'EPSG','9201','EPSG','8806','False easting',656166.667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15318','SPCS83 Florida East zone (US Survey feet)',NULL,NULL,'EPSG','2186','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',24.2,'EPSG','9110','EPSG','8802','Longitude of natural origin',-81.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999941177,'EPSG','9201','EPSG','8806','False easting',656166.667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15319','SPCS83 Florida West zone (US Survey feet)',NULL,NULL,'EPSG','2188','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',24.2,'EPSG','9110','EPSG','8802','Longitude of natural origin',-82.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999941177,'EPSG','9201','EPSG','8806','False easting',656166.667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15320','SPCS83 Florida North zone (US Survey feet)',NULL,NULL,'EPSG','2187','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',29.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-84.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',30.45,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',29.35,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15321','SPCS83 Georgia East zone (US Survey feet)',NULL,NULL,'EPSG','2189','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-82.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',656166.667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15322','SPCS83 Georgia West zone (US Survey feet)',NULL,NULL,'EPSG','2190','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-84.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',2296583.333,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15323','SPCS83 Idaho East zone (US Survey feet)',NULL,NULL,'EPSG','2192','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-112.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999947368,'EPSG','9201','EPSG','8806','False easting',656166.667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15324','SPCS83 Idaho Central zone (US Survey feet)',NULL,NULL,'EPSG','2191','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-114.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999947368,'EPSG','9201','EPSG','8806','False easting',1640416.667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15325','SPCS83 Idaho West zone (US Survey feet)',NULL,NULL,'EPSG','2193','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-115.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999933333,'EPSG','9201','EPSG','8806','False easting',2624666.667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15326','SPCS83 Indiana East zone (US Survey feet)',NULL,NULL,'EPSG','2196','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',328083.333,'EPSG','9003','EPSG','8807','False northing',818125.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15327','SPCS83 Indiana West zone (US Survey feet)',NULL,NULL,'EPSG','2197','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.05,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',2952750.0,'EPSG','9003','EPSG','8807','False northing',818125.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15328','SPCS83 Kentucky North zone (US Survey feet)',NULL,NULL,'EPSG','2202','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-84.15,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',37.58,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.58,'EPSG','9110','EPSG','8826','Easting at false origin',1640416.667,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15329','SPCS83 Kentucky South zone (US Survey feet)',NULL,NULL,'EPSG','2203','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-85.45,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',37.56,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',36.44,'EPSG','9110','EPSG','8826','Easting at false origin',1640416.667,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15330','SPCS83 Maryland zone (US Survey feet)',NULL,NULL,'EPSG','1389','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-77.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.27,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.18,'EPSG','9110','EPSG','8826','Easting at false origin',1312333.333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15331','SPCS83 Massachusetts Mainland zone (US Survey feet)',NULL,NULL,'EPSG','2209','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-71.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',42.41,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',41.43,'EPSG','9110','EPSG','8826','Easting at false origin',656166.667,'EPSG','9003','EPSG','8827','Northing at false origin',2460625.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15332','SPCS83 Massachusetts Island zone (US Survey feet)',NULL,NULL,'EPSG','2208','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-70.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.29,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',41.17,'EPSG','9110','EPSG','8826','Easting at false origin',1640416.667,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15333','SPCS83 Michigan North zone (International feet)',NULL,NULL,'EPSG','1723','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.47,'EPSG','9110','EPSG','8822','Longitude of false origin',-87.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',47.05,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',45.29,'EPSG','9110','EPSG','8826','Easting at false origin',26246719.16,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15334','SPCS83 Michigan Central zone (International feet)',NULL,NULL,'EPSG','1724','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.19,'EPSG','9110','EPSG','8822','Longitude of false origin',-84.22,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',45.42,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',44.11,'EPSG','9110','EPSG','8826','Easting at false origin',19685039.37,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15335','SPCS83 Michigan South zone (International feet)',NULL,NULL,'EPSG','1725','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-84.22,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',43.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',42.06,'EPSG','9110','EPSG','8826','Easting at false origin',13123359.58,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15336','SPCS83 Mississippi East zone (US Survey feet)',NULL,NULL,'EPSG','2216','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',29.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.5,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',984250.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15337','SPCS83 Mississippi West zone (US Survey feet)',NULL,NULL,'EPSG','2217','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',29.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',2296583.333,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15338','SPCS83 Montana zone (International feet)',NULL,NULL,'EPSG','1395','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.15,'EPSG','9110','EPSG','8822','Longitude of false origin',-109.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',49.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',45.0,'EPSG','9110','EPSG','8826','Easting at false origin',1968503.937,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15339','SPCS83 New Mexico East zone (US Survey feet)',NULL,NULL,'EPSG','2228','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-104.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999909091,'EPSG','9201','EPSG','8806','False easting',541337.5,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15340','SPCS83 New Mexico Central zone (US Survey feet)',NULL,NULL,'EPSG','2231','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-106.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',1640416.667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15341','SPCS83 New Mexico West zone (US Survey feet)',NULL,NULL,'EPSG','2232','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-107.5,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999916667,'EPSG','9201','EPSG','8806','False easting',2723091.667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15342','SPCS83 New York East zone (US Survey feet)',NULL,NULL,'EPSG','2234','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-74.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',492125.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15343','SPCS83 New York Central zone (US Survey feet)',NULL,NULL,'EPSG','2233','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-76.35,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',820208.333,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15344','SPCS83 New York West zone (US Survey feet)',NULL,NULL,'EPSG','2236','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-78.35,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',1148291.667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15345','SPCS83 New York Long Island zone (US Survey feet)',NULL,NULL,'EPSG','2235','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.1,'EPSG','9110','EPSG','8822','Longitude of false origin',-74.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.02,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.4,'EPSG','9110','EPSG','8826','Easting at false origin',984250.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15346','SPCS83 North Carolina zone (US Survey feet)',NULL,NULL,'EPSG','1402','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.45,'EPSG','9110','EPSG','8822','Longitude of false origin',-79.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',36.1,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',34.2,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15347','SPCS83 North Dakota North zone (International feet)',NULL,NULL,'EPSG','2237','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',48.44,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',47.26,'EPSG','9110','EPSG','8826','Easting at false origin',1968503.937,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15348','SPCS83 North Dakota South zone (International feet)',NULL,NULL,'EPSG','2238','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',47.29,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',46.11,'EPSG','9110','EPSG','8826','Easting at false origin',1968503.937,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15349','SPCS83 Oklahoma North zone (US Survey feet)',NULL,NULL,'EPSG','2241','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',35.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',36.46,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',35.34,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15350','SPCS83 Oklahoma South zone (US Survey feet)',NULL,NULL,'EPSG','2242','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',35.14,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',33.56,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15351','SPCS83 Oregon North zone (International feet)',NULL,NULL,'EPSG','2243','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-120.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',46.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',44.2,'EPSG','9110','EPSG','8826','Easting at false origin',8202099.738,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15352','SPCS83 Oregon South zone (International feet)',NULL,NULL,'EPSG','2244','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-120.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',44.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',42.2,'EPSG','9110','EPSG','8826','Easting at false origin',4921259.843,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15353','SPCS83 Pennsylvania North zone (US Survey feet)',NULL,NULL,'EPSG','2245','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.1,'EPSG','9110','EPSG','8822','Longitude of false origin',-77.45,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.57,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.53,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15354','SPCS83 Pennsylvania South zone (US Survey feet)',NULL,NULL,'EPSG','2246','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-77.45,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',40.58,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',39.56,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15355','SPCS83 South Carolina zone (International feet)',NULL,NULL,'EPSG','1409','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',34.5,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',32.3,'EPSG','9110','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15356','SPCS83 Tennessee zone (US Survey feet)',NULL,NULL,'EPSG','1411','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-86.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',36.25,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',35.15,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15357','SPCS83 Texas North zone (US Survey feet)',NULL,NULL,'EPSG','2253','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-101.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',36.11,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',34.39,'EPSG','9110','EPSG','8826','Easting at false origin',656166.667,'EPSG','9003','EPSG','8827','Northing at false origin',3280833.333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15358','SPCS83 Texas North Central zone (US Survey feet)',NULL,NULL,'EPSG','2254','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',33.58,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',32.08,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',6561666.667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15359','SPCS83 Texas Central zone (US Survey feet)',NULL,NULL,'EPSG','2252','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',29.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',31.53,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',30.07,'EPSG','9110','EPSG','8826','Easting at false origin',2296583.333,'EPSG','9003','EPSG','8827','Northing at false origin',9842500.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15360','SPCS83 Texas South Central zone (US Survey feet)',NULL,NULL,'EPSG','2527','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',27.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-99.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',30.17,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',28.23,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',13123333.333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15361','SPCS83 Texas South zone (US Survey feet)',NULL,NULL,'EPSG','2528','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',25.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',27.5,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',26.1,'EPSG','9110','EPSG','8826','Easting at false origin',984250.0,'EPSG','9003','EPSG','8827','Northing at false origin',16404166.667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15362','SPCS83 Utah North zone (International feet)',NULL,NULL,'EPSG','2258','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-111.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.47,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.43,'EPSG','9110','EPSG','8826','Easting at false origin',1640419.948,'EPSG','9002','EPSG','8827','Northing at false origin',3280839.895,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15363','SPCS83 Utah Central zone (International feet)',NULL,NULL,'EPSG','2257','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-111.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',40.39,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',39.01,'EPSG','9110','EPSG','8826','Easting at false origin',1640419.948,'EPSG','9002','EPSG','8827','Northing at false origin',6561679.79,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15364','SPCS83 Utah South zone (International feet)',NULL,NULL,'EPSG','2259','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-111.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',38.21,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.13,'EPSG','9110','EPSG','8826','Easting at false origin',1640419.948,'EPSG','9002','EPSG','8827','Northing at false origin',9842519.685,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15365','SPCS83 Virginia North zone (US Survey feet)',NULL,NULL,'EPSG','2260','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-78.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.12,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.02,'EPSG','9110','EPSG','8826','Easting at false origin',11482916.667,'EPSG','9003','EPSG','8827','Northing at false origin',6561666.667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15366','SPCS83 Virginia South zone (US Survey feet)',NULL,NULL,'EPSG','2261','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-78.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',37.58,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',36.46,'EPSG','9110','EPSG','8826','Easting at false origin',11482916.667,'EPSG','9003','EPSG','8827','Northing at false origin',3280833.333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15367','SPCS83 Washington North zone (US Survey feet)',NULL,NULL,'EPSG','2273','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',48.44,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',47.3,'EPSG','9110','EPSG','8826','Easting at false origin',1640416.667,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15368','SPCS83 Washington South zone (US Survey feet)',NULL,NULL,'EPSG','2274','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-120.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',47.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',45.5,'EPSG','9110','EPSG','8826','Easting at false origin',1640416.667,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15369','SPCS83 Wisconsin North zone (US Survey feet)',NULL,NULL,'EPSG','2267','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.1,'EPSG','9110','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',46.46,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',45.34,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15370','SPCS83 Wisconsin Central zone (US Survey feet)',NULL,NULL,'EPSG','2266','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',45.3,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',44.15,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15371','SPCS83 Wisconsin South zone (US Survey feet)',NULL,NULL,'EPSG','2268','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',44.04,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',42.44,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15372','SPCS83 Indiana East zone (US Survey feet)',NULL,NULL,'EPSG','2196','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-85.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',328083.333,'EPSG','9003','EPSG','8807','False northing',820208.333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15373','SPCS83 Indiana West zone (US Survey feet)',NULL,NULL,'EPSG','2197','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-87.05,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',2952750.0,'EPSG','9003','EPSG','8807','False northing',820208.333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15374','Oregon GIC Lambert (International feet)',NULL,NULL,'EPSG','1406','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.45,'EPSG','9110','EPSG','8822','Longitude of false origin',-120.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',43.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',45.3,'EPSG','9110','EPSG','8826','Easting at false origin',1312335.958,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15375','SPCS83 Kentucky Single Zone (US Survey feet)',NULL,NULL,'EPSG','1386','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-85.45,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',37.05,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.4,'EPSG','9110','EPSG','8826','Easting at false origin',4921250.0,'EPSG','9003','EPSG','8827','Northing at false origin',3280833.333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15376','American Samoa Lambert',NULL,NULL,'EPSG','3109','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',-14.16,'EPSG','9110','EPSG','8802','Longitude of natural origin',-170.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',312234.65,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15377','SPCS83 Iowa North zone (US Survey feet)',NULL,NULL,'EPSG','2198','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-93.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',43.16,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',42.04,'EPSG','9110','EPSG','8826','Easting at false origin',4921250.0,'EPSG','9003','EPSG','8827','Northing at false origin',3280833.3333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15378','SPCS83 Iowa South zone (US Survey feet)',NULL,NULL,'EPSG','2199','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-93.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',41.47,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.37,'EPSG','9110','EPSG','8826','Easting at false origin',1640416.6667,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15379','SPCS83 Kansas North zone (US Survey feet)',NULL,NULL,'EPSG','2200','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',39.47,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',38.43,'EPSG','9110','EPSG','8826','Easting at false origin',1312333.3333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15380','SPCS83 Kansas South zone (US Survey feet)',NULL,NULL,'EPSG','2201','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-98.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',38.34,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',37.16,'EPSG','9110','EPSG','8826','Easting at false origin',1312333.3333,'EPSG','9003','EPSG','8827','Northing at false origin',1312333.3333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15381','SPCS83 Nevada East zone (US Survey feet)',NULL,NULL,'EPSG','2224','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-115.35,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',656166.6667,'EPSG','9003','EPSG','8807','False northing',26246666.6667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15382','SPCS83 Nevada Central zone (US Survey feet)',NULL,NULL,'EPSG','2223','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-116.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',1640416.6667,'EPSG','9003','EPSG','8807','False northing',19685000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15383','SPCS83 Nevada West zone (US Survey feet)',NULL,NULL,'EPSG','2225','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.45,'EPSG','9110','EPSG','8802','Longitude of natural origin',-118.35,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',2624666.6667,'EPSG','9003','EPSG','8807','False northing',13123333.3333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15384','SPCS83 New Jersey zone (US Survey feet)',NULL,NULL,'EPSG','1399','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',-74.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',492125.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15385','SPCS83 Arkansas North zone (US Survey feet)',NULL,NULL,'EPSG','2169','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-92.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',36.14,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',34.56,'EPSG','9110','EPSG','8826','Easting at false origin',1312333.3333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15386','SPCS83 Arkansas South zone (US Survey feet)',NULL,NULL,'EPSG','2170','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',32.4,'EPSG','9110','EPSG','8822','Longitude of false origin',-92.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',34.46,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',33.18,'EPSG','9110','EPSG','8826','Easting at false origin',1312333.3333,'EPSG','9003','EPSG','8827','Northing at false origin',1312333.3333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15387','SPCS83 Illinois East zone (US Survey feet)',NULL,NULL,'EPSG','2194','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-88.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999975,'EPSG','9201','EPSG','8806','False easting',984250.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15388','SPCS83 Illinois West zone (US Survey feet)',NULL,NULL,'EPSG','2195','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999941177,'EPSG','9201','EPSG','8806','False easting',2296583.3333,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15389','SPCS83 New Hampshire zone (US Survey feet)',NULL,NULL,'EPSG','1398','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-71.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999966667,'EPSG','9201','EPSG','8806','False easting',984250.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15390','SPCS83 Rhode Island zone (US Survey feet)',NULL,NULL,'EPSG','1408','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.05,'EPSG','9110','EPSG','8802','Longitude of natural origin',-71.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99999375,'EPSG','9201','EPSG','8806','False easting',328083.3333,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15391','SPCS83 Louisiana North zone (US Survey feet)',NULL,NULL,'EPSG','2204','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',30.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-92.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',32.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',31.1,'EPSG','9110','EPSG','8826','Easting at false origin',3280833.3333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15392','SPCS83 Louisiana South zone (US Survey feet)',NULL,NULL,'EPSG','2529','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',28.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-91.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',30.42,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',29.18,'EPSG','9110','EPSG','8826','Easting at false origin',3280833.3333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15393','SPCS83 Louisiana Offshore zone (US Survey feet)',NULL,NULL,'EPSG','1387','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',25.3,'EPSG','9110','EPSG','8822','Longitude of false origin',-91.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',27.5,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',26.1,'EPSG','9110','EPSG','8826','Easting at false origin',3280833.3333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15394','SPCS83 South Dakota North zone (US Survey feet)',NULL,NULL,'EPSG','2249','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',45.41,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',44.25,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15395','SPCS83 South Dakota South zone (US Survey feet)',NULL,NULL,'EPSG','2250','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.2,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',44.24,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',42.5,'EPSG','9110','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15396','SPCS83 Nebraska zone (US Survey feet)',NULL,NULL,'EPSG','1396','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.5,'EPSG','9110','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',43.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',40.0,'EPSG','9110','EPSG','8826','Easting at false origin',1640416.6667,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15397','Great Lakes Albers',NULL,NULL,'EPSG','3467','EPSG','9822','Albers Equal Area','EPSG','8821','Latitude of false origin',45.568977,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.455955,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.122774,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',49.01518,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15398','Great Lakes and St Lawrence Albers',NULL,NULL,'EPSG','3468','EPSG','9822','Albers Equal Area','EPSG','8821','Latitude of false origin',45.568977,'EPSG','9102','EPSG','8822','Longitude of false origin',-83.248627,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.122774,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',49.01518,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15399','Yap Islands',NULL,NULL,'EPSG','3108','EPSG','9832','Modified Azimuthal Equidistant','EPSG','8801','Latitude of natural origin',9.324815,'EPSG','9110','EPSG','8802','Longitude of natural origin',138.100748,'EPSG','9110','EPSG','8806','False easting',40000.0,'EPSG','9001','EPSG','8807','False northing',60000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15400','Guam SPCS',NULL,NULL,'EPSG','3255','EPSG','9831','Guam Projection','EPSG','8801','Latitude of natural origin',13.282087887,'EPSG','9110','EPSG','8802','Longitude of natural origin',144.445550254,'EPSG','9110','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',50000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15498','axis order change (2D)',NULL,NULL,'EPSG','1262','EPSG','9843','Axis Order Reversal (2D)',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15499','axis order change (geographic3D horizontal)',NULL,NULL,'EPSG','1262','EPSG','9844','Axis Order Reversal (Geographic3D horizontal)',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15500','Australian Antarctic geocentric to geog3D',NULL,NULL,'EPSG','1278','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15501','Australian Antarctic geog3D to geog2D',NULL,NULL,'EPSG','1278','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15502','CHTRF95 geocentric to geog3D',NULL,NULL,'EPSG','1286','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15503','CHTRF95 geog3D to geog2D',NULL,NULL,'EPSG','1286','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15504','EST97 geocentric to geog3D',NULL,NULL,'EPSG','1090','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15505','EST97 geog3D to geog2D',NULL,NULL,'EPSG','1090','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15506','ETRS89 geocentric to geog3D',NULL,NULL,'EPSG','1298','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15507','ETRS89 geog3D to geog2D',NULL,NULL,'EPSG','1298','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15508','GDA94 geocentric to geog3D',NULL,NULL,'EPSG','2575','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15509','GDA94 geog3D to geog2D',NULL,NULL,'EPSG','2575','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15510','Hartebeesthoek94 geocentric to geog3D',NULL,NULL,'EPSG','1215','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15511','Hartebeesthoek94 geog3D to geog2D',NULL,NULL,'EPSG','1215','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15512','IRENET95 geocentric to geog3D',NULL,NULL,'EPSG','1305','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15513','IRENET95 geog3D to geog2D',NULL,NULL,'EPSG','1305','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15514','ISN93 geocentric to geog3D',NULL,NULL,'EPSG','1120','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15515','ISN93 geog3D to geog2D',NULL,NULL,'EPSG','1120','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15516','JGD2000 geocentric to geog3D',NULL,NULL,'EPSG','1129','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15517','JGD2000 geog3D to geog2D',NULL,NULL,'EPSG','1129','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15518','LKS92 geocentric to geog3D',NULL,NULL,'EPSG','1139','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15519','LKS92 geog3D to geog2D',NULL,NULL,'EPSG','1139','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15520','LKS94 geocentric to geog3D',NULL,NULL,'EPSG','1145','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15521','LKS94 geocentric to geog3D',NULL,NULL,'EPSG','1145','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15522','Moznet geocentric to geog3D',NULL,NULL,'EPSG','1167','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15523','Moznet geog3D to geog2D',NULL,NULL,'EPSG','1167','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15524','NAD83(CSRS) geocentric to geog3D',NULL,NULL,'EPSG','1061','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15525','NAD83(CSRS) geog3D to geog2D',NULL,NULL,'EPSG','1061','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15526','NAD83(HARN) geocentric to geog3D',NULL,NULL,'EPSG','1337','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15527','NAD83(HARN) geog3D to geog2D',NULL,NULL,'EPSG','1337','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15528','NZGD2000 geocentric to geog3D',NULL,NULL,'EPSG','1175','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15529','NZGD2000 geog3D to geog2D',NULL,NULL,'EPSG','1175','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15530','POSGAR 98 geocentric to geog3D',NULL,NULL,'EPSG','1033','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15531','POSGAR 98 geog3D to geog2D',NULL,NULL,'EPSG','1033','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15532','REGVEN geocentric to geog3D',NULL,NULL,'EPSG','1251','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15533','REGVEN geog3D to geog2D',NULL,NULL,'EPSG','1251','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15534','RGF93 geocentric to geog3D',NULL,NULL,'EPSG','1096','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15535','RGF93 geog3D to geog2D',NULL,NULL,'EPSG','1096','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15536','RGFG95 geocentric to geog3D',NULL,NULL,'EPSG','1097','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15537','RGFG95 geog3D to geog2D',NULL,NULL,'EPSG','1097','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15538','RGNC91-93 geocentric to geog3D',NULL,NULL,'EPSG','1174','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15539','RGNC91-93 geog3D to geog2D',NULL,NULL,'EPSG','1174','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15540','RGR92 geocentric to geog3D',NULL,NULL,'EPSG','1196','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15541','RGR92 geog3D to geog2D',NULL,NULL,'EPSG','1196','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15542','RRAF 1991 geocentric to geog3D',NULL,NULL,'EPSG','2824','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15543','RRAF 1991 geog3D to geog2D',NULL,NULL,'EPSG','2824','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15544','SIRGAS geocentric to geog3D',NULL,NULL,'EPSG','3448','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15545','SIRGAS geog3D to geog2D',NULL,NULL,'EPSG','3448','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15546','SWEREF99 geocentric to geog3D',NULL,NULL,'EPSG','1225','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15547','SWEREF99 geog3D to geog2D',NULL,NULL,'EPSG','1225','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15548','WGS 84 geocentric to geog3D',NULL,NULL,'EPSG','1262','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15549','WGS 84 geog3D to geog2D',NULL,NULL,'EPSG','1262','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15550','Yemen NGN96 geocentric to geog3D',NULL,NULL,'EPSG','1257','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15551','Yemen NGN96 geog3D to geog2D',NULL,NULL,'EPSG','1257','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15552','IGM95 geocentric to geog3D',NULL,NULL,'EPSG','1127','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15553','IGM95 geog3D to geog2D',NULL,NULL,'EPSG','1127','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15554','WGS 72 geocentric to geog3D',NULL,NULL,'EPSG','1262','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15555','WGS 72 geog3D to geog2D',NULL,NULL,'EPSG','1262','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15556','WGS 72BE geocentric to geog3D',NULL,NULL,'EPSG','1262','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15557','WGS 72BE geog3D to geog2D',NULL,NULL,'EPSG','1262','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15558','SIRGAS 2000 geocentric to geog3D',NULL,NULL,'EPSG','3418','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15559','SIRGAS 2000 geog3D to geog2D',NULL,NULL,'EPSG','3418','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15560','Lao 1993 geocentric to geog3D',NULL,NULL,'EPSG','1138','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15561','Lao 1993 geog3D to geog2D',NULL,NULL,'EPSG','1138','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15562','Lao 1997 geocentric to geog3D',NULL,NULL,'EPSG','1138','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15563','Lao 1997 geog3D to geog2D',NULL,NULL,'EPSG','1138','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15564','PRS92 geocentric to geog3D',NULL,NULL,'EPSG','1190','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15565','PRS92 geog3D to geog2D',NULL,NULL,'EPSG','1190','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15566','MAGNA-SIRGAS geocentric to geog3D',NULL,NULL,'EPSG','1070','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15567','MAGNA-SIRGAS geog3D to geog2D',NULL,NULL,'EPSG','1070','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15568','RGPF geocentric to geog3D',NULL,NULL,'EPSG','1098','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15569','RGPF geog3D to geog2D',NULL,NULL,'EPSG','1098','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15570','POSGAR 94 geocentric to geog3D',NULL,NULL,'EPSG','1033','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15571','POSGAR 94 geog3D to geog2D',NULL,NULL,'EPSG','1033','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15572','Korean 2000 geocentric to geog3D',NULL,NULL,'EPSG','1135','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15573','Korean 2000 geog3D to geog2D',NULL,NULL,'EPSG','1135','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15574','Mauritania 1999 geocentric to geog3D',NULL,NULL,'EPSG','1157','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15575','Mauritania 1999 geog3D to geog2D',NULL,NULL,'EPSG','1157','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15576','PZ-90 geocentric to geog3D',NULL,NULL,'EPSG','1262','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15577','PZ-90 geog3D to geog2D',NULL,NULL,'EPSG','1262','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15578','GDM2000 geocentric to geog3D',NULL,NULL,'EPSG','1151','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15579','GDM2000 geog3D to geog2D',NULL,NULL,'EPSG','1151','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15580','GR96 geocentric to geog3D',NULL,NULL,'EPSG','1107','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15581','GR96 geog3D to geog2D',NULL,NULL,'EPSG','1107','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15582','LGD2006 geocentric to geog3D',NULL,NULL,'EPSG','1143','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15583','LGD2006 geog3D to geog2D',NULL,NULL,'EPSG','1143','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15584','DGN95 geocentric to geog3D',NULL,NULL,'EPSG','1122','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15585','DGN95 geog3D to geog2D',NULL,NULL,'EPSG','1122','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15586','JAD2001 geocentric to geog3D',NULL,NULL,'EPSG','1128','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15587','JAD2001 geog3D to geog2D',NULL,NULL,'EPSG','1128','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15588','NAD83(NSRS2007) geocentric to geog3D',NULL,NULL,'EPSG','1511','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15589','NAD83(NSRS2007) geog3D to geog2D',NULL,NULL,'EPSG','1511','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15590','WGS 66 geocentric to geog3D',NULL,NULL,'EPSG','1262','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15591','WGS 66 geog3D to geog2D',NULL,NULL,'EPSG','1262','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','15592','geocentric to geographic3D',NULL,NULL,'EPSG','1262','EPSG','9602','Geographic/geocentric conversions',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15593','geographic3D to geographic2D',NULL,NULL,'EPSG','1262','EPSG','9659','Geographic3D to 2D conversion',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15594','EPSG topocentric example A',NULL,NULL,'EPSG','1263','EPSG','9837','Geographic/topocentric conversions','EPSG','8834','Latitude of topocentric origin',55.0,'EPSG','9102','EPSG','8835','Longitude of topocentric origin',5.0,'EPSG','9102','EPSG','8836','Ellipsoidal height of topocentric origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15595','EPSG topocentric example B',NULL,NULL,'EPSG','1263','EPSG','9836','Geocentric/topocentric conversions','EPSG','8837','Geocentric X of topocentric origin',3771793.97,'EPSG','9001','EPSG','8838','Geocentric Y of topocentric origin',140253.34,'EPSG','9001','EPSG','8839','Geocentric Z of topocentric origin',5124304.35,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15914','BLM zone 14N (US survey feet)',NULL,NULL,'EPSG','3637','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-99.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15915','BLM zone 15N (US survey feet)',NULL,NULL,'EPSG','3640','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-93.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15916','BLM zone 16N (US survey feet)',NULL,NULL,'EPSG','3641','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','15917','BLM zone 17N (US survey feet)',NULL,NULL,'EPSG','3642','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-81.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1640416.67,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16000','UTM grid system (northern hemisphere)',NULL,NULL,'EPSG','1998','EPSG','9824','Transverse Mercator Zoned Grid System','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8830','Initial longitude',-180.0,'EPSG','9102','EPSG','8831','Zone width',6.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16001','UTM zone 1N',NULL,NULL,'EPSG','1873','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16002','UTM zone 2N',NULL,NULL,'EPSG','1875','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-171.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16003','UTM zone 3N',NULL,NULL,'EPSG','1877','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16004','UTM zone 4N',NULL,NULL,'EPSG','1879','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-159.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16005','UTM zone 5N',NULL,NULL,'EPSG','1881','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16006','UTM zone 6N',NULL,NULL,'EPSG','1883','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16007','UTM zone 7N',NULL,NULL,'EPSG','1885','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16008','UTM zone 8N',NULL,NULL,'EPSG','1887','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-135.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16009','UTM zone 9N',NULL,NULL,'EPSG','1889','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-129.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16010','UTM zone 10N',NULL,NULL,'EPSG','1891','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-123.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16011','UTM zone 11N',NULL,NULL,'EPSG','1893','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-117.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16012','UTM zone 12N',NULL,NULL,'EPSG','1895','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-111.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16013','UTM zone 13N',NULL,NULL,'EPSG','1897','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-105.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16014','UTM zone 14N',NULL,NULL,'EPSG','1899','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-99.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16015','UTM zone 15N',NULL,NULL,'EPSG','1901','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-93.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16016','UTM zone 16N',NULL,NULL,'EPSG','1903','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16017','UTM zone 17N',NULL,NULL,'EPSG','1905','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-81.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16018','UTM zone 18N',NULL,NULL,'EPSG','1907','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-75.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16019','UTM zone 19N',NULL,NULL,'EPSG','1909','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-69.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16020','UTM zone 20N',NULL,NULL,'EPSG','1911','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-63.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16021','UTM zone 21N',NULL,NULL,'EPSG','1913','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-57.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16022','UTM zone 22N',NULL,NULL,'EPSG','1915','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-51.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16023','UTM zone 23N',NULL,NULL,'EPSG','1917','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16024','UTM zone 24N',NULL,NULL,'EPSG','1919','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-39.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16025','UTM zone 25N',NULL,NULL,'EPSG','1921','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16026','UTM zone 26N',NULL,NULL,'EPSG','1923','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16027','UTM zone 27N',NULL,NULL,'EPSG','1925','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16028','UTM zone 28N',NULL,NULL,'EPSG','1927','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16029','UTM zone 29N',NULL,NULL,'EPSG','1929','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16030','UTM zone 30N',NULL,NULL,'EPSG','1931','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16031','UTM zone 31N',NULL,NULL,'EPSG','1933','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16032','UTM zone 32N',NULL,NULL,'EPSG','1935','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16033','UTM zone 33N',NULL,NULL,'EPSG','1937','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16034','UTM zone 34N',NULL,NULL,'EPSG','1939','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16035','UTM zone 35N',NULL,NULL,'EPSG','1941','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16036','UTM zone 36N',NULL,NULL,'EPSG','1943','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16037','UTM zone 37N',NULL,NULL,'EPSG','1945','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',39.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16038','UTM zone 38N',NULL,NULL,'EPSG','1947','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16039','UTM zone 39N',NULL,NULL,'EPSG','1949','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',51.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16040','UTM zone 40N',NULL,NULL,'EPSG','1951','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',57.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16041','UTM zone 41N',NULL,NULL,'EPSG','1953','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',63.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16042','UTM zone 42N',NULL,NULL,'EPSG','1955','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',69.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16043','UTM zone 43N',NULL,NULL,'EPSG','1957','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',75.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16044','UTM zone 44N',NULL,NULL,'EPSG','1959','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',81.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16045','UTM zone 45N',NULL,NULL,'EPSG','1961','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',87.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16046','UTM zone 46N',NULL,NULL,'EPSG','1963','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',93.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16047','UTM zone 47N',NULL,NULL,'EPSG','1965','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',99.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16048','UTM zone 48N',NULL,NULL,'EPSG','1967','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',105.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16049','UTM zone 49N',NULL,NULL,'EPSG','1969','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',111.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16050','UTM zone 50N',NULL,NULL,'EPSG','1971','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',117.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16051','UTM zone 51N',NULL,NULL,'EPSG','1973','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',123.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16052','UTM zone 52N',NULL,NULL,'EPSG','1975','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',129.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16053','UTM zone 53N',NULL,NULL,'EPSG','1977','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',135.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16054','UTM zone 54N',NULL,NULL,'EPSG','1979','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16055','UTM zone 55N',NULL,NULL,'EPSG','1981','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16056','UTM zone 56N',NULL,NULL,'EPSG','1983','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16057','UTM zone 57N',NULL,NULL,'EPSG','1985','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',159.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16058','UTM zone 58N',NULL,NULL,'EPSG','1987','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16059','UTM zone 59N',NULL,NULL,'EPSG','1989','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',171.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16060','UTM zone 60N',NULL,NULL,'EPSG','1991','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16061','Universal Polar Stereographic North',NULL,NULL,'EPSG','1996','EPSG','9810','Polar Stereographic (variant A)','EPSG','8801','Latitude of natural origin',90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.994,'EPSG','9201','EPSG','8806','False easting',2000000.0,'EPSG','9001','EPSG','8807','False northing',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16065','TM35FIN',NULL,NULL,'EPSG','1095','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16070','3-degree Gauss-Kruger zone 40',NULL,NULL,'EPSG','2628','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',120.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',40500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16071','3-degree Gauss-Kruger zone 41',NULL,NULL,'EPSG','2629','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',123.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',41500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16072','3-degree Gauss-Kruger zone 42',NULL,NULL,'EPSG','2630','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',126.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',42500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16073','3-degree Gauss-Kruger zone 43',NULL,NULL,'EPSG','2631','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',129.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',43500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16074','3-degree Gauss-Kruger zone 44',NULL,NULL,'EPSG','2632','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',132.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',44500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16075','3-degree Gauss-Kruger zone 45',NULL,NULL,'EPSG','2633','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',135.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',45500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16076','3-degree Gauss-Kruger zone 46',NULL,NULL,'EPSG','2634','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',138.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',46500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16077','3-degree Gauss-Kruger zone 47',NULL,NULL,'EPSG','2635','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',47500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16078','3-degree Gauss-Kruger zone 48',NULL,NULL,'EPSG','2636','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',144.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',48500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16079','3-degree Gauss-Kruger zone 49',NULL,NULL,'EPSG','2637','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',49500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16080','3-degree Gauss-Kruger zone 50',NULL,NULL,'EPSG','2638','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',150.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',50500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16081','3-degree Gauss-Kruger zone 51',NULL,NULL,'EPSG','2639','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',51500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16082','3-degree Gauss-Kruger zone 52',NULL,NULL,'EPSG','2640','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',156.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',52500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16083','3-degree Gauss-Kruger zone 53',NULL,NULL,'EPSG','2641','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',159.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',53500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16084','3-degree Gauss-Kruger zone 54',NULL,NULL,'EPSG','2642','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',162.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',54500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16085','3-degree Gauss-Kruger zone 55',NULL,NULL,'EPSG','2643','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',55500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16086','3-degree Gauss-Kruger zone 56',NULL,NULL,'EPSG','2644','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',168.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',56500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16087','3-degree Gauss-Kruger zone 57',NULL,NULL,'EPSG','2645','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',171.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',57500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16088','3-degree Gauss-Kruger zone 58',NULL,NULL,'EPSG','2646','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',174.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',58500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16089','3-degree Gauss-Kruger zone 59',NULL,NULL,'EPSG','2647','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',59500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16090','3-degree Gauss-Kruger zone 60',NULL,NULL,'EPSG','2648','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',180.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',60000000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16091','3-degree Gauss-Kruger zone 61',NULL,NULL,'EPSG','2649','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',61500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16092','3-degree Gauss-Kruger zone 62',NULL,NULL,'EPSG','2650','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-174.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',62500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16093','3-degree Gauss-Kruger zone 63',NULL,NULL,'EPSG','2651','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-171.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',63500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16094','3-degree Gauss-Kruger zone 64',NULL,NULL,'EPSG','2652','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-168.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',64500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16099','3-degree Gauss-Kruger zone 60',NULL,NULL,'EPSG','2648','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',180.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',60500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16100','UTM grid system (southern hemisphere)',NULL,NULL,'EPSG','1999','EPSG','9824','Transverse Mercator Zoned Grid System','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8830','Initial longitude',-180.0,'EPSG','9102','EPSG','8831','Zone width',6.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16101','UTM zone 1S',NULL,NULL,'EPSG','1874','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16102','UTM zone 2S',NULL,NULL,'EPSG','1876','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-171.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16103','UTM zone 3S',NULL,NULL,'EPSG','1878','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16104','UTM zone 4S',NULL,NULL,'EPSG','1880','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-159.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16105','UTM zone 5S',NULL,NULL,'EPSG','1882','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16106','UTM zone 6S',NULL,NULL,'EPSG','1884','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16107','UTM zone 7S',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16108','UTM zone 8S',NULL,NULL,'EPSG','1888','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-135.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16109','UTM zone 9S',NULL,NULL,'EPSG','1890','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-129.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16110','UTM zone 10S',NULL,NULL,'EPSG','1892','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-123.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16111','UTM zone 11S',NULL,NULL,'EPSG','1894','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-117.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16112','UTM zone 12S',NULL,NULL,'EPSG','1896','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-111.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16113','UTM zone 13S',NULL,NULL,'EPSG','1898','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-105.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16114','UTM zone 14S',NULL,NULL,'EPSG','1900','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-99.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16115','UTM zone 15S',NULL,NULL,'EPSG','1902','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-93.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16116','UTM zone 16S',NULL,NULL,'EPSG','1904','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16117','UTM zone 17S',NULL,NULL,'EPSG','1906','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-81.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16118','UTM zone 18S',NULL,NULL,'EPSG','1908','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-75.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16119','UTM zone 19S',NULL,NULL,'EPSG','1910','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-69.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16120','UTM zone 20S',NULL,NULL,'EPSG','1912','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-63.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16121','UTM zone 21S',NULL,NULL,'EPSG','1914','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-57.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16122','UTM zone 22S',NULL,NULL,'EPSG','1916','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-51.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16123','UTM zone 23S',NULL,NULL,'EPSG','1918','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16124','UTM zone 24S',NULL,NULL,'EPSG','1920','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-39.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16125','UTM zone 25S',NULL,NULL,'EPSG','1922','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16126','UTM zone 26S',NULL,NULL,'EPSG','1924','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16127','UTM zone 27S',NULL,NULL,'EPSG','1926','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16128','UTM zone 28S',NULL,NULL,'EPSG','1928','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16129','UTM zone 29S',NULL,NULL,'EPSG','1930','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16130','UTM zone 30S',NULL,NULL,'EPSG','1932','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16131','UTM zone 31S',NULL,NULL,'EPSG','1934','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16132','UTM zone 32S',NULL,NULL,'EPSG','1936','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16133','UTM zone 33S',NULL,NULL,'EPSG','1938','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16134','UTM zone 34S',NULL,NULL,'EPSG','1940','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16135','UTM zone 35S',NULL,NULL,'EPSG','1942','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16136','UTM zone 36S',NULL,NULL,'EPSG','1944','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16137','UTM zone 37S',NULL,NULL,'EPSG','1946','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',39.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16138','UTM zone 38S',NULL,NULL,'EPSG','1948','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16139','UTM zone 39S',NULL,NULL,'EPSG','1950','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',51.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16140','UTM zone 40S',NULL,NULL,'EPSG','1952','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',57.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16141','UTM zone 41S',NULL,NULL,'EPSG','1954','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',63.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16142','UTM zone 42S',NULL,NULL,'EPSG','1956','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',69.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16143','UTM zone 43S',NULL,NULL,'EPSG','1958','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',75.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16144','UTM zone 44S',NULL,NULL,'EPSG','1960','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',81.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16145','UTM zone 45S',NULL,NULL,'EPSG','1962','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',87.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16146','UTM zone 46S',NULL,NULL,'EPSG','1964','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',93.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16147','UTM zone 47S',NULL,NULL,'EPSG','1966','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',99.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16148','UTM zone 48S',NULL,NULL,'EPSG','1968','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',105.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16149','UTM zone 49S',NULL,NULL,'EPSG','1970','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',111.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16150','UTM zone 50S',NULL,NULL,'EPSG','1972','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',117.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16151','UTM zone 51S',NULL,NULL,'EPSG','1974','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',123.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16152','UTM zone 52S',NULL,NULL,'EPSG','1976','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',129.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16153','UTM zone 53S',NULL,NULL,'EPSG','1978','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',135.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16154','UTM zone 54S',NULL,NULL,'EPSG','1980','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16155','UTM zone 55S',NULL,NULL,'EPSG','1982','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16156','UTM zone 56S',NULL,NULL,'EPSG','1984','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16157','UTM zone 57S',NULL,NULL,'EPSG','1986','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',159.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16158','UTM zone 58S',NULL,NULL,'EPSG','1988','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16159','UTM zone 59S',NULL,NULL,'EPSG','1990','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',171.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16160','UTM zone 60S',NULL,NULL,'EPSG','1992','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16161','Universal Polar Stereographic South',NULL,NULL,'EPSG','1997','EPSG','9810','Polar Stereographic (variant A)','EPSG','8801','Latitude of natural origin',-90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.994,'EPSG','9201','EPSG','8806','False easting',2000000.0,'EPSG','9001','EPSG','8807','False northing',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16170','3-degree Gauss-Kruger CM 120E',NULL,NULL,'EPSG','2628','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',120.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16171','3-degree Gauss-Kruger CM 123E',NULL,NULL,'EPSG','2629','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',123.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16172','3-degree Gauss-Kruger CM 126E',NULL,NULL,'EPSG','2630','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',126.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16173','3-degree Gauss-Kruger CM 129E',NULL,NULL,'EPSG','2631','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',129.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16174','3-degree Gauss-Kruger CM 132E',NULL,NULL,'EPSG','2632','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',132.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16175','3-degree Gauss-Kruger CM 135E',NULL,NULL,'EPSG','2633','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',135.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16176','3-degree Gauss-Kruger CM 138E',NULL,NULL,'EPSG','2634','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',138.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16177','3-degree Gauss-Kruger CM 141E',NULL,NULL,'EPSG','2635','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16178','3-degree Gauss-Kruger CM 144E',NULL,NULL,'EPSG','2636','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',144.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16179','3-degree Gauss-Kruger CM 147E',NULL,NULL,'EPSG','2637','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16180','3-degree Gauss-Kruger CM 150E',NULL,NULL,'EPSG','2638','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',150.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16181','3-degree Gauss-Kruger CM 153E',NULL,NULL,'EPSG','2639','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16182','3-degree Gauss-Kruger CM 156E',NULL,NULL,'EPSG','2640','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',156.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16183','3-degree Gauss-Kruger CM 159E',NULL,NULL,'EPSG','2641','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',159.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16184','3-degree Gauss-Kruger CM 162E',NULL,NULL,'EPSG','2642','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',162.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16185','3-degree Gauss-Kruger CM 165E',NULL,NULL,'EPSG','2643','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16186','3-degree Gauss-Kruger CM 168E',NULL,NULL,'EPSG','2644','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',168.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16187','3-degree Gauss-Kruger CM 171E',NULL,NULL,'EPSG','2645','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',171.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16188','3-degree Gauss-Kruger CM 174E',NULL,NULL,'EPSG','2646','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',174.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16189','3-degree Gauss-Kruger CM 177E',NULL,NULL,'EPSG','2647','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16190','3-degree Gauss-Kruger CM 180',NULL,NULL,'EPSG','2648','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',180.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16191','3-degree Gauss-Kruger CM 177W',NULL,NULL,'EPSG','2649','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16192','3-degree Gauss-Kruger CM 174W',NULL,NULL,'EPSG','2650','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-174.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16193','3-degree Gauss-Kruger CM 171W',NULL,NULL,'EPSG','2651','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-171.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16194','3-degree Gauss-Kruger CM 168W',NULL,NULL,'EPSG','2652','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-168.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16201','6-degree Gauss-Kruger zone 1',NULL,NULL,'EPSG','1933','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16202','6-degree Gauss-Kruger zone 2',NULL,NULL,'EPSG','2741','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',2500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16203','6-degree Gauss-Kruger zone 3',NULL,NULL,'EPSG','2742','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',3500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16204','6-degree Gauss-Kruger zone 4',NULL,NULL,'EPSG','2743','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',4500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16205','6-degree Gauss-Kruger zone 5',NULL,NULL,'EPSG','2744','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',5500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16206','6-degree Gauss-Kruger zone 6',NULL,NULL,'EPSG','2745','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',6500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16207','6-degree Gauss-Kruger zone 7',NULL,NULL,'EPSG','2746','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',39.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',7500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16208','6-degree Gauss-Kruger zone 8',NULL,NULL,'EPSG','1947','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',8500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16209','6-degree Gauss-Kruger zone 9',NULL,NULL,'EPSG','1949','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',51.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',9500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16210','6-degree Gauss-Kruger zone 10',NULL,NULL,'EPSG','1951','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',57.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',10500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16211','6-degree Gauss-Kruger zone 11',NULL,NULL,'EPSG','1953','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',63.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',11500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16212','6-degree Gauss-Kruger zone 12',NULL,NULL,'EPSG','1955','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',69.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',12500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16213','6-degree Gauss-Kruger zone 13',NULL,NULL,'EPSG','1957','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',75.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',13500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16214','6-degree Gauss-Kruger zone 14',NULL,NULL,'EPSG','1959','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',81.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',14500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16215','6-degree Gauss-Kruger zone 15',NULL,NULL,'EPSG','1961','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',87.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',15500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16216','6-degree Gauss-Kruger zone 16',NULL,NULL,'EPSG','1963','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',93.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',16500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16217','6-degree Gauss-Kruger zone 17',NULL,NULL,'EPSG','1965','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',99.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',17500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16218','6-degree Gauss-Kruger zone 18',NULL,NULL,'EPSG','1967','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',105.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',18500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16219','6-degree Gauss-Kruger zone 19',NULL,NULL,'EPSG','1969','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',111.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',19500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16220','6-degree Gauss-Kruger zone 20',NULL,NULL,'EPSG','1971','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',117.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',20500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16221','6-degree Gauss-Kruger zone 21',NULL,NULL,'EPSG','1973','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',123.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',21500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16222','6-degree Gauss-Kruger zone 22',NULL,NULL,'EPSG','1975','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',129.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',22500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16223','6-degree Gauss-Kruger zone 23',NULL,NULL,'EPSG','1977','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',135.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',23500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16224','6-degree Gauss-Kruger zone 24',NULL,NULL,'EPSG','1979','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',24500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16225','6-degree Gauss-Kruger zone 25',NULL,NULL,'EPSG','1981','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',25500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16226','6-degree Gauss-Kruger zone 26',NULL,NULL,'EPSG','1983','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',26500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16227','6-degree Gauss-Kruger zone 27',NULL,NULL,'EPSG','1985','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',159.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',27500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16228','6-degree Gauss-Kruger zone 28',NULL,NULL,'EPSG','1987','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',28500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16229','6-degree Gauss-Kruger zone 29',NULL,NULL,'EPSG','1989','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',171.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',29500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16230','6-degree Gauss-Kruger zone 30',NULL,NULL,'EPSG','1991','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',30500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16231','6-degree Gauss-Kruger zone 31',NULL,NULL,'EPSG','1873','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',31500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16232','6-degree Gauss-Kruger zone 32',NULL,NULL,'EPSG','1875','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-171.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',32500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16233','6-degree Gauss-Kruger zone 33',NULL,NULL,'EPSG','1877','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',33500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16234','6-degree Gauss-Kruger zone 34',NULL,NULL,'EPSG','1879','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-159.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',34500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16235','6-degree Gauss-Kruger zone 35',NULL,NULL,'EPSG','1881','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',35500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16236','6-degree Gauss-Kruger zone 36',NULL,NULL,'EPSG','1883','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',36500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16237','6-degree Gauss-Kruger zone 37',NULL,NULL,'EPSG','1885','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',37500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16238','6-degree Gauss-Kruger zone 38',NULL,NULL,'EPSG','1887','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-135.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',38500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16239','6-degree Gauss-Kruger zone 39',NULL,NULL,'EPSG','1889','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-129.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',39500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16240','6-degree Gauss-Kruger zone 40',NULL,NULL,'EPSG','1891','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-123.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',40500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16241','6-degree Gauss-Kruger zone 41',NULL,NULL,'EPSG','1893','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-117.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',41500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16242','6-degree Gauss-Kruger zone 42',NULL,NULL,'EPSG','1895','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-111.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',42500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16243','6-degree Gauss-Kruger zone 43',NULL,NULL,'EPSG','1897','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-105.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',43500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16244','6-degree Gauss-Kruger zone 44',NULL,NULL,'EPSG','1899','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-99.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',44500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16245','6-degree Gauss-Kruger zone 45',NULL,NULL,'EPSG','1901','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-93.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',45500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16246','6-degree Gauss-Kruger zone 46',NULL,NULL,'EPSG','1903','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',46500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16247','6-degree Gauss-Kruger zone 47',NULL,NULL,'EPSG','2732','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-81.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',47500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16248','6-degree Gauss-Kruger zone 48',NULL,NULL,'EPSG','2733','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-75.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',48500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16249','6-degree Gauss-Kruger zone 49',NULL,NULL,'EPSG','2734','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-69.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',49500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16250','6-degree Gauss-Kruger zone 50',NULL,NULL,'EPSG','2735','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-63.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',50500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16251','6-degree Gauss-Kruger zone 51',NULL,NULL,'EPSG','2736','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-57.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',51500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16252','6-degree Gauss-Kruger zone 52',NULL,NULL,'EPSG','2737','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-51.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',52500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16253','6-degree Gauss-Kruger zone 53',NULL,NULL,'EPSG','2738','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',53500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16254','6-degree Gauss-Kruger zone 54',NULL,NULL,'EPSG','2739','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-39.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',54500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16255','6-degree Gauss-Kruger zone 55',NULL,NULL,'EPSG','2740','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',55500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16256','6-degree Gauss-Kruger zone 56',NULL,NULL,'EPSG','1923','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',56500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16257','6-degree Gauss-Kruger zone 57',NULL,NULL,'EPSG','1925','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',57500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16258','6-degree Gauss-Kruger zone 58',NULL,NULL,'EPSG','1927','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',58500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16259','6-degree Gauss-Kruger zone 59',NULL,NULL,'EPSG','1929','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',59500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16260','6-degree Gauss-Kruger zone 60',NULL,NULL,'EPSG','1931','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',60500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16261','3-degree Gauss-Kruger zone 1',NULL,NULL,'EPSG','2299','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16262','3-degree Gauss-Kruger zone 2',NULL,NULL,'EPSG','2300','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',6.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',2500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16263','3-degree Gauss-Kruger zone 3',NULL,NULL,'EPSG','2301','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',3500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16264','3-degree Gauss-Kruger zone 4',NULL,NULL,'EPSG','2302','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',12.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',4500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16265','3-degree Gauss-Kruger zone 5',NULL,NULL,'EPSG','2303','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',5500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16266','3-degree Gauss-Kruger zone 6',NULL,NULL,'EPSG','2304','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',18.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',6500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16267','3-degree Gauss-Kruger zone 7',NULL,NULL,'EPSG','2305','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',7500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16268','3-degree Gauss-Kruger zone 8',NULL,NULL,'EPSG','2306','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',24.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',8500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16269','3-degree Gauss-Kruger zone 9',NULL,NULL,'EPSG','2534','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',9500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16270','3-degree Gauss-Kruger zone 10',NULL,NULL,'EPSG','2535','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',30.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',10500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16271','3-degree Gauss-Kruger zone 11',NULL,NULL,'EPSG','2536','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',11500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16272','3-degree Gauss-Kruger zone 12',NULL,NULL,'EPSG','2537','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',36.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',12500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16273','3-degree Gauss-Kruger zone 13',NULL,NULL,'EPSG','2538','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',39.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',13500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16274','3-degree Gauss-Kruger zone 14',NULL,NULL,'EPSG','2539','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',42.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',14500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16275','3-degree Gauss-Kruger zone 15',NULL,NULL,'EPSG','2540','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',15500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16276','3-degree Gauss-Kruger zone 16',NULL,NULL,'EPSG','2604','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',48.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',16500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16277','3-degree Gauss-Kruger zone 17',NULL,NULL,'EPSG','2605','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',51.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',17500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16278','3-degree Gauss-Kruger zone 18',NULL,NULL,'EPSG','2606','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',54.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',18500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16279','3-degree Gauss-Kruger zone 19',NULL,NULL,'EPSG','2607','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',57.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',19500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16280','3-degree Gauss-Kruger zone 20',NULL,NULL,'EPSG','2608','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',60.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',20500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16281','3-degree Gauss-Kruger zone 21',NULL,NULL,'EPSG','2609','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',63.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',21500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16282','3-degree Gauss-Kruger zone 22',NULL,NULL,'EPSG','2610','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',66.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',22500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16283','3-degree Gauss-Kruger zone 23',NULL,NULL,'EPSG','2611','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',69.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',23500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16284','3-degree Gauss-Kruger zone 24',NULL,NULL,'EPSG','2612','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',72.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',24500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16285','3-degree Gauss-Kruger zone 25',NULL,NULL,'EPSG','2613','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',75.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',25500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16286','3-degree Gauss-Kruger zone 26',NULL,NULL,'EPSG','2614','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',78.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',26500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16287','3-degree Gauss-Kruger zone 27',NULL,NULL,'EPSG','2615','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',81.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',27500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16288','3-degree Gauss-Kruger zone 28',NULL,NULL,'EPSG','2616','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',84.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',28500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16289','3-degree Gauss-Kruger zone 29',NULL,NULL,'EPSG','2617','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',87.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',29500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16290','3-degree Gauss-Kruger zone 30',NULL,NULL,'EPSG','2618','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',90.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',30500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16291','3-degree Gauss-Kruger zone 31',NULL,NULL,'EPSG','2619','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',93.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',31500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16292','3-degree Gauss-Kruger zone 32',NULL,NULL,'EPSG','2620','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',96.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',32500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16293','3-degree Gauss-Kruger zone 33',NULL,NULL,'EPSG','2621','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',99.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',33500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16294','3-degree Gauss-Kruger zone 34',NULL,NULL,'EPSG','2622','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',102.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',34500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16295','3-degree Gauss-Kruger zone 35',NULL,NULL,'EPSG','2623','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',105.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',35500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16296','3-degree Gauss-Kruger zone 36',NULL,NULL,'EPSG','2624','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',108.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',36500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16297','3-degree Gauss-Kruger zone 37',NULL,NULL,'EPSG','2625','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',111.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',37500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16298','3-degree Gauss-Kruger zone 38',NULL,NULL,'EPSG','2626','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',114.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',38500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16299','3-degree Gauss-Kruger zone 39',NULL,NULL,'EPSG','2627','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',117.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',39500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16301','Gauss-Kruger CM 3E',NULL,NULL,'EPSG','1933','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16302','Gauss-Kruger CM 9E',NULL,NULL,'EPSG','1935','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16303','Gauss-Kruger CM 15E',NULL,NULL,'EPSG','1937','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16304','Gauss-Kruger CM 21E',NULL,NULL,'EPSG','1939','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16305','Gauss-Kruger CM 27E',NULL,NULL,'EPSG','1941','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16306','Gauss-Kruger CM 33E',NULL,NULL,'EPSG','1943','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16307','Gauss-Kruger CM 39E',NULL,NULL,'EPSG','1945','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',39.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16308','Gauss-Kruger CM 45E',NULL,NULL,'EPSG','1947','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16309','Gauss-Kruger CM 51E',NULL,NULL,'EPSG','1949','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',51.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16310','Gauss-Kruger CM 57E',NULL,NULL,'EPSG','1951','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',57.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16311','Gauss-Kruger CM 63E',NULL,NULL,'EPSG','1953','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',63.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16312','Gauss-Kruger CM 69E',NULL,NULL,'EPSG','1955','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',69.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16313','Gauss-Kruger CM 75E',NULL,NULL,'EPSG','1957','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',75.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16314','Gauss-Kruger CM 81E',NULL,NULL,'EPSG','1959','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',81.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16315','Gauss-Kruger CM 87E',NULL,NULL,'EPSG','1961','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',87.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16316','Gauss-Kruger CM 93E',NULL,NULL,'EPSG','1963','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',93.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16317','Gauss-Kruger CM 99E',NULL,NULL,'EPSG','1965','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',99.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16318','Gauss-Kruger CM 105E',NULL,NULL,'EPSG','1967','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',105.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16319','Gauss-Kruger CM 111E',NULL,NULL,'EPSG','1969','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',111.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16320','Gauss-Kruger CM 117E',NULL,NULL,'EPSG','1971','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',117.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16321','Gauss-Kruger CM 123E',NULL,NULL,'EPSG','1973','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',123.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16322','Gauss-Kruger CM 129E',NULL,NULL,'EPSG','1975','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',129.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16323','Gauss-Kruger CM 135E',NULL,NULL,'EPSG','1977','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',135.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16324','Gauss-Kruger CM 141E',NULL,NULL,'EPSG','1979','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16325','Gauss-Kruger CM 147E',NULL,NULL,'EPSG','1981','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16326','Gauss-Kruger CM 153E',NULL,NULL,'EPSG','1983','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16327','Gauss-Kruger CM 159E',NULL,NULL,'EPSG','1985','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',159.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16328','Gauss-Kruger CM 165E',NULL,NULL,'EPSG','1987','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16329','Gauss-Kruger CM 171E',NULL,NULL,'EPSG','1989','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',171.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16330','Gauss-Kruger CM 177E',NULL,NULL,'EPSG','1991','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16331','Gauss-Kruger CM 177W',NULL,NULL,'EPSG','1873','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16332','Gauss-Kruger CM 171W',NULL,NULL,'EPSG','1875','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-171.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16333','Gauss-Kruger CM 165W',NULL,NULL,'EPSG','1877','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16334','Gauss-Kruger CM 159W',NULL,NULL,'EPSG','1879','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-159.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16335','Gauss-Kruger CM 153W',NULL,NULL,'EPSG','1881','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16336','Gauss-Kruger CM 147W',NULL,NULL,'EPSG','1883','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16337','Gauss-Kruger CM 141W',NULL,NULL,'EPSG','1885','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16338','Gauss-Kruger CM 135W',NULL,NULL,'EPSG','1887','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-135.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16339','Gauss-Kruger CM 129W',NULL,NULL,'EPSG','1889','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-129.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16340','Gauss-Kruger CM 123W',NULL,NULL,'EPSG','1891','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-123.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16341','Gauss-Kruger CM 117W',NULL,NULL,'EPSG','1893','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-117.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16342','Gauss-Kruger CM 111W',NULL,NULL,'EPSG','1895','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-111.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16343','Gauss-Kruger CM 105W',NULL,NULL,'EPSG','1897','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-105.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16344','Gauss-Kruger CM 99W',NULL,NULL,'EPSG','1899','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-99.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16345','Gauss-Kruger CM 93W',NULL,NULL,'EPSG','1901','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-93.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16346','Gauss-Kruger CM 87W',NULL,NULL,'EPSG','1903','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16347','Gauss-Kruger CM 81W',NULL,NULL,'EPSG','1905','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-81.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16348','Gauss-Kruger CM 75W',NULL,NULL,'EPSG','1907','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-75.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16349','Gauss-Kruger CM 69W',NULL,NULL,'EPSG','1909','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-69.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16350','Gauss-Kruger CM 63W',NULL,NULL,'EPSG','1911','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-63.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16351','Gauss-Kruger CM 57W',NULL,NULL,'EPSG','1913','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-57.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16352','Gauss-Kruger CM 51W',NULL,NULL,'EPSG','1915','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-51.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16353','Gauss-Kruger CM 45W',NULL,NULL,'EPSG','1917','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16354','Gauss-Kruger CM 39W',NULL,NULL,'EPSG','1919','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-39.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16355','Gauss-Kruger CM 33W',NULL,NULL,'EPSG','1921','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16356','Gauss-Kruger CM 27W',NULL,NULL,'EPSG','1923','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16357','Gauss-Kruger CM 21W',NULL,NULL,'EPSG','1925','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16358','Gauss-Kruger CM 15W',NULL,NULL,'EPSG','1927','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16359','Gauss-Kruger CM 9W',NULL,NULL,'EPSG','1929','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16360','Gauss-Kruger CM 3W',NULL,NULL,'EPSG','1931','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16361','3-degree Gauss-Kruger CM 3E',NULL,NULL,'EPSG','2299','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16362','3-degree Gauss-Kruger CM 6E',NULL,NULL,'EPSG','2300','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',6.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16363','3-degree Gauss-Kruger CM 9E',NULL,NULL,'EPSG','2301','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16364','3-degree Gauss-Kruger CM 12E',NULL,NULL,'EPSG','2302','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',12.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16365','3-degree Gauss-Kruger CM 15E',NULL,NULL,'EPSG','2303','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16366','3-degree Gauss-Kruger CM 18E',NULL,NULL,'EPSG','2304','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',18.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16367','3-degree Gauss-Kruger CM 21E',NULL,NULL,'EPSG','2305','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16368','3-degree Gauss-Kruger CM 24E',NULL,NULL,'EPSG','2306','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',24.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16369','3-degree Gauss-Kruger CM 27E',NULL,NULL,'EPSG','2534','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16370','3-degree Gauss-Kruger CM 30E',NULL,NULL,'EPSG','2535','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',30.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16371','3-degree Gauss-Kruger CM 33E',NULL,NULL,'EPSG','2536','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16372','3-degree Gauss-Kruger CM 36E',NULL,NULL,'EPSG','2537','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',36.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16373','3-degree Gauss-Kruger CM 39E',NULL,NULL,'EPSG','2538','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',39.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16374','3-degree Gauss-Kruger CM 42E',NULL,NULL,'EPSG','2539','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',42.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16375','3-degree Gauss-Kruger CM 45E',NULL,NULL,'EPSG','2540','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16376','3-degree Gauss-Kruger CM 48E',NULL,NULL,'EPSG','2604','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',48.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16377','3-degree Gauss-Kruger CM 51E',NULL,NULL,'EPSG','2605','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',51.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16378','3-degree Gauss-Kruger CM 54E',NULL,NULL,'EPSG','2606','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',54.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16379','3-degree Gauss-Kruger CM 57E',NULL,NULL,'EPSG','2607','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',57.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16380','3-degree Gauss-Kruger CM 60E',NULL,NULL,'EPSG','2608','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',60.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16381','3-degree Gauss-Kruger CM 63E',NULL,NULL,'EPSG','2609','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',63.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16382','3-degree Gauss-Kruger CM 66E',NULL,NULL,'EPSG','2610','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',66.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16383','3-degree Gauss-Kruger CM 69E',NULL,NULL,'EPSG','2611','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',69.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16384','3-degree Gauss-Kruger CM 72E',NULL,NULL,'EPSG','2612','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',72.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16385','3-degree Gauss-Kruger CM 75E',NULL,NULL,'EPSG','2613','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',75.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16386','3-degree Gauss-Kruger CM 78E',NULL,NULL,'EPSG','2614','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',78.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16387','3-degree Gauss-Kruger CM 81E',NULL,NULL,'EPSG','2615','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',81.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16388','3-degree Gauss-Kruger CM 84E',NULL,NULL,'EPSG','2616','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',84.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16389','3-degree Gauss-Kruger CM 87E',NULL,NULL,'EPSG','2617','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',87.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16390','3-degree Gauss-Kruger CM 90E',NULL,NULL,'EPSG','2618','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',90.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16391','3-degree Gauss-Kruger CM 93E',NULL,NULL,'EPSG','2619','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',93.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16392','3-degree Gauss-Kruger CM 96E',NULL,NULL,'EPSG','2620','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',96.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16393','3-degree Gauss-Kruger CM 99E',NULL,NULL,'EPSG','2621','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',99.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16394','3-degree Gauss-Kruger CM 102E',NULL,NULL,'EPSG','2622','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',102.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16395','3-degree Gauss-Kruger CM 105E',NULL,NULL,'EPSG','2623','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',105.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16396','3-degree Gauss-Kruger CM 108E',NULL,NULL,'EPSG','2624','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',108.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16397','3-degree Gauss-Kruger CM 111E',NULL,NULL,'EPSG','2625','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',111.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16398','3-degree Gauss-Kruger CM 114E',NULL,NULL,'EPSG','2626','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',114.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16399','3-degree Gauss-Kruger CM 117E',NULL,NULL,'EPSG','2627','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',117.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','16400','TM 0 N',NULL,NULL,'EPSG','1629','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16405','TM 5 NE',NULL,NULL,'EPSG','1630','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',5.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16406','TM 6 NE',NULL,NULL,'EPSG','3914','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',6.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16411','TM 11 NE',NULL,NULL,'EPSG','1489','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',11.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16412','TM 12 NE',NULL,NULL,'EPSG','1482','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',12.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16413','TM 13 NE',NULL,NULL,'EPSG','2771','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',13.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16430','TM 30 NE',NULL,NULL,'EPSG','2546','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',30.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16490','Bangladesh Transverse Mercator',NULL,NULL,'EPSG','1041','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',90.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16506','TM 106 NE',NULL,NULL,'EPSG','1495','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',106.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16586','GK 106 NE',NULL,NULL,'EPSG','1494','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',106.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16611','TM 11.30 SE',NULL,NULL,'EPSG','1605','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',11.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16612','TM 12 SE',NULL,NULL,'EPSG','1604','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',12.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16636','TM 36 SE',NULL,NULL,'EPSG','1726','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',36.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16709','TM 109 SE',NULL,NULL,'EPSG','2577','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',109.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16716','TM 116 SE',NULL,NULL,'EPSG','2588','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',116.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','16732','TM 132 SE',NULL,NULL,'EPSG','2589','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',132.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17001','TM 1 NW',NULL,NULL,'EPSG','1505','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-1.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17005','TM 5 NW',NULL,NULL,'EPSG','2296','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-5.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17054','TM 54 NW',NULL,NULL,'EPSG','1727','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-54.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17204','SCAR IMW SP19-20',NULL,NULL,'EPSG','2991','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-66.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-60.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-63.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17205','SCAR IMW SP21-22',NULL,NULL,'EPSG','2992','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-54.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-60.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-63.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17206','SCAR IMW SP23-24',NULL,NULL,'EPSG','2993','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-42.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-60.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-63.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17207','SCAR IMW SQ01-02',NULL,NULL,'EPSG','2994','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-174.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-64.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-67.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17208','SCAR IMW SQ19-20',NULL,NULL,'EPSG','2995','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-66.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-64.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-67.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17209','SCAR IMW SQ21-22',NULL,NULL,'EPSG','2996','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-54.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-64.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-67.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17210','SCAR IMW SQ37-38',NULL,NULL,'EPSG','2997','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',42.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-64.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-67.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17211','SCAR IMW SQ39-40',NULL,NULL,'EPSG','2998','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',54.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-64.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-67.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17212','SCAR IMW SQ41-42',NULL,NULL,'EPSG','2999','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',66.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-64.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-67.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17213','SCAR IMW SQ43-44',NULL,NULL,'EPSG','3000','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',78.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-64.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-67.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17214','SCAR IMW SQ45-46',NULL,NULL,'EPSG','3001','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',90.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-64.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-67.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17215','SCAR IMW SQ47-48',NULL,NULL,'EPSG','3002','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',102.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-64.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-67.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17216','SCAR IMW SQ49-50',NULL,NULL,'EPSG','3003','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',114.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-64.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-67.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17217','SCAR IMW SQ51-52',NULL,NULL,'EPSG','3004','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',126.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-64.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-67.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17218','SCAR IMW SQ53-54',NULL,NULL,'EPSG','3005','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',138.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-64.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-67.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17219','SCAR IMW SQ55-56',NULL,NULL,'EPSG','3006','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',150.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-64.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-67.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17220','SCAR IMW SQ57-58',NULL,NULL,'EPSG','3007','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',162.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-64.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-67.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17221','SCAR IMW SR13-14',NULL,NULL,'EPSG','3008','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-102.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17222','SCAR IMW SR15-16',NULL,NULL,'EPSG','3009','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17223','SCAR IMW SR17-18',NULL,NULL,'EPSG','3010','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-78.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17224','SCAR IMW SR19-20',NULL,NULL,'EPSG','3011','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-66.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17225','SCAR IMW SR27-28',NULL,NULL,'EPSG','3012','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-18.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17226','SCAR IMW SR29-30',NULL,NULL,'EPSG','3013','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-6.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17227','SCAR IMW SR31-32',NULL,NULL,'EPSG','3014','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',6.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17228','SCAR IMW SR33-34',NULL,NULL,'EPSG','3015','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',18.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17229','SCAR IMW SR35-36',NULL,NULL,'EPSG','3016','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',30.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17230','SCAR IMW SR37-38',NULL,NULL,'EPSG','3017','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',42.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17231','SCAR IMW SR39-40',NULL,NULL,'EPSG','3018','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',54.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17232','SCAR IMW SR41-42',NULL,NULL,'EPSG','3019','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',66.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17233','SCAR IMW SR43-44',NULL,NULL,'EPSG','3020','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',78.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17234','SCAR IMW SR45-46',NULL,NULL,'EPSG','3021','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',90.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17235','SCAR IMW SR47-48',NULL,NULL,'EPSG','3022','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',102.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17236','SCAR IMW SR49-50',NULL,NULL,'EPSG','3023','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',114.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17237','SCAR IMW SR51-52',NULL,NULL,'EPSG','3024','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',126.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17238','SCAR IMW SR53-54',NULL,NULL,'EPSG','3025','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',138.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17239','SCAR IMW SR55-56',NULL,NULL,'EPSG','3026','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',150.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17240','SCAR IMW SR57-58',NULL,NULL,'EPSG','3027','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',162.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17241','SCAR IMW SR59-60',NULL,NULL,'EPSG','3028','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',174.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-68.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-71.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17242','SCAR IMW SS04-06',NULL,NULL,'EPSG','3029','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-153.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-72.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17243','SCAR IMW SS07-09',NULL,NULL,'EPSG','3030','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-135.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-72.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17244','SCAR IMW SS10-12',NULL,NULL,'EPSG','3031','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-117.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-72.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17245','SCAR IMW SS13-15',NULL,NULL,'EPSG','3032','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-99.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-72.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17246','SCAR IMW SS16-18',NULL,NULL,'EPSG','3033','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-72.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17247','SCAR IMW SS19-21',NULL,NULL,'EPSG','3034','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-63.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-72.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17248','SCAR IMW SS25-27',NULL,NULL,'EPSG','3035','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-27.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-72.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17249','SCAR IMW SS28-30',NULL,NULL,'EPSG','3036','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-9.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-72.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17250','SCAR IMW SS31-33',NULL,NULL,'EPSG','3037','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',9.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-72.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17251','SCAR IMW SS34-36',NULL,NULL,'EPSG','3038','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',27.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-72.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17252','SCAR IMW SS37-39',NULL,NULL,'EPSG','3039','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',45.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-72.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17253','SCAR IMW SS40-42',NULL,NULL,'EPSG','3040','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',63.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-72.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17254','SCAR IMW SS43-45',NULL,NULL,'EPSG','3041','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',81.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-72.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17255','SCAR IMW SS46-48',NULL,NULL,'EPSG','3042','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',99.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-72.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17256','SCAR IMW SS49-51',NULL,NULL,'EPSG','3043','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',117.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-72.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17257','SCAR IMW SS52-54',NULL,NULL,'EPSG','3044','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',135.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-72.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17258','SCAR IMW SS55-57',NULL,NULL,'EPSG','3045','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',153.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-72.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17259','SCAR IMW SS58-60',NULL,NULL,'EPSG','3046','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',171.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-72.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-75.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17260','SCAR IMW ST01-04',NULL,NULL,'EPSG','3047','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-168.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-76.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-79.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17261','SCAR IMW ST05-08',NULL,NULL,'EPSG','3048','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-144.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-76.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-79.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17262','SCAR IMW ST09-12',NULL,NULL,'EPSG','3049','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-76.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-79.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17263','SCAR IMW ST13-16',NULL,NULL,'EPSG','3050','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-76.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-79.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17264','SCAR IMW ST17-20',NULL,NULL,'EPSG','3051','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-72.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-76.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-79.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17265','SCAR IMW ST21-24',NULL,NULL,'EPSG','3052','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-48.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-76.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-79.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17266','SCAR IMW ST25-28',NULL,NULL,'EPSG','3053','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-24.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-76.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-79.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17267','SCAR IMW ST29-32',NULL,NULL,'EPSG','3054','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',0.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-76.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-79.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17268','SCAR IMW ST33-36',NULL,NULL,'EPSG','3055','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',24.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-76.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-79.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17269','SCAR IMW ST37-40',NULL,NULL,'EPSG','3056','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',48.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-76.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-79.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17270','SCAR IMW ST41-44',NULL,NULL,'EPSG','3057','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',72.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-76.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-79.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17271','SCAR IMW ST45-48',NULL,NULL,'EPSG','3058','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',96.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-76.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-79.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17272','SCAR IMW ST49-52',NULL,NULL,'EPSG','3059','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',120.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-76.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-79.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17273','SCAR IMW ST53-56',NULL,NULL,'EPSG','3060','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',144.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-76.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-79.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17274','SCAR IMW ST57-60',NULL,NULL,'EPSG','3061','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',168.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-76.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-79.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17275','SCAR IMW SU01-05',NULL,NULL,'EPSG','3062','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',-165.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17276','SCAR IMW SU06-10',NULL,NULL,'EPSG','3063','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',-135.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17277','SCAR IMW SU11-15',NULL,NULL,'EPSG','3064','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',-105.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17278','SCAR IMW SU16-20',NULL,NULL,'EPSG','3065','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',-75.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17279','SCAR IMW SU21-25',NULL,NULL,'EPSG','3066','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',-45.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17280','SCAR IMW SU26-30',NULL,NULL,'EPSG','3067','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',-15.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17281','SCAR IMW SU31-35',NULL,NULL,'EPSG','3068','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',15.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17282','SCAR IMW SU36-40',NULL,NULL,'EPSG','3069','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',45.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17283','SCAR IMW SU41-45',NULL,NULL,'EPSG','3070','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',75.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17284','SCAR IMW SU46-50',NULL,NULL,'EPSG','3071','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',105.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17285','SCAR IMW SU51-55',NULL,NULL,'EPSG','3072','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',135.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17286','SCAR IMW SU56-60',NULL,NULL,'EPSG','3073','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',165.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17287','SCAR IMW SV01-10',NULL,NULL,'EPSG','3074','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',-150.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17288','SCAR IMW SV11-20',NULL,NULL,'EPSG','3075','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',-90.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17289','SCAR IMW SV21-30',NULL,NULL,'EPSG','3076','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',-30.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17290','SCAR IMW SV31-40',NULL,NULL,'EPSG','3077','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',30.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17291','SCAR IMW SV41-50',NULL,NULL,'EPSG','3078','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',90.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17292','SCAR IMW SV51-60',NULL,NULL,'EPSG','3079','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',150.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17293','SCAR IMW SW01-60',NULL,NULL,'EPSG','3080','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-80.1419,'EPSG','9110','EPSG','8833','Longitude of origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17294','USGS Transantarctic Mountains',NULL,NULL,'EPSG','3081','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-78.0,'EPSG','9102','EPSG','8822','Longitude of false origin',162.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-76.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-79.2,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17295','North Pole Lambert Azimuthal Equal Area (Bering Sea)',NULL,NULL,'EPSG','3480','EPSG','9820','Lambert Azimuthal Equal Area','EPSG','8801','Latitude of natural origin',90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',180.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17296','North Pole Lambert Azimuthal Equal Area (Alaska)',NULL,NULL,'EPSG','3480','EPSG','9820','Lambert Azimuthal Equal Area','EPSG','8801','Latitude of natural origin',90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-150.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17297','North Pole Lambert Azimuthal Equal Area (Canada)',NULL,NULL,'EPSG','3480','EPSG','9820','Lambert Azimuthal Equal Area','EPSG','8801','Latitude of natural origin',90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-100.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17298','North Pole Lambert Azimuthal Equal Area (Atlantic)',NULL,NULL,'EPSG','3480','EPSG','9820','Lambert Azimuthal Equal Area','EPSG','8801','Latitude of natural origin',90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-40.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17299','North Pole Lambert Azimuthal Equal Area (Europe)',NULL,NULL,'EPSG','3480','EPSG','9820','Lambert Azimuthal Equal Area','EPSG','8801','Latitude of natural origin',90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',10.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17300','North Pole Lambert Azimuthal Equal Area (Russia)',NULL,NULL,'EPSG','3480','EPSG','9820','Lambert Azimuthal Equal Area','EPSG','8801','Latitude of natural origin',90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',90.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17321','SWEREF99 12 00',NULL,NULL,'EPSG','2833','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',12.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17322','SWEREF99 13 30',NULL,NULL,'EPSG','2834','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',13.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17323','SWEREF99 15 00',NULL,NULL,'EPSG','2835','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17324','SWEREF99 16 30',NULL,NULL,'EPSG','2836','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',16.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17325','SWEREF99 18 00',NULL,NULL,'EPSG','2837','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',18.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17326','SWEREF99 14 15',NULL,NULL,'EPSG','2838','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',14.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17327','SWEREF99 15 45',NULL,NULL,'EPSG','2839','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',15.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17328','SWEREF99 17 15',NULL,NULL,'EPSG','2840','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',17.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17329','SWEREF99 18 45',NULL,NULL,'EPSG','2841','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',18.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17330','SWEREF99 20 15',NULL,NULL,'EPSG','2842','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',20.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17331','SWEREF99 21 45',NULL,NULL,'EPSG','2843','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',21.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17332','SWEREF99 23 15',NULL,NULL,'EPSG','2844','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',23.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17333','SWEREF99 TM',NULL,NULL,'EPSG','1225','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17334','Sweden zone 7.5 gon V',NULL,NULL,'EPSG','2845','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',11.18298,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17335','Sweden zone 5 gon V',NULL,NULL,'EPSG','2846','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',13.33298,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17336','Sweden zone 0 gon',NULL,NULL,'EPSG','2848','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',18.03298,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17337','Sweden zone 2.5 gon O',NULL,NULL,'EPSG','2849','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',20.18298,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17338','Sweden zone 5 gon O',NULL,NULL,'EPSG','2850','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',22.33298,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17339','RT90 zone 7.5 gon V emulation',NULL,NULL,'EPSG','2845','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',11.18225,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000006,'EPSG','9201','EPSG','8806','False easting',1500025.141,'EPSG','9001','EPSG','8807','False northing',-667.282,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17340','RT90 zone 5 gon V emulation',NULL,NULL,'EPSG','2846','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',13.332256,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000058,'EPSG','9201','EPSG','8806','False easting',1500044.695,'EPSG','9001','EPSG','8807','False northing',-667.13,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17341','RT90 zone 2.5 gon V emulation',NULL,NULL,'EPSG','2847','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',15.4822624306,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.00000561024,'EPSG','9201','EPSG','8806','False easting',1500064.274,'EPSG','9001','EPSG','8807','False northing',-667.711,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17342','RT90 zone 0 gon emulation',NULL,NULL,'EPSG','2848','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',18.032268,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000054,'EPSG','9201','EPSG','8806','False easting',1500083.521,'EPSG','9001','EPSG','8807','False northing',-668.844,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17343','RT90 zone 2.5 gon O emulation',NULL,NULL,'EPSG','2849','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',20.182274,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000052,'EPSG','9201','EPSG','8806','False easting',1500102.765,'EPSG','9001','EPSG','8807','False northing',-670.706,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17344','RT90 zone 5 gon O emulation',NULL,NULL,'EPSG','2850','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',22.33228,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000049,'EPSG','9201','EPSG','8806','False easting',1500121.846,'EPSG','9001','EPSG','8807','False northing',-672.557,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17348','Map Grid of Australia zone 48',NULL,NULL,'EPSG','4191','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',105.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17349','Map Grid of Australia zone 49',NULL,NULL,'EPSG','4176','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',111.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17350','Map Grid of Australia zone 50',NULL,NULL,'EPSG','4178','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',117.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17351','Map Grid of Australia zone 51',NULL,NULL,'EPSG','1559','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',123.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17352','Map Grid of Australia zone 52',NULL,NULL,'EPSG','1560','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',129.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17353','Map Grid of Australia zone 53',NULL,NULL,'EPSG','1561','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',135.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17354','Map Grid of Australia zone 54',NULL,NULL,'EPSG','1562','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17355','Map Grid of Australia zone 55',NULL,NULL,'EPSG','1563','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17356','Map Grid of Australia zone 56',NULL,NULL,'EPSG','1564','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17357','Map Grid of Australia zone 57',NULL,NULL,'EPSG','4196','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',159.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17358','Map Grid of Australia zone 58',NULL,NULL,'EPSG','4175','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17359','South Australia Lambert',NULL,NULL,'EPSG','2986','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-32.0,'EPSG','9102','EPSG','8822','Longitude of false origin',135.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-28.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-36.0,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17360','Vicgrid66',NULL,NULL,'EPSG','2285','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-37.0,'EPSG','9102','EPSG','8822','Longitude of false origin',145.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-36.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-38.0,'EPSG','9102','EPSG','8826','Easting at false origin',2500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17361','Vicgrid',NULL,NULL,'EPSG','2285','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-37.0,'EPSG','9102','EPSG','8822','Longitude of false origin',145.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-36.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-38.0,'EPSG','9102','EPSG','8826','Easting at false origin',2500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17362','Geoscience Australia Standard National Scale Lambert Projection',NULL,NULL,'EPSG','2575','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',0.0,'EPSG','9102','EPSG','8822','Longitude of false origin',134.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-18.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-36.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17363','Brisbane City Survey Grid 02',NULL,NULL,'EPSG','2990','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-28.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99999,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17364','New South Wales Lambert',NULL,NULL,'EPSG','3139','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-33.25,'EPSG','9102','EPSG','8822','Longitude of false origin',147.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-30.75,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-35.75,'EPSG','9102','EPSG','8826','Easting at false origin',9300000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17365','Australian Albers',NULL,NULL,'EPSG','2575','EPSG','9822','Albers Equal Area','EPSG','8821','Latitude of false origin',0.0,'EPSG','9102','EPSG','8822','Longitude of false origin',132.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-18.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-36.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17401','Katanga Lambert Conformal',NULL,NULL,'EPSG','3147','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',0.0,'EPSG','9102','EPSG','8822','Longitude of false origin',26.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-6.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-11.5,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','17402','Katanga Transverse Mercator',NULL,NULL,'EPSG','3147','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-9.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',26.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9998,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','17412','Congo Transverse Mercator zone 12',NULL,NULL,'EPSG','3937','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',12.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17414','Congo Transverse Mercator zone 14',NULL,NULL,'EPSG','3151','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',14.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17416','Congo Transverse Mercator zone 16',NULL,NULL,'EPSG','3152','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',16.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17418','Congo Transverse Mercator zone 18',NULL,NULL,'EPSG','3153','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',18.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17420','Congo Transverse Mercator zone 20',NULL,NULL,'EPSG','3154','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',20.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17422','Congo Transverse Mercator zone 22',NULL,NULL,'EPSG','3155','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',22.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17424','Congo Transverse Mercator zone 24',NULL,NULL,'EPSG','3156','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',24.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17426','Congo Transverse Mercator zone 26',NULL,NULL,'EPSG','3157','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',26.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17428','Congo Transverse Mercator zone 28',NULL,NULL,'EPSG','3158','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',28.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17430','Congo Transverse Mercator zone 30',NULL,NULL,'EPSG','3159','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',30.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17432','Indonesia TM-3 zone 46.2',NULL,NULL,'EPSG','3976','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',94.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17433','Indonesia TM-3 zone 47.1',NULL,NULL,'EPSG','3510','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',97.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17434','Indonesia TM-3 zone 47.2',NULL,NULL,'EPSG','3511','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',100.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17435','Indonesia TM-3 zone 48.1',NULL,NULL,'EPSG','3512','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',103.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17436','Indonesia TM-3 zone 48.2',NULL,NULL,'EPSG','3513','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',106.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17437','Indonesia TM-3 zone 49.1',NULL,NULL,'EPSG','3514','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',109.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17438','Indonesia TM-3 zone 49.2',NULL,NULL,'EPSG','3515','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',112.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17439','Indonesia TM-3 zone 50.1',NULL,NULL,'EPSG','3516','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',115.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17440','Indonesia TM-3 zone 50.2',NULL,NULL,'EPSG','3517','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',118.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17441','Indonesia TM-3 zone 51.1',NULL,NULL,'EPSG','3518','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',121.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17442','Indonesia TM-3 zone 51.2',NULL,NULL,'EPSG','3519','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',124.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17443','Indonesia TM-3 zone 52.1',NULL,NULL,'EPSG','3520','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',127.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17444','Indonesia TM-3 zone 52.2',NULL,NULL,'EPSG','3521','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',130.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17445','Indonesia TM-3 zone 53.1',NULL,NULL,'EPSG','3522','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',133.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17446','Indonesia TM-3 zone 53.2',NULL,NULL,'EPSG','3523','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',136.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17447','Indonesia TM-3 zone 54.1',NULL,NULL,'EPSG','3975','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',139.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',1500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17448','Australian Map Grid zone 48',NULL,NULL,'EPSG','1556','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',105.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','17449','Australian Map Grid zone 49',NULL,NULL,'EPSG','1557','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',111.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17450','Australian Map Grid zone 50',NULL,NULL,'EPSG','1558','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',117.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17451','Australian Map Grid zone 51',NULL,NULL,'EPSG','1559','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',123.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17452','Australian Map Grid zone 52',NULL,NULL,'EPSG','1560','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',129.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17453','Australian Map Grid zone 53',NULL,NULL,'EPSG','1561','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',135.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17454','Australian Map Grid zone 54',NULL,NULL,'EPSG','1567','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17455','Australian Map Grid zone 55',NULL,NULL,'EPSG','1568','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17456','Australian Map Grid zone 56',NULL,NULL,'EPSG','2291','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17457','Australian Map Grid zone 57',NULL,NULL,'EPSG','1565','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',159.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17458','Australian Map Grid zone 58',NULL,NULL,'EPSG','1566','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17515','South African Survey Grid zone 15',NULL,NULL,'EPSG','1454','EPSG','9808','Transverse Mercator (South Orientated)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17517','South African Survey Grid zone 17',NULL,NULL,'EPSG','1455','EPSG','9808','Transverse Mercator (South Orientated)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',17.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17519','South African Survey Grid zone 19',NULL,NULL,'EPSG','1456','EPSG','9808','Transverse Mercator (South Orientated)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',19.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17521','South African Survey Grid zone 21',NULL,NULL,'EPSG','1457','EPSG','9808','Transverse Mercator (South Orientated)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17523','South African Survey Grid zone 23',NULL,NULL,'EPSG','1458','EPSG','9808','Transverse Mercator (South Orientated)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',23.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17525','South African Survey Grid zone 25',NULL,NULL,'EPSG','1459','EPSG','9808','Transverse Mercator (South Orientated)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',25.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17527','South African Survey Grid zone 27',NULL,NULL,'EPSG','1460','EPSG','9808','Transverse Mercator (South Orientated)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17529','South African Survey Grid zone 29',NULL,NULL,'EPSG','1461','EPSG','9808','Transverse Mercator (South Orientated)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',29.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17531','South African Survey Grid zone 31',NULL,NULL,'EPSG','1462','EPSG','9808','Transverse Mercator (South Orientated)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',31.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17533','South African Survey Grid zone 33',NULL,NULL,'EPSG','1463','EPSG','9808','Transverse Mercator (South Orientated)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17611','South West African Survey Grid zone 11',NULL,NULL,'EPSG','1838','EPSG','9808','Transverse Mercator (South Orientated)','EPSG','8801','Latitude of natural origin',-22.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',11.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9031','EPSG','8807','False northing',0.0,'EPSG','9031',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17613','South West African Survey Grid zone 13',NULL,NULL,'EPSG','1839','EPSG','9808','Transverse Mercator (South Orientated)','EPSG','8801','Latitude of natural origin',-22.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',13.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9031','EPSG','8807','False northing',0.0,'EPSG','9031',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17615','South West African Survey Grid zone 15',NULL,NULL,'EPSG','1840','EPSG','9808','Transverse Mercator (South Orientated)','EPSG','8801','Latitude of natural origin',-22.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9031','EPSG','8807','False northing',0.0,'EPSG','9031',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17617','South West African Survey Grid zone 17',NULL,NULL,'EPSG','1841','EPSG','9808','Transverse Mercator (South Orientated)','EPSG','8801','Latitude of natural origin',-22.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',17.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9031','EPSG','8807','False northing',0.0,'EPSG','9031',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17619','South West African Survey Grid zone 19',NULL,NULL,'EPSG','1842','EPSG','9808','Transverse Mercator (South Orientated)','EPSG','8801','Latitude of natural origin',-22.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',19.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9031','EPSG','8807','False northing',0.0,'EPSG','9031',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17621','South West African Survey Grid zone 21',NULL,NULL,'EPSG','1843','EPSG','9808','Transverse Mercator (South Orientated)','EPSG','8801','Latitude of natural origin',-22.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9031','EPSG','8807','False northing',0.0,'EPSG','9031',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17623','South West African Survey Grid zone 23',NULL,NULL,'EPSG','1844','EPSG','9808','Transverse Mercator (South Orientated)','EPSG','8801','Latitude of natural origin',-22.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',23.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9031','EPSG','8807','False northing',0.0,'EPSG','9031',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17625','South West African Survey Grid zone 25',NULL,NULL,'EPSG','1845','EPSG','9808','Transverse Mercator (South Orientated)','EPSG','8801','Latitude of natural origin',-22.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',25.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9031','EPSG','8807','False northing',0.0,'EPSG','9031',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17700','MTM Quebec zone 2',NULL,NULL,'EPSG','1420','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-55.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',304800.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','17701','MTM zone 1',NULL,NULL,'EPSG','2226','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-53.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',304800.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17702','MTM zone 2',NULL,NULL,'EPSG','2227','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-56.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',304800.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17703','MTM zone 3',NULL,NULL,'EPSG','2290','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-58.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',304800.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17704','MTM zone 4',NULL,NULL,'EPSG','2276','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-61.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',304800.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17705','MTM zone 5',NULL,NULL,'EPSG','2277','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-64.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',304800.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17706','MTM zone 6',NULL,NULL,'EPSG','2278','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-67.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',304800.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17707','MTM zone 7',NULL,NULL,'EPSG','1425','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-70.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',304800.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17708','MTM zone 8',NULL,NULL,'EPSG','2279','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-73.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',304800.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17709','MTM zone 9',NULL,NULL,'EPSG','2280','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-76.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',304800.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17710','MTM zone 10',NULL,NULL,'EPSG','2281','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-79.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',304800.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17711','MTM zone 11',NULL,NULL,'EPSG','1432','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-82.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',304800.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17712','MTM zone 12',NULL,NULL,'EPSG','1433','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-81.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',304800.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17713','MTM zone 13',NULL,NULL,'EPSG','1434','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-84.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',304800.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17714','MTM zone 14',NULL,NULL,'EPSG','1435','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',304800.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17715','MTM zone 15',NULL,NULL,'EPSG','1436','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',304800.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17716','MTM zone 16',NULL,NULL,'EPSG','1437','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-93.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',304800.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17717','MTM zone 17',NULL,NULL,'EPSG','1438','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-96.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',304800.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17722','Alberta 3-degree TM reference meridian 111 W',NULL,NULL,'EPSG','3543','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-111.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17723','Alberta 3-degree TM reference meridian 114 W',NULL,NULL,'EPSG','3542','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-114.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17724','Alberta 3-degree TM reference meridian 117 W',NULL,NULL,'EPSG','3541','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-117.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17725','Alberta 3-degree TM reference meridian 120 W',NULL,NULL,'EPSG','3540','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-120.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9001','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','17726','Alberta 3-degree TM reference meridian 120 W',NULL,NULL,'EPSG','3540','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-120.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17794','MTM Nova Scotia zone 4',NULL,NULL,'EPSG','1534','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-61.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',4500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17795','MTM Nova Scotia zone 5',NULL,NULL,'EPSG','1535','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-64.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',5500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17801','Japan Plane Rectangular CS zone I',NULL,NULL,'EPSG','1854','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',33.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',129.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17802','Japan Plane Rectangular CS zone II',NULL,NULL,'EPSG','1855','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',33.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',131.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17803','Japan Plane Rectangular CS zone III',NULL,NULL,'EPSG','1856','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',132.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17804','Japan Plane Rectangular CS zone IV',NULL,NULL,'EPSG','1857','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',33.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',133.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17805','Japan Plane Rectangular CS zone V',NULL,NULL,'EPSG','1858','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',134.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17806','Japan Plane Rectangular CS zone VI',NULL,NULL,'EPSG','1859','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',136.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17807','Japan Plane Rectangular CS zone VII',NULL,NULL,'EPSG','1860','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',137.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17808','Japan Plane Rectangular CS zone VIII',NULL,NULL,'EPSG','1861','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',138.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17809','Japan Plane Rectangular CS zone IX',NULL,NULL,'EPSG','1862','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',139.5,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17810','Japan Plane Rectangular CS zone X',NULL,NULL,'EPSG','1863','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',140.5,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17811','Japan Plane Rectangular CS zone XI',NULL,NULL,'EPSG','1864','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',140.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17812','Japan Plane Rectangular CS zone XII',NULL,NULL,'EPSG','1865','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',142.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17813','Japan Plane Rectangular CS zone XIII',NULL,NULL,'EPSG','1866','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',144.15,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17814','Japan Plane Rectangular CS zone XIV',NULL,NULL,'EPSG','1867','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',26.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',142.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17815','Japan Plane Rectangular CS zone XV',NULL,NULL,'EPSG','1868','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',26.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',127.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17816','Japan Plane Rectangular CS zone XVI',NULL,NULL,'EPSG','1869','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',26.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',124.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17817','Japan Plane Rectangular CS zone XVII',NULL,NULL,'EPSG','1870','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',26.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',131.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17818','Japan Plane Rectangular CS zone XVIII',NULL,NULL,'EPSG','1871','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',20.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',136.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17819','Japan Plane Rectangular CS zone XIX',NULL,NULL,'EPSG','1872','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',26.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',154.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17901','Mount Eden Circuit',NULL,NULL,'EPSG','3781','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-36.5247515,'EPSG','9110','EPSG','8802','Longitude of natural origin',174.45516217,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17902','Bay of Plenty Circuit',NULL,NULL,'EPSG','3779','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-37.45404993,'EPSG','9110','EPSG','8802','Longitude of natural origin',176.27583101,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17903','Poverty Bay Circuit',NULL,NULL,'EPSG','3780','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-38.372893,'EPSG','9110','EPSG','8802','Longitude of natural origin',177.53082906,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17904','Hawkes Bay Circuit',NULL,NULL,'EPSG','3772','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-39.39033455,'EPSG','9110','EPSG','8802','Longitude of natural origin',176.40252499,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17905','Taranaki Circuit',NULL,NULL,'EPSG','3777','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-39.08087299,'EPSG','9110','EPSG','8802','Longitude of natural origin',174.13408423,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17906','Tuhirangi Circuit',NULL,NULL,'EPSG','3778','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-39.30448934,'EPSG','9110','EPSG','8802','Longitude of natural origin',175.38241325,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17907','Wanganui Circuit',NULL,NULL,'EPSG','3776','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-40.14310097,'EPSG','9110','EPSG','8802','Longitude of natural origin',175.29171586,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17908','Wairarapa Circuit',NULL,NULL,'EPSG','3775','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-40.55319175,'EPSG','9110','EPSG','8802','Longitude of natural origin',175.38504588,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17909','Wellington Circuit',NULL,NULL,'EPSG','3774','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-41.18047507,'EPSG','9110','EPSG','8802','Longitude of natural origin',174.46358432,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17910','Collingwood Circuit',NULL,NULL,'EPSG','3782','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-40.42531326,'EPSG','9110','EPSG','8802','Longitude of natural origin',172.40193674,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17911','Nelson Circuit',NULL,NULL,'EPSG','3784','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-41.1628361,'EPSG','9110','EPSG','8802','Longitude of natural origin',173.17575405,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17912','Karamea Circuit',NULL,NULL,'EPSG','3783','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-41.17236815,'EPSG','9110','EPSG','8802','Longitude of natural origin',172.06325015,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17913','Buller Circuit',NULL,NULL,'EPSG','3786','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-41.48388903,'EPSG','9110','EPSG','8802','Longitude of natural origin',171.34525362,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17914','Grey Circuit',NULL,NULL,'EPSG','3787','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-42.20012994,'EPSG','9110','EPSG','8802','Longitude of natural origin',171.32591767,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17915','Amuri Circuit',NULL,NULL,'EPSG','3788','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-42.41208197,'EPSG','9110','EPSG','8802','Longitude of natural origin',173.00364802,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17916','Marlborough Circuit',NULL,NULL,'EPSG','3785','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-41.3240152,'EPSG','9110','EPSG','8802','Longitude of natural origin',173.48074668,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17917','Hokitika Circuit',NULL,NULL,'EPSG','3789','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-42.53107605,'EPSG','9110','EPSG','8802','Longitude of natural origin',170.58479766,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17918','Okarito Circuit',NULL,NULL,'EPSG','3791','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-43.06364613,'EPSG','9110','EPSG','8802','Longitude of natural origin',170.1539333,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17919','Jacksons Bay Circuit',NULL,NULL,'EPSG','3794','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-43.58400904,'EPSG','9110','EPSG','8802','Longitude of natural origin',168.36225612,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17920','Mount Pleasant Circuit',NULL,NULL,'EPSG','3790','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-43.35262953,'EPSG','9110','EPSG','8802','Longitude of natural origin',172.43378969,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17921','Gawler Circuit',NULL,NULL,'EPSG','3792','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-43.44553616,'EPSG','9110','EPSG','8802','Longitude of natural origin',171.21386945,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17922','Timaru Circuit',NULL,NULL,'EPSG','3793','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-44.24079933,'EPSG','9110','EPSG','8802','Longitude of natural origin',171.0326103,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17923','Lindis Peak Circuit',NULL,NULL,'EPSG','3795','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-44.44069647,'EPSG','9110','EPSG','8802','Longitude of natural origin',169.28039183,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17924','Mount Nicholas Circuit',NULL,NULL,'EPSG','3797','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-45.07584493,'EPSG','9110','EPSG','8802','Longitude of natural origin',168.23551083,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17925','Mount York Circuit',NULL,NULL,'EPSG','3799','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-45.33494142,'EPSG','9110','EPSG','8802','Longitude of natural origin',167.44199024,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17926','Observation Point Circuit',NULL,NULL,'EPSG','3796','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-45.48583078,'EPSG','9110','EPSG','8802','Longitude of natural origin',170.37429426,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17927','North Taieri Circuit',NULL,NULL,'EPSG','3798','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-45.51414481,'EPSG','9110','EPSG','8802','Longitude of natural origin',170.16573208,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99996,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17928','Bluff Circuit',NULL,NULL,'EPSG','3800','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-46.36000346,'EPSG','9110','EPSG','8802','Longitude of natural origin',168.20343392,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300002.66,'EPSG','9001','EPSG','8807','False northing',699999.58,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17931','Mount Eden 2000',NULL,NULL,'EPSG','3781','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-36.5247,'EPSG','9110','EPSG','8802','Longitude of natural origin',174.4551,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17932','Bay of Plenty 2000',NULL,NULL,'EPSG','3779','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-37.454,'EPSG','9110','EPSG','8802','Longitude of natural origin',176.2758,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17933','Poverty Bay 2000',NULL,NULL,'EPSG','3780','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-38.3728,'EPSG','9110','EPSG','8802','Longitude of natural origin',177.5308,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17934','Hawkes Bay 2000',NULL,NULL,'EPSG','3772','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-39.3903,'EPSG','9110','EPSG','8802','Longitude of natural origin',176.4025,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17935','Taranaki 2000',NULL,NULL,'EPSG','3777','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-39.0808,'EPSG','9110','EPSG','8802','Longitude of natural origin',174.134,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17936','Tuhirangi 2000',NULL,NULL,'EPSG','3778','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-39.3044,'EPSG','9110','EPSG','8802','Longitude of natural origin',175.3824,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17937','Wanganui 2000',NULL,NULL,'EPSG','3776','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-40.1431,'EPSG','9110','EPSG','8802','Longitude of natural origin',175.2917,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17938','Wairarapa 2000',NULL,NULL,'EPSG','3775','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-40.5531,'EPSG','9110','EPSG','8802','Longitude of natural origin',175.385,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17939','Wellington 2000',NULL,NULL,'EPSG','3774','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-41.1804,'EPSG','9110','EPSG','8802','Longitude of natural origin',174.4635,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17940','Collingwood 2000',NULL,NULL,'EPSG','3782','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-40.4253,'EPSG','9110','EPSG','8802','Longitude of natural origin',172.4019,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17941','Nelson 2000',NULL,NULL,'EPSG','3784','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-41.1628,'EPSG','9110','EPSG','8802','Longitude of natural origin',173.1757,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17942','Karamea 2000',NULL,NULL,'EPSG','3783','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-41.1723,'EPSG','9110','EPSG','8802','Longitude of natural origin',172.0632,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17943','Buller 2000',NULL,NULL,'EPSG','3786','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-41.4838,'EPSG','9110','EPSG','8802','Longitude of natural origin',171.3452,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17944','Grey 2000',NULL,NULL,'EPSG','3787','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-42.2001,'EPSG','9110','EPSG','8802','Longitude of natural origin',171.3259,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17945','Amuri 2000',NULL,NULL,'EPSG','3788','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-42.412,'EPSG','9110','EPSG','8802','Longitude of natural origin',173.0036,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17946','Marlborough 2000',NULL,NULL,'EPSG','3785','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-41.324,'EPSG','9110','EPSG','8802','Longitude of natural origin',173.4807,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17947','Hokitika 2000',NULL,NULL,'EPSG','3789','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-42.531,'EPSG','9110','EPSG','8802','Longitude of natural origin',170.5847,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17948','Okarito 2000',NULL,NULL,'EPSG','3791','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-43.0636,'EPSG','9110','EPSG','8802','Longitude of natural origin',170.1539,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17949','Jacksons Bay 2000',NULL,NULL,'EPSG','3794','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-43.584,'EPSG','9110','EPSG','8802','Longitude of natural origin',168.3622,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17950','Mount Pleasant 2000',NULL,NULL,'EPSG','3790','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-43.3526,'EPSG','9110','EPSG','8802','Longitude of natural origin',172.4337,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17951','Gawler 2000',NULL,NULL,'EPSG','3792','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-43.4455,'EPSG','9110','EPSG','8802','Longitude of natural origin',171.2138,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17952','Timaru 2000',NULL,NULL,'EPSG','3793','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-44.2407,'EPSG','9110','EPSG','8802','Longitude of natural origin',171.0326,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17953','Lindis Peak 2000',NULL,NULL,'EPSG','3795','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-44.4406,'EPSG','9110','EPSG','8802','Longitude of natural origin',169.2803,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17954','Mount Nicholas 2000',NULL,NULL,'EPSG','3797','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-45.0758,'EPSG','9110','EPSG','8802','Longitude of natural origin',168.2355,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17955','Mount York 2000',NULL,NULL,'EPSG','3799','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-45.3349,'EPSG','9110','EPSG','8802','Longitude of natural origin',167.4419,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17956','Observation Point 2000',NULL,NULL,'EPSG','3796','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-45.4858,'EPSG','9110','EPSG','8802','Longitude of natural origin',170.3742,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17957','North Taieri 2000',NULL,NULL,'EPSG','3798','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-45.5141,'EPSG','9110','EPSG','8802','Longitude of natural origin',170.1657,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99996,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17958','Bluff 2000',NULL,NULL,'EPSG','3800','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-46.36,'EPSG','9110','EPSG','8802','Longitude of natural origin',168.2034,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17959','Chatham Island Circuit 2000',NULL,NULL,'EPSG','2889','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-44.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-176.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17960','Auckland Islands Transverse Mercator 2000',NULL,NULL,'EPSG','3554','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',166.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',3500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17961','Campbell Island Transverse Mercator 2000',NULL,NULL,'EPSG','3555','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',169.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',3500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17962','Antipodes Islands Transverse Mercator 2000',NULL,NULL,'EPSG','3556','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',179.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',3500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17963','Raoul Island Transverse Mercator 2000',NULL,NULL,'EPSG','3557','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-178.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',3500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17964','New Zealand Continental Shelf Lambert Conformal 2000',NULL,NULL,'EPSG','3593','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-41.0,'EPSG','9110','EPSG','8822','Longitude of false origin',173.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',-37.3,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-44.3,'EPSG','9110','EPSG','8826','Easting at false origin',3000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',7000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17965','Chatham Islands Transverse Mercator 2000',NULL,NULL,'EPSG','2889','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-176.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',3500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','17966','Darwin Glacier Lambert Conformal 2000',NULL,NULL,'EPSG','3592','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-90.0,'EPSG','9110','EPSG','8822','Longitude of false origin',157.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',-76.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-79.2,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18001','Austria Gauss-Kruger West Zone',NULL,NULL,'EPSG','1706','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',28.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',-5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18002','Austria Gauss-Kruger Central Zone',NULL,NULL,'EPSG','1707','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',31.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',-5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18003','Austria Gauss-Kruger East Zone',NULL,NULL,'EPSG','1708','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',34.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',-5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18004','Austria Gauss-Kruger West',NULL,NULL,'EPSG','1706','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',10.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',-5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18005','Austria Gauss-Kruger Central',NULL,NULL,'EPSG','1707','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',13.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',-5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18006','Austria Gauss-Kruger East',NULL,NULL,'EPSG','1708','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',16.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',-5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18007','Austria Gauss-Kruger M28',NULL,NULL,'EPSG','1706','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',10.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',-5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18008','Austria Gauss-Kruger M31',NULL,NULL,'EPSG','1707','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',13.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',450000.0,'EPSG','9001','EPSG','8807','False northing',-5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18009','Austria Gauss-Kruger M34',NULL,NULL,'EPSG','1708','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',16.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',750000.0,'EPSG','9001','EPSG','8807','False northing',-5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18011','Nord Algerie (ancienne)',NULL,NULL,'EPSG','1728','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',3.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.999625544,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18012','Sud Algerie (ancienne)',NULL,NULL,'EPSG','1729','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',37.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',3.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.999625769,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18021','Nord Algerie',NULL,NULL,'EPSG','1728','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',3.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.999625544,'EPSG','9201','EPSG','8806','False easting',500135.0,'EPSG','9001','EPSG','8807','False northing',300090.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18022','Sud Algerie',NULL,NULL,'EPSG','1729','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',37.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',3.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.999625769,'EPSG','9201','EPSG','8806','False easting',500135.0,'EPSG','9001','EPSG','8807','False northing',300090.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18031','Argentina zone 1',NULL,NULL,'EPSG','1608','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-72.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18032','Argentina zone 2',NULL,NULL,'EPSG','1609','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-69.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',2500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18033','Argentina zone 3',NULL,NULL,'EPSG','1610','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-66.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',3500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18034','Argentina zone 4',NULL,NULL,'EPSG','1611','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-63.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',4500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18035','Argentina zone 5',NULL,NULL,'EPSG','1612','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-60.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',5500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18036','Argentina zone 6',NULL,NULL,'EPSG','1613','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-57.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',6500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18037','Argentina zone 7',NULL,NULL,'EPSG','1614','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-54.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',7500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18041','Austria West Zone',NULL,NULL,'EPSG','1706','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',28.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18042','Austria Central Zone',NULL,NULL,'EPSG','1707','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',31.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18043','Austria East Zone',NULL,NULL,'EPSG','1708','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',34.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18044','Austria M28',NULL,NULL,'EPSG','1706','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',10.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18045','Austria M31',NULL,NULL,'EPSG','1707','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',13.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',450000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18046','Austria M34',NULL,NULL,'EPSG','1708','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',16.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',750000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18047','Austria zone M28',NULL,NULL,'EPSG','1706','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',28.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18048','Austria zone M31',NULL,NULL,'EPSG','1707','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',31.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',450000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18049','Austria zone M34',NULL,NULL,'EPSG','1708','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',34.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',750000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18051','Colombia West zone',NULL,NULL,'EPSG','1598','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',4.355657,'EPSG','9110','EPSG','8802','Longitude of natural origin',-77.04513,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18052','Colombia Bogota zone',NULL,NULL,'EPSG','1599','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',4.355657,'EPSG','9110','EPSG','8802','Longitude of natural origin',-74.04513,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18053','Colombia East Central zone',NULL,NULL,'EPSG','1600','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',4.355657,'EPSG','9110','EPSG','8802','Longitude of natural origin',-71.04513,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18054','Colombia East zone',NULL,NULL,'EPSG','1601','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',4.355657,'EPSG','9110','EPSG','8802','Longitude of natural origin',-68.04513,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18055','Colombia MAGNA Far West zone',NULL,NULL,'EPSG','3091','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',4.35463215,'EPSG','9110','EPSG','8802','Longitude of natural origin',-80.04390285,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18056','Colombia MAGNA West zone',NULL,NULL,'EPSG','3090','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',4.35463215,'EPSG','9110','EPSG','8802','Longitude of natural origin',-77.04390285,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18057','Colombia MAGNA Bogota zone',NULL,NULL,'EPSG','1599','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',4.35463215,'EPSG','9110','EPSG','8802','Longitude of natural origin',-74.04390285,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18058','Colombia MAGNA East Central zone',NULL,NULL,'EPSG','1600','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',4.35463215,'EPSG','9110','EPSG','8802','Longitude of natural origin',-71.04390285,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18059','Colombia MAGNA East zone',NULL,NULL,'EPSG','1601','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',4.35463215,'EPSG','9110','EPSG','8802','Longitude of natural origin',-68.04390285,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18061','Cuba Norte',NULL,NULL,'EPSG','1487','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',22.21,'EPSG','9110','EPSG','8802','Longitude of natural origin',-81.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99993602,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',280296.016,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','18062','Cuba Sur',NULL,NULL,'EPSG','1488','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',20.43,'EPSG','9110','EPSG','8802','Longitude of natural origin',-76.5,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99994848,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',229126.939,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','18063','Cuba Norte',NULL,NULL,'EPSG','1487','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',22.21,'EPSG','9110','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',23.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',21.42,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',280296.016,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18064','Cuba Sur',NULL,NULL,'EPSG','1488','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',20.43,'EPSG','9110','EPSG','8822','Longitude of false origin',-76.5,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',21.18,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',20.08,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',229126.939,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18071','Egypt Blue Belt',NULL,NULL,'EPSG','1642','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',35.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',1100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18072','Egypt Red Belt',NULL,NULL,'EPSG','1643','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',31.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',615000.0,'EPSG','9001','EPSG','8807','False northing',810000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18073','Egypt Purple Belt',NULL,NULL,'EPSG','1644','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9001','EPSG','8807','False northing',200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18074','Egypt Extended Purple Belt',NULL,NULL,'EPSG','1645','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9001','EPSG','8807','False northing',1200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18081','Lambert zone I',NULL,NULL,'EPSG','1731','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',55.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.999877341,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',1200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18082','Lambert zone II',NULL,NULL,'EPSG','1734','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',52.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.99987742,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',2200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18083','Lambert zone III',NULL,NULL,'EPSG','1733','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.999877499,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',3200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18084','Lambert zone IV',NULL,NULL,'EPSG','1327','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.85,'EPSG','9105','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.99994471,'EPSG','9201','EPSG','8806','False easting',234.358,'EPSG','9001','EPSG','8807','False northing',4185861.369,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18085','Lambert-93',NULL,NULL,'EPSG','1326','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.3,'EPSG','9110','EPSG','8822','Longitude of false origin',3.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',49.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',44.0,'EPSG','9110','EPSG','8826','Easting at false origin',700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',6600000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18086','France EuroLambert',NULL,NULL,'EPSG','1326','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.48,'EPSG','9110','EPSG','8802','Longitude of natural origin',2.2014025,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99987742,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',2200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','18091','Lambert Nord France',NULL,NULL,'EPSG','1731','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',55.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.999877341,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18092','Lambert Centre France',NULL,NULL,'EPSG','1734','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',52.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.99987742,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18093','Lambert Sud France',NULL,NULL,'EPSG','1733','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.999877499,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18094','Lambert Corse',NULL,NULL,'EPSG','1327','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.85,'EPSG','9105','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.99994471,'EPSG','9201','EPSG','8806','False easting',234.358,'EPSG','9001','EPSG','8807','False northing',185861.369,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18101','France Conic Conformal zone 1',NULL,NULL,'EPSG','3545','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.0,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',41.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',42.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18102','France Conic Conformal zone 2',NULL,NULL,'EPSG','3546','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.0,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18103','France Conic Conformal zone 3',NULL,NULL,'EPSG','3547','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.0,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18104','France Conic Conformal zone 4',NULL,NULL,'EPSG','3548','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.0,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18105','France Conic Conformal zone 5',NULL,NULL,'EPSG','3549','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.0,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18106','France Conic Conformal zone 6',NULL,NULL,'EPSG','3550','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',6200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18107','France Conic Conformal zone 7',NULL,NULL,'EPSG','3551','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',48.0,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',7200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18108','France Conic Conformal zone 8',NULL,NULL,'EPSG','3552','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',49.0,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',48.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',49.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',8200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18109','France Conic Conformal zone 9',NULL,NULL,'EPSG','3553','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',50.0,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',49.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',50.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',9200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18110','India zone 0',NULL,NULL,'EPSG','1668','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',39.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',68.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99846154,'EPSG','9201','EPSG','8806','False easting',2355500.0,'EPSG','9084','EPSG','8807','False northing',2590000.0,'EPSG','9084',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18111','India zone I',NULL,NULL,'EPSG','1669','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',32.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',68.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99878641,'EPSG','9201','EPSG','8806','False easting',3000000.0,'EPSG','9084','EPSG','8807','False northing',1000000.0,'EPSG','9084',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18112','India zone IIa',NULL,NULL,'EPSG','1670','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',26.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',74.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99878641,'EPSG','9201','EPSG','8806','False easting',3000000.0,'EPSG','9084','EPSG','8807','False northing',1000000.0,'EPSG','9084',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18113','India zone IIb',NULL,NULL,'EPSG','1671','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',26.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',90.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99878641,'EPSG','9201','EPSG','8806','False easting',3000000.0,'EPSG','9084','EPSG','8807','False northing',1000000.0,'EPSG','9084',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18114','India zone IIIa',NULL,NULL,'EPSG','1672','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',19.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',80.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99878641,'EPSG','9201','EPSG','8806','False easting',3000000.0,'EPSG','9084','EPSG','8807','False northing',1000000.0,'EPSG','9084',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18115','India zone IIIb',NULL,NULL,'EPSG','2292','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',19.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',100.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99878641,'EPSG','9201','EPSG','8806','False easting',3000000.0,'EPSG','9084','EPSG','8807','False northing',1000000.0,'EPSG','9084',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18116','India zone IVa',NULL,NULL,'EPSG','1673','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',12.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',80.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99878641,'EPSG','9201','EPSG','8806','False easting',3000000.0,'EPSG','9084','EPSG','8807','False northing',1000000.0,'EPSG','9084',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18117','India zone IVb',NULL,NULL,'EPSG','2293','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',12.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',100.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99878641,'EPSG','9201','EPSG','8806','False easting',3000000.0,'EPSG','9084','EPSG','8807','False northing',1000000.0,'EPSG','9084',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18121','Italy zone 1',NULL,NULL,'EPSG','1718','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18122','Italy zone 2',NULL,NULL,'EPSG','1719','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',2520000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18131','Nord Maroc',NULL,NULL,'EPSG','1703','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',37.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',-6.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.999625769,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18132','Sud Maroc',NULL,NULL,'EPSG','2787','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',33.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',-6.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.999615596,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18133','Sahara',NULL,NULL,'EPSG','1705','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',29.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',-6.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1200000.0,'EPSG','9001','EPSG','8807','False northing',400000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','18134','Sahara Nord',NULL,NULL,'EPSG','2788','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',29.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',-6.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.999616304,'EPSG','9201','EPSG','8806','False easting',1200000.0,'EPSG','9001','EPSG','8807','False northing',400000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18135','Sahara Sud',NULL,NULL,'EPSG','2789','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',25.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',-6.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.999616437,'EPSG','9201','EPSG','8806','False easting',1500000.0,'EPSG','9001','EPSG','8807','False northing',400000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18141','New Zealand North Island National Grid',NULL,NULL,'EPSG','1500','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-39.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',175.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9040','EPSG','8807','False northing',400000.0,'EPSG','9040',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18142','New Zealand South Island National Grid',NULL,NULL,'EPSG','3344','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-44.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',171.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9040','EPSG','8807','False northing',500000.0,'EPSG','9040',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18151','Nigeria West Belt',NULL,NULL,'EPSG','1715','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',4.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',4.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99975,'EPSG','9201','EPSG','8806','False easting',230738.26,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18152','Nigeria Mid Belt',NULL,NULL,'EPSG','1714','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',4.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',8.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99975,'EPSG','9201','EPSG','8806','False easting',670553.98,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18153','Nigeria East Belt',NULL,NULL,'EPSG','1713','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',4.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',12.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99975,'EPSG','9201','EPSG','8806','False easting',1110369.7,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18161','Peru west zone',NULL,NULL,'EPSG','1753','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-6.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-80.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99983008,'EPSG','9201','EPSG','8806','False easting',222000.0,'EPSG','9001','EPSG','8807','False northing',1426834.743,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18162','Peru central zone',NULL,NULL,'EPSG','1752','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-9.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-76.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99932994,'EPSG','9201','EPSG','8806','False easting',720000.0,'EPSG','9001','EPSG','8807','False northing',1039979.159,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18163','Peru east zone',NULL,NULL,'EPSG','1751','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-9.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-70.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99952992,'EPSG','9201','EPSG','8806','False easting',1324000.0,'EPSG','9001','EPSG','8807','False northing',1040084.558,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18171','Philippines zone I',NULL,NULL,'EPSG','1698','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',117.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18172','Philippines zone II',NULL,NULL,'EPSG','1699','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',119.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18173','Philippines zone III',NULL,NULL,'EPSG','1700','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',121.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18174','Philippines zone IV',NULL,NULL,'EPSG','1701','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',123.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18175','Philippines zone V',NULL,NULL,'EPSG','1702','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',125.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18180','Finland zone 0',NULL,NULL,'EPSG','3092','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',18.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18181','Nord Tunisie',NULL,NULL,'EPSG','1619','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',11.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.999625544,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18182','Sud Tunisie',NULL,NULL,'EPSG','1620','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',37.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',11.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.999625769,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18183','Finland ETRS-GK19',NULL,NULL,'EPSG','3092','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',19.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18184','Finland ETRS-GK20',NULL,NULL,'EPSG','3093','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',20.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18185','Finland ETRS-GK21',NULL,NULL,'EPSG','3094','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18186','Finland ETRS-GK22',NULL,NULL,'EPSG','3095','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',22.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18187','Finland ETRS-GK23',NULL,NULL,'EPSG','3096','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',23.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18188','Finland ETRS-GK24',NULL,NULL,'EPSG','3097','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',24.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18189','Finland ETRS-GK25',NULL,NULL,'EPSG','3098','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',25.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18190','Finland ETRS-GK26',NULL,NULL,'EPSG','3099','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',26.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18191','Finland zone 1',NULL,NULL,'EPSG','1536','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18192','Finland zone 2',NULL,NULL,'EPSG','1537','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',24.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',2500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18193','Finland Uniform Coordinate System',NULL,NULL,'EPSG','1095','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',3500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18194','Finland zone 4',NULL,NULL,'EPSG','1539','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',30.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',4500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18195','Finland ETRS-GK27',NULL,NULL,'EPSG','3100','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18196','Finland ETRS-GK28',NULL,NULL,'EPSG','3101','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',28.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18197','Finland ETRS-GK29',NULL,NULL,'EPSG','3102','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',29.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18198','Finland ETRS-GK30',NULL,NULL,'EPSG','3103','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',30.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18199','Finland ETRS-GK31',NULL,NULL,'EPSG','3104','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',31.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18201','Palestine Grid',NULL,NULL,'EPSG','1356','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',31.4402749,'EPSG','9110','EPSG','8802','Longitude of natural origin',35.124349,'EPSG','9110','EPSG','8806','False easting',170251.555,'EPSG','9001','EPSG','8807','False northing',126867.909,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18202','Palestine Belt',NULL,NULL,'EPSG','1356','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.4402749,'EPSG','9110','EPSG','8802','Longitude of natural origin',35.124349,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',170251.555,'EPSG','9001','EPSG','8807','False northing',1126867.909,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18203','Israeli CS',NULL,NULL,'EPSG','2603','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',31.4402749,'EPSG','9110','EPSG','8802','Longitude of natural origin',35.124349,'EPSG','9110','EPSG','8806','False easting',170251.555,'EPSG','9001','EPSG','8807','False northing',1126867.909,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18204','Israeli TM',NULL,NULL,'EPSG','2603','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.4403817,'EPSG','9110','EPSG','8802','Longitude of natural origin',35.1216261,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0000067,'EPSG','9201','EPSG','8806','False easting',219529.584,'EPSG','9001','EPSG','8807','False northing',626907.39,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18205','Finland zone 5',NULL,NULL,'EPSG','3385','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',5500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18211','Guatemala Norte',NULL,NULL,'EPSG','2120','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',16.49,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99992226,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',292209.579,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18212','Guatemala Sur',NULL,NULL,'EPSG','2121','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',14.54,'EPSG','9110','EPSG','8802','Longitude of natural origin',-90.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99989906,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',325992.681,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18221','NGO zone I',NULL,NULL,'EPSG','1741','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-4.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18222','NGO zone II',NULL,NULL,'EPSG','1742','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-2.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18223','NGO zone III',NULL,NULL,'EPSG','1743','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18224','NGO zone IV',NULL,NULL,'EPSG','1744','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',2.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18225','NGO zone V',NULL,NULL,'EPSG','1745','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',6.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18226','NGO zone VI',NULL,NULL,'EPSG','1746','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',10.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18227','NGO zone VII',NULL,NULL,'EPSG','1747','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',14.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18228','NGO zone VIII',NULL,NULL,'EPSG','1748','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',18.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18231','India zone I (1975 metres)',NULL,NULL,'EPSG','1676','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',32.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',68.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99878641,'EPSG','9201','EPSG','8806','False easting',2743195.5,'EPSG','9001','EPSG','8807','False northing',914398.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18232','India zone IIa (1975 metres)',NULL,NULL,'EPSG','1677','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',26.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',74.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99878641,'EPSG','9201','EPSG','8806','False easting',2743195.5,'EPSG','9001','EPSG','8807','False northing',914398.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18233','India zone IIIa (1975 metres)',NULL,NULL,'EPSG','1672','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',19.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',80.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99878641,'EPSG','9201','EPSG','8806','False easting',2743195.5,'EPSG','9001','EPSG','8807','False northing',914398.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18234','India zone IVa (1975 metres)',NULL,NULL,'EPSG','1673','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',12.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',80.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99878641,'EPSG','9201','EPSG','8806','False easting',2743195.5,'EPSG','9001','EPSG','8807','False northing',914398.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18235','India zone IIb (1975 metres)',NULL,NULL,'EPSG','1678','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',26.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',90.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99878641,'EPSG','9201','EPSG','8806','False easting',2743195.5,'EPSG','9001','EPSG','8807','False northing',914398.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18236','India zone I (1962 metres)',NULL,NULL,'EPSG','1685','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',32.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',68.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99878641,'EPSG','9201','EPSG','8806','False easting',2743196.4,'EPSG','9001','EPSG','8807','False northing',914398.8,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18237','India zone IIa (1962 metres)',NULL,NULL,'EPSG','1686','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',26.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',74.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99878641,'EPSG','9201','EPSG','8806','False easting',2743196.4,'EPSG','9001','EPSG','8807','False northing',914398.8,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18238','India zone IIb (1937 metres)',NULL,NULL,'EPSG','3217','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',26.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',90.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99878641,'EPSG','9201','EPSG','8806','False easting',2743185.69,'EPSG','9001','EPSG','8807','False northing',914395.23,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18240','Libya zone 5',NULL,NULL,'EPSG','1470','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18241','Libya zone 6',NULL,NULL,'EPSG','1471','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',11.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18242','Libya zone 7',NULL,NULL,'EPSG','1472','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',13.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18243','Libya zone 8',NULL,NULL,'EPSG','1473','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18244','Libya zone 9',NULL,NULL,'EPSG','1474','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',17.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18245','Libya zone 10',NULL,NULL,'EPSG','1475','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',19.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18246','Libya zone 11',NULL,NULL,'EPSG','1476','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18247','Libya zone 12',NULL,NULL,'EPSG','1477','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',23.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18248','Libya zone 13',NULL,NULL,'EPSG','1478','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',25.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18251','Korea East Belt',NULL,NULL,'EPSG','3726','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',129.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18252','Korea Central Belt',NULL,NULL,'EPSG','3716','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',127.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18253','Korea West Belt',NULL,NULL,'EPSG','3713','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',125.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18260','Maracaibo Grid (M1)',NULL,NULL,'EPSG','1319','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',10.1,'EPSG','9110','EPSG','8802','Longitude of natural origin',-71.3620224,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',-52684.972,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18261','Maracaibo Grid',NULL,NULL,'EPSG','1319','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',10.1,'EPSG','9110','EPSG','8802','Longitude of natural origin',-71.3620224,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',147315.028,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18262','Maracaibo Grid (M3)',NULL,NULL,'EPSG','1319','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',10.1,'EPSG','9110','EPSG','8802','Longitude of natural origin',-71.3620224,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',447315.028,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18263','Maracaibo La Rosa Grid',NULL,NULL,'EPSG','1319','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',10.1,'EPSG','9110','EPSG','8802','Longitude of natural origin',-71.3620224,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',-17044.0,'EPSG','9001','EPSG','8807','False northing',-23139.97,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18275','Balkans zone 5',NULL,NULL,'EPSG','1709','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',5500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18276','Balkans zone 6',NULL,NULL,'EPSG','1710','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',18.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',6500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18277','Balkans zone 7',NULL,NULL,'EPSG','1711','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',7500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18278','Balkans zone 8',NULL,NULL,'EPSG','1712','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',24.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',8500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18280','Poland zone I',NULL,NULL,'EPSG','1515','EPSG','9809','Oblique Stereographic','EPSG','8801','Latitude of natural origin',50.373,'EPSG','9110','EPSG','8802','Longitude of natural origin',21.05,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9998,'EPSG','9201','EPSG','8806','False easting',4637000.0,'EPSG','9001','EPSG','8807','False northing',5467000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18281','Poland zone I',NULL,NULL,'EPSG','1515','EPSG','9809','Oblique Stereographic','EPSG','8801','Latitude of natural origin',50.373,'EPSG','9110','EPSG','8802','Longitude of natural origin',21.05,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9998,'EPSG','9201','EPSG','8806','False easting',4637000.0,'EPSG','9001','EPSG','8807','False northing',5647000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','18282','Poland zone II',NULL,NULL,'EPSG','1516','EPSG','9809','Oblique Stereographic','EPSG','8801','Latitude of natural origin',53.0007,'EPSG','9110','EPSG','8802','Longitude of natural origin',21.301,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9998,'EPSG','9201','EPSG','8806','False easting',4603000.0,'EPSG','9001','EPSG','8807','False northing',5806000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18283','Poland zone III',NULL,NULL,'EPSG','1517','EPSG','9809','Oblique Stereographic','EPSG','8801','Latitude of natural origin',53.35,'EPSG','9110','EPSG','8802','Longitude of natural origin',17.003,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9998,'EPSG','9201','EPSG','8806','False easting',3501000.0,'EPSG','9001','EPSG','8807','False northing',5999000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18284','Poland zone IV',NULL,NULL,'EPSG','1518','EPSG','9809','Oblique Stereographic','EPSG','8801','Latitude of natural origin',51.4015,'EPSG','9110','EPSG','8802','Longitude of natural origin',16.402,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9998,'EPSG','9201','EPSG','8806','False easting',3703000.0,'EPSG','9001','EPSG','8807','False northing',5627000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18285','Poland zone V',NULL,NULL,'EPSG','1519','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',18.573,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999983,'EPSG','9201','EPSG','8806','False easting',237000.0,'EPSG','9001','EPSG','8807','False northing',-4700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18286','GUGiK-80',NULL,NULL,'EPSG','1192','EPSG','9809','Oblique Stereographic','EPSG','8801','Latitude of natural origin',52.1,'EPSG','9110','EPSG','8802','Longitude of natural origin',19.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999714,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18300','Poland CS92',NULL,NULL,'EPSG','1192','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',19.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9993,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',-5300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18305','Poland CS2000 zone 5',NULL,NULL,'EPSG','1520','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999923,'EPSG','9201','EPSG','8806','False easting',5500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18306','Poland CS2000 zone 6',NULL,NULL,'EPSG','1521','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',18.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999923,'EPSG','9201','EPSG','8806','False easting',6500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18307','Poland CS2000 zone 7',NULL,NULL,'EPSG','1522','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999923,'EPSG','9201','EPSG','8806','False easting',7500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18308','Poland CS2000 zone 8',NULL,NULL,'EPSG','1523','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',24.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999923,'EPSG','9201','EPSG','8806','False easting',8500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18310','Libya TM zone 5',NULL,NULL,'EPSG','1470','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18311','Libya TM zone 6',NULL,NULL,'EPSG','1471','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',11.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18312','Libya TM zone 7',NULL,NULL,'EPSG','1472','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',13.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18313','Libya TM zone 8',NULL,NULL,'EPSG','1473','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18314','Libya TM zone 9',NULL,NULL,'EPSG','1474','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',17.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18315','Libya TM zone 10',NULL,NULL,'EPSG','1475','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',19.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18316','Libya TM zone 11',NULL,NULL,'EPSG','1476','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18317','Libya TM zone 12',NULL,NULL,'EPSG','1477','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',23.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18318','Libya TM zone 13',NULL,NULL,'EPSG','1478','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',25.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18319','Libya TM',NULL,NULL,'EPSG','1143','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',17.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9965,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18401','Kp2000 Jylland og Fyn',NULL,NULL,'EPSG','2531','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',9.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18402','Kp2000 Sjaelland',NULL,NULL,'EPSG','2532','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',12.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18403','Kp2000 Bornholm',NULL,NULL,'EPSG','2533','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',900000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18411','French West Africa Senegal zone',NULL,NULL,'EPSG','2548','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-13.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18412','French West Africa Ivory Coast zone',NULL,NULL,'EPSG','2549','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-6.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18413','French West Africa Dahomey zone',NULL,NULL,'EPSG','2550','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',0.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18414','French West Africa Niger zone',NULL,NULL,'EPSG','2551','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',7.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18415','French Equatorial Africa west zone',NULL,NULL,'EPSG','2552','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',10.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18416','French Equatorial Africa central zone',NULL,NULL,'EPSG','2553','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',17.4,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18417','French Equatorial Africa east zone',NULL,NULL,'EPSG','2554','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',24.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18421','Greenland zone 1 east',NULL,NULL,'EPSG','2556','EPSG','9826','Lambert Conic Conformal (West Orientated)','EPSG','8801','Latitude of natural origin',82.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-40.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18422','Greenland zone 2 east',NULL,NULL,'EPSG','2557','EPSG','9826','Lambert Conic Conformal (West Orientated)','EPSG','8801','Latitude of natural origin',79.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-24.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18423','Greenland zone 3 east',NULL,NULL,'EPSG','2558','EPSG','9826','Lambert Conic Conformal (West Orientated)','EPSG','8801','Latitude of natural origin',76.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-20.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18424','Greenland zone 4 east',NULL,NULL,'EPSG','2559','EPSG','9826','Lambert Conic Conformal (West Orientated)','EPSG','8801','Latitude of natural origin',73.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-24.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18425','Greenland zone 5 east',NULL,NULL,'EPSG','2560','EPSG','9826','Lambert Conic Conformal (West Orientated)','EPSG','8801','Latitude of natural origin',70.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-24.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18426','Greenland zone 6 east',NULL,NULL,'EPSG','2561','EPSG','9826','Lambert Conic Conformal (West Orientated)','EPSG','8801','Latitude of natural origin',67.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-32.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18427','Greenland zone 7 east',NULL,NULL,'EPSG','2562','EPSG','9826','Lambert Conic Conformal (West Orientated)','EPSG','8801','Latitude of natural origin',64.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-40.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18428','Greenland zone 8 east',NULL,NULL,'EPSG','2569','EPSG','9826','Lambert Conic Conformal (West Orientated)','EPSG','8801','Latitude of natural origin',61.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-48.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18432','Greenland zone 2 west',NULL,NULL,'EPSG','2563','EPSG','9826','Lambert Conic Conformal (West Orientated)','EPSG','8801','Latitude of natural origin',79.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-64.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18433','Greenland zone 3 west',NULL,NULL,'EPSG','2564','EPSG','9826','Lambert Conic Conformal (West Orientated)','EPSG','8801','Latitude of natural origin',76.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-64.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18434','Greenland zone 4 west',NULL,NULL,'EPSG','2565','EPSG','9826','Lambert Conic Conformal (West Orientated)','EPSG','8801','Latitude of natural origin',73.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-52.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18435','Greenland zone 5 west',NULL,NULL,'EPSG','2566','EPSG','9826','Lambert Conic Conformal (West Orientated)','EPSG','8801','Latitude of natural origin',70.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-52.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18436','Greenland zone 6 west',NULL,NULL,'EPSG','2567','EPSG','9826','Lambert Conic Conformal (West Orientated)','EPSG','8801','Latitude of natural origin',67.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-52.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18437','Greenland zone 7 west',NULL,NULL,'EPSG','2568','EPSG','9826','Lambert Conic Conformal (West Orientated)','EPSG','8801','Latitude of natural origin',64.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-52.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18441','CS63 zone A1',NULL,NULL,'EPSG','2772','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.07,'EPSG','9110','EPSG','8802','Longitude of natural origin',41.32,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18442','CS63 zone A2',NULL,NULL,'EPSG','2773','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.07,'EPSG','9110','EPSG','8802','Longitude of natural origin',44.32,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',2300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18443','CS63 zone A3',NULL,NULL,'EPSG','2774','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.07,'EPSG','9110','EPSG','8802','Longitude of natural origin',47.32,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',3300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18444','CS63 zone A4',NULL,NULL,'EPSG','2775','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.07,'EPSG','9110','EPSG','8802','Longitude of natural origin',50.32,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',4300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18446','CS63 zone K2',NULL,NULL,'EPSG','2776','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.08,'EPSG','9110','EPSG','8802','Longitude of natural origin',50.46,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',2300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18447','CS63 zone K3',NULL,NULL,'EPSG','2777','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.08,'EPSG','9110','EPSG','8802','Longitude of natural origin',53.46,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',3300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18448','CS63 zone K4',NULL,NULL,'EPSG','2778','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.08,'EPSG','9110','EPSG','8802','Longitude of natural origin',56.46,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',4300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18450','CS63 zone C0',NULL,NULL,'EPSG','3173','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.06,'EPSG','9110','EPSG','8802','Longitude of natural origin',21.57,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18451','CS63 zone C1',NULL,NULL,'EPSG','3174','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.06,'EPSG','9110','EPSG','8802','Longitude of natural origin',24.57,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1250000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','18452','CS63 zone C2',NULL,NULL,'EPSG','3175','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.06,'EPSG','9110','EPSG','8802','Longitude of natural origin',27.57,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',2250000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19839','Dubai Local Transverse Mercator',NULL,NULL,'EPSG','3531','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',55.2,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19840','IBCAO Polar Stereographic',NULL,NULL,'EPSG','1996','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',75.0,'EPSG','9102','EPSG','8833','Longitude of origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19841','Swiss Oblique Mercator 1903C (Greenwich)',NULL,NULL,'EPSG','1144','EPSG','9815','Hotine Oblique Mercator (variant B)','EPSG','8811','Latitude of projection centre',46.570866,'EPSG','9110','EPSG','8812','Longitude of projection centre',7.26225,'EPSG','9110','EPSG','8813','Azimuth of initial line',90.0,'EPSG','9110','EPSG','8814','Angle from Rectified to Skew Grid',90.0,'EPSG','9110','EPSG','8815','Scale factor on initial line',1.0,'EPSG','9201','EPSG','8816','Easting at projection centre',0.0,'EPSG','9001','EPSG','8817','Northing at projection centre',0.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','19842','Arctic Polar Stereographic',NULL,NULL,'EPSG','1996','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',71.0,'EPSG','9102','EPSG','8833','Longitude of origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19843','Mercator 41',NULL,NULL,'EPSG','3508','EPSG','9805','Mercator (variant B)','EPSG','8823','Latitude of 1st standard parallel',-41.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',100.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19844','Ministry of Transport of Quebec Lambert',NULL,NULL,'EPSG','1368','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-70.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',50.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.0,'EPSG','9102','EPSG','8826','Easting at false origin',800000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19845','Slovene National Grid',NULL,NULL,'EPSG','1212','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',-5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19846','World Equidistant Cylindrical',NULL,NULL,'EPSG','1262','EPSG','9842','Equidistant Cylindrical','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8822','Longitude of false origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','19847','Popular Visualisation Mercator',NULL,NULL,'EPSG','1262','EPSG','9841','Mercator (1SP) (Spherical)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','19848','Pitcairn TM 2006',NULL,NULL,'EPSG','3208','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-25.04067894,'EPSG','9110','EPSG','8802','Longitude of natural origin',-130.06466816,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',14200.0,'EPSG','9001','EPSG','8807','False northing',15500.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19849','Bermuda 2000 National Grid',NULL,NULL,'EPSG','1047','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',32.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-64.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',550000.0,'EPSG','9001','EPSG','8807','False northing',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19850','EPSG vertical perspective example',NULL,NULL,'EPSG','1263','EPSG','9838','Vertical Perspective','EPSG','8834','Latitude of topocentric origin',55.0,'EPSG','9102','EPSG','8835','Longitude of topocentric origin',5.0,'EPSG','9102','EPSG','8836','Ellipsoidal height of topocentric origin',200.0,'EPSG','9001','EPSG','8840','Viewpoint height',5900.0,'EPSG','9036',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19851','Croatia Transverse Mercator',NULL,NULL,'EPSG','1076','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',16.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19852','Croatia Lambert Conformal Conic',NULL,NULL,'EPSG','1076','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',0.0,'EPSG','9102','EPSG','8822','Longitude of false origin',16.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',45.55,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',43.05,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19853','Portugual TM06',NULL,NULL,'EPSG','1294','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.400573,'EPSG','9110','EPSG','8802','Longitude of natural origin',-8.075919,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19854','South Georgia Lambert',NULL,NULL,'EPSG','3529','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-55.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-37.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-54.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-54.45,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19855','Mercator 41',NULL,NULL,'EPSG','3508','EPSG','9804','Mercator (variant A)','EPSG','8801','Latitude of natural origin',-41.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',100.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','19856','TM Reunion',NULL,NULL,'EPSG','3337','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-21.07,'EPSG','9110','EPSG','8802','Longitude of natural origin',55.32,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',160000.0,'EPSG','9001','EPSG','8807','False northing',50000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19857','Northwest Territories Lambert',NULL,NULL,'EPSG','3481','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',0.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-112.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',62.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',70.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19858','Yukon Albers',NULL,NULL,'EPSG','2417','EPSG','9822','Albers Equal Area','EPSG','8821','Latitude of false origin',59.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-132.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',61.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',68.0,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19859','Fiji Map Grid',NULL,NULL,'EPSG','1094','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-17.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',178.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99985,'EPSG','9201','EPSG','8806','False easting',2000000.0,'EPSG','9001','EPSG','8807','False northing',4000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19860','Jamaica Metric Grid 2001',NULL,NULL,'EPSG','3342','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',18.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-77.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',750000.0,'EPSG','9001','EPSG','8807','False northing',650000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19861','Laborde Grid',NULL,NULL,'EPSG','1149','EPSG','9813','Laborde Oblique Mercator','EPSG','8811','Latitude of projection centre',-21.0,'EPSG','9105','EPSG','8812','Longitude of projection centre',49.0,'EPSG','9105','EPSG','8813','Azimuth of initial line',21.0,'EPSG','9105','EPSG','8815','Scale factor on initial line',0.9995,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19862','Belgian Lambert 2005',NULL,NULL,'EPSG','1347','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',50.4752134,'EPSG','9110','EPSG','8822','Longitude of false origin',4.2133177,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',49.5,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',51.1,'EPSG','9110','EPSG','8826','Easting at false origin',150328.0,'EPSG','9001','EPSG','8827','Northing at false origin',166262.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19863','South China Sea Lambert',NULL,NULL,'EPSG','3470','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',21.0,'EPSG','9102','EPSG','8822','Longitude of false origin',114.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',18.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',24.0,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19864','Singapore Transverse Mercator',NULL,NULL,'EPSG','1210','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',1.22,'EPSG','9110','EPSG','8802','Longitude of natural origin',103.5,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',28001.642,'EPSG','9001','EPSG','8807','False northing',38744.572,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19865','US NSIDC Sea Ice polar stereographic north',NULL,NULL,'EPSG','1996','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',70.0,'EPSG','9102','EPSG','8833','Longitude of origin',-45.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19866','US NSIDC Sea Ice polar stereographic south',NULL,NULL,'EPSG','1997','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-70.0,'EPSG','9102','EPSG','8833','Longitude of origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19867','US NSIDC Equal Area north projection',NULL,NULL,'EPSG','1996','EPSG','9821','Lambert Azimuthal Equal Area (Spherical)','EPSG','8828','Spherical latitude of origin',90.0,'EPSG','9102','EPSG','8829','Spherical longitude of origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','19868','US NSIDC Equal Area south projection',NULL,NULL,'EPSG','1997','EPSG','9821','Lambert Azimuthal Equal Area (Spherical)','EPSG','8828','Spherical latitude of origin',-90.0,'EPSG','9102','EPSG','8829','Spherical longitude of origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','19869','US NSIDC Equal Area global projection',NULL,NULL,'EPSG','3463','EPSG','9834','Lambert Cylindrical Equal Area (Spherical)','EPSG','8823','Latitude of 1st standard parallel',30.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19870','Faroe Lambert',NULL,NULL,'EPSG','3248','EPSG','9826','Lambert Conic Conformal (West Orientated)','EPSG','8801','Latitude of natural origin',62.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19871','Rectified Skew Orthomorphic Malaya Grid (chains)',NULL,NULL,'EPSG','1690','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',4.0,'EPSG','9110','EPSG','8812','Longitude of projection centre',102.15,'EPSG','9110','EPSG','8813','Azimuth of initial line',323.01328458,'EPSG','9110','EPSG','8814','Angle from Rectified to Skew Grid',323.07483685,'EPSG','9110','EPSG','8815','Scale factor on initial line',0.99984,'EPSG','9201','EPSG','8806','False easting',40000.0,'EPSG','9301','EPSG','8807','False northing',0.0,'EPSG','9301',0);
INSERT INTO "conversion" VALUES('EPSG','19872','Rectified Skew Orthomorphic Malaya Grid (metres)',NULL,NULL,'EPSG','1690','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',4.0,'EPSG','9110','EPSG','8812','Longitude of projection centre',102.15,'EPSG','9110','EPSG','8813','Azimuth of initial line',323.01328458,'EPSG','9110','EPSG','8814','Angle from Rectified to Skew Grid',323.07483685,'EPSG','9110','EPSG','8815','Scale factor on initial line',0.99984,'EPSG','9201','EPSG','8806','False easting',804670.24,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','19873','Noumea Lambert',NULL,NULL,'EPSG','2823','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-22.16108903,'EPSG','9110','EPSG','8822','Longitude of false origin',166.26327327,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',-22.14408903,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-22.17408903,'EPSG','9110','EPSG','8826','Easting at false origin',0.66,'EPSG','9001','EPSG','8827','Northing at false origin',1.02,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19874','Noumea Lambert 2',NULL,NULL,'EPSG','2823','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-22.1611,'EPSG','9110','EPSG','8822','Longitude of false origin',166.2633,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',-22.1441,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-22.1741,'EPSG','9110','EPSG','8826','Easting at false origin',8.313,'EPSG','9001','EPSG','8827','Northing at false origin',-2.354,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19875','Ontario MNR Lambert',NULL,NULL,'EPSG','1367','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',0.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-85.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',53.5,'EPSG','9102','EPSG','8826','Easting at false origin',930000.0,'EPSG','9001','EPSG','8827','Northing at false origin',6430000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19876','ST74',NULL,NULL,'EPSG','3408','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',18.0328044,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99999425,'EPSG','9201','EPSG','8806','False easting',100178.1808,'EPSG','9001','EPSG','8807','False northing',-6500614.7836,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19877','Faroe Lambert fk89',NULL,NULL,'EPSG','3248','EPSG','9826','Lambert Conic Conformal (West Orientated)','EPSG','8801','Latitude of natural origin',62.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9001','EPSG','8807','False northing',700000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19878','Vanua Levu Grid',NULL,NULL,'EPSG','3401','EPSG','9833','Hyperbolic Cassini-Soldner','EPSG','8801','Latitude of natural origin',-16.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',179.2,'EPSG','9110','EPSG','8806','False easting',1251331.8,'EPSG','9098','EPSG','8807','False northing',1662888.5,'EPSG','9098',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19879','Viti Levu Grid',NULL,NULL,'EPSG','3195','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',-18.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',178.0,'EPSG','9102','EPSG','8806','False easting',544000.0,'EPSG','9098','EPSG','8807','False northing',704000.0,'EPSG','9098',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19880','Fiji Map Grid',NULL,NULL,'EPSG','1094','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-17.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',178.45,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99985,'EPSG','9001','EPSG','8806','False easting',2000000.0,'EPSG','9001','EPSG','8807','False northing',4000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','19881','Alberta 10-degree TM (Forest)',NULL,NULL,'EPSG','2376','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-115.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9992,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19882','Alberta 10-degree TM (Resource)',NULL,NULL,'EPSG','2376','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-115.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9992,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19883','World Mercator',NULL,NULL,'EPSG','3391','EPSG','9804','Mercator (variant A)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19884','Caspian Sea Mercator',NULL,NULL,'EPSG','1291','EPSG','9805','Mercator (variant B)','EPSG','8823','Latitude of 1st standard parallel',42.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',51.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19885','Kelantan Grid',NULL,NULL,'EPSG','3384','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',5.582115717,'EPSG','9110','EPSG','8802','Longitude of natural origin',102.174287001,'EPSG','9110','EPSG','8806','False easting',13227.851,'EPSG','9001','EPSG','8807','False northing',8739.894,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19886','Perak Grid',NULL,NULL,'EPSG','3383','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',4.513262688,'EPSG','9110','EPSG','8802','Longitude of natural origin',100.485547811,'EPSG','9110','EPSG','8806','False easting',-1.769,'EPSG','9001','EPSG','8807','False northing',133454.779,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19887','Kedah and Perlis Grid',NULL,NULL,'EPSG','3382','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',5.575282177,'EPSG','9110','EPSG','8802','Longitude of natural origin',100.3810936,'EPSG','9110','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19888','Pinang Grid',NULL,NULL,'EPSG','3381','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',5.251746315,'EPSG','9110','EPSG','8802','Longitude of natural origin',100.203975707,'EPSG','9110','EPSG','8806','False easting',-23.414,'EPSG','9001','EPSG','8807','False northing',62.283,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19889','Terengganu Grid',NULL,NULL,'EPSG','3380','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',4.583462672,'EPSG','9110','EPSG','8802','Longitude of natural origin',103.041299225,'EPSG','9110','EPSG','8806','False easting',19594.245,'EPSG','9001','EPSG','8807','False northing',3371.895,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19890','Selangor Grid',NULL,NULL,'EPSG','3379','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',3.410473658,'EPSG','9110','EPSG','8802','Longitude of natural origin',101.232078849,'EPSG','9110','EPSG','8806','False easting',-34836.161,'EPSG','9001','EPSG','8807','False northing',56464.049,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19891','Pahang Grid',NULL,NULL,'EPSG','3378','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',3.460979712,'EPSG','9110','EPSG','8802','Longitude of natural origin',102.220587634,'EPSG','9110','EPSG','8806','False easting',-7368.228,'EPSG','9001','EPSG','8807','False northing',6485.858,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19892','Sembilan and Melaka Grid',NULL,NULL,'EPSG','3377','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',2.405645149,'EPSG','9110','EPSG','8802','Longitude of natural origin',101.582965815,'EPSG','9110','EPSG','8806','False easting',3673.785,'EPSG','9001','EPSG','8807','False northing',-4240.573,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19893','Johor Grid',NULL,NULL,'EPSG','3376','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',2.071804708,'EPSG','9110','EPSG','8802','Longitude of natural origin',103.254057045,'EPSG','9110','EPSG','8806','False easting',-14810.562,'EPSG','9001','EPSG','8807','False northing',8758.32,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19894','Borneo RSO',NULL,NULL,'EPSG','1362','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',4.0,'EPSG','9110','EPSG','8812','Longitude of projection centre',115.0,'EPSG','9110','EPSG','8813','Azimuth of initial line',53.185691582,'EPSG','9110','EPSG','8814','Angle from Rectified to Skew Grid',53.07483685,'EPSG','9110','EPSG','8815','Scale factor on initial line',0.99984,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','19895','Peninsular RSO',NULL,NULL,'EPSG','3955','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',4.0,'EPSG','9110','EPSG','8812','Longitude of projection centre',102.15,'EPSG','9110','EPSG','8813','Azimuth of initial line',323.013286728,'EPSG','9110','EPSG','8814','Angle from Rectified to Skew Grid',323.07483685,'EPSG','9110','EPSG','8815','Scale factor on initial line',0.99984,'EPSG','9201','EPSG','8806','False easting',804671.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','19896','Hong Kong 1963 Grid',NULL,NULL,'EPSG','1118','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',22.184368,'EPSG','9110','EPSG','8802','Longitude of natural origin',114.10428,'EPSG','9110','EPSG','8806','False easting',132033.92,'EPSG','9005','EPSG','8807','False northing',62565.96,'EPSG','9005',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19897','Statistics Canada Lambert',NULL,NULL,'EPSG','1061','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',63.390675,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.52,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',49.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9102','EPSG','8826','Easting at false origin',6200000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19898','Pacific Disaster Center Mercator',NULL,NULL,'EPSG','3172','EPSG','9804','Mercator (variant A)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-150.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','19899','Mauritius Grid',NULL,NULL,'EPSG','3209','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',-20.114225,'EPSG','9110','EPSG','8802','Longitude of natural origin',57.311858,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19900','Bahrain State Grid',NULL,NULL,'EPSG','1040','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',51.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19901','Belge Lambert 50',NULL,NULL,'EPSG','1347','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',90.0,'EPSG','9110','EPSG','8822','Longitude of false origin',0.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',49.5,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',51.1,'EPSG','9110','EPSG','8826','Easting at false origin',150000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5400000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19902','Belge Lambert 72',NULL,NULL,'EPSG','1347','EPSG','9803','Lambert Conic Conformal (2SP Belgium)','EPSG','8821','Latitude of false origin',90.0,'EPSG','9110','EPSG','8822','Longitude of false origin',4.2124983,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',49.5,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',51.1,'EPSG','9110','EPSG','8826','Easting at false origin',150000.01256,'EPSG','9001','EPSG','8827','Northing at false origin',5400088.4378,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19903','Nord de Guerre',NULL,NULL,'EPSG','1369','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',55.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',6.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.99950908,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19904','Ghana Metre Grid',NULL,NULL,'EPSG','1104','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',4.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-1.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99975,'EPSG','9201','EPSG','8806','False easting',274319.51,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19905','Netherlands East Indies Equatorial Zone',NULL,NULL,'EPSG','4020','EPSG','9804','Mercator (variant A)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',110.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.997,'EPSG','9201','EPSG','8806','False easting',3900000.0,'EPSG','9001','EPSG','8807','False northing',900000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19906','Iraq zone',NULL,NULL,'EPSG','2294','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',32.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',45.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9987864078,'EPSG','9201','EPSG','8806','False easting',1500000.0,'EPSG','9001','EPSG','8807','False northing',1166200.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19907','Iraq National Grid',NULL,NULL,'EPSG','3625','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',29.0134566,'EPSG','9110','EPSG','8802','Longitude of natural origin',46.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9994,'EPSG','9201','EPSG','8806','False easting',800000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19908','Irish National Grid',NULL,NULL,'EPSG','1305','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',53.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-8.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000035,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',250000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','19909','Jamaica (Old Grid)',NULL,NULL,'EPSG','3342','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',18.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-77.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',550000.0,'EPSG','9005','EPSG','8807','False northing',400000.0,'EPSG','9005',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19910','Jamaica National Grid',NULL,NULL,'EPSG','3342','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',18.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-77.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',150000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19911','Laborde Grid approximation',NULL,NULL,'EPSG','1149','EPSG','9815','Hotine Oblique Mercator (variant B)','EPSG','8811','Latitude of projection centre',-21.0,'EPSG','9105','EPSG','8812','Longitude of projection centre',49.0,'EPSG','9105','EPSG','8813','Azimuth of initial line',21.0,'EPSG','9105','EPSG','8814','Angle from Rectified to Skew Grid',21.0,'EPSG','9105','EPSG','8815','Scale factor on initial line',0.9995,'EPSG','9201','EPSG','8816','Easting at projection centre',400000.0,'EPSG','9001','EPSG','8817','Northing at projection centre',800000.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','19913','RD Old',NULL,NULL,'EPSG','1275','EPSG','9809','Oblique Stereographic','EPSG','8801','Latitude of natural origin',52.0922178,'EPSG','9110','EPSG','8802','Longitude of natural origin',5.23155,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999079,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19914','RD New',NULL,NULL,'EPSG','1275','EPSG','9809','Oblique Stereographic','EPSG','8801','Latitude of natural origin',52.0922178,'EPSG','9110','EPSG','8802','Longitude of natural origin',5.23155,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999079,'EPSG','9201','EPSG','8806','False easting',155000.0,'EPSG','9001','EPSG','8807','False northing',463000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19915','Aden Zone',NULL,NULL,'EPSG','3332','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',15.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999365678,'EPSG','9201','EPSG','8806','False easting',1500000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19916','British National Grid',NULL,NULL,'EPSG','4390','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996012717,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',-100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19917','New Zealand Map Grid',NULL,NULL,'EPSG','3973','EPSG','9811','New Zealand Map Grid','EPSG','8801','Latitude of natural origin',-41.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',173.0,'EPSG','9102','EPSG','8806','False easting',2510000.0,'EPSG','9001','EPSG','8807','False northing',6023150.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19919','Qatar National Grid',NULL,NULL,'EPSG','1195','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',24.27,'EPSG','9110','EPSG','8802','Longitude of natural origin',51.13,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19920','Singapore Grid',NULL,NULL,'EPSG','1210','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',1.1715528,'EPSG','9110','EPSG','8802','Longitude of natural origin',103.5110808,'EPSG','9110','EPSG','8806','False easting',30000.0,'EPSG','9001','EPSG','8807','False northing',30000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19921','Spain',NULL,NULL,'EPSG','2366','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9988085293,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',600000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19922','Swiss Oblique Mercator 1903M',NULL,NULL,'EPSG','1286','EPSG','9815','Hotine Oblique Mercator (variant B)','EPSG','8811','Latitude of projection centre',46.570866,'EPSG','9110','EPSG','8812','Longitude of projection centre',7.26225,'EPSG','9110','EPSG','8813','Azimuth of initial line',90.0,'EPSG','9110','EPSG','8814','Angle from Rectified to Skew Grid',90.0,'EPSG','9110','EPSG','8815','Scale factor on initial line',1.0,'EPSG','9201','EPSG','8816','Easting at projection centre',600000.0,'EPSG','9001','EPSG','8817','Northing at projection centre',200000.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','19923','Swiss Oblique Mercator 1903C',NULL,NULL,'EPSG','1286','EPSG','9815','Hotine Oblique Mercator (variant B)','EPSG','8811','Latitude of projection centre',46.570866,'EPSG','9110','EPSG','8812','Longitude of projection centre',0.0,'EPSG','9110','EPSG','8813','Azimuth of initial line',90.0,'EPSG','9110','EPSG','8814','Angle from Rectified to Skew Grid',90.0,'EPSG','9110','EPSG','8815','Scale factor on initial line',1.0,'EPSG','9201','EPSG','8816','Easting at projection centre',0.0,'EPSG','9001','EPSG','8817','Northing at projection centre',0.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','19924','Tobago Grid',NULL,NULL,'EPSG','1322','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',11.1507843,'EPSG','9110','EPSG','8802','Longitude of natural origin',-60.4109632,'EPSG','9110','EPSG','8806','False easting',187500.0,'EPSG','9039','EPSG','8807','False northing',180000.0,'EPSG','9039',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19925','Trinidad Grid',NULL,NULL,'EPSG','1339','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',10.263,'EPSG','9110','EPSG','8802','Longitude of natural origin',-61.2,'EPSG','9110','EPSG','8806','False easting',430000.0,'EPSG','9039','EPSG','8807','False northing',325000.0,'EPSG','9039',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19926','Stereo 70',NULL,NULL,'EPSG','1197','EPSG','9809','Oblique Stereographic','EPSG','8801','Latitude of natural origin',46.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',25.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99975,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19927','Stereo 33',NULL,NULL,'EPSG','1197','EPSG','9809','Oblique Stereographic','EPSG','8801','Latitude of natural origin',45.54,'EPSG','9110','EPSG','8802','Longitude of natural origin',25.23328772,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9996667,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19928','Kuwait TM',NULL,NULL,'EPSG','1310','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',48.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','19929','Sweden zone 2.5 gon V',NULL,NULL,'EPSG','2847','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',15.48298,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19930','Greek Grid',NULL,NULL,'EPSG','3254','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',24.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19931','Egyseges Orszagos Vetuleti',NULL,NULL,'EPSG','1119','EPSG','9815','Hotine Oblique Mercator (variant B)','EPSG','8811','Latitude of projection centre',47.08398174,'EPSG','9110','EPSG','8812','Longitude of projection centre',19.02548584,'EPSG','9110','EPSG','8813','Azimuth of initial line',90.0,'EPSG','9110','EPSG','8814','Angle from Rectified to Skew Grid',90.0,'EPSG','9110','EPSG','8815','Scale factor on initial line',0.99993,'EPSG','9201','EPSG','8816','Easting at projection centre',650000.0,'EPSG','9001','EPSG','8817','Northing at projection centre',200000.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','19933','Prince Edward Island Stereographic (ATS77)',NULL,NULL,'EPSG','1533','EPSG','9809','Oblique Stereographic','EPSG','8801','Latitude of natural origin',47.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-63.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999912,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9001','EPSG','8807','False northing',400000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19934','Lithuania 1994',NULL,NULL,'EPSG','1145','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',24.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9998,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19935','Rectified Skew Orthomorphic Malaya Grid',NULL,NULL,'EPSG','1690','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',4.0,'EPSG','9110','EPSG','8812','Longitude of projection centre',102.15,'EPSG','9110','EPSG','8813','Azimuth of initial line',323.01328458,'EPSG','9110','EPSG','8814','Angle from Rectified to Skew Grid',323.07483685,'EPSG','9110','EPSG','8815','Scale factor on initial line',0.99984,'EPSG','9201','EPSG','8806','False easting',40000.0,'EPSG','9062','EPSG','8807','False northing',0.0,'EPSG','9062',1);
INSERT INTO "conversion" VALUES('EPSG','19936','Portuguese National Grid',NULL,NULL,'EPSG','1294','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',1.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19937','Tunisia Mining Grid',NULL,NULL,'EPSG','1618','EPSG','9816','Tunisia Mining Grid','EPSG','8821','Latitude of false origin',36.5964,'EPSG','9105','EPSG','8822','Longitude of false origin',7.83445,'EPSG','9105','EPSG','8826','Easting at false origin',270.0,'EPSG','9036','EPSG','8827','Northing at false origin',360.0,'EPSG','9036',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19938','Estonian National Grid',NULL,NULL,'EPSG','1090','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',57.310319415,'EPSG','9110','EPSG','8822','Longitude of false origin',24.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',59.2,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',58.0,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',6375000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19939','TM Baltic 93',NULL,NULL,'EPSG','1646','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',24.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19940','Levant Zone',NULL,NULL,'EPSG','1623','EPSG','9817','Lambert Conic Near-Conformal','EPSG','8801','Latitude of natural origin',34.39,'EPSG','9110','EPSG','8802','Longitude of natural origin',37.21,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9996256,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19941','Brazil Polyconic',NULL,NULL,'EPSG','1053','EPSG','9818','American Polyconic','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-54.0,'EPSG','9102','EPSG','8806','False easting',5000000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19942','British West Indies Grid',NULL,NULL,'EPSG','2295','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-62.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9995,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19943','Barbados National Grid',NULL,NULL,'EPSG','3218','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',13.1035,'EPSG','9110','EPSG','8802','Longitude of natural origin',-59.3335,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999986,'EPSG','9201','EPSG','8806','False easting',30000.0,'EPSG','9001','EPSG','8807','False northing',75000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19944','Quebec Lambert Projection',NULL,NULL,'EPSG','1368','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-68.3,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',60.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',46.0,'EPSG','9110','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19945','New Brunswick Stereographic (ATS77)',NULL,NULL,'EPSG','1447','EPSG','9809','Oblique Stereographic','EPSG','8801','Latitude of natural origin',46.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-66.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999912,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19946','New Brunswick Stereographic (NAD83)',NULL,NULL,'EPSG','1447','EPSG','9809','Oblique Stereographic','EPSG','8801','Latitude of natural origin',46.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-66.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999912,'EPSG','9201','EPSG','8806','False easting',2500000.0,'EPSG','9001','EPSG','8807','False northing',7500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19947','Austria Lambert',NULL,NULL,'EPSG','1037','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.3,'EPSG','9110','EPSG','8822','Longitude of false origin',13.2,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',49.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',46.0,'EPSG','9110','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',400000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19948','Syria Lambert',NULL,NULL,'EPSG','1623','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',34.39,'EPSG','9110','EPSG','8802','Longitude of natural origin',37.21,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9996256,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19949','Levant Stereographic',NULL,NULL,'EPSG','1623','EPSG','9809','Oblique Stereographic','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',43.5,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.9995341,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19950','Swiss Oblique Mercator 1995',NULL,NULL,'EPSG','1286','EPSG','9815','Hotine Oblique Mercator (variant B)','EPSG','8811','Latitude of projection centre',46.570866,'EPSG','9110','EPSG','8812','Longitude of projection centre',7.26225,'EPSG','9110','EPSG','8813','Azimuth of initial line',90.0,'EPSG','9110','EPSG','8814','Angle from Rectified to Skew Grid',90.0,'EPSG','9110','EPSG','8815','Scale factor on initial line',1.0,'EPSG','9201','EPSG','8816','Easting at projection centre',2600000.0,'EPSG','9001','EPSG','8817','Northing at projection centre',1200000.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','19951','Nakhl e Taqi Oblique Mercator',NULL,NULL,'EPSG','1338','EPSG','9815','Hotine Oblique Mercator (variant B)','EPSG','8811','Latitude of projection centre',27.31077837,'EPSG','9110','EPSG','8812','Longitude of projection centre',52.3612741,'EPSG','9110','EPSG','8813','Azimuth of initial line',0.34179803,'EPSG','9110','EPSG','8814','Angle from Rectified to Skew Grid',0.34179803,'EPSG','9110','EPSG','8815','Scale factor on initial line',0.999895934,'EPSG','9201','EPSG','8816','Easting at projection centre',658377.437,'EPSG','9001','EPSG','8817','Northing at projection centre',3044969.194,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','19952','Krovak',NULL,NULL,'EPSG','1306','EPSG','9819','Krovak','EPSG','8811','Latitude of projection centre',49.3,'EPSG','9110','EPSG','8833','Longitude of origin',42.3,'EPSG','9110','EPSG','1036','Co-latitude of cone axis',30.171730311,'EPSG','9110','EPSG','8818','Latitude of pseudo standard parallel',78.3,'EPSG','9110','EPSG','8819','Scale factor on pseudo standard parallel',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','19953','Qatar Grid',NULL,NULL,'EPSG','1346','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',25.22565,'EPSG','9110','EPSG','8802','Longitude of natural origin',50.4541,'EPSG','9110','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19954','Suriname Old TM',NULL,NULL,'EPSG','1222','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-55.41,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19955','Suriname TM',NULL,NULL,'EPSG','1222','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-55.41,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19956','Rectified Skew Orthomorphic Borneo Grid (chains)',NULL,NULL,'EPSG','1362','EPSG','9815','Hotine Oblique Mercator (variant B)','EPSG','8811','Latitude of projection centre',4.0,'EPSG','9110','EPSG','8812','Longitude of projection centre',115.0,'EPSG','9110','EPSG','8813','Azimuth of initial line',53.18569537,'EPSG','9110','EPSG','8814','Angle from Rectified to Skew Grid',53.07483685,'EPSG','9110','EPSG','8815','Scale factor on initial line',0.99984,'EPSG','9201','EPSG','8816','Easting at projection centre',29352.4763,'EPSG','9042','EPSG','8817','Northing at projection centre',22014.3572,'EPSG','9042',0);
INSERT INTO "conversion" VALUES('EPSG','19957','Rectified Skew Orthomorphic Borneo Grid (feet)',NULL,NULL,'EPSG','1851','EPSG','9815','Hotine Oblique Mercator (variant B)','EPSG','8811','Latitude of projection centre',4.0,'EPSG','9110','EPSG','8812','Longitude of projection centre',115.0,'EPSG','9110','EPSG','8813','Azimuth of initial line',53.18569537,'EPSG','9110','EPSG','8814','Angle from Rectified to Skew Grid',53.07483685,'EPSG','9110','EPSG','8815','Scale factor on initial line',0.99984,'EPSG','9201','EPSG','8816','Easting at projection centre',1937263.44,'EPSG','9041','EPSG','8817','Northing at projection centre',1452947.58,'EPSG','9041',0);
INSERT INTO "conversion" VALUES('EPSG','19958','Rectified Skew Orthomorphic Borneo Grid (metres)',NULL,NULL,'EPSG','1362','EPSG','9815','Hotine Oblique Mercator (variant B)','EPSG','8811','Latitude of projection centre',4.0,'EPSG','9110','EPSG','8812','Longitude of projection centre',115.0,'EPSG','9110','EPSG','8813','Azimuth of initial line',53.18569537,'EPSG','9110','EPSG','8814','Angle from Rectified to Skew Grid',53.07483685,'EPSG','9110','EPSG','8815','Scale factor on initial line',0.99984,'EPSG','9201','EPSG','8816','Easting at projection centre',590476.87,'EPSG','9001','EPSG','8817','Northing at projection centre',442857.65,'EPSG','9001',0);
INSERT INTO "conversion" VALUES('EPSG','19959','Ghana National Grid',NULL,NULL,'EPSG','1104','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',4.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-1.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99975,'EPSG','9201','EPSG','8806','False easting',900000.0,'EPSG','9094','EPSG','8807','False northing',0.0,'EPSG','9094',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19960','Prince Edward Isl. Stereographic (NAD83)',NULL,NULL,'EPSG','1533','EPSG','9809','Oblique Stereographic','EPSG','8801','Latitude of natural origin',47.15,'EPSG','9110','EPSG','8802','Longitude of natural origin',-63.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999912,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19961','Belgian Lambert 72',NULL,NULL,'EPSG','1347','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',90.0,'EPSG','9110','EPSG','8822','Longitude of false origin',4.2202952,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',51.100000204,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',49.500000204,'EPSG','9110','EPSG','8826','Easting at false origin',150000.013,'EPSG','9001','EPSG','8827','Northing at false origin',5400088.438,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19962','Irish Transverse Mercator',NULL,NULL,'EPSG','1305','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',53.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-8.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.99982,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',750000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19963','Sierra Leone New Colony Grid',NULL,NULL,'EPSG','1342','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',6.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-12.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9094','EPSG','8807','False northing',0.0,'EPSG','9094',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19964','New War Office Sierra Leone Grid',NULL,NULL,'EPSG','1342','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',6.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-12.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',800000.0,'EPSG','9094','EPSG','8807','False northing',600000.0,'EPSG','9094',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19965','US National Atlas Equal Area',NULL,NULL,'EPSG','1245','EPSG','9821','Lambert Azimuthal Equal Area (Spherical)','EPSG','8828','Spherical latitude of origin',45.0,'EPSG','9102','EPSG','8829','Spherical longitude of origin',-100.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','19966','Luxembourg Gauss',NULL,NULL,'EPSG','1146','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.5,'EPSG','9110','EPSG','8802','Longitude of natural origin',6.1,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',80000.0,'EPSG','9001','EPSG','8807','False northing',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19967','Slovenia Grid',NULL,NULL,'EPSG','1212','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19968','World Equidistant Cylindrical (Sphere)',NULL,NULL,'EPSG','1262','EPSG','9823','Equidistant Cylindrical (Spherical)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','19969','Portuguese Grid',NULL,NULL,'EPSG','1294','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',1.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19971','New Zealand Transverse Mercator 2000',NULL,NULL,'EPSG','3973','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',173.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1600000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19972','Irish Grid',NULL,NULL,'EPSG','1305','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',53.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-8.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.000035,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',250000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19973','Irish National Grid',NULL,NULL,'EPSG','2530','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',53.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-8.0,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',250000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19974','Modified Portuguese Grid',NULL,NULL,'EPSG','1294','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',-8.0754862,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',180.598,'EPSG','9001','EPSG','8807','False northing',-86.99,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19975','Trinidad Grid (Clarke''s feet)',NULL,NULL,'EPSG','1339','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',10.263,'EPSG','9110','EPSG','8802','Longitude of natural origin',-61.2,'EPSG','9110','EPSG','8806','False easting',283800.0,'EPSG','9005','EPSG','8807','False northing',214500.0,'EPSG','9005',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19976','ICN Regional',NULL,NULL,'EPSG','1251','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',6.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-66.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',9.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',3.0,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19977','Aramco Lambert',NULL,NULL,'EPSG','3303','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',25.0522236,'EPSG','9110','EPSG','8822','Longitude of false origin',48.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',17.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',33.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19978','Hong Kong 1980 Grid',NULL,NULL,'EPSG','1118','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',22.184368,'EPSG','9110','EPSG','8802','Longitude of natural origin',114.10428,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',836694.05,'EPSG','9001','EPSG','8807','False northing',819069.8,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19979','Portugal Bonne',NULL,NULL,'EPSG','1294','EPSG','9828','Bonne (South Orientated)','EPSG','8801','Latitude of natural origin',39.4,'EPSG','9110','EPSG','8802','Longitude of natural origin',1.0,'EPSG','9110','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19981','Lambert New Caledonia',NULL,NULL,'EPSG','3430','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-21.3,'EPSG','9110','EPSG','8822','Longitude of false origin',166.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',-20.4,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-22.2,'EPSG','9110','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19982','TM Reunion',NULL,NULL,'EPSG','1196','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-21.07,'EPSG','9110','EPSG','8802','Longitude of natural origin',55.32,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',160000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "conversion" VALUES('EPSG','19983','Terre Adelie Polar Stereographic',NULL,NULL,'EPSG','2818','EPSG','9830','Polar Stereographic (variant C)','EPSG','8832','Latitude of standard parallel',-67.0,'EPSG','9102','EPSG','8833','Longitude of origin',140.0,'EPSG','9102','EPSG','8826','Easting at false origin',300000.0,'EPSG','9001','EPSG','8827','Northing at false origin',200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19984','British Columbia Albers',NULL,NULL,'EPSG','2832','EPSG','9822','Albers Equal Area','EPSG','8821','Latitude of false origin',45.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-126.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',50.0,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',58.3,'EPSG','9110','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19985','Europe Conformal 2001',NULL,NULL,'EPSG','2881','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',52.0,'EPSG','9102','EPSG','8822','Longitude of false origin',10.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',35.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',65.0,'EPSG','9102','EPSG','8826','Easting at false origin',4000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19986','Europe Equal Area 2001',NULL,NULL,'EPSG','2881','EPSG','9820','Lambert Azimuthal Equal Area','EPSG','8801','Latitude of natural origin',52.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',10.0,'EPSG','9102','EPSG','8806','False easting',4321000.0,'EPSG','9001','EPSG','8807','False northing',3210000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19987','Iceland Lambert 1900',NULL,NULL,'EPSG','3262','EPSG','9826','Lambert Conic Conformal (West Orientated)','EPSG','8801','Latitude of natural origin',65.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-19.011965,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19988','Iceland Lambert 1955',NULL,NULL,'EPSG','3262','EPSG','9826','Lambert Conic Conformal (West Orientated)','EPSG','8801','Latitude of natural origin',65.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-18.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19989','Iceland Lambert 1993',NULL,NULL,'EPSG','1120','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',65.0,'EPSG','9110','EPSG','8822','Longitude of false origin',-19.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',64.15,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',65.45,'EPSG','9110','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19990','Latvian Transverse Mercator',NULL,NULL,'EPSG','1139','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',24.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',-6000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19991','Jan Mayen Grid',NULL,NULL,'EPSG','2869','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9110','EPSG','8802','Longitude of natural origin',-8.3,'EPSG','9110','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',-7800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19992','Antarctic Polar Stereographic',NULL,NULL,'EPSG','1031','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-71.0,'EPSG','9102','EPSG','8833','Longitude of origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19993','Australian Antarctic Polar Stereographic',NULL,NULL,'EPSG','1278','EPSG','9829','Polar Stereographic (variant B)','EPSG','8832','Latitude of standard parallel',-71.0,'EPSG','9102','EPSG','8833','Longitude of origin',70.0,'EPSG','9102','EPSG','8806','False easting',6000000.0,'EPSG','9001','EPSG','8807','False northing',6000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19994','Australian Antarctic Lambert',NULL,NULL,'EPSG','2880','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-50.0,'EPSG','9110','EPSG','8822','Longitude of false origin',70.0,'EPSG','9110','EPSG','8823','Latitude of 1st standard parallel',-68.3,'EPSG','9110','EPSG','8824','Latitude of 2nd standard parallel',-74.3,'EPSG','9110','EPSG','8826','Easting at false origin',6000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',6000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19995','Jordan Transverse Mercator',NULL,NULL,'EPSG','1130','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',37.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9998,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',-3000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19996','Soldner Berlin',NULL,NULL,'EPSG','2898','EPSG','9806','Cassini-Soldner','EPSG','8801','Latitude of natural origin',52.25071338,'EPSG','9110','EPSG','8802','Longitude of natural origin',13.37379332,'EPSG','9110','EPSG','8806','False easting',40000.0,'EPSG','9001','EPSG','8807','False northing',10000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19997','Kuwait Transverse Mercator',NULL,NULL,'EPSG','1310','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',48.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19998','Guernsey Grid',NULL,NULL,'EPSG','2989','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.3,'EPSG','9110','EPSG','8802','Longitude of natural origin',-2.25,'EPSG','9110','EPSG','8805','Scale factor at natural origin',0.999997,'EPSG','9201','EPSG','8806','False easting',47000.0,'EPSG','9001','EPSG','8807','False northing',50000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('EPSG','19999','Jersey Transverse Mercator',NULL,NULL,'EPSG','2988','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.225,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.135,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999999,'EPSG','9201','EPSG','8806','False easting',40000.0,'EPSG','9001','EPSG','8807','False northing',70000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
