--- This file has been generated by scripts/build_db.py. DO NOT EDIT !

INSERT INTO "area" VALUES('EPSG','1024','Afghanistan','Afghanistan.',29.4,38.48,60.5,74.92,0);
INSERT INTO "area" VALUES('EPSG','1025','Albania','Albania - onshore and offshore.',39.63,42.67,18.46,21.06,0);
INSERT INTO "area" VALUES('EPSG','1026','Algeria','Algeria - onshore and offshore.',18.97,38.8,-8.67,11.99,0);
INSERT INTO "area" VALUES('EPSG','1027','American Samoa','American Samoa - onshore and offshore.',-17.56,-10.02,-173.75,-165.2,0);
INSERT INTO "area" VALUES('EPSG','1028','Andorra','Andorra.',42.43,42.66,1.42,1.79,0);
INSERT INTO "area" VALUES('EPSG','1029','Angola','Angola - onshore and offshore.',-18.02,-4.38,8.2,24.09,0);
INSERT INTO "area" VALUES('EPSG','1030','Anguilla','Anguilla - onshore and offshore.',17.94,21.93,-63.9,-60.68,0);
INSERT INTO "area" VALUES('EPSG','1031','Antarctica','Antarctica.',-90.0,-60.0,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','1032','Antigua and Barbuda','Antigua and Barbuda - Antigua, Barbuda and Redonda.',16.61,20.88,-62.76,-58.37,0);
INSERT INTO "area" VALUES('EPSG','1033','Argentina','Argentina - onshore and offshore.',-58.41,-21.78,-73.59,-52.63,0);
INSERT INTO "area" VALUES('EPSG','1034','Armenia','Armenia.',38.84,41.3,43.45,46.63,0);
INSERT INTO "area" VALUES('EPSG','1035','Aruba','Aruba - onshore and offshore.',12.14,15.42,-70.42,-69.31,0);
INSERT INTO "area" VALUES('EPSG','1036','Australia - onshore and EEZ','Australia - onshore and offshore to 200 nautical mile EEZ boundary. Includes Lord Howe Island, Ashmore and Cartier Islands.',-47.2,-8.88,109.23,163.2,0);
INSERT INTO "area" VALUES('EPSG','1037','Austria','Austria.',46.4,49.02,9.53,17.17,0);
INSERT INTO "area" VALUES('EPSG','1038','Azerbaijan','Azerbaijan - onshore and offshore.',37.89,42.59,44.77,51.73,0);
INSERT INTO "area" VALUES('EPSG','1039','Bahamas','Bahamas - onshore and offshore.',20.36,30.36,-81.22,-70.63,0);
INSERT INTO "area" VALUES('EPSG','1040','Bahrain','Bahrain - onshore and offshore.',25.53,27.17,50.26,51.13,0);
INSERT INTO "area" VALUES('EPSG','1041','Bangladesh','Bangladesh - onshore and offshore.',18.56,26.64,88.01,92.67,0);
INSERT INTO "area" VALUES('EPSG','1042','Barbados','Barbados - onshore and offshore.',10.68,16.0,-60.39,-55.99,0);
INSERT INTO "area" VALUES('EPSG','1043','Belarus','Belarus.',51.25,56.17,23.16,32.75,0);
INSERT INTO "area" VALUES('EPSG','1044','Belgium','Belgium - onshore and offshore.',49.5,51.88,2.23,6.4,0);
INSERT INTO "area" VALUES('EPSG','1045','Belize','Belize - onshore and offshore.',15.88,18.49,-89.22,-86.11,0);
INSERT INTO "area" VALUES('EPSG','1046','Benin','Benin - onshore and offshore.',2.99,12.4,0.77,3.86,0);
INSERT INTO "area" VALUES('EPSG','1047','Bermuda','Bermuda - onshore and offshore.',28.91,35.73,-68.83,-60.7,0);
INSERT INTO "area" VALUES('EPSG','1048','Bhutan','Bhutan.',26.7,28.33,88.74,92.13,0);
INSERT INTO "area" VALUES('EPSG','1049','Bolivia','Bolivia.',-22.91,-9.67,-69.66,-57.52,0);
INSERT INTO "area" VALUES('EPSG','1050','Bosnia and Herzegovina','Bosnia and Herzegovina.',42.56,45.27,15.74,19.62,0);
INSERT INTO "area" VALUES('EPSG','1051','Botswana','Botswana.',-26.88,-17.78,19.99,29.38,0);
INSERT INTO "area" VALUES('EPSG','1052','Bouvet Island','Bouvet Island - onshore and offshore.',-57.8,-51.06,-2.38,9.21,0);
INSERT INTO "area" VALUES('EPSG','1053','Brazil','Brazil - onshore and offshore. Includes Rocas, Fernando de Noronha archipelago, Trindade, Ihlas Martim Vaz and Sao Pedro e Sao Paulo.',-35.71,7.04,-74.01,-25.28,0);
INSERT INTO "area" VALUES('EPSG','1054','British Indian Ocean Territory','British Indian Ocean Territory - onshore and offshore - Chagos Archipelago.',-10.8,-2.28,67.88,75.86,0);
INSERT INTO "area" VALUES('EPSG','1055','Brunei','Brunei Darussalam - onshore and offshore.',4.01,6.31,112.37,115.37,0);
INSERT INTO "area" VALUES('EPSG','1056','Bulgaria','Bulgaria - onshore and offshore.',41.24,44.23,22.36,31.35,0);
INSERT INTO "area" VALUES('EPSG','1057','Burkina Faso','Burkina Faso.',9.39,15.09,-5.53,2.4,0);
INSERT INTO "area" VALUES('EPSG','1058','Burundi','Burundi.',-4.45,-2.3,28.98,30.86,0);
INSERT INTO "area" VALUES('EPSG','1059','Cambodia','Cambodia - onshore and offshore.',8.78,14.71,101.33,107.64,0);
INSERT INTO "area" VALUES('EPSG','1060','Cameroon','Cameroon - onshore and offshore.',1.65,13.09,8.32,16.21,0);
INSERT INTO "area" VALUES('EPSG','1061','Canada','Canada - onshore and offshore - Alberta; British Columbia; Manitoba; New Brunswick; Newfoundland and Labrador; Northwest Territories; Nova Scotia; Nunavut; Ontario; Prince Edward Island; Quebec; Saskatchewan; Yukon.',40.04,86.46,-141.01,-47.74,0);
INSERT INTO "area" VALUES('EPSG','1062','Cape Verde','Cape Verde - onshore and offshore. Includes Boa Vista, Brava, Fogo, Maio, Sal, Santo Antao, Sao Nicolau, Sao Tiago, Sao Vicente.',11.47,20.54,-28.85,-19.53,0);
INSERT INTO "area" VALUES('EPSG','1063','Cayman Islands','Cayman Islands - onshore and offshore. Includes Grand Cayman, Little Cayman and Cayman Brac.',17.58,20.68,-83.6,-78.72,0);
INSERT INTO "area" VALUES('EPSG','1064','Central African Republic','Central African Republic.',2.22,11.01,14.41,27.46,0);
INSERT INTO "area" VALUES('EPSG','1065','Chad','Chad.',7.45,23.46,13.46,24.01,0);
INSERT INTO "area" VALUES('EPSG','1066','Chile','Chile - onshore and offshore. Includes Easter Island, Juan Fernandez Islands, San Felix, and Sala y Gomez.',-59.87,-17.5,-113.21,-65.72,0);
INSERT INTO "area" VALUES('EPSG','1067','China','China - onshore and offshore.',16.7,53.56,73.62,134.77,0);
INSERT INTO "area" VALUES('EPSG','1068','Christmas Island','Christmas Island - onshore and offshore.',-13.92,-8.87,102.14,109.03,0);
INSERT INTO "area" VALUES('EPSG','1069','Cocos (Keeling) Islands - onshore','Cocos (Keeling) Islands - onshore.',-12.27,-11.76,96.76,96.99,0);
INSERT INTO "area" VALUES('EPSG','1070','Colombia','Colombia - onshore and offshore. Includes San Andres y Providencia, Malpelo Islands, Roncador Bank, Serrana Bank and Serranilla Bank.',-4.23,15.51,-84.77,-66.87,0);
INSERT INTO "area" VALUES('EPSG','1071','Comoros','Comoros - onshore and offshore. Includes Anjouan, Grande Comore, Moheli and other islands.',-14.43,-8.01,41.93,45.79,0);
INSERT INTO "area" VALUES('EPSG','1072','Congo','Congo - onshore and offshore.',-6.91,3.72,8.84,18.65,0);
INSERT INTO "area" VALUES('EPSG','1073','Cook Islands','Cook Islands - onshore and offshore.',-25.28,-5.85,-168.53,-154.8,0);
INSERT INTO "area" VALUES('EPSG','1074','Costa Rica','Costa Rica - onshore and offshore.',2.15,11.77,-90.45,-81.43,0);
INSERT INTO "area" VALUES('EPSG','1075','Cote d''Ivoire (Ivory Coast)','Côte d''Ivoire (Ivory Coast) - onshore and offshore.',1.02,10.74,-8.61,-2.48,0);
INSERT INTO "area" VALUES('EPSG','1076','Croatia','Croatia - onshore and offshore.',41.62,46.54,13.0,19.43,0);
INSERT INTO "area" VALUES('EPSG','1077','Cuba','Cuba - onshore and offshore.',18.83,25.51,-87.01,-73.57,0);
INSERT INTO "area" VALUES('EPSG','1078','Cyprus','Cyprus - onshore and offshore.',32.88,36.21,29.95,35.2,0);
INSERT INTO "area" VALUES('EPSG','1079','Czechia','Czechia.',48.58,51.06,12.09,18.86,0);
INSERT INTO "area" VALUES('EPSG','1080','Denmark','Denmark - onshore and offshore.',54.36,58.27,3.24,16.51,0);
INSERT INTO "area" VALUES('EPSG','1081','Djibouti','Djibouti - onshore and offshore.',10.94,12.72,41.75,44.15,0);
INSERT INTO "area" VALUES('EPSG','1082','Dominica','Dominica - onshore and offshore.',14.48,16.62,-62.82,-57.52,0);
INSERT INTO "area" VALUES('EPSG','1083','Dominican Republic','Dominican Republic - onshore and offshore.',14.96,22.42,-73.46,-66.82,0);
INSERT INTO "area" VALUES('EPSG','1084','East Timor','Timor-Leste (East Timor) - onshore and offshore. Includes enclave of Oe-Cussi (Okusi).',-10.47,-7.97,123.92,127.97,0);
INSERT INTO "area" VALUES('EPSG','1085','Ecuador','Ecuador - onshore and offshore. Includes Galapagos Islands (Archipelago de Colon).',-5.01,5.0,-95.35,-75.21,0);
INSERT INTO "area" VALUES('EPSG','1086','Egypt','Egypt - onshore and offshore.',21.89,33.82,24.7,37.91,0);
INSERT INTO "area" VALUES('EPSG','1087','El Salvador','El Salvador - onshore and offshore.',9.97,14.44,-91.43,-87.65,0);
INSERT INTO "area" VALUES('EPSG','1088','Equatorial Guinea','Equatorial Guinea - onshore and offshore. Includes Rio Muni, Bioko, Annobon, Corisco, Elobey Chico, and Ebony Grande.',-4.8,4.13,2.26,11.36,0);
INSERT INTO "area" VALUES('EPSG','1089','Eritrea','Eritrea - onshore and offshore.',12.36,18.1,36.44,43.31,0);
INSERT INTO "area" VALUES('EPSG','1090','Estonia','Estonia - onshore and offshore.',57.52,60.0,20.37,28.2,0);
INSERT INTO "area" VALUES('EPSG','1091','Ethiopia','Ethiopia.',3.4,14.89,32.99,47.99,0);
INSERT INTO "area" VALUES('EPSG','1092','Falkland Islands','Falkland Islands (Malvinas) - onshore and offshore.',-56.25,-47.68,-65.01,-52.31,0);
INSERT INTO "area" VALUES('EPSG','1093','Faroe Islands','Faroe Islands - onshore and offshore.',59.94,65.7,-13.91,-0.48,0);
INSERT INTO "area" VALUES('EPSG','1094','Fiji - onshore','Fiji - onshore. Includes Viti Levu, Vanua Levu, Taveuni, the Yasawa Group, the Kadavu Group, the Lau Islands and Rotuma Islands.',-20.81,-12.42,176.81,-178.15,0);
INSERT INTO "area" VALUES('EPSG','1095','Finland','Finland - onshore and offshore.',58.84,70.09,19.08,31.59,0);
INSERT INTO "area" VALUES('EPSG','1096','France','France - onshore and offshore, mainland and Corsica.',41.15,51.56,-9.86,10.38,0);
INSERT INTO "area" VALUES('EPSG','1097','French Guiana','French Guiana - onshore and offshore.',2.11,8.88,-54.6,-49.46,0);
INSERT INTO "area" VALUES('EPSG','1098','French Polynesia','French Polynesia - onshore and offshore. Includes Society archipelago, Tuamotu archipelago, Marquesas Islands, Gambier Islands and Austral Islands.',-31.24,-4.52,-158.13,-131.97,0);
INSERT INTO "area" VALUES('EPSG','1099','French Southern Territories','French Southern Territories - onshore and offshore. Includes Amsterdam and St Paul, Bassas da India, Crozet, Europa, Glorieuses, Juan de Nova, Kerguelen and Tromelin.',-53.24,-10.65,37.55,81.83,0);
INSERT INTO "area" VALUES('EPSG','1100','Gabon','Gabon - onshore and offshore.',-6.37,2.32,7.03,14.52,0);
INSERT INTO "area" VALUES('EPSG','1101','Gambia','Gambia - onshore and offshore.',13.05,13.83,-20.19,-13.79,0);
INSERT INTO "area" VALUES('EPSG','1102','Georgia','Georgia - onshore and offshore.',41.04,43.59,38.97,46.72,0);
INSERT INTO "area" VALUES('EPSG','1103','Germany','Germany - onshore and offshore.',47.27,55.92,3.34,15.04,0);
INSERT INTO "area" VALUES('EPSG','1104','Ghana','Ghana - onshore and offshore.',1.4,11.16,-3.79,2.1,0);
INSERT INTO "area" VALUES('EPSG','1105','Gibraltar','Gibraltar - onshore and offshore.',36.0,36.16,-5.42,-4.89,0);
INSERT INTO "area" VALUES('EPSG','1106','Greece','Greece - onshore and offshore. Includes Aegean Islands, Ionian Islands, Dodecanese Islands, Crete, and Mount Athos.',33.26,41.75,18.26,30.23,0);
INSERT INTO "area" VALUES('EPSG','1107','Greenland','Greenland - onshore and offshore.',56.38,87.03,-75.0,8.12,0);
INSERT INTO "area" VALUES('EPSG','1108','Grenada','Grenada and southern Grenadine Islands - onshore and offshore.',11.36,13.4,-63.28,-60.82,0);
INSERT INTO "area" VALUES('EPSG','1109','Guadeloupe','Guadeloupe - onshore and offshore. Includes Grande Terre, Basse Terre, Marie Galante, Les Saintes, Iles de la Petite Terre, La Desirade; St Barthélemy, and northern St Martin.',15.06,18.54,-63.66,-57.54,0);
INSERT INTO "area" VALUES('EPSG','1110','Guam','Guam - onshore and offshore.',10.95,15.91,141.19,148.18,0);
INSERT INTO "area" VALUES('EPSG','1111','Guatemala','Guatemala - onshore and offshore.',10.6,17.83,-94.57,-88.16,0);
INSERT INTO "area" VALUES('EPSG','1112','Guinea','Guinea - onshore and offshore.',7.19,12.68,-18.26,-7.65,0);
INSERT INTO "area" VALUES('EPSG','1113','Guinea-Bissau','Guinea-Bissau - onshore and offshore.',8.64,12.69,-19.8,-13.64,0);
INSERT INTO "area" VALUES('EPSG','1114','Guyana','Guyana - onshore and offshore.',1.18,10.7,-61.39,-55.77,0);
INSERT INTO "area" VALUES('EPSG','1115','Haiti','Haiti - onshore and offshore.',14.73,20.72,-75.73,-71.62,0);
INSERT INTO "area" VALUES('EPSG','1116','Heard Island and McDonald Islands','Heard Island and McDonald Islands - onshore and offshore.',-59.02,-49.5,62.92,83.57,0);
INSERT INTO "area" VALUES('EPSG','1117','Honduras','Honduras - onshore and offshore. Includes Swan Islands.',12.98,19.59,-89.36,-79.87,0);
INSERT INTO "area" VALUES('EPSG','1118','China - Hong Kong','China - Hong Kong - onshore and offshore.',22.13,22.58,113.76,114.51,0);
INSERT INTO "area" VALUES('EPSG','1119','Hungary','Hungary.',45.74,48.58,16.11,22.9,0);
INSERT INTO "area" VALUES('EPSG','1120','Iceland','Iceland - onshore and offshore.',59.96,69.59,-30.87,-5.55,0);
INSERT INTO "area" VALUES('EPSG','1121','India','India - onshore and offshore. Includes Amandivis, Laccadives, Minicoy, Andaman Islands, Nicobar Islands, and Sikkim.',3.87,35.51,65.6,97.42,0);
INSERT INTO "area" VALUES('EPSG','1122','Indonesia','Indonesia - onshore and offshore.',-13.95,7.79,92.01,141.46,0);
INSERT INTO "area" VALUES('EPSG','1123','Iran','Iran - onshore and offshore.',23.34,39.78,44.03,63.34,0);
INSERT INTO "area" VALUES('EPSG','1124','Iraq','Iraq - onshore and offshore.',29.06,37.39,38.79,48.75,0);
INSERT INTO "area" VALUES('EPSG','1125','Ireland','Ireland - onshore and offshore.',48.18,56.57,-16.1,-5.24,0);
INSERT INTO "area" VALUES('EPSG','1126','Israel','Israel - onshore and offshore.',29.45,33.53,32.99,35.69,0);
INSERT INTO "area" VALUES('EPSG','1127','Italy','Italy - onshore and offshore.',34.76,47.1,5.93,18.99,0);
INSERT INTO "area" VALUES('EPSG','1128','Jamaica','Jamaica - onshore and offshore. Includes Morant Cays and Pedro Cays.',14.08,19.36,-80.6,-74.51,0);
INSERT INTO "area" VALUES('EPSG','1129','Japan','Japan - onshore and offshore.',17.09,46.05,122.38,157.65,0);
INSERT INTO "area" VALUES('EPSG','1130','Jordan','Jordan.',29.18,33.38,34.88,39.31,0);
INSERT INTO "area" VALUES('EPSG','1131','Kazakhstan','Kazakhstan - onshore including Caspian Sea.',40.59,55.45,46.49,87.35,0);
INSERT INTO "area" VALUES('EPSG','1132','Kenya','Kenya - onshore and offshore.',-4.9,4.63,33.9,44.28,0);
INSERT INTO "area" VALUES('EPSG','1133','Kiribati','Kiribati - onshore and offshore. Includes Fanning Island, Washington Island and Christmas in the Line Islands, Ocean Islands, Phoenix Islands.',-13.84,7.92,167.81,-146.82,0);
INSERT INTO "area" VALUES('EPSG','1134','Korea, Democratic People''s Republic of (North Korea)','Democratic People''s Republic of Korea (North Korea) - onshore and offshore.',37.1,43.01,123.54,132.82,0);
INSERT INTO "area" VALUES('EPSG','1135','Korea, Republic of (South Korea)','Republic of Korea (South Korea) - onshore and offshore.',28.6,40.27,122.71,134.28,0);
INSERT INTO "area" VALUES('EPSG','1136','Kuwait','Kuwait - onshore and offshore.',28.53,30.09,46.54,49.53,0);
INSERT INTO "area" VALUES('EPSG','1137','Kyrgyzstan','Kyrgyzstan.',39.19,43.22,69.24,80.29,0);
INSERT INTO "area" VALUES('EPSG','1138','Laos','Laos.',13.92,22.5,100.09,107.7,0);
INSERT INTO "area" VALUES('EPSG','1139','Latvia','Latvia - onshore and offshore.',55.67,58.09,19.06,28.24,0);
INSERT INTO "area" VALUES('EPSG','1140','Lebanon','Lebanon - onshore and offshore.',33.06,34.84,33.75,36.63,0);
INSERT INTO "area" VALUES('EPSG','1141','Lesotho','Lesotho.',-30.66,-28.57,27.01,29.46,0);
INSERT INTO "area" VALUES('EPSG','1142','Liberia','Liberia - onshore and offshore.',1.02,8.52,-13.59,-7.36,0);
INSERT INTO "area" VALUES('EPSG','1143','Libya','Libya - onshore and offshore.',19.5,35.23,9.31,26.21,0);
INSERT INTO "area" VALUES('EPSG','1144','Liechtenstein','Liechtenstein.',47.05,47.28,9.47,9.64,0);
INSERT INTO "area" VALUES('EPSG','1145','Lithuania','Lithuania - onshore and offshore.',53.89,56.45,19.02,26.82,0);
INSERT INTO "area" VALUES('EPSG','1146','Luxembourg','Luxembourg.',49.44,50.19,5.73,6.53,0);
INSERT INTO "area" VALUES('EPSG','1147','China - Macao','China - Macao - onshore and offshore.',22.06,22.23,113.52,113.68,0);
INSERT INTO "area" VALUES('EPSG','1148','North Macedonia','North Macedonia.',40.85,42.36,20.45,23.04,0);
INSERT INTO "area" VALUES('EPSG','1149','Madagascar - onshore and nearshore','Madagascar - onshore and nearshore.',-26.59,-11.69,42.53,51.03,0);
INSERT INTO "area" VALUES('EPSG','1150','Malawi','Malawi.',-17.14,-9.37,32.68,35.93,0);
INSERT INTO "area" VALUES('EPSG','1151','Malaysia','Malaysia - onshore and offshore. Includes peninsular Malayasia, Sabah and Sarawak.',0.85,7.81,98.02,119.61,0);
INSERT INTO "area" VALUES('EPSG','1152','Maldives','Maldives - onshore and offshore.',-3.47,8.1,69.29,77.08,0);
INSERT INTO "area" VALUES('EPSG','1153','Mali','Mali.',10.14,25.01,-12.25,4.26,0);
INSERT INTO "area" VALUES('EPSG','1154','Malta','Malta - onshore and offshore.',34.49,36.56,13.41,18.06,0);
INSERT INTO "area" VALUES('EPSG','1155','Marshall Islands','Marshall Islands - onshore and offshore.',1.77,17.88,157.47,175.52,0);
INSERT INTO "area" VALUES('EPSG','1156','Martinique','Martinique - onshore and offshore.',14.08,16.36,-62.82,-57.52,0);
INSERT INTO "area" VALUES('EPSG','1157','Mauritania','Mauritania - onshore and offshore.',14.72,27.3,-20.04,-4.8,0);
INSERT INTO "area" VALUES('EPSG','1158','Mauritius','Mauritius - onshore and offshore. Includes Rodrigues, Agalega Islands, and Cargados Carajos.',-23.81,-8.43,53.8,67.05,0);
INSERT INTO "area" VALUES('EPSG','1159','Mayotte','Mayotte - onshore and offshore.',-14.49,-11.33,43.68,46.7,0);
INSERT INTO "area" VALUES('EPSG','1160','Mexico','Mexico - onshore and offshore.',12.1,32.72,-122.19,-84.64,0);
INSERT INTO "area" VALUES('EPSG','1161','Micronesia','Federated States of Micronesia - onshore and offshore. Includes Caroline Islands, Yap, Truk, Ponape, Kosrae.',-1.19,13.43,135.27,165.68,0);
INSERT INTO "area" VALUES('EPSG','1162','Moldova','Moldova.',45.44,48.47,26.63,30.13,0);
INSERT INTO "area" VALUES('EPSG','1163','Monaco','Monaco - onshore and offshore.',42.94,43.77,7.39,7.76,0);
INSERT INTO "area" VALUES('EPSG','1164','Mongolia','Mongolia.',41.58,52.15,87.76,119.94,0);
INSERT INTO "area" VALUES('EPSG','1165','Montserrat','Montserrat - onshore and offshore.',15.84,17.04,-63.05,-61.82,0);
INSERT INTO "area" VALUES('EPSG','1166','Morocco','Morocco - onshore and offshore.',27.66,36.0,-13.86,-1.01,0);
INSERT INTO "area" VALUES('EPSG','1167','Mozambique','Mozambique - onshore and offshore.',-27.71,-10.09,30.21,43.03,0);
INSERT INTO "area" VALUES('EPSG','1168','Myanmar (Burma)','Myanmar (Burma) - onshore and offshore.',9.48,28.55,89.61,101.17,0);
INSERT INTO "area" VALUES('EPSG','1169','Namibia','Namibia - onshore and offshore.',-30.64,-16.95,8.24,25.27,0);
INSERT INTO "area" VALUES('EPSG','1170','Nauru','Nauru - onshore and offshore.',-3.91,2.69,163.58,168.6,0);
INSERT INTO "area" VALUES('EPSG','1171','Nepal','Nepal.',26.34,30.43,80.06,88.21,0);
INSERT INTO "area" VALUES('EPSG','1172','Netherlands','Netherlands - onshore and offshore.',50.75,55.77,2.53,7.22,0);
INSERT INTO "area" VALUES('EPSG','1173','Netherlands Antilles','Netherlands Antilles - onshore and offshore. Includes Bonaire, Curacao, Saba, St Eustatius, and southern St Martin',11.67,18.07,-69.59,-62.82,1);
INSERT INTO "area" VALUES('EPSG','1174','New Caledonia','New Caledonia - onshore and offshore. Isle de Pins, Loyalty Islands, Huon Islands, Belep archipelago, Chesterfield Islands, and Walpole.',-26.45,-14.83,156.25,174.28,0);
INSERT INTO "area" VALUES('EPSG','1175','New Zealand','New Zealand - onshore and offshore. Includes Antipodes Islands, Auckland Islands, Bounty Islands, Chatham Islands, Cambell Island, Kermadec Islands, Raoul Island and Snares Islands.',-55.95,-25.88,160.6,-171.2,0);
INSERT INTO "area" VALUES('EPSG','1176','Nicaragua','Nicaragua - onshore and offshore.',9.75,16.26,-89.43,-79.76,0);
INSERT INTO "area" VALUES('EPSG','1177','Niger','Niger.',11.69,23.53,0.16,16.0,0);
INSERT INTO "area" VALUES('EPSG','1178','Nigeria','Nigeria - onshore and offshore.',1.92,13.9,2.66,14.65,0);
INSERT INTO "area" VALUES('EPSG','1179','Niue','Niue - onshore and offshore.',-22.49,-16.58,-172.01,-166.31,0);
INSERT INTO "area" VALUES('EPSG','1180','Norfolk Island','Norfolk Island - onshore and offshore.',-32.48,-25.61,163.36,173.35,0);
INSERT INTO "area" VALUES('EPSG','1181','Northern Mariana Islands','Northern Mariana Islands - onshore and offshore.',12.38,23.9,141.33,149.55,0);
INSERT INTO "area" VALUES('EPSG','1182','Norway','Norway including Svalbard - onshore and offshore.',56.08,84.17,-3.7,39.65,0);
INSERT INTO "area" VALUES('EPSG','1183','Oman','Oman - onshore and offshore.',14.33,26.74,51.99,63.38,0);
INSERT INTO "area" VALUES('EPSG','1184','Pakistan','Pakistan - onshore and offshore.',21.05,37.07,60.86,77.83,0);
INSERT INTO "area" VALUES('EPSG','1185','Palau','Palau - onshore and offshore.',1.64,11.45,129.48,136.98,0);
INSERT INTO "area" VALUES('EPSG','1186','Panama','Panama - onshore and offshore.',5.0,12.51,-84.32,-77.04,0);
INSERT INTO "area" VALUES('EPSG','1187','Papua New Guinea','Papua New Guinea - onshore and offshore. Includes Bismark archipelago, Louisade archipelago, Admiralty Islands, d''Entrecasteaux Islands, northern Solomon Islands, Trobriand Islands, New Britain, New Ireland, Woodlark, and associated islands.',-14.75,2.58,139.2,162.81,0);
INSERT INTO "area" VALUES('EPSG','1188','Paraguay','Paraguay.',-27.59,-19.29,-62.65,-54.24,0);
INSERT INTO "area" VALUES('EPSG','1189','Peru','Peru - onshore and offshore.',-21.05,-0.03,-84.68,-68.67,0);
INSERT INTO "area" VALUES('EPSG','1190','Philippines','Philippines - onshore and offshore.',3.0,22.18,116.04,129.95,0);
INSERT INTO "area" VALUES('EPSG','1191','Pitcairn','Pitcairn - Pitcairn Island, Henderson Island, Ducie Island and Oeno Atoll.',-28.41,-20.58,-133.43,-121.11,0);
INSERT INTO "area" VALUES('EPSG','1192','Poland','Poland - onshore and offshore.',49.0,55.93,14.14,24.15,0);
INSERT INTO "area" VALUES('EPSG','1193','Portugal','Portugal - mainland, Azores and Madeira, onshore and offshore.',29.24,43.07,-35.58,-6.19,0);
INSERT INTO "area" VALUES('EPSG','1194','Puerto Rico','Puerto Rico - onshore and offshore.',14.92,21.86,-68.49,-65.04,0);
INSERT INTO "area" VALUES('EPSG','1195','Qatar','Qatar - onshore and offshore.',24.55,27.05,50.55,53.04,0);
INSERT INTO "area" VALUES('EPSG','1196','Reunion','Reunion - onshore and offshore - Reunion island, Ile Europa, Bassas da India, Juan de Nova, Iles Glorieuses, and Ile Tromelin.',-25.92,-10.6,37.58,58.27,1);
INSERT INTO "area" VALUES('EPSG','1197','Romania','Romania - onshore and offshore.',43.44,48.27,20.26,31.41,0);
INSERT INTO "area" VALUES('EPSG','1198','Russia','Russian Federation - onshore and offshore.',39.87,85.2,18.92,-168.97,0);
INSERT INTO "area" VALUES('EPSG','1199','Rwanda','Rwanda.',-2.83,-1.05,28.85,30.9,0);
INSERT INTO "area" VALUES('EPSG','1200','St Kitts and Nevis','St Kitts and Nevis - onshore and offshore.',16.34,17.67,-63.63,-62.2,0);
INSERT INTO "area" VALUES('EPSG','1201','St Lucia','St Lucia - onshore and offshore.',13.23,14.28,-62.5,-59.99,0);
INSERT INTO "area" VALUES('EPSG','1202','St Vincent and the Grenadines','St Vincent and the northern Grenadine Islands - onshore and offshore.',12.03,14.09,-63.38,-60.28,0);
INSERT INTO "area" VALUES('EPSG','1203','Samoa','Samoa - onshore and offshore.',-15.84,-10.94,-174.54,-170.51,0);
INSERT INTO "area" VALUES('EPSG','1204','San Marino','San Marino.',43.89,43.99,12.4,12.52,0);
INSERT INTO "area" VALUES('EPSG','1205','Sao Tome and Principe','Sao Tome and Principe - onshore and offshore.',-1.49,2.72,3.2,8.56,0);
INSERT INTO "area" VALUES('EPSG','1206','Saudi Arabia','Saudi Arabia - onshore and offshore.',15.61,32.16,34.44,55.67,0);
INSERT INTO "area" VALUES('EPSG','1207','Senegal','Senegal - onshore and offshore.',10.64,16.7,-20.22,-11.36,0);
INSERT INTO "area" VALUES('EPSG','1208','Seychelles','Seychelles - onshore and offshore - Alphonse, Bijoutier, St Francois Islands, St Pierre islet, Cosmoledo Islands, Amirantes, Aldabra, Farquhar, and Desroches.',-12.72,-0.37,43.19,59.66,0);
INSERT INTO "area" VALUES('EPSG','1209','Sierra Leone','Sierra Leone - onshore and offshore.',4.22,10.0,-16.57,-10.26,0);
INSERT INTO "area" VALUES('EPSG','1210','Singapore','Singapore - onshore and offshore.',1.13,1.47,103.59,104.07,0);
INSERT INTO "area" VALUES('EPSG','1211','Slovakia','Slovakia.',47.73,49.61,16.84,22.56,0);
INSERT INTO "area" VALUES('EPSG','1212','Slovenia','Slovenia - onshore and offshore.',45.42,46.88,13.38,16.61,0);
INSERT INTO "area" VALUES('EPSG','1213','Solomon Islands - onshore main islands','Solomon Islands - onshore southern Solomon Islands, primarily Guadalcanal, Malaita, San Cristobel, Santa Isobel, Choiseul, Makira-Ulawa.',-10.9,-6.55,155.62,162.44,0);
INSERT INTO "area" VALUES('EPSG','1214','Somalia','Somalia - onshore and offshore.',-3.61,13.5,40.98,54.43,0);
INSERT INTO "area" VALUES('EPSG','1215','South Africa','South Africa - onshore and offshore, including Marion Island, and Prince Edward Island.',-50.32,-22.13,13.33,42.85,0);
INSERT INTO "area" VALUES('EPSG','1216','South Georgia and the South Sandwich Islands','South Georgia and the South Sandwich Islands - onshore and offshore.',-62.79,-50.15,-48.06,-19.84,0);
INSERT INTO "area" VALUES('EPSG','1217','Spain','Spain - mainland, Balearic Islands, Canary Islands, Ceuta and Melila - onshore and offshore.',24.6,46.26,-21.93,6.3,0);
INSERT INTO "area" VALUES('EPSG','1218','Sri Lanka','Sri Lanka - onshore and offshore.',2.58,11.45,77.02,85.24,0);
INSERT INTO "area" VALUES('EPSG','1219','St Helena, Ascension and Tristan da Cunha','St Helena, Ascension and Tristan da Cunha archipelago (Gough, Inaccessible, Nightingale and Stoltenhoff Islands) - onshore and offshore.',-43.71,-4.55,-17.79,-2.16,0);
INSERT INTO "area" VALUES('EPSG','1220','St Pierre and Miquelon','St Pierre and Miquelon - onshore and offshore.',43.41,47.37,-57.1,-55.9,0);
INSERT INTO "area" VALUES('EPSG','1221','Sudan','Sudan - onshore and offshore.',8.64,22.24,21.82,39.76,0);
INSERT INTO "area" VALUES('EPSG','1222','Suriname','Suriname - onshore and offshore.',1.83,9.35,-58.08,-52.66,0);
INSERT INTO "area" VALUES('EPSG','1223','Svalbard and Jan Mayen','Svalbard and Jan Mayen - onshore and offshore. Includes Bear Island.',66.24,85.05,-16.22,35.02,1);
INSERT INTO "area" VALUES('EPSG','1224','Eswatini','Eswatini (Swaziland).',-27.32,-25.72,30.79,32.14,0);
INSERT INTO "area" VALUES('EPSG','1225','Sweden','Sweden - onshore and offshore.',54.96,69.07,10.03,24.17,0);
INSERT INTO "area" VALUES('EPSG','1226','Switzerland','Switzerland.',45.82,47.81,5.96,10.49,0);
INSERT INTO "area" VALUES('EPSG','1227','Syria','Syria - onshore and offshore.',32.31,37.3,34.96,42.38,0);
INSERT INTO "area" VALUES('EPSG','1228','Taiwan','Taiwan, Republic of China - onshore and offshore - Taiwan Island, Penghu (Pescadores) Islands.',17.36,26.96,114.32,123.61,0);
INSERT INTO "area" VALUES('EPSG','1229','Tajikistan','Tajikistan.',36.67,41.05,67.36,75.19,0);
INSERT INTO "area" VALUES('EPSG','1230','Tanzania','Tanzania - onshore and offshore.',-11.75,-0.99,29.34,43.29,0);
INSERT INTO "area" VALUES('EPSG','1231','Thailand','Thailand - onshore and offshore.',5.63,20.46,95.52,105.64,0);
INSERT INTO "area" VALUES('EPSG','1232','Togo','Togo - onshore and offshore.',2.91,11.14,-0.15,2.42,0);
INSERT INTO "area" VALUES('EPSG','1233','Tokelau','Tokelau - onshore and offshore.',-11.04,-6.46,-175.86,-167.98,0);
INSERT INTO "area" VALUES('EPSG','1234','Tonga','Tonga - onshore and offshore.',-25.68,-14.14,-179.08,-171.28,0);
INSERT INTO "area" VALUES('EPSG','1235','Trinidad and Tobago','Trinidad and Tobago - onshore and offshore.',9.83,12.34,-62.09,-57.28,0);
INSERT INTO "area" VALUES('EPSG','1236','Tunisia','Tunisia - onshore and offshore.',30.23,38.41,7.49,13.67,0);
INSERT INTO "area" VALUES('EPSG','1237','Turkey','Turkey - onshore and offshore.',34.42,43.45,25.62,44.83,0);
INSERT INTO "area" VALUES('EPSG','1238','Turkmenistan','Turkmenistan - onshore and offshore.',35.14,42.8,51.3,66.68,0);
INSERT INTO "area" VALUES('EPSG','1239','Turks and Caicos Islands','Turks and Caicos Islands - onshore and offshore.',20.54,25.07,-72.82,-67.66,0);
INSERT INTO "area" VALUES('EPSG','1240','Tuvalu','Tuvalu - onshore and offshore. Funafuti, Nanumanga, Nui, Nanomea, Nurakita, Niutao, Nukufetau, Nukulaelae, and Vaitupu.',-13.24,-4.0,172.73,-176.71,0);
INSERT INTO "area" VALUES('EPSG','1241','Uganda','Uganda.',-1.48,4.23,29.57,35.01,0);
INSERT INTO "area" VALUES('EPSG','1242','Ukraine','Ukraine - onshore and offshore.',43.18,52.38,22.15,40.18,0);
INSERT INTO "area" VALUES('EPSG','1243','UAE','United Arab Emirates (UAE) - onshore and offshore. Abu Dhabi, Dubai, Sharjah, Umm al Qaywayn, Al Fujairah, Ras al Khaymah.',22.63,26.27,51.5,57.13,0);
INSERT INTO "area" VALUES('EPSG','1244','UK','United Kingdom (UK) - onshore and offshore - England, Scotland including Orkney and Shetland Islands, Wales, Northern Ireland (Ulster).',47.42,63.89,-14.89,3.4,0);
INSERT INTO "area" VALUES('EPSG','1245','USA','United States (USA) - onshore and offshore.',15.56,74.71,167.65,-65.69,0);
INSERT INTO "area" VALUES('EPSG','1246','United States Minor Outlying Islands','United States Minor Outlying Islands - onshore and offshore - Baker Island, Howland Islands, Jarvis Island, Johnston Atoll, Kingman Reef, Midway Islands, Palmyra Islands, and Wake Island.',-3.74,31.8,163.07,-157.41,0);
INSERT INTO "area" VALUES('EPSG','1247','Uruguay','Uruguay - onshore and offshore.',-37.77,-30.09,-58.49,-50.01,0);
INSERT INTO "area" VALUES('EPSG','1248','Uzbekistan','Uzbekistan.',37.18,45.58,55.99,73.17,0);
INSERT INTO "area" VALUES('EPSG','1249','Vanuatu','Vanuatu - onshore and offshore.',-21.65,-12.27,163.16,173.59,0);
INSERT INTO "area" VALUES('EPSG','1250','Holy See (Vatican City State)','Holy See (Vatican City State).',41.9,41.91,12.44,12.46,0);
INSERT INTO "area" VALUES('EPSG','1251','Venezuela','Venezuela - onshore and offshore.',0.64,16.75,-73.38,-58.95,0);
INSERT INTO "area" VALUES('EPSG','1252','Vietnam','Vietnam - onshore and offshore.',5.67,23.33,102.14,112.55,0);
INSERT INTO "area" VALUES('EPSG','1253','Virgin Islands, British','British Virgin Islands - onshore and offshore - Anegada, Jost Van Dyke, Tortola, and Virgin Gorda.',17.96,22.09,-65.85,-63.29,0);
INSERT INTO "area" VALUES('EPSG','1254','Virgin Islands, US','US Virgin Islands - onshore and offshore - St Croix, St John, and St Thomas.',16.22,21.83,-66.05,-63.88,0);
INSERT INTO "area" VALUES('EPSG','1255','Wallis and Futuna','Wallis and Futuna - onshore and offshore - Uvea, Futuna, and Alofi.',-15.94,-9.84,179.49,-174.27,0);
INSERT INTO "area" VALUES('EPSG','1256','Western Sahara','Western Sahara - onshore and offshore.',18.98,27.67,-20.68,-8.66,0);
INSERT INTO "area" VALUES('EPSG','1257','Yemen','Yemen - onshore and offshore.',8.95,19.0,41.08,57.96,0);
INSERT INTO "area" VALUES('EPSG','1258','Yugoslavia - Serbia and Montenegro','Yugoslavia - Union of Serbia and Montenegro - onshore and offshore.',41.82,46.23,18.44,23.05,1);
INSERT INTO "area" VALUES('EPSG','1259','Congo DR (Zaire)','The Democratic Republic of the Congo (Zaire) - onshore and offshore.',-13.46,5.39,11.79,31.31,0);
INSERT INTO "area" VALUES('EPSG','1260','Zambia','Zambia.',-18.08,-8.19,21.99,33.71,0);
INSERT INTO "area" VALUES('EPSG','1261','Zimbabwe','Zimbabwe.',-22.42,-15.61,25.23,33.08,0);
INSERT INTO "area" VALUES('EPSG','1262','World','World.',-90.0,90.0,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','1263','Not specified','Not specified.',-90.0,90.0,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','1264','UK - Great Britain; Isle of Man','United Kingdom (UK) - Great Britain - England and Wales onshore, Scotland onshore and Western Isles nearshore; Isle of Man onshore.',49.79,60.94,-8.82,1.92,0);
INSERT INTO "area" VALUES('EPSG','1265','Argentina - Comodoro Rivadavia','Argentina - Comodoro Rivadavia area.',-46.7,-45.19,-69.5,-67.1,0);
INSERT INTO "area" VALUES('EPSG','1266','Venezuela - Puerto La Cruz','Venezuela - Puerto La Cruz area.',10.0,10.31,-64.7,-64.5,0);
INSERT INTO "area" VALUES('EPSG','1267','Venezuela - Barinas','Venezuela - Barinas area.',7.31,9.07,-71.49,-67.58,0);
INSERT INTO "area" VALUES('EPSG','1268','Venezuela - Falcon state','Venezuela - Falcon state.',10.3,12.25,-71.3,-68.19,0);
INSERT INTO "area" VALUES('EPSG','1269','Venezuela - Pedregal area of Falcon state','Venezuela - Pedregal area of Falcon state.',10.8,11.26,-70.4,-69.69,0);
INSERT INTO "area" VALUES('EPSG','1270','Venezuela - Maracaibo south','Venezuela - south Maracaibo area.',8.72,10.01,-72.4,-70.78,0);
INSERT INTO "area" VALUES('EPSG','1271','Africa - Eritrea, Ethiopia, South Sudan and Sudan','Eritrea; Ethiopia; South Sudan; Sudan.',3.4,22.24,21.82,47.99,0);
INSERT INTO "area" VALUES('EPSG','1272','Asia - Middle East - Bahrain, Kuwait and Saudi Arabia','Bahrain, Kuwait and Saudi Arabia - onshore.',15.61,32.16,34.51,55.67,0);
INSERT INTO "area" VALUES('EPSG','1273','Antigua - onshore','Antigua island - onshore.',16.94,17.22,-61.95,-61.61,0);
INSERT INTO "area" VALUES('EPSG','1274','Brazil - Aratu','Brazil - offshore south and east of a line intersecting the coast at 2°55''S; onshore Tucano basin.',-35.71,4.26,-53.38,-26.0,0);
INSERT INTO "area" VALUES('EPSG','1275','Netherlands - onshore','Netherlands - onshore, including Waddenzee, Dutch Wadden Islands and 12-mile offshore coastal zone.',50.75,53.7,3.2,7.22,0);
INSERT INTO "area" VALUES('EPSG','1276','Africa - Botswana, Malawi, Zambia, Zimbabwe','Botswana; Malawi; Zambia; Zimbabwe.',-26.88,-8.19,19.99,35.93,0);
INSERT INTO "area" VALUES('EPSG','1277','Africa - Burundi, Kenya, Rwanda, Tanzania and Uganda','Burundi, Kenya, Rwanda, Tanzania and Uganda.',-11.75,4.63,28.85,41.91,0);
INSERT INTO "area" VALUES('EPSG','1278','Antarctica - Australian sector','Antarctica between 45°E and 136°E and between 142°E and 160°E - Australian sector.',-90.0,-60.0,45.0,160.0,0);
INSERT INTO "area" VALUES('EPSG','1279','Australasia - Australia and PNG - AGD66','Australia - onshore and offshore. Papua New Guinea - onshore.',-47.2,-1.3,109.23,163.2,0);
INSERT INTO "area" VALUES('EPSG','1280','Australia - Western Australia','Australia - Western Australia.',-35.19,-13.67,112.85,129.01,0);
INSERT INTO "area" VALUES('EPSG','1281','Australia - mainland','Australia - Australian Capital Territory; New South Wales; Northern Territory; Queensland; South Australia; Western Australia; Victoria.',-39.2,-10.65,112.85,153.69,0);
INSERT INTO "area" VALUES('EPSG','1282','Australia - Tasmania','Australia - Tasmania including islands - onshore.',-43.7,-39.52,143.77,148.55,0);
INSERT INTO "area" VALUES('EPSG','1283','Canada - Maritime Provinces','Canada - New Brunswick; Nova Scotia; Prince Edward Island.',43.41,48.07,-69.05,-59.73,0);
INSERT INTO "area" VALUES('EPSG','1284','Europe - FSU, Czechoslovakia - onshore','Armenia; Azerbaijan; Belarus; Czechia; Estonia - onshore; Georgia - onshore; Kazakhstan; Kyrgyzstan; Latvia - onshore; Lithuania - onshore; Moldova; Russian Federation - onshore; Slovakia; Tajikistan; Turkmenistan; Ukraine - onshore; Uzbekistan.',35.14,77.79,12.09,-169.57,0);
INSERT INTO "area" VALUES('EPSG','1285','Indonesia - Java and Bali onshore','Indonesia - onshore Java and Bali.',-8.91,-5.83,105.06,115.77,0);
INSERT INTO "area" VALUES('EPSG','1286','Europe - Liechtenstein and Switzerland','Liechtenstein; Switzerland.',45.82,47.81,5.96,10.49,0);
INSERT INTO "area" VALUES('EPSG','1287','Indonesia - Banga & Belitung Islands','Indonesia - Banga and Belitung Islands.',-3.3,-1.44,105.07,108.35,0);
INSERT INTO "area" VALUES('EPSG','1288','Angola - Angola proper','Angola - Angola proper - onshore and offshore.',-18.02,-5.82,8.2,24.09,0);
INSERT INTO "area" VALUES('EPSG','1289','Canada - CGVD28','Canada - onshore - Alberta; British Columbia; Manitoba south of 57°N; New Brunswick; Northwest Territories south west of a line between 60°N, 110°W and the coast at 132°W; Nova Scotia; Ontario south of 52°N; Prince Edward Island; Quebec - mainland west of 66°W and south of 55°N; Saskatchewan south of 55°N; Yukon.',41.67,69.8,-141.01,-59.73,0);
INSERT INTO "area" VALUES('EPSG','1290','Africa - Botswana, Eswatini, Lesotho and South Africa','Botswana; Eswatini (Swaziland); Lesotho; South Africa - mainland.',-34.88,-17.78,16.45,32.95,0);
INSERT INTO "area" VALUES('EPSG','1291','Asia - FSU - Caspian Sea','Azerbaijan - offshore; Kazakhstan - offshore; Russian Federation - Caspian Sea; Turkmenistan - offshore.',37.35,46.97,46.95,53.93,0);
INSERT INTO "area" VALUES('EPSG','1292','Argentina - Neuquen province','Argentina - Neuquen province.',-41.1,-36.14,-71.96,-68.01,0);
INSERT INTO "area" VALUES('EPSG','1293','Brazil - Corrego Alegre 1970-1972','Brazil - onshore - west of 54°W and south of 18°S; also south of 15°S between 54°W and 42°W; also east of 42°W.',-33.78,-2.68,-58.16,-34.74,0);
INSERT INTO "area" VALUES('EPSG','1294','Portugal - mainland - onshore','Portugal - mainland - onshore.',36.95,42.16,-9.56,-6.19,0);
INSERT INTO "area" VALUES('EPSG','1295','Germany - DHDN','Germany - onshore - Baden-Wurtemberg, Bayern, Hessen, Niedersachsen, Nordrhein-Westfalen, Rheinland-Pfalz, Saarland, Schleswig-Holstein. Also former DDR states of Sachsen and Thuringen by transformation.',47.27,55.06,5.87,15.03,1);
INSERT INTO "area" VALUES('EPSG','1296','Europe - ED50 by country','Europe - west: Andorra; Cyprus; Denmark - onshore and offshore; Faroe Islands - onshore; France - offshore; Germany - offshore North Sea; Gibraltar; Greece - offshore; Israel - offshore; Italy including San Marino and Vatican City State; Ireland offshore; Malta; Netherlands - offshore; North Sea; Norway including Svalbard - onshore and offshore; Portugal - mainland - offshore; Spain - onshore; Turkey - onshore and offshore; United Kingdom UKCS offshore east of 6°W including Channel Islands (Guernsey and Jersey). Egypt - Western Desert; Iraq - onshore; Jordan.',25.71,84.17,-16.1,48.61,0);
INSERT INTO "area" VALUES('EPSG','1297','Europe - west','Europe - west.',34.88,84.17,-10.56,39.65,0);
INSERT INTO "area" VALUES('EPSG','1298','Europe - ETRS89','Europe - onshore and offshore: Albania; Andorra; Austria; Belgium; Bosnia and Herzegovina; Bulgaria; Croatia; Cyprus; Czechia; Denmark; Estonia; Faroe Islands; Finland; France; Germany; Gibraltar; Greece; Hungary; Ireland; Italy; Kosovo; Latvia; Liechtenstein; Lithuania; Luxembourg; Malta; Moldova; Monaco; Montenegro; Netherlands; North Macedonia; Norway including Svalbard and Jan Mayen; Poland; Portugal; Romania; San Marino; Serbia; Slovakia; Slovenia; Spain; Sweden; Switzerland; United Kingdom (UK) including Channel Islands and Isle of Man; Vatican City State.',32.88,84.17,-16.1,40.18,0);
INSERT INTO "area" VALUES('EPSG','1299','Europe - EVRF2000','Europe - onshore - Andorra; Austria; Belgium; Bosnia and Herzegovina; Croatia; Czechia; Denmark; Estonia; Finland; France - mainland; Germany; Gibraltar; Hungary; Italy - mainland and Sicily; Latvia; Liechtenstein; Lithuania; Luxembourg; Netherlands; Norway; Poland; Portugal - mainland; Romania; San Marino; Slovakia; Slovenia; Spain - mainland; Sweden; Switzerland; United Kingdom (UK) - Great Britain mainland; Vatican City State.',35.95,71.21,-9.56,31.59,0);
INSERT INTO "area" VALUES('EPSG','1300','Iran - FD58','Iran - Arwaz area and onshore Gulf coast west of 54°E, Lavan Island, offshore Balal field and South Pars blocks 2 and 3.',26.21,33.22,47.13,53.61,0);
INSERT INTO "area" VALUES('EPSG','1301','Portugal - Azores C - onshore','Portugal - central Azores onshore - Faial, Graciosa, Pico, Sao Jorge, Terceira.',38.32,39.14,-28.9,-26.97,0);
INSERT INTO "area" VALUES('EPSG','1302','Asia - Cambodia and Vietnam - mainland','Cambodia - mainland onshore; Vietnam - mainland onshore.',8.5,23.33,102.14,109.52,0);
INSERT INTO "area" VALUES('EPSG','1303','South America - Tierra del Fuego','Argentina and Chile - Tierra del Fuego, onshore.',-55.96,-51.99,-74.83,-63.73,0);
INSERT INTO "area" VALUES('EPSG','1304','Asia - Myanmar and Thailand onshore','Myanmar (Burma) - onshore; Thailand - onshore.',5.63,28.55,92.2,105.64,0);
INSERT INTO "area" VALUES('EPSG','1305','Europe - Ireland (Republic and Ulster) - onshore','Ireland - onshore. United Kingdom (UK) - Northern Ireland (Ulster) - onshore.',51.39,55.43,-10.56,-5.34,0);
INSERT INTO "area" VALUES('EPSG','1306','Europe - Czechoslovakia','Czechia; Slovakia.',47.73,51.06,12.09,22.56,0);
INSERT INTO "area" VALUES('EPSG','1307','Asia - Bangladesh; India; Myanmar; Pakistan - onshore','Bangladesh - onshore; India - mainland onshore; Myanmar (Burma) - onshore; Pakistan - onshore.',8.02,37.07,60.86,101.17,0);
INSERT INTO "area" VALUES('EPSG','1308','Asia - Bangladesh; India; Myanmar; Pakistan - onshore','Bangladesh - onshore; India - mainland onshore; Myanmar - onshore and Moattama area offshore; Pakistan - onshore.',8.02,37.07,60.86,101.17,0);
INSERT INTO "area" VALUES('EPSG','1309','Asia - Malaysia (west) and Singapore','Malaysia - West Malaysia; Singapore.',1.13,6.72,99.59,104.6,0);
INSERT INTO "area" VALUES('EPSG','1310','Kuwait - Kuwait City','Kuwait - Kuwait City.',29.17,29.45,47.78,48.16,0);
INSERT INTO "area" VALUES('EPSG','1311','Venezuela - Cabimas','Venezuela - Cabimas area.',10.14,10.61,-71.55,-71.29,0);
INSERT INTO "area" VALUES('EPSG','1312','Venezuela - Lake Maracaibo','Venezuela - Lake Maracaibo area, onshore and offshore in lake.',8.72,11.04,-72.4,-70.78,0);
INSERT INTO "area" VALUES('EPSG','1313','Venezuela - north of 7°45''N','Venezuela - onshore north of approximately 7°45''N.',7.75,12.25,-73.38,-59.8,0);
INSERT INTO "area" VALUES('EPSG','1314','Portugal - Madeira archipelago onshore','Portugal - Madeira, Porto Santo and Desertas islands - onshore.',32.35,33.15,-17.31,-16.23,0);
INSERT INTO "area" VALUES('EPSG','1315','Mozambique - west - Tete province','Mozambique - west - Tete province.',-17.76,-14.01,30.21,35.37,0);
INSERT INTO "area" VALUES('EPSG','1316','Indonesia - Sulawesi SW','Indonesia - south west Sulawesi.',-6.54,-1.88,118.71,120.78,0);
INSERT INTO "area" VALUES('EPSG','1317','Angola - Cabinda offshore','Angola - Cabinda offshore.',-6.04,-5.05,10.53,12.18,0);
INSERT INTO "area" VALUES('EPSG','1318','Angola - Cabinda','Angola - Cabinda.',-6.04,-4.38,10.53,13.1,0);
INSERT INTO "area" VALUES('EPSG','1319','Venezuela - Maracaibo area','Venezuela - Maracaibo area, onshore and offshore in lake.',10.0,11.0,-72.25,-71.5,0);
INSERT INTO "area" VALUES('EPSG','1320','Venezuela - Maturin','Venezuela - Maturin area.',9.1,10.13,-64.3,-63.0,0);
INSERT INTO "area" VALUES('EPSG','1321','Europe - Austria and former Yugoslavia onshore','Austria. Bosnia and Herzegovina. Croatia - onshore. Kosovo. Montenegro - onshore. North Macedonia. Serbia. Slovenia - onshore.',40.85,49.02,9.53,23.04,0);
INSERT INTO "area" VALUES('EPSG','1322','Trinidad and Tobago - Tobago - onshore','Trinidad and Tobago - Tobago - onshore.',11.08,11.41,-60.9,-60.44,0);
INSERT INTO "area" VALUES('EPSG','1323','USA - CONUS - onshore','United States (USA) - CONUS onshore - Alabama; Arizona; Arkansas; California; Colorado; Connecticut; Delaware; Florida; Georgia; Idaho; Illinois; Indiana; Iowa; Kansas; Kentucky; Louisiana; Maine; Maryland; Massachusetts; Michigan; Minnesota; Mississippi; Missouri; Montana; Nebraska; Nevada; New Hampshire; New Jersey; New Mexico; New York; North Carolina; North Dakota; Ohio; Oklahoma; Oregon; Pennsylvania; Rhode Island; South Carolina; South Dakota; Tennessee; Texas; Utah; Vermont; Virginia; Washington; West Virginia; Wisconsin; Wyoming.',24.41,49.38,-124.79,-66.91,0);
INSERT INTO "area" VALUES('EPSG','1324','USA (all states)','United States (USA) - onshore and offshore - Alabama; Alaska; Arizona; Arkansas; California; Colorado; Connecticut; Delaware; Florida; Georgia; Hawaii; Idaho; Illinois; Indiana; Iowa; Kansas; Kentucky; Louisiana; Maine; Maryland; Massachusetts; Michigan; Minnesota; Mississippi; Missouri; Montana; Nebraska; Nevada; New Hampshire; New Jersey; New Mexico; New York; North Carolina; North Dakota; Ohio; Oklahoma; Oregon; Pennsylvania; Rhode Island; South Carolina; South Dakota; Tennessee; Texas; Utah; Vermont; Virginia; Washington; West Virginia; Wisconsin; Wyoming.',15.56,74.71,167.65,-65.69,0);
INSERT INTO "area" VALUES('EPSG','1325','North America - Canada and USA (CONUS, Alaska mainland)','North America - onshore and offshore: Canada - Alberta; British Columbia; Manitoba; New Brunswick; Newfoundland and Labrador; Northwest Territories; Nova Scotia; Nunavut; Ontario; Prince Edward Island; Quebec; Saskatchewan; Yukon. United States (USA) - Alabama; Alaska (mainland); Arizona; Arkansas; California; Colorado; Connecticut; Delaware; Florida; Georgia; Idaho; Illinois; Indiana; Iowa; Kansas; Kentucky; Louisiana; Maine; Maryland; Massachusetts; Michigan; Minnesota; Mississippi; Missouri; Montana; Nebraska; Nevada; New Hampshire; New Jersey; New Mexico; New York; North Carolina; North Dakota; Ohio; Oklahoma; Oregon; Pennsylvania; Rhode Island; South Carolina; South Dakota; Tennessee; Texas; Utah; Vermont; Virginia; Washington; West Virginia; Wisconsin; Wyoming.',23.81,86.46,-172.54,-47.74,0);
INSERT INTO "area" VALUES('EPSG','1326','France - mainland onshore','France - mainland onshore.',42.33,51.14,-4.87,8.23,0);
INSERT INTO "area" VALUES('EPSG','1327','France - Corsica onshore','France - Corsica onshore.',41.31,43.07,8.5,9.63,0);
INSERT INTO "area" VALUES('EPSG','1328','Indonesia - Kalimantan - Mahakam delta','Indonesia - east Kalimantan - Mahakam delta coastal and offshore shelf areas.',-1.24,0.0,116.72,117.99,0);
INSERT INTO "area" VALUES('EPSG','1329','Mozambique - south','Mozambique - south.',-26.87,-19.84,31.29,35.65,0);
INSERT INTO "area" VALUES('EPSG','1330','USA - Alaska','United States (USA) - Alaska.',51.3,71.4,172.42,-129.99,0);
INSERT INTO "area" VALUES('EPSG','1331','USA - Alaska - St. George Island','United States (USA) - Alaska - Pribilof Islands - St George Island.',56.49,56.67,-169.88,-169.38,0);
INSERT INTO "area" VALUES('EPSG','1332','USA - Alaska - St. Lawrence Island','United States (USA) - Alaska - St Lawrence Island.',62.89,63.84,-171.97,-168.59,0);
INSERT INTO "area" VALUES('EPSG','1333','USA - Alaska - St. Paul Island','United States (USA) - Alaska - Pribilof Islands - St Paul Island.',57.06,57.28,-170.51,-170.04,0);
INSERT INTO "area" VALUES('EPSG','1334','USA - Hawaii - onshore','United States (USA) - Hawaii - main islands onshore.',18.87,22.29,-160.3,-154.74,0);
INSERT INTO "area" VALUES('EPSG','1335','Caribbean - Puerto Rico and Virgin Islands - onshore','Puerto Rico, US Virgin Islands and British Virgin Islands - onshore.',17.62,18.78,-67.97,-64.25,0);
INSERT INTO "area" VALUES('EPSG','1336','Canada - CSRS98','Canada - Alberta; New Brunswick; Saskatchewan; Prince Edward Island; and Quebec.',44.61,62.56,-120.0,-57.1,1);
INSERT INTO "area" VALUES('EPSG','1337','USA - HARN','American Samoa - onshore - Tutuila, Aunu''u, Ofu, Olesega, Ta''u and Rose islands. Guam - onshore. Northern Mariana Islands - onshore. Puerto Rico - onshore. United States (USA) - onshore Alabama, Alaska, Arizona, Arkansas, California, Colorado, Connecticut, Delaware, Florida, Georgia, Hawaii, Idaho, Illinois, Indiana, Iowa, Kansas, Kentucky, Louisiana, Maine, Maryland, Massachusetts, Michigan, Minnesota, Mississippi, Missouri, Montana, Nebraska, Nevada, New Hampshire, New Jersey, New Mexico, New York, North Carolina, North Dakota, Ohio, Oklahoma, Oregon, Pennsylvania, Rhode Island, South Carolina, South Dakota, Tennessee, Texas, Utah, Vermont, Virginia, Washington, West Virginia, Wisconsin and Wyoming; offshore Gulf of Mexico continental shelf (GoM OCS). US Virgin Islands - onshore.',-14.59,71.4,144.58,-64.51,0);
INSERT INTO "area" VALUES('EPSG','1338','Iran - Taheri refinery','Iran - Taheri refinery site.',27.39,27.61,52.5,52.71,0);
INSERT INTO "area" VALUES('EPSG','1339','Trinidad and Tobago - Trinidad','Trinidad and Tobago - Trinidad - onshore and offshore.',9.83,11.51,-62.09,-60.0,0);
INSERT INTO "area" VALUES('EPSG','1340','Yemen - South Yemen - mainland','Yemen - South Yemen onshore mainland.',12.54,19.0,43.37,53.14,0);
INSERT INTO "area" VALUES('EPSG','1341','South America by country','South America - Argentina, Brazil, Bolivia, Chile, Colombia, Ecuador, French Guiana, Guyana, Paraguay, Peru, Suriname, Uruguay, Venezuela.',-56.15,13.0,-82.0,-34.0,1);
INSERT INTO "area" VALUES('EPSG','1342','Sierra Leone - Freetown Peninsula','Sierra Leone - Freetown Peninsula.',8.32,8.55,-13.34,-13.13,0);
INSERT INTO "area" VALUES('EPSG','1343','Germany - East Germany all states','Germany - states of former East Germany - Berlin, Brandenburg; Mecklenburg-Vorpommern; Sachsen; Sachsen-Anhalt; Thuringen.',50.2,54.74,9.92,15.04,0);
INSERT INTO "area" VALUES('EPSG','1344','Portugal - Azores W - onshore','Portugal - western Azores onshore - Flores, Corvo.',39.3,39.77,-31.34,-31.02,0);
INSERT INTO "area" VALUES('EPSG','1345','Portugal - Azores E - onshore','Portugal - eastern Azores onshore - Sao Miguel, Santa Maria, Formigas.',36.87,37.96,-25.92,-24.62,0);
INSERT INTO "area" VALUES('EPSG','1346','Qatar - onshore','Qatar - onshore.',24.55,26.2,50.69,51.68,0);
INSERT INTO "area" VALUES('EPSG','1347','Belgium - onshore','Belgium - onshore.',49.5,51.51,2.5,6.4,0);
INSERT INTO "area" VALUES('EPSG','1348','South America - PSAD56 by country','Aruba - onshore; Bolivia; Bonaire - onshore; Brazil - offshore - Amazon Cone shelf; Chile - onshore north of 43°30''S; Curacao - onshore; Ecuador - mainland onshore; Guyana - onshore; Peru - onshore; Venezuela - onshore.',-43.5,12.68,-81.41,-47.99,0);
INSERT INTO "area" VALUES('EPSG','1349','North America - NAD27','North and central America: Antigua and Barbuda - onshore. Bahamas - onshore plus offshore over internal continental shelf only. Belize - onshore. British Virgin Islands - onshore. Canada onshore - Alberta, British Columbia, Manitoba, New Brunswick, Newfoundland and Labrador, Northwest Territories, Nova Scotia, Nunavut, Ontario, Prince Edward Island, Quebec, Saskatchewan and Yukon - plus offshore east coast. Cuba - onshore and offshore. El Salvador - onshore. Guatemala - onshore. Honduras - onshore. Panama - onshore. Puerto Rico - onshore. Mexico - onshore plus offshore east coast. Nicaragua - onshore. United States (USA) onshore and offshore - Alabama, Alaska, Arizona, Arkansas, California, Colorado, Connecticut, Delaware, Florida, Georgia, Idaho, Illinois, Indiana, Iowa, Kansas, Kentucky, Louisiana, Maine, Maryland, Massachusetts, Michigan, Minnesota, Mississippi, Missouri, Montana, Nebraska, Nevada, New Hampshire, New Jersey, New Mexico, New York, North Carolina, North Dakota, Ohio, Oklahoma, Oregon, Pennsylvania, Rhode Island, South Carolina, South Dakota, Tennessee, Texas, Utah, Vermont, Virginia, Washington, West Virginia, Wisconsin and Wyoming - plus offshore . US Virgin Islands - onshore.',7.15,83.17,167.65,-47.74,0);
INSERT INTO "area" VALUES('EPSG','1350','North America - NAD83','North America - onshore and offshore: Canada - Alberta; British Columbia; Manitoba; New Brunswick; Newfoundland and Labrador; Northwest Territories; Nova Scotia; Nunavut; Ontario; Prince Edward Island; Quebec; Saskatchewan; Yukon. Puerto Rico. United States (USA) - Alabama; Alaska; Arizona; Arkansas; California; Colorado; Connecticut; Delaware; Florida; Georgia; Hawaii; Idaho; Illinois; Indiana; Iowa; Kansas; Kentucky; Louisiana; Maine; Maryland; Massachusetts; Michigan; Minnesota; Mississippi; Missouri; Montana; Nebraska; Nevada; New Hampshire; New Jersey; New Mexico; New York; North Carolina; North Dakota; Ohio; Oklahoma; Oregon; Pennsylvania; Rhode Island; South Carolina; South Dakota; Tennessee; Texas; Utah; Vermont; Virginia; Washington; West Virginia; Wisconsin; Wyoming. US Virgin Islands.  British Virgin Islands.',14.92,86.46,167.65,-47.74,0);
INSERT INTO "area" VALUES('EPSG','1351','Asia - Middle East - Qatar offshore and UAE','Arabian Gulf; Qatar - offshore; United Arab Emirates (UAE) - Abu Dhabi; Dubai; Sharjah; Ajman; Fujairah; Ras Al Kaimah; Umm Al Qaiwain - onshore and offshore.',22.63,27.05,50.55,57.13,0);
INSERT INTO "area" VALUES('EPSG','1352','Norway - onshore','Norway - onshore.',57.93,71.21,4.68,31.22,0);
INSERT INTO "area" VALUES('EPSG','1353','France - onshore','France - onshore.',NULL,NULL,NULL,NULL,1);
INSERT INTO "area" VALUES('EPSG','1354','Europe - British Isles - UK and Ireland onshore','Ireland - onshore. United Kingdom (UK) - onshore - England; Scotland; Wales; Northern Ireland. Isle of Man.',49.81,60.9,-10.56,1.84,0);
INSERT INTO "area" VALUES('EPSG','1355','Indonesia - Sumatra','Indonesia - Sumatra.',-5.99,5.97,95.16,106.13,0);
INSERT INTO "area" VALUES('EPSG','1356','Asia - Middle East - Israel, Jordan and Palestine onshore','Israel - onshore; Jordan; Palestine Territory - onshore.',29.18,33.38,34.17,39.31,0);
INSERT INTO "area" VALUES('EPSG','1357','Europe - eastern and FSU','Albania; Bulgaria; Czech Republic; Germany (former DDR); Hungary; Poland; Romania; Slovakia. Armenia; Azerbaijan; Belarus; Estonia; Georgia; Kazakhstan; Kyrgyzstan; Latvia; Lithuania; Moldova; Russian Federation; Tajikistan; Turkmenistan; Ukraine; Uzbekistan.',35.1,78.0,9.87,-169.73,1);
INSERT INTO "area" VALUES('EPSG','1358','South America - SAD69 by country','Brazil - onshore and offshore. In rest of South America - onshore north of approximately 45°S and Tierra del Fuego.',-55.96,12.52,-91.72,-25.28,0);
INSERT INTO "area" VALUES('EPSG','1359','Indonesia - Kalimantan SE','Indonesia - Kalimantan - onshore southeast coastal area including Mahakam delta coastal and offshore shelf areas.',-4.24,0.0,114.55,117.99,0);
INSERT INTO "area" VALUES('EPSG','1360','Indonesia - Kalimantan E','Indonesia - Kalimantan - onshore east coastal area including Mahakam delta coastal and offshore shelf areas.',-4.24,4.29,114.55,119.06,0);
INSERT INTO "area" VALUES('EPSG','1361','Sudan - south','Sudan - south.',NULL,NULL,NULL,NULL,1);
INSERT INTO "area" VALUES('EPSG','1362','Asia - Brunei and East Malaysia','Brunei - onshore and offshore; Malaysia - East Malaysia (Sabah; Sarawak) - onshore and offshore.',0.85,7.67,109.31,119.61,0);
INSERT INTO "area" VALUES('EPSG','1363','UAE - Abu Dhabi and Dubai - onshore','United Arab Emirates (UAE) - Abu Dhabi onshore and Dubai onshore.',22.63,25.34,51.56,56.03,0);
INSERT INTO "area" VALUES('EPSG','1364','Asia - Japan and Korea','Japan - onshore; North Korea - onshore; South Korea - onshore.',20.37,45.54,122.83,154.05,0);
INSERT INTO "area" VALUES('EPSG','1365','Algeria - north of 32°N','Algeria - onshore north of 32°N.',31.99,37.14,-2.95,9.09,0);
INSERT INTO "area" VALUES('EPSG','1366','Africa - Algeria, Morocco and Tunisia','Algeria; Morocco; Tunisia.',18.98,37.34,-13.17,11.99,1);
INSERT INTO "area" VALUES('EPSG','1367','Canada - Ontario','Canada - Ontario.',41.67,56.9,-95.16,-74.35,0);
INSERT INTO "area" VALUES('EPSG','1368','Canada - Quebec','Canada - Quebec.',44.99,62.62,-79.85,-57.1,0);
INSERT INTO "area" VALUES('EPSG','1369','France - Alsace','France - Alsace.',47.42,49.07,6.84,8.23,0);
INSERT INTO "area" VALUES('EPSG','1370','Venezuela - Deltana','Venezuela - Deltana area.',7.89,10.46,-62.8,-59.8,0);
INSERT INTO "area" VALUES('EPSG','1371','Venezuela - Guarico state','Venezuela - Guarico state.',7.54,10.03,-68.0,-64.76,0);
INSERT INTO "area" VALUES('EPSG','1372','USA - Alabama','United States (USA) - Alabama.',30.14,35.02,-88.48,-84.89,0);
INSERT INTO "area" VALUES('EPSG','1373','USA - Arizona','United States (USA) - Arizona.',31.33,37.01,-114.81,-109.04,0);
INSERT INTO "area" VALUES('EPSG','1374','USA - Arkansas','United States (USA) - Arkansas.',33.01,36.5,-94.62,-89.64,0);
INSERT INTO "area" VALUES('EPSG','1375','USA - California','United States (USA) - California.',32.53,42.01,-124.45,-114.12,0);
INSERT INTO "area" VALUES('EPSG','1376','USA - Colorado','United States (USA) - Colorado.',36.98,41.01,-109.06,-102.04,0);
INSERT INTO "area" VALUES('EPSG','1377','USA - Connecticut','United States (USA) - Connecticut - counties of Fairfield; Hartford; Litchfield; Middlesex; New Haven; New London; Tolland; Windham.',40.98,42.05,-73.73,-71.78,0);
INSERT INTO "area" VALUES('EPSG','1378','USA - Delaware','United States (USA) - Delaware - counties of Kent; New Castle; Sussex.',38.44,39.85,-75.8,-74.97,0);
INSERT INTO "area" VALUES('EPSG','1379','USA - Florida','United States (USA) - Florida.',24.41,31.01,-87.63,-79.97,0);
INSERT INTO "area" VALUES('EPSG','1380','USA - Georgia','United States (USA) - Georgia.',30.36,35.01,-85.61,-80.77,0);
INSERT INTO "area" VALUES('EPSG','1381','USA - Idaho','United States (USA) - Idaho.',41.99,49.01,-117.24,-111.04,0);
INSERT INTO "area" VALUES('EPSG','1382','USA - Illinois','United States (USA) - Illinois.',36.98,42.51,-91.52,-87.02,0);
INSERT INTO "area" VALUES('EPSG','1383','USA - Indiana','United States (USA) - Indiana.',37.77,41.77,-88.06,-84.78,0);
INSERT INTO "area" VALUES('EPSG','1384','USA - Iowa','United States (USA) - Iowa.',40.37,43.51,-96.65,-90.14,0);
INSERT INTO "area" VALUES('EPSG','1385','USA - Kansas','United States (USA) - Kansas.',36.99,40.01,-102.06,-94.58,0);
INSERT INTO "area" VALUES('EPSG','1386','USA - Kentucky','United States (USA) - Kentucky.',36.49,39.15,-89.57,-81.95,0);
INSERT INTO "area" VALUES('EPSG','1387','USA - Louisiana','United States (USA) - Louisiana.',28.85,33.03,-94.05,-88.75,0);
INSERT INTO "area" VALUES('EPSG','1388','USA - Maine','United States (USA) - Maine.',43.04,47.47,-71.09,-66.91,0);
INSERT INTO "area" VALUES('EPSG','1389','USA - Maryland','United States (USA) - Maryland - counties of Allegany; Anne Arundel; Baltimore; Calvert; Caroline; Carroll; Cecil; Charles; Dorchester; Frederick; Garrett; Harford; Howard; Kent; Montgomery; Prince Georges; Queen Annes; Somerset; St Marys; Talbot; Washington; Wicomico; Worcester.',37.97,39.73,-79.49,-74.97,0);
INSERT INTO "area" VALUES('EPSG','1390','USA - Massachusetts','United States (USA) - Massachusetts.',41.19,42.89,-73.5,-69.86,0);
INSERT INTO "area" VALUES('EPSG','1391','USA - Michigan','United States (USA) - Michigan.',41.69,48.32,-90.42,-82.13,0);
INSERT INTO "area" VALUES('EPSG','1392','USA - Minnesota','United States (USA) - Minnesota.',43.49,49.38,-97.22,-89.49,0);
INSERT INTO "area" VALUES('EPSG','1393','USA - Mississippi','United States (USA) - Mississippi.',30.01,35.01,-91.65,-88.09,0);
INSERT INTO "area" VALUES('EPSG','1394','USA - Missouri','United States (USA) - Missouri.',35.98,40.61,-95.77,-89.1,0);
INSERT INTO "area" VALUES('EPSG','1395','USA - Montana','United States (USA) - Montana - counties of Beaverhead; Big Horn; Blaine; Broadwater; Carbon; Carter; Cascade; Chouteau; Custer; Daniels; Dawson; Deer Lodge; Fallon; Fergus; Flathead; Gallatin; Garfield; Glacier; Golden Valley; Granite; Hill; Jefferson; Judith Basin; Lake; Lewis and Clark; Liberty; Lincoln; Madison; McCone; Meagher; Mineral; Missoula; Musselshell; Park; Petroleum; Phillips; Pondera; Powder River; Powell; Prairie; Ravalli; Richland; Roosevelt; Rosebud; Sanders; Sheridan; Silver Bow; Stillwater; Sweet Grass; Teton; Toole; Treasure; Valley; Wheatland; Wibaux; Yellowstone.',44.35,49.01,-116.07,-104.04,0);
INSERT INTO "area" VALUES('EPSG','1396','USA - Nebraska','United States (USA) - Nebraska - counties of Adams; Antelope; Arthur; Banner; Blaine; Boone; Box Butte; Boyd; Brown; Buffalo; Burt; Butler; Cass; Cedar; Chase; Cherry; Cheyenne; Clay; Colfax; Cuming; Custer; Dakota; Dawes; Dawson; Deuel; Dixon; Dodge; Douglas; Dundy; Fillmore; Franklin; Frontier; Furnas; Gage; Garden; Garfield; Gosper; Grant; Greeley; Hall; Hamilton; Harlan; Hayes; Hitchcock; Holt; Hooker; Howard; Jefferson; Johnson; Kearney; Keith; Keya Paha; Kimball; Knox; Lancaster; Lincoln; Logan; Loup; Madison; McPherson; Merrick; Morrill; Nance; Nemaha; Nuckolls; Otoe; Pawnee; Perkins; Phelps; Pierce; Platte; Polk; Red Willow; Richardson; Rock; Saline; Sarpy; Saunders; Scotts Bluff; Seward; Sheridan; Sherman; Sioux; Stanton; Thayer; Thomas; Thurston; Valley; Washington; Wayne; Webster; Wheeler; York.',39.99,43.01,-104.06,-95.3,0);
INSERT INTO "area" VALUES('EPSG','1397','USA - Nevada','United States (USA) - Nevada.',34.99,42.0,-120.0,-114.03,0);
INSERT INTO "area" VALUES('EPSG','1398','USA - New Hampshire','United States (USA) - New Hampshire - counties of Belknap; Carroll; Cheshire; Coos; Grafton; Hillsborough; Merrimack; Rockingham; Strafford; Sullivan.',42.69,45.31,-72.56,-70.63,0);
INSERT INTO "area" VALUES('EPSG','1399','USA - New Jersey','United States (USA) - New Jersey - counties of Atlantic; Bergen; Burlington; Camden; Cape May; Cumberland; Essex; Gloucester; Hudson; Hunterdon; Mercer; Middlesex; Monmouth; Morris; Ocean; Passaic; Salem; Somerset; Sussex; Union; Warren.',38.87,41.36,-75.6,-73.88,0);
INSERT INTO "area" VALUES('EPSG','1400','USA - New Mexico','United States (USA) - New Mexico.',31.33,37.0,-109.06,-102.99,0);
INSERT INTO "area" VALUES('EPSG','1401','USA - New York','United States (USA) - New York.',40.47,45.02,-79.77,-71.8,0);
INSERT INTO "area" VALUES('EPSG','1402','USA - North Carolina','United States (USA) - North Carolina - counties of Alamance; Alexander; Alleghany; Anson; Ashe; Avery; Beaufort; Bertie; Bladen; Brunswick; Buncombe; Burke; Cabarrus; Caldwell; Camden; Carteret; Caswell; Catawba; Chatham; Cherokee; Chowan; Clay; Cleveland; Columbus; Craven; Cumberland; Currituck; Dare; Davidson; Davie; Duplin; Durham; Edgecombe; Forsyth; Franklin; Gaston; Gates; Graham; Granville; Greene; Guilford; Halifax; Harnett; Haywood; Henderson; Hertford; Hoke; Hyde; Iredell; Jackson; Johnston; Jones; Lee; Lenoir; Lincoln; Macon; Madison; Martin; McDowell; Mecklenburg; Mitchell; Montgomery; Moore; Nash; New Hanover; Northampton; Onslow; Orange; Pamlico; Pasquotank; Pender; Perquimans; Person; Pitt; Polk; Randolph; Richmond; Robeson; Rockingham; Rowan; Rutherford; Sampson; Scotland; Stanly; Stokes; Surry; Swain; Transylvania; Tyrrell; Union; Vance; Wake; Warren; Washington; Watauga; Wayne; Wilkes; Wilson; Yadkin; Yancey.',33.83,36.59,-84.33,-75.38,0);
INSERT INTO "area" VALUES('EPSG','1403','USA - North Dakota','United States (USA) - North Dakota.',45.93,49.01,-104.07,-96.55,0);
INSERT INTO "area" VALUES('EPSG','1404','USA - Ohio','United States (USA) - Ohio.',38.4,42.33,-84.83,-80.51,0);
INSERT INTO "area" VALUES('EPSG','1405','USA - Oklahoma','United States (USA) - Oklahoma.',33.62,37.01,-103.0,-94.42,0);
INSERT INTO "area" VALUES('EPSG','1406','USA - Oregon','United States (USA) - Oregon.',41.98,46.26,-124.6,-116.47,0);
INSERT INTO "area" VALUES('EPSG','1407','USA - Pennsylvania','United States (USA) - Pennsylvania.',39.71,42.53,-80.53,-74.7,0);
INSERT INTO "area" VALUES('EPSG','1408','USA - Rhode Island','United States (USA) - Rhode Island - counties of Bristol; Kent; Newport; Providence; Washington.',41.13,42.02,-71.85,-71.08,0);
INSERT INTO "area" VALUES('EPSG','1409','USA - South Carolina','United States (USA) - South Carolina - counties of Abbeville; Aiken; Allendale; Anderson; Bamberg; Barnwell; Beaufort; Berkeley; Calhoun; Charleston; Cherokee; Chester; Chesterfield; Clarendon; Colleton; Darlington; Dillon; Dorchester; Edgefield; Fairfield; Florence; Georgetown; Greenville; Greenwood; Hampton; Horry; Jasper; Kershaw; Lancaster; Laurens; Lee; Lexington; Marion; Marlboro; McCormick; Newberry; Oconee; Orangeburg; Pickens; Richland; Saluda; Spartanburg; Sumter; Union; Williamsburg; York.',32.05,35.21,-83.36,-78.52,0);
INSERT INTO "area" VALUES('EPSG','1410','USA - South Dakota','United States (USA) - South Dakota.',42.48,45.95,-104.07,-96.43,0);
INSERT INTO "area" VALUES('EPSG','1411','USA - Tennessee','United States (USA) - Tennessee - counties of Anderson; Bedford; Benton; Bledsoe; Blount; Bradley; Campbell; Cannon; Carroll; Carter; Cheatham; Chester; Claiborne; Clay; Cocke; Coffee; Crockett; Cumberland; Davidson; De Kalb; Decatur; Dickson; Dyer; Fayette; Fentress; Franklin; Gibson; Giles; Grainger; Greene; Grundy; Hamblen; Hamilton; Hancock; Hardeman; Hardin; Hawkins; Haywood; Henderson; Henry; Hickman; Houston; Humphreys; Jackson; Jefferson; Johnson; Knox; Lake; Lauderdale; Lawrence; Lewis; Lincoln; Loudon; Macon; Madison; Marion; Marshall; Maury; McMinn; McNairy; Meigs; Monroe; Montgomery; Moore; Morgan; Obion; Overton; Perry; Pickett; Polk; Putnam; Rhea; Roane; Robertson; Rutherford; Scott; Sequatchie; Sevier; Shelby; Smith; Stewart; Sullivan; Sumner; Tipton; Trousdale; Unicoi; Union; Van Buren; Warren; Washington; Wayne; Weakley; White; Williamson; Wilson.',34.98,36.68,-90.31,-81.65,0);
INSERT INTO "area" VALUES('EPSG','1412','USA - Texas','United States (USA) - Texas.',25.83,36.5,-106.66,-93.5,0);
INSERT INTO "area" VALUES('EPSG','1413','USA - Utah','United States (USA) - Utah.',36.99,42.01,-114.05,-109.04,0);
INSERT INTO "area" VALUES('EPSG','1414','USA - Vermont','United States (USA) - Vermont - counties of Addison; Bennington; Caledonia; Chittenden; Essex; Franklin; Grand Isle; Lamoille; Orange; Orleans; Rutland; Washington; Windham; Windsor.',42.72,45.03,-73.44,-71.5,0);
INSERT INTO "area" VALUES('EPSG','1415','USA - Virginia','United States (USA) - Virginia.',36.54,39.46,-83.68,-75.31,0);
INSERT INTO "area" VALUES('EPSG','1416','USA - Washington','United States (USA) - Washington.',45.54,49.05,-124.79,-116.91,0);
INSERT INTO "area" VALUES('EPSG','1417','USA - West Virginia','United States (USA) - West Virginia.',37.2,40.64,-82.65,-77.72,0);
INSERT INTO "area" VALUES('EPSG','1418','USA - Wisconsin','United States (USA) - Wisconsin.',42.48,47.31,-92.89,-86.25,0);
INSERT INTO "area" VALUES('EPSG','1419','USA - Wyoming','United States (USA) - Wyoming.',40.99,45.01,-111.06,-104.05,0);
INSERT INTO "area" VALUES('EPSG','1420','Canada - Quebec - east of 57°W','Canada - Quebec - east of 57°W.',46.6,53.76,-57.0,-54.0,1);
INSERT INTO "area" VALUES('EPSG','1421','Canada - Quebec - 60°W to 57°W','Canada - Quebec - between 60°W and 57°W.',50.1,52.0,-60.0,-57.1,1);
INSERT INTO "area" VALUES('EPSG','1422','Canada - Quebec - 63°W to 60°W','Canada - Quebec - between 63°W and 60°W.',47.16,52.01,-63.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','1423','Canada - Quebec - 66°W to 63°W','Canada - Quebec - between 66°W and 63°W.',47.95,60.42,-66.0,-63.0,0);
INSERT INTO "area" VALUES('EPSG','1424','Canada - Quebec - 69°W to 66°W','Canada - Quebec - between 69°W and 66°W.',47.31,59.0,-69.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','1425','Canada - Quebec - 72°W to 69°W','Canada - Quebec - between 72°W and 69°W.',45.01,61.8,-72.0,-69.0,0);
INSERT INTO "area" VALUES('EPSG','1426','Canada - Quebec - 75°W to 72°W','Canada - Quebec - between 75°W and 72°W.',44.99,62.53,-75.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','1427','Canada - Quebec - 78°W to 75°W','Canada - Quebec - between 78°W and 75°W.',45.37,62.62,-78.0,-75.0,0);
INSERT INTO "area" VALUES('EPSG','1428','Canada - Quebec - west of 78°W','Canada - Quebec - west of 78°W.',46.23,62.45,-79.85,-78.0,0);
INSERT INTO "area" VALUES('EPSG','1429','Canada - Ontario - east of 75°W','Canada - Ontario - east of 75°W.',44.98,45.65,-75.0,-74.35,0);
INSERT INTO "area" VALUES('EPSG','1430','Canada - Ontario - 78°W to 75°W','Canada - Ontario - between 78°W and 75°W.',43.63,46.25,-78.0,-75.0,0);
INSERT INTO "area" VALUES('EPSG','1431','Canada - Ontario - MTM zone 10','Canada - Ontario - between 81°W and 78°W: south of 46°N in area to west of 80°15''W, south of 47°N in area between 80°15''W and 79°30''W, entire province between 79°30''W and 78°W.',42.26,47.33,-81.0,-77.99,0);
INSERT INTO "area" VALUES('EPSG','1432','Canada - Ontario - MTM zone 11','Canada - Ontario - south of 46°N and west of 81°W.',41.67,46.0,-83.6,-81.0,0);
INSERT INTO "area" VALUES('EPSG','1433','Canada - Ontario - MTM zone 12','Canada - Ontario - between 82°30''W and 79°30''W: north of 46°N in area between 82°30''W and 80°15''W, north of 47°N in area between 80°15''W and 79°30''W.',46.0,55.21,-82.5,-79.5,0);
INSERT INTO "area" VALUES('EPSG','1434','Canada - Ontario - MTM zone 13','Canada - Ontario - between 85°30''W and 82°30''W and north of 46°N.',46.0,55.59,-85.5,-82.5,0);
INSERT INTO "area" VALUES('EPSG','1435','Canada - Ontario - 88.5°W to 85.5°W','Canada - Ontario - between 88°30''W and 85°30''W.',47.17,56.7,-88.5,-85.5,0);
INSERT INTO "area" VALUES('EPSG','1436','Canada - Ontario - 91.5°W to 88.5°W','Canada - Ontario - between 91°30''W and 88°30''W.',47.97,56.9,-91.5,-88.5,0);
INSERT INTO "area" VALUES('EPSG','1437','Canada - Ontario - 94.5°W to 91.5°W','Canada - Ontario - between 94°30''W and 91°30''W.',48.06,55.2,-94.5,-91.5,0);
INSERT INTO "area" VALUES('EPSG','1438','Canada - Ontario - west of 94.5°W','Canada - Ontario - west of 94°30''W.',48.69,53.24,-95.16,-94.5,0);
INSERT INTO "area" VALUES('EPSG','1439','Canada - Ontario - west of 90°W','Canada - Ontario - west of 90°W.',48.03,56.2,-95.17,-90.0,0);
INSERT INTO "area" VALUES('EPSG','1440','Canada - Ontario - 90°W to 84°W','Canada - Ontario - between 90°W and 84°W.',46.11,56.9,-90.0,-84.0,0);
INSERT INTO "area" VALUES('EPSG','1441','Canada - Ontario - 84°W to 78°W','Canada - Ontario - between 84°W and 78°W.',41.67,55.37,-84.0,-78.0,0);
INSERT INTO "area" VALUES('EPSG','1442','Canada - Ontario - east of 78°W','Canada - Ontario - east of 78°W.',43.63,46.25,-78.0,-74.35,0);
INSERT INTO "area" VALUES('EPSG','1443','Canada - Quebec - 78°W to 72°W','Canada - Quebec - between 78°W and 72°W.',44.99,62.62,-78.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','1444','Canada - Quebec - 72°W to 66°W','Canada - Quebec - between 72°W and 66°W.',45.01,61.8,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','1445','Canada - Quebec - 66°W to 60°W','Canada - Quebec - between 66°W and 60°W.',47.16,60.42,-66.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','1446','Canada - Quebec - east of 60°W','Canada - Quebec - east of 60°W.',50.2,52.01,-60.0,-57.1,0);
INSERT INTO "area" VALUES('EPSG','1447','Canada - New Brunswick','Canada - New Brunswick.',44.56,48.07,-69.05,-63.7,0);
INSERT INTO "area" VALUES('EPSG','1448','Canada - 72°W to 66°W, south of 62°N','Canada south of 60°N and between 72°W and 66°W - New Brunswick (NB), Labrador, Nova Scotia (NS), Quebec.',44.6,61.5,-72.0,-66.0,1);
INSERT INTO "area" VALUES('EPSG','1449','Canada - 66°W to 60°W, south of 60°N','Canada south of 60°N and between 66°W and 60°W - New Brunswick (NB), Labrador, Nova Scotia (NS), Prince Edward Island (PEI), Quebec.',43.2,60.0,-66.0,-60.0,1);
INSERT INTO "area" VALUES('EPSG','1450','Cote d''Ivoire (Ivory Coast) - east of 6°W','Côte d''Ivoire (Ivory Coast) east of 6°W.',4.92,10.46,-6.0,-2.48,0);
INSERT INTO "area" VALUES('EPSG','1451','Cote d''Ivoire (Ivory Coast) - west of 6°W','Côte d''Ivoire (Ivory Coast) west of 6°W.',4.29,10.74,-8.61,-6.0,0);
INSERT INTO "area" VALUES('EPSG','1452','Vietnam - west of 108°E onshore','Vietnam - onshore west of 108°E.',8.5,23.33,102.14,108.0,0);
INSERT INTO "area" VALUES('EPSG','1453','Vietnam - east of 108°E onshore','Vietnam - onshore east of 108°E.',10.42,21.56,108.0,109.52,0);
INSERT INTO "area" VALUES('EPSG','1454','Namibia - Walvis Bay','Namibia - Walvis Bay.',-23.15,-22.68,14.35,14.6,0);
INSERT INTO "area" VALUES('EPSG','1455','South Africa - west of 18°E','South Africa - onshore west of 18°E.',-33.1,-28.03,16.45,18.0,0);
INSERT INTO "area" VALUES('EPSG','1456','South Africa - 18°E to 20°E','South Africa - onshore between 18°E and 20°E.',-34.88,-28.38,17.99,20.0,0);
INSERT INTO "area" VALUES('EPSG','1457','South Africa - 20°E to 22°E','South Africa - onshore between 20°E and 22°E.',-34.88,-24.76,19.99,22.01,0);
INSERT INTO "area" VALUES('EPSG','1458','South Africa - 22°E to 24°E','South Africa - onshore between 22°E and 24°E.',-34.26,-25.26,22.0,24.01,0);
INSERT INTO "area" VALUES('EPSG','1459','South Africa - 24°E to 26°E','South Africa - onshore between 24°E and 26°E.',-34.26,-24.71,24.0,26.01,0);
INSERT INTO "area" VALUES('EPSG','1460','South Africa - 26°E to 28°E','Lesotho - west of 28°E. South Africa - onshore between 26°E and 28°E.',-33.83,-22.92,26.0,28.0,0);
INSERT INTO "area" VALUES('EPSG','1461','South Africa - 28°E to 30°E','Lesotho - east of 28°E. South Africa - onshore between 28°E and 30°E.',-33.03,-22.13,27.99,30.0,0);
INSERT INTO "area" VALUES('EPSG','1462','South Africa - 30°E to 32°E','South Africa - onshore between 30°E and 32°E. Eswatini (Swaziland).',-31.38,-22.22,29.99,32.02,0);
INSERT INTO "area" VALUES('EPSG','1463','South Africa - east of 32°E','South Africa - east of 32°E.',-28.94,-26.8,31.95,32.95,0);
INSERT INTO "area" VALUES('EPSG','1464','Iran - west of 48°E','Iran - west of 48°E.',30.99,39.78,44.03,48.0,0);
INSERT INTO "area" VALUES('EPSG','1465','Iran - 48°E to 54°E','Iran - onshore and offshore between 48°E and 54°E.',25.47,39.71,48.0,54.0,0);
INSERT INTO "area" VALUES('EPSG','1466','Iran - 54°E to 60°E','Iran - onshore between 54°E and 60°E, Gulf offshore between of 54°E and Strait of Hormuz.',25.32,38.29,54.0,60.0,0);
INSERT INTO "area" VALUES('EPSG','1467','Iran - east of 60°E onshore','Iran - onshore east of 60°E.',25.02,37.06,60.0,63.34,0);
INSERT INTO "area" VALUES('EPSG','1468','Guinea - west of 12°W','Guinea - onshore west of 12°W.',9.01,12.68,-15.13,-12.0,0);
INSERT INTO "area" VALUES('EPSG','1469','Guinea - east of 12°W','Guinea - east of 12°W.',7.19,12.51,-12.0,-7.65,0);
INSERT INTO "area" VALUES('EPSG','1470','Libya - west of 10°E','Libya - west of 10°E.',25.37,30.49,9.31,10.01,0);
INSERT INTO "area" VALUES('EPSG','1471','Libya - 10°E to 12°E onshore','Libya - onshore between 10°E and 12°E.',23.51,33.23,10.0,12.0,0);
INSERT INTO "area" VALUES('EPSG','1472','Libya - 12°E to 14°E onshore','Libya - onshore between 12°E and 14°E.',22.8,33.06,12.0,14.0,0);
INSERT INTO "area" VALUES('EPSG','1473','Libya - 14°E to 16°E onshore','Libya - onshore between 14°E and 16°E.',22.61,32.79,14.0,16.0,0);
INSERT INTO "area" VALUES('EPSG','1474','Libya - 16°E to 18°E onshore','Libya - onshore between 16°E and 18°E.',22.51,31.34,16.0,18.01,0);
INSERT INTO "area" VALUES('EPSG','1475','Libya - 18°E to 20°E onshore','Libya - onshore between 18°E and 20°E.',21.54,32.17,18.0,20.0,0);
INSERT INTO "area" VALUES('EPSG','1476','Libya - 20°E to 22°E onshore','Libya - onshore between 20°E and 22°E.',20.54,33.0,20.0,22.0,0);
INSERT INTO "area" VALUES('EPSG','1477','Libya - 22°E to 24°E onshore','Libya - onshore between 22°E and 24°E.',19.5,32.97,22.0,24.0,0);
INSERT INTO "area" VALUES('EPSG','1478','Libya - east of 24°E onshore','Libya - onshore east of 24°E.',19.99,32.15,24.0,25.21,0);
INSERT INTO "area" VALUES('EPSG','1479','Libya - west of 12°E onshore','Libya - onshore west of 12°E.',23.51,33.23,9.31,12.0,0);
INSERT INTO "area" VALUES('EPSG','1480','Libya - 12°E to 18°E onshore','Libya - onshore between 12°E and 18°E.',22.51,33.06,12.0,18.01,0);
INSERT INTO "area" VALUES('EPSG','1481','Libya - 18°E to 24°E onshore','Libya - onshore between 18°E and 24°E.',19.5,33.0,17.99,24.0,0);
INSERT INTO "area" VALUES('EPSG','1482','Libya - west of 15°E onshore','Libya - onshore west of 15°E.',22.61,33.23,9.31,15.0,0);
INSERT INTO "area" VALUES('EPSG','1483','Argentina - Neuquen province east of 70.5°W','Argentina - Neuquen province east of 70°30''W.',-40.54,-36.14,-70.51,-68.01,0);
INSERT INTO "area" VALUES('EPSG','1484','Argentina - Comodoro Rivadavia - west of 67.5°W','Argentina - Comodoro Rivadavia area west of 67°30''W.',-46.7,-45.19,-69.5,-67.5,0);
INSERT INTO "area" VALUES('EPSG','1485','Argentina - Tierra del Fuego onshore west of 67.5°W','Argentina - Tierra del Fuego onshore west of 67°30''W.',-54.9,-52.59,-68.64,-67.5,0);
INSERT INTO "area" VALUES('EPSG','1486','Argentina - Tierra del Fuego offshore','Argentina - Tierra del Fuego offshore Atlantic.',-54.93,-51.36,-68.62,-61.49,0);
INSERT INTO "area" VALUES('EPSG','1487','Cuba - onshore north of 21°30''N','Cuba - onshore north of 21°30''N but also including all of Isla de la Juventud.',21.38,23.25,-85.01,-76.91,0);
INSERT INTO "area" VALUES('EPSG','1488','Cuba - onshore south of 21°30''N','Cuba - onshore south of 21°30''N and east of 80°W .',19.77,21.5,-78.69,-74.07,0);
INSERT INTO "area" VALUES('EPSG','1489','Tunisia - offshore','Tunisia - offshore.',33.22,38.41,7.81,13.67,0);
INSERT INTO "area" VALUES('EPSG','1490','Yemen - 42°E to 48°E','Yemen - between 42°E and 48°E, onshore and offshore.',11.57,17.53,42.0,48.0,0);
INSERT INTO "area" VALUES('EPSG','1491','Yemen - 48°E to 54°E','Yemen - between 48°E and 54°E, onshore and offshore.',9.45,19.0,48.0,54.0,0);
INSERT INTO "area" VALUES('EPSG','1492','Yemen - South Yemen - mainland west of 48°E','Yemen - South Yemen onshore mainland west of 48°E.',12.54,17.44,43.37,48.0,0);
INSERT INTO "area" VALUES('EPSG','1493','Yemen - South Yemen - mainland east of 48°E','Yemen - South Yemen onshore mainland east of 48°E.',13.94,19.0,48.0,53.14,0);
INSERT INTO "area" VALUES('EPSG','1494','Vietnam - onshore Vung Tau area','Vietnam - onshore Vung Tau area.',9.02,11.03,105.49,107.59,0);
INSERT INTO "area" VALUES('EPSG','1495','Vietnam - offshore Cuu Long basin','Vietnam - offshore - Cuu Long basin and northwestern part of Nam Con Son basin.',7.99,11.15,106.54,110.0,0);
INSERT INTO "area" VALUES('EPSG','1496','Korea, Republic of (South Korea) - east of 128°E onshore','Republic of Korea (South Korea) - onshore east of 128°E.',34.49,38.64,128.0,129.65,0);
INSERT INTO "area" VALUES('EPSG','1497','Korea, Republic of (South Korea) - 126°E to 128°E onshore','Republic of Korea (South Korea) - onshore between 126°E and 128°E.',33.14,38.33,126.0,128.0,0);
INSERT INTO "area" VALUES('EPSG','1498','Korea, Republic of (South Korea) - 124°E to 126°E onshore','Republic of Korea (South Korea) - onshore between 124°E and 126°E.',33.99,38.04,124.53,126.0,0);
INSERT INTO "area" VALUES('EPSG','1499','Venezuela - Maracaibo - blocks I II and III','Venezuela - Maracaibo area offshore blocks I, II and III.',10.0,10.51,-71.5,-71.17,0);
INSERT INTO "area" VALUES('EPSG','1500','New Zealand - North Island','New Zealand - North Island.',-41.67,-34.1,171.99,178.63,0);
INSERT INTO "area" VALUES('EPSG','1501','New Zealand - South Island','New Zealand - South Island.',-46.86,-40.44,166.37,174.46,0);
INSERT INTO "area" VALUES('EPSG','1502','New Zealand - offshore 162°E to168°E','New Zealand - offshore between 162°E and 168°E.',-55.89,-39.68,162.0,168.0,0);
INSERT INTO "area" VALUES('EPSG','1503','New Zealand - offshore 168°E to 174°E','New Zealand - offshore between 168°E and 174°E.',-55.95,-30.78,168.0,174.0,0);
INSERT INTO "area" VALUES('EPSG','1504','New Zealand - offshore 174°E to 180°E','New Zealand - offshore between 174°E and 180°E.',-54.32,-26.42,174.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','1505','Ghana - offshore','Ghana - offshore.',1.4,6.06,-3.79,2.1,0);
INSERT INTO "area" VALUES('EPSG','1506','Canada - 108°W to 102°W, south of 60°N','Canada south of 60°N and between 108°E and 102°W - Saskatchewan.',49.0,60.0,-108.0,-102.0,1);
INSERT INTO "area" VALUES('EPSG','1507','Canada - 114°W to 108°W, south of 60°N','Canada south of 60°N and between 114°E and 108°W - Alberta, Saskatchewan.',49.0,60.0,-114.0,-108.0,1);
INSERT INTO "area" VALUES('EPSG','1508','Canada - 120°W to 114°W, south of 60°N','Canada south of 60°N and between 120°E and 114°W - Alberta, British Columbia (BC).',49.0,60.0,-120.0,-114.0,1);
INSERT INTO "area" VALUES('EPSG','1509','Sierra Leone - west of 12°W','Sierra Leone - onshore west of 12°W.',7.15,9.94,-13.35,-12.0,0);
INSERT INTO "area" VALUES('EPSG','1510','Sierra Leone - east of 12°W','Sierra Leone - onshore east of 12°W.',6.88,10.0,-12.0,-10.26,0);
INSERT INTO "area" VALUES('EPSG','1511','USA - CONUS and Alaska; PRVI','Puerto Rico - onshore and offshore. United States (USA) onshore and offshore - Alabama; Alaska; Arizona; Arkansas; California; Colorado; Connecticut; Delaware; Florida; Georgia; Idaho; Illinois; Indiana; Iowa; Kansas; Kentucky; Louisiana; Maine; Maryland; Massachusetts; Michigan; Minnesota; Mississippi; Missouri; Montana; Nebraska; Nevada; New Hampshire; New Jersey; New Mexico; New York; North Carolina; North Dakota; Ohio; Oklahoma; Oregon; Pennsylvania; Rhode Island; South Carolina; South Dakota; Tennessee; Texas; Utah; Vermont; Virginia; Washington; West Virginia; Wisconsin; Wyoming. US Virgin Islands - onshore and offshore.',14.92,74.71,167.65,-63.88,0);
INSERT INTO "area" VALUES('EPSG','1512','Germany - East Germany - west of 10.5°E','Germany - states of former East Germany - west of 10°30''E - Thuringen.',50.35,51.56,9.92,10.5,0);
INSERT INTO "area" VALUES('EPSG','1513','Europe - 10.5°E to 13.5°E onshore by country','Czechia - west of 13°30''E. Germany - states of former East Germany onshore - between 10°30''E and 13°30''E - Brandenburg; Mecklenburg-Vorpommern; Sachsen; Sachsen-Anhalt; Thuringen.',48.97,54.74,10.5,13.5,0);
INSERT INTO "area" VALUES('EPSG','1514','Europe - 13.5°E to 16.5°E onshore and S-42(83) by country','Czechia - between 13°30''E and 16°30''E. Germany - states of former East Germany onshore east of 13°30''E - Brandenburg; Mecklenburg-Vorpommern; Sachsen. Hungary - west of 16°30''E.',46.54,54.72,13.5,16.5,0);
INSERT INTO "area" VALUES('EPSG','1515','Poland - zone I','Poland - southeast - south of 52°20''N and east of 18°E.',49.0,52.34,18.0,24.15,0);
INSERT INTO "area" VALUES('EPSG','1516','Poland - zone II','Poland - northeast - onshore north of 51°20''N and east of 19°E.',51.33,54.51,19.0,23.95,0);
INSERT INTO "area" VALUES('EPSG','1517','Poland - zone III','Poland - northwest - onshore north of 52°10''N and west of 20°E.',52.16,54.89,14.14,20.0,0);
INSERT INTO "area" VALUES('EPSG','1518','Poland - zone IV','Poland - southwest - south of 53°20''N and west of 19°05''E.',49.39,53.34,14.14,19.09,0);
INSERT INTO "area" VALUES('EPSG','1519','Poland - zone V','Poland - south central - between 49°20''N and 51°20''N, 18°20''E and 19°40''E.',49.39,51.34,18.33,19.67,0);
INSERT INTO "area" VALUES('EPSG','1520','Poland - west of 16.5°E','Poland - onshore and offshore west of 16°30''E.',50.26,55.35,14.14,16.5,0);
INSERT INTO "area" VALUES('EPSG','1521','Poland - 16.5°E to 19.5°E','Poland - onshore and offshore between 16°30''E and 19°30''E.',49.39,55.93,16.5,19.5,0);
INSERT INTO "area" VALUES('EPSG','1522','Poland - 19.5°E to 22.5°E','Poland - onshore and offshore between 19°30''E and 22°30''E.',49.09,54.55,19.5,22.5,0);
INSERT INTO "area" VALUES('EPSG','1523','Poland - east of 22.5°E','Poland - east of 22°30''E.',49.0,54.41,22.5,24.15,0);
INSERT INTO "area" VALUES('EPSG','1524','Turkey - west of 28.5°E onshore','Turkey west of 28°30''E, onshore.',36.5,42.11,25.62,28.5,0);
INSERT INTO "area" VALUES('EPSG','1525','Turkey - 28.5°E to 31.5°E onshore','Turkey between 28°30''E and 31°30''E, onshore.',36.06,41.46,28.5,31.5,0);
INSERT INTO "area" VALUES('EPSG','1526','Turkey - 31.5°E to 34.5°E onshore','Turkey between 31°30''E and 34°30''E, onshore.',35.97,42.07,31.5,34.5,0);
INSERT INTO "area" VALUES('EPSG','1527','Turkey - 34.5°E to 37.5°E onshore','Turkey between 34°30''E and 37°30''E, onshore.',35.81,42.15,34.5,37.5,0);
INSERT INTO "area" VALUES('EPSG','1528','Turkey - 37.5°E to 40.5°E onshore','Turkey between 37°30''E and 40°30''E, onshore.',36.66,41.19,37.5,40.5,0);
INSERT INTO "area" VALUES('EPSG','1529','Turkey - 40.5°E to 43.5°E onshore','Turkey between 40°30''E and 43°30''E, onshore.',37.02,41.6,40.5,43.5,0);
INSERT INTO "area" VALUES('EPSG','1530','Turkey - east of 43.5°E','Turkey east of 43°30''E.',36.97,41.02,43.5,44.83,0);
INSERT INTO "area" VALUES('EPSG','1531','Canada - Maritime Provinces - west of 66°W','Canada - New Brunswick and Nova Scotia - west of 66°W.',43.64,48.07,-69.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','1532','Canada - Maritime Provinces - east of 66°W','Canada - New Brunswick and Nova Scotia east of 66°W; Prince Edward Island.',43.41,47.98,-66.0,-59.73,0);
INSERT INTO "area" VALUES('EPSG','1533','Canada - Prince Edward Island','Canada - Prince Edward Island.',45.9,47.09,-64.49,-61.9,0);
INSERT INTO "area" VALUES('EPSG','1534','Canada - Nova Scotia - east of 63°W','Canada - Nova Scotia - east of 63°W.',44.64,47.08,-63.0,-59.73,0);
INSERT INTO "area" VALUES('EPSG','1535','Canada - Nova Scotia - west of 63°W','Canada - Nova Scotia - west of 63°W.',43.41,46.02,-66.28,-63.0,0);
INSERT INTO "area" VALUES('EPSG','1536','Finland - 19.5°E to 22.5°E onshore','Finland - onshore between 19°30''E and 22°30''E.',59.76,69.33,19.5,22.5,0);
INSERT INTO "area" VALUES('EPSG','1537','Finland - 22.5°E to 25.5°E onshore','Finland - onshore between 22°30''E and 25°30''E.',59.75,68.9,22.5,25.5,0);
INSERT INTO "area" VALUES('EPSG','1538','Finland - 25.5°E to 28.5°E onshore. Also all country.','Finland - onshore between 25°30''E and 28°30''E for Basic Coordinate System and all onshore Finland for Uniform Coordinate System.',59.75,70.09,19.24,31.59,0);
INSERT INTO "area" VALUES('EPSG','1539','Finland - 28.5°E to 31.5°E','Finland - between 28°30''E and 31°30''E.',60.94,69.81,28.5,31.5,0);
INSERT INTO "area" VALUES('EPSG','1540','Mozambique - onshore west of 36°E','Mozambique - onshore west of 36°E.',-26.87,-11.41,30.21,36.0,0);
INSERT INTO "area" VALUES('EPSG','1541','Mozambique - onshore east of 36°E','Mozambique - onshore east of 36°E.',-18.98,-10.42,35.99,40.9,0);
INSERT INTO "area" VALUES('EPSG','1542','Asia - Cambodia and Vietnam - west of 108°E','Cambodia; Vietnam west of 108°E.',8.5,23.33,102.14,108.0,0);
INSERT INTO "area" VALUES('EPSG','1543','Austria - Styria','Austria - Styria.',46.64,47.84,13.58,16.17,0);
INSERT INTO "area" VALUES('EPSG','1544','Oman - onshore west of 54°E','Oman - onshore west of 54°E.',16.59,19.67,51.99,54.0,0);
INSERT INTO "area" VALUES('EPSG','1545','Oman - onshore east of 54°E','Oman - onshore east of 54°E. Includes Musandam and the Kuria Muria (Al Hallaniyah) islands.',16.89,26.58,54.0,59.91,0);
INSERT INTO "area" VALUES('EPSG','1546','USA - Hawaii - island of Hawaii - onshore','United States (USA) - Hawaii - island of Hawaii - onshore.',18.87,20.33,-156.1,-154.74,0);
INSERT INTO "area" VALUES('EPSG','1547','USA - Hawaii - Maui; Kahoolawe; Lanai; Molokai - onshore','United States (USA) - Hawaii - Maui; Kahoolawe; Lanai; Molokai - onshore.',20.45,21.26,-157.36,-155.93,0);
INSERT INTO "area" VALUES('EPSG','1548','USA - Hawaii - Oahu - onshore','United States (USA) - Hawaii - Oahu - onshore.',21.2,21.75,-158.33,-157.61,0);
INSERT INTO "area" VALUES('EPSG','1549','USA - Hawaii - Kauai - onshore','United States (USA) - Hawaii - Kauai - onshore.',21.81,22.29,-159.85,-159.23,0);
INSERT INTO "area" VALUES('EPSG','1550','USA - Hawaii - Niihau - onshore','United States (USA) - Hawaii - Niihau - onshore.',21.73,22.07,-160.3,-159.99,0);
INSERT INTO "area" VALUES('EPSG','1551','Grenada and southern Grenadines - onshore','Grenada and southern Grenadine Islands - onshore.',11.94,12.57,-61.84,-61.35,0);
INSERT INTO "area" VALUES('EPSG','1552','Africa - Eritrea, Ethiopia and Sudan - 36°E to 42°E','Eritrea. Ethiopia - between 36°E and 42°E. Sudan - east of 36°E.',3.4,22.01,36.0,42.0,0);
INSERT INTO "area" VALUES('EPSG','1553','Ethiopia - east of 42°E','Ethiopia - east of 42°E.',4.11,12.85,42.0,47.99,0);
INSERT INTO "area" VALUES('EPSG','1554','Somalia - 42°E to 48°E, N hemisphere onshore','Somalia - onshore north of equator and between 42°E and 48°E.',0.0,11.52,42.0,48.0,0);
INSERT INTO "area" VALUES('EPSG','1555','Somalia - onshore east of 48°E','Somalia - onshore east of 48°E.',4.44,12.03,48.0,51.47,0);
INSERT INTO "area" VALUES('EPSG','1556','Australia - 102°E to 108°E','Australia - between 102°E and 108°E.',-56.0,-10.0,102.0,108.0,1);
INSERT INTO "area" VALUES('EPSG','1557','Australia - 108°E to 114°E (EEZ)','Australia - onshore and offshore to 200 nautical mile EEZ boundary between 108°E and 114°E.',-37.84,-17.19,109.23,114.0,0);
INSERT INTO "area" VALUES('EPSG','1558','Australia - 114°E to 120°E (EEZ)','Australia - onshore and offshore to 200 nautical mile EEZ boundary between 114°E and 120°E.',-38.53,-12.61,114.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','1559','Australia - 120°E to 126°E','Australia - onshore and offshore between 120°E and 126°E.',-38.07,-10.46,120.0,126.01,0);
INSERT INTO "area" VALUES('EPSG','1560','Australia - 126°E to 132°E','Australia - onshore and offshore between 126°E and 132°E.',-37.38,-9.1,125.99,132.0,0);
INSERT INTO "area" VALUES('EPSG','1561','Australia - 132°E to 138°E','Australia - onshore and offshore between 132°E and 138°E.',-40.71,-8.88,132.0,138.01,0);
INSERT INTO "area" VALUES('EPSG','1562','Australia - 138°E to 144°E','Australia - onshore and offshore between 138°E and 144°E.',-48.19,-9.08,138.0,144.01,0);
INSERT INTO "area" VALUES('EPSG','1563','Australia - 144°E to 150°E','Australia - onshore and offshore between 144°E and 150°E.',-50.89,-9.23,144.0,150.01,0);
INSERT INTO "area" VALUES('EPSG','1564','Australia - 150°E to 156°E','Australia - onshore and offshore between 150°E and 156°E.',-58.96,-13.87,150.0,156.0,0);
INSERT INTO "area" VALUES('EPSG','1565','Australia - 156°E to 162°E','Australia including Lord Howe Island - onshore and offshore between 156°E and 162°E.',-35.13,-14.08,156.0,162.01,0);
INSERT INTO "area" VALUES('EPSG','1566','Australia - EEZ east of 162°E','Australia - offshore east of 162°E to 200 nautical mile EEZ boundary.',-34.22,-27.25,162.0,163.2,0);
INSERT INTO "area" VALUES('EPSG','1567','Australasia - Australia and PNG - 138°E to 144°E','Australia - onshore and offshore between 138°E and 144°E. Papua New Guinea - onshore west of 144°E.',-46.63,-2.53,138.0,144.01,0);
INSERT INTO "area" VALUES('EPSG','1568','Australasia - Australia and PNG - 144°E to 150°E','Australia - onshore and offshore between 144°E and 150°E. Papua New Guinea (PNG) - onshore between 144°E and 150°E.',-47.2,-1.3,144.0,150.01,0);
INSERT INTO "area" VALUES('EPSG','1569','Saudi Arabia - onshore 36°E to 42°E','Saudi Arabia - onshore between 36°E and 42°E.',16.59,32.16,36.0,42.0,0);
INSERT INTO "area" VALUES('EPSG','1570','Asia - Middle East - Kuwait and Saudi - 48°E to 54°E','Kuwait - onshore east of 48°E. Saudi Arabia - onshore between 48°E and 54°E.',17.43,30.04,48.0,54.01,0);
INSERT INTO "area" VALUES('EPSG','1571','Asia - Middle East - Kuwait and Saudi - 42°E to 48°E','Kuwait - west of 48°E. Saudi Arabia - between of 42°E and 48°E.',15.61,31.15,42.0,48.0,0);
INSERT INTO "area" VALUES('EPSG','1572','Brazil - 54°W to 48°W and Aratu','Brazil - offshore between 54°W and 48°W, including Pelotas basin.',-35.71,-25.01,-53.38,-47.99,0);
INSERT INTO "area" VALUES('EPSG','1573','Brazil - 48°W to 42°W and Aratu','Brazil - offshore areas south of intersection of parallel of 2°55''S with coast and between 48°W and 42°W including Santos basin.',-33.5,0.0,-48.01,-41.99,0);
INSERT INTO "area" VALUES('EPSG','1574','Brazil - 42°W to 36°W and Aratu','Brazil - between 42°W and 36°W, southern hemisphere offshore including Campos and Espirito Santo basins; onshore Tucano basin area.',-26.35,0.01,-42.01,-36.0,0);
INSERT INTO "area" VALUES('EPSG','1575','Africa - Botswana and Zambia - west of 24°E','Botswana and Zambia - west of 24°E.',-26.88,-10.86,19.99,24.0,0);
INSERT INTO "area" VALUES('EPSG','1576','Africa - Botswana, Zambia and Zimbabwe - 24°E to 30°E','Botswana - east of 24°E; Zambia - between 24°E and 30°E; Zimbabwe - west of 30°E .',-25.84,-8.31,24.0,30.0,0);
INSERT INTO "area" VALUES('EPSG','1577','Africa - Malawi, Zambia and Zimbabwe - east of 30°E','Malawi. Zambia and Zimbabwe - east of 30°E.',-22.42,-8.19,30.0,35.93,0);
INSERT INTO "area" VALUES('EPSG','1578','Uganda - north of equator and west of 30°E','Uganda - north of equator and west of 30°E.',0.0,0.86,29.71,30.0,0);
INSERT INTO "area" VALUES('EPSG','1579','Africa - Tanzania and Uganda - south of equator and west of 30°E','Tanzania - west of 30°E; Uganda - south of equator and west of 30°E.',-6.81,0.0,29.34,30.0,0);
INSERT INTO "area" VALUES('EPSG','1580','Africa - Kenya and Uganda - north of equator and 30°E to 36°E','Kenya - north of equator and west of 36°E; Uganda - north of equator and east of 30°E.',0.0,4.63,29.99,36.0,0);
INSERT INTO "area" VALUES('EPSG','1581','Africa - Kenya, Tanzania and Uganda - south of equator and 30°E to 36°E','Kenya - south of equator and west of 36°E; Tanzania - 30°E to 36°E; Uganda - south of equator and east of 30°E.',-11.61,0.01,29.99,36.0,0);
INSERT INTO "area" VALUES('EPSG','1582','Kenya - north of equator and east of 36°E','Kenya - north of equator and east of 36°E.',0.0,4.49,36.0,41.91,0);
INSERT INTO "area" VALUES('EPSG','1583','Africa - Kenya and Tanzania - south of equator and east of 36°E','Kenya - south of equator and east of 36°E; Tanzania - east of 36°E.',-11.75,0.0,36.0,41.6,0);
INSERT INTO "area" VALUES('EPSG','1584','Indonesia - Java and Java Sea - west of 108°E','Indonesia - onshore Java and offshore southern Java Sea west of 108°E.',-7.79,-4.07,105.06,108.0,0);
INSERT INTO "area" VALUES('EPSG','1585','Indonesia - Java and Java Sea - east of 114°E','Indonesia - onshore Java and Bali, offshore southern Java Sea, Madura Strait and western Bali Sea - east of 114°E.',-8.91,-5.33,114.0,117.01,0);
INSERT INTO "area" VALUES('EPSG','1586','Indonesia - Java and Java Sea - 108°E to 114°E','Indonesia - onshore Java and Madura and offshore southern Java Sea and Madura Strait - between 108°E and 114°E.',-8.67,-4.27,108.0,114.0,0);
INSERT INTO "area" VALUES('EPSG','1587','China - west of 78°E','China - west of 78°E.',35.42,41.07,73.62,78.01,0);
INSERT INTO "area" VALUES('EPSG','1588','China - 78°E to 84°E','China - between 78°E and 84°E.',29.16,47.23,77.98,84.0,0);
INSERT INTO "area" VALUES('EPSG','1589','China - 84°E to 90°E','China - between 84°E and 90°E.',27.32,49.18,84.0,90.0,0);
INSERT INTO "area" VALUES('EPSG','1590','China - 90°E to 96°E','China - between 90°E and 96°E.',27.71,47.9,90.0,96.01,0);
INSERT INTO "area" VALUES('EPSG','1591','China - 96°E to 102°E','China - between 96°E and 102°E.',21.13,43.18,96.0,102.01,0);
INSERT INTO "area" VALUES('EPSG','1592','China - 102°E to 108°E onshore','China - onshore between 102°E and 108°E.',21.53,42.47,102.0,108.0,0);
INSERT INTO "area" VALUES('EPSG','1593','China - 108°E to 114°E onshore','China - onshore between 108°E and 114°E.',18.11,45.11,108.0,114.0,0);
INSERT INTO "area" VALUES('EPSG','1594','China - 114°E to 120°E onshore','China - onshore between 114°E and 120°E.',22.14,51.52,114.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','1595','China - 120°E to 126°E onshore','China - onshore between 120°E and 126°E.',26.34,53.56,120.0,126.0,0);
INSERT INTO "area" VALUES('EPSG','1596','China - 126°E to 132°E onshore','China - onshore between 126°E and 132°E.',40.89,52.79,126.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','1597','China - east of 132°E','China - east of 132°E.',45.02,48.4,132.0,134.77,0);
INSERT INTO "area" VALUES('EPSG','1598','Colombia - west of 75°35''W','Colombia - mainland onshore west of 1°30''W of Bogota (75°34''51.30"W of Greenwich).',0.03,10.21,-79.1,-75.58,0);
INSERT INTO "area" VALUES('EPSG','1599','Colombia - 75°35''W to 72°35''W','Colombia - onshore between 1°30''W and 1°30''E of Bogota (75°35''W and 72°35''W of Greenwich).',-2.51,11.82,-75.59,-72.58,0);
INSERT INTO "area" VALUES('EPSG','1600','Colombia - 72°35''W to 69°35''W','Colombia - onshore between 1°30''E and 4°30''E of Bogota (72°35''W and 69°34''W of Greenwich).',-4.23,12.52,-72.59,-69.58,0);
INSERT INTO "area" VALUES('EPSG','1601','Colombia - east of 69°35''W','Colombia - east of 4°30''E of Bogota (69°34''51.3"W of Greenwich).',-2.25,6.31,-69.59,-66.87,0);
INSERT INTO "area" VALUES('EPSG','1602','Colombia - offshore west of 78°W','Colombia - offshore west of 78°W of Greenwich.',NULL,NULL,NULL,NULL,1);
INSERT INTO "area" VALUES('EPSG','1603','Colombia - offshore Caribbean west of 72°W','Colombia - offshore Caribbean west of 72°W of Greenwich.',7.9,13.68,-77.37,-72.0,0);
INSERT INTO "area" VALUES('EPSG','1604','Angola - Angola proper - offshore','Angola - Angola proper - offshore.',-17.26,-6.01,8.2,13.86,0);
INSERT INTO "area" VALUES('EPSG','1605','Angola - offshore block 15','Angola - offshore block 15.',-6.59,-6.03,10.83,11.67,0);
INSERT INTO "area" VALUES('EPSG','1606','Angola - Angola proper - offshore - west of 12°E','Angola - Angola proper - offshore - west of 12°E.',-17.26,-6.03,8.2,12.0,0);
INSERT INTO "area" VALUES('EPSG','1607','Angola - Angola proper - 12°E to 18°E','Angola - Angola proper between 12°E and 18°E.',-17.44,-5.82,12.0,18.0,0);
INSERT INTO "area" VALUES('EPSG','1608','Argentina - west of 70.5°W','Argentina - west of 70°30''W.',-52.0,-36.16,-73.59,-70.5,0);
INSERT INTO "area" VALUES('EPSG','1609','Argentina - 70.5°W to 67.5°W onshore','Argentina - between 70°30''W and 67°30''W, onshore.',-54.9,-24.08,-70.5,-67.49,0);
INSERT INTO "area" VALUES('EPSG','1610','Argentina - 67.5°W to 64.5°W onshore','Argentina - between 67°30''W and 64°30''W, onshore.',-55.11,-21.78,-67.5,-64.49,0);
INSERT INTO "area" VALUES('EPSG','1611','Argentina - 64.5°W to 61.5°W onshore','Argentina - between 64°30''W and 61°30''W, onshore.',-54.91,-21.99,-64.5,-61.5,0);
INSERT INTO "area" VALUES('EPSG','1612','Argentina - 61.5°W to 58.5°W onshore','Argentina - between 61°30''W and 58°30''W onshore.',-39.06,-23.37,-61.51,-58.5,0);
INSERT INTO "area" VALUES('EPSG','1613','Argentina - 58.5°W to 55.5°W onshore','Argentina - between 58°30''W and 55°30''W, onshore.',-38.59,-24.84,-58.5,-55.49,0);
INSERT INTO "area" VALUES('EPSG','1614','Argentina - east of 55.5°W onshore','Argentina - east of 55°30''W, onshore.',-28.11,-25.49,-55.5,-53.65,0);
INSERT INTO "area" VALUES('EPSG','1615','Botswana - west of 24°E','Botswana - west of 24°E.',-26.88,-17.99,19.99,24.0,0);
INSERT INTO "area" VALUES('EPSG','1616','Botswana - 21°E to 27°E','Botswana - between 21°E and 27°E.',-26.88,-17.78,21.0,27.0,1);
INSERT INTO "area" VALUES('EPSG','1617','Botswana - east of 24°E','Botswana - east of 24°E.',-25.84,-17.78,24.0,29.38,0);
INSERT INTO "area" VALUES('EPSG','1618','Tunisia - onshore','Tunisia - onshore.',30.23,37.4,7.49,11.59,0);
INSERT INTO "area" VALUES('EPSG','1619','Tunisia - north of 34°39''N','Tunisia - onshore north of 38.5 grads North (34°39''N).',34.65,37.4,8.18,11.37,0);
INSERT INTO "area" VALUES('EPSG','1620','Tunisia - south of 34°39''N','Tunisia - onshore south of 38.5 grads North (34°39''N) .',30.23,34.66,7.49,11.59,0);
INSERT INTO "area" VALUES('EPSG','1621','Brazil - Corrego Alegre - west of 42°W','Brazil - NE coastal area between 45°W and 42°W.',-3.9,-1.5,-45.0,-42.0,1);
INSERT INTO "area" VALUES('EPSG','1622','Brazil - Corrego Alegre - east of 42°W','Brazil - NE coastal area between 42°W and 40°W.',-4.0,-2.7,-42.0,-40.0,1);
INSERT INTO "area" VALUES('EPSG','1623','Asia - Middle East - Lebanon and Syria onshore','Lebanon - onshore. Syrian Arab Republic - onshore.',32.31,37.3,35.04,42.38,0);
INSERT INTO "area" VALUES('EPSG','1624','Germany - West Germany - west of 7.5°E','Germany - former West Germany onshore west of 7°30''E - states of Niedersachsen, Nordrhein-Westfalen, Rheinland-Pfalz, Saarland.',49.11,53.81,5.86,7.5,0);
INSERT INTO "area" VALUES('EPSG','1625','Germany - West-Germany - 7.5°E to 10.5°E','Germany - former West Germany onshore between 7°30''E and 10°30''E - states of Baden-Wurtemberg, Bayern, Bremen, Hamberg, Hessen, Niedersachsen, Nordrhein-Westfalen, Rhineland-Pfalz, Schleswig-Holstein.',47.27,55.09,7.5,10.51,0);
INSERT INTO "area" VALUES('EPSG','1626','Germany - West Germany - 10.5°E to 13.5°E','Germany - former West Germany onshore between 10°30''E and 13°30''E - states of Bayern, Berlin, Niedersachsen, Schleswig-Holstein.',47.39,54.59,10.5,13.51,0);
INSERT INTO "area" VALUES('EPSG','1627','Germany - West Germany - east of 13.5°E','Germany - former West Germany onshore east of 13°30''E - state of Bayern.',48.51,48.98,13.5,13.84,0);
INSERT INTO "area" VALUES('EPSG','1628','Germany - west of 4.5°E','Germany - onshore - west of 4°30''E.',NULL,NULL,NULL,NULL,1);
INSERT INTO "area" VALUES('EPSG','1629','UK - offshore - North Sea','United Kingdom (UK) - offshore - North Sea.',51.03,62.03,-5.05,3.4,0);
INSERT INTO "area" VALUES('EPSG','1630','Netherlands - offshore','Netherlands - offshore North Sea.',51.45,55.77,2.53,6.41,0);
INSERT INTO "area" VALUES('EPSG','1631','Europe - 18°W to 12°W and ED50 by country','Europe - between 18°W and 12°W - Ireland offshore.',48.43,56.57,-16.1,-12.0,0);
INSERT INTO "area" VALUES('EPSG','1632','Europe - 12°W to 6°W and ED50 by country','Europe - between 12°W and 6°W - Faroe Islands - onshore; Spain - mainland onshore; Ireland offshore.',36.13,62.41,-12.0,-6.0,0);
INSERT INTO "area" VALUES('EPSG','1633','Europe - 6°W to 0°W and ED50 by country','Europe - between 6°W and 0°W - Channel Islands (Jersey, Guernsey); France offshore; Gibraltar; Ireland offshore; Norway including Svalbard - offshore; Spain - onshore; United Kingdom - UKCS offshore.',35.26,80.53,-6.0,0.0,0);
INSERT INTO "area" VALUES('EPSG','1634','Europe - 0°E to 6°E and ED50 by country','Europe - between 0°E and 6°E - Andorra; Denmark (North Sea); Germany offshore; Netherlands offshore; Norway including Svalbard - onshore and offshore; Spain - onshore (mainland and Balearic Islands); United Kingdom (UKCS) offshore.',38.56,82.41,0.0,6.01,0);
INSERT INTO "area" VALUES('EPSG','1635','Europe - 6°E to 12°E and ED50 by country','Europe - between 6°E and 12°E - Denmark - onshore and offshore; France - offshore; Germany offshore; Italy - onshore and offshore; Netherlands offshore; Norway including Svalbard - onshore and offshore.',36.53,83.92,5.99,12.0,0);
INSERT INTO "area" VALUES('EPSG','1636','Europe - 12°E to 18°E and ED50 by country','Europe - between 12°E and 18°E onshore and offshore - Denmark (including Bornholm); Italy including San Marino and Vatican City State; Malta; Norway including Svalbard.',34.49,84.0,12.0,18.0,0);
INSERT INTO "area" VALUES('EPSG','1637','Europe - 18°E to 24°E and ED50 by country','Europe - between 18°E and 24°E - Greece - offshore; Italy - onshore and offshore; Norway including Svalbard - onshore and offshore.',33.59,84.0,18.0,24.0,0);
INSERT INTO "area" VALUES('EPSG','1638','Europe - 24°E to 30°E and ED50 by country','Europe - between 24°E and 30°E - Greece - offshore; Norway including Svalbard - onshore and offshore; Turkey - onshore and offshore. Egypt - Western Desert.',25.71,84.01,24.0,30.0,0);
INSERT INTO "area" VALUES('EPSG','1639','Europe - 30°E to 36°E and ED50 by country','Europe - between 30°E and 36°E - Israel - offshore; Jordan; Norway including Svalbard - onshore and offshore; Turkey - onshore and offshore.',29.19,83.89,29.99,36.0,0);
INSERT INTO "area" VALUES('EPSG','1640','Europe - 36°E to 42°E and ED50 by country','Europe - between 36°E and 42°E - Jordan; Norway including Svalbard - offshore; Turkey onshore and offshore.',29.18,79.09,36.0,42.0,0);
INSERT INTO "area" VALUES('EPSG','1641','Europe - 42°E to 48°E and ED50 by country','Europe - between 42°E and 48°E - Turkey.',36.97,41.6,42.0,44.83,0);
INSERT INTO "area" VALUES('EPSG','1642','Egypt - east of 33°E onshore','Egypt - east of 33°E - onshore plus offshore Gulf of Suez.',21.97,31.36,33.0,36.95,0);
INSERT INTO "area" VALUES('EPSG','1643','Egypt - 29°E to 33°E','Egypt – onshore between 29°E and 33°E, offshore Mediterranean east of 29°E and offshore Gulf of Suez.',21.99,33.82,29.0,34.27,0);
INSERT INTO "area" VALUES('EPSG','1644','Egypt - west of 29°E; north of 28°11''N','Egypt - onshore west of 29°E and north of approximately 28°11''N.',28.18,31.68,24.7,29.0,0);
INSERT INTO "area" VALUES('EPSG','1645','Egypt - west of 29°E; south of 28°11''N','Egypt - west of 29°E; south of approximately 28°11''N.',21.99,28.19,24.99,29.01,0);
INSERT INTO "area" VALUES('EPSG','1646','Europe - Estonia; Latvia; Lithuania','Estonia, Latvia and Lithuania - onshore and offshore.',53.89,60.0,19.02,28.24,0);
INSERT INTO "area" VALUES('EPSG','1647','Indonesia - west of 96°E, N hemisphere','Indonesia - north of equator and west of 96°E - onshore and offshore.',0.0,7.79,92.01,96.0,0);
INSERT INTO "area" VALUES('EPSG','1648','Indonesia - west of 96°E, S hemisphere','Indonesia - south of equator and west of 96°E.',NULL,NULL,NULL,NULL,1);
INSERT INTO "area" VALUES('EPSG','1649','Indonesia - 96°E to 102°E, N hemisphere','Indonesia - north of equator and between 96°E and 102°E - onshore and offshore.',0.0,7.49,96.0,102.0,0);
INSERT INTO "area" VALUES('EPSG','1650','Indonesia - 96°E to 102°E, S hemisphere','Indonesia - south of equator and between 96°E and 102°E  - onshore and offshore.',-8.86,0.0,96.0,102.0,0);
INSERT INTO "area" VALUES('EPSG','1651','Indonesia - 102°E to 108°E, N hemisphere','Indonesia - north of equator and between 102°E and 108°E - onshore and offshore.',0.0,6.94,102.0,108.0,0);
INSERT INTO "area" VALUES('EPSG','1652','Indonesia - 102°E to 108°E, S hemisphere','Indonesia - south of equator and between 102°E and 108°E - onshore and offshore.',-10.73,0.0,102.0,108.01,0);
INSERT INTO "area" VALUES('EPSG','1653','Indonesia - 108°E to 114°E, N hemisphere','Indonesia - north of equator and between 108°E and 114°E - onshore and offshore.',0.0,7.37,108.0,114.0,0);
INSERT INTO "area" VALUES('EPSG','1654','Indonesia - 108°E to 114°E, S hemisphere','Indonesia - south of equator and between 108°E and 114°E - onshore and offshore.',-12.07,0.0,108.0,114.0,0);
INSERT INTO "area" VALUES('EPSG','1655','Indonesia - 114°E to 120°E, N hemisphere','Indonesia - north of equator and between 114°E and 120°E - onshore and offshore.',0.0,4.37,114.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','1656','Indonesia - 114°E to 120°E, S hemisphere','Indonesia - south of equator and between 114°E and 120°E - onshore and offshore.',-13.06,0.0,114.0,120.01,0);
INSERT INTO "area" VALUES('EPSG','1657','Indonesia - 120°E to 126°E, N hemisphere','Indonesia - north of equator and between 120°E and 126°E - onshore and offshore.',0.0,5.48,120.0,126.0,0);
INSERT INTO "area" VALUES('EPSG','1658','Indonesia - 120°E to 126°E, S hemisphere','Indonesia - south of equator and between 120°E and 126°E - onshore and offshore.',-13.95,0.01,120.0,126.01,0);
INSERT INTO "area" VALUES('EPSG','1659','Indonesia - 126°E to 132°E, N hemisphere','Indonesia - north of equator and between 126°E and 132°E - onshore and offshore.',0.0,6.68,126.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','1660','Indonesia - 126°E to 132°E, S hemisphere','Indonesia - south of equator and between 126°E and 132°E - onshore and offshore.',-9.45,0.0,126.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','1661','Indonesia - 132°E to 138°E, N hemisphere','Indonesia - north of equator and east of 132°E.',NULL,NULL,NULL,NULL,1);
INSERT INTO "area" VALUES('EPSG','1662','Indonesia - 132°E to 138°E, S hemisphere','Indonesia - south of equator and between 132°E and 138°E - onshore and offshore.',-10.06,0.0,132.0,138.01,0);
INSERT INTO "area" VALUES('EPSG','1663','Indonesia - east of 138°E, S hemisphere','Indonesia - south of equator and east of 138°E - onshore and offshore.',-10.84,0.0,138.0,141.46,0);
INSERT INTO "area" VALUES('EPSG','1664','Myanmar (Burma) - onshore west of 96°E','Myanmar (Burma) - onshore west of 96°E.',15.66,27.14,92.2,96.01,0);
INSERT INTO "area" VALUES('EPSG','1665','Asia - Myanmar and Thailand - 96°E to 102°E','Myanmar (Burma) - onshore east of 96°E; Thailand - onshore west of 102°E.',5.63,28.55,95.99,102.01,0);
INSERT INTO "area" VALUES('EPSG','1666','Thailand - east of 102°E','Thailand - onshore and offshore east of 102°E.',6.02,18.44,102.0,105.64,0);
INSERT INTO "area" VALUES('EPSG','1667','Thailand - onshore and GoT 96°E to102°E','Thailand - onshore west of 102°E plus offshore Gulf of Thailand west of 102°E.',5.63,20.46,97.34,102.01,0);
INSERT INTO "area" VALUES('EPSG','1668','Pakistan - north of 35°35''N','Pakistan - north of 35°35''N.',35.58,37.07,71.18,77.01,0);
INSERT INTO "area" VALUES('EPSG','1669','Asia - India; Pakistan - 28°N to 35°35''N','India - north of 28°N; Pakistan - between 28°N and 35°35''N.',28.0,35.59,60.86,81.64,0);
INSERT INTO "area" VALUES('EPSG','1670','Asia - India; Pakistan - onshore 21°N to 28°N and west of 82°E','India - onshore between 21°N and 28°N and west of 82°E; Pakistan - onshore south of 28°N.',21.0,28.01,61.59,82.01,0);
INSERT INTO "area" VALUES('EPSG','1671','Asia - Bangladesh; India; Myanmar; Pakistan - zone Ilb','Bangladesh - onshore north of 21°N; India - onshore north of 21°N and east of 82°E; Myanmar (Burma) - north of 21°N.',21.0,29.47,82.0,101.17,0);
INSERT INTO "area" VALUES('EPSG','1672','India - onshore 15°N to 21°N','India - onshore between 15°N and 21°N.',15.0,21.01,70.14,87.15,0);
INSERT INTO "area" VALUES('EPSG','1673','India - mainland south of 15°N','India - mainland onshore south of 15°N.',8.02,15.01,73.94,80.4,0);
INSERT INTO "area" VALUES('EPSG','1674','Bangladesh - onshore west of 90°E','Bangladesh - onshore west of 90°E.',21.59,26.64,88.01,90.0,0);
INSERT INTO "area" VALUES('EPSG','1675','Bangladesh - onshore east of 90°E','Bangladesh - onshore east of 90°E.',20.52,25.29,90.0,92.67,0);
INSERT INTO "area" VALUES('EPSG','1676','India - north of 28°N','India - north of 28°N.',28.0,35.51,70.35,81.64,0);
INSERT INTO "area" VALUES('EPSG','1677','India - onshore 21°N to 28°N and west of 82°E','India - onshore between 21°N and 28°N and west of 82°E.',21.0,28.01,68.13,82.01,0);
INSERT INTO "area" VALUES('EPSG','1678','India - onshore north of 21°N and east of 82°E','India - onshore north of 21°N and east of 82°E.',21.0,29.47,82.0,97.42,0);
INSERT INTO "area" VALUES('EPSG','1679','India - onshore west of 72°E','India - onshore west of 72°E.',20.64,28.22,68.13,72.01,0);
INSERT INTO "area" VALUES('EPSG','1680','India - mainland 72°E to 78°E','India - mainland onshore between 72°E and 78°E.',8.02,35.51,72.0,78.01,0);
INSERT INTO "area" VALUES('EPSG','1681','India - onshore 78°E to 84°E','India - onshore between 78°E and 84°E.',8.29,35.5,78.0,84.01,0);
INSERT INTO "area" VALUES('EPSG','1682','India - onshore 84°E to 90°E','India - onshore between 84°E and 90°E.',18.18,28.14,84.0,90.01,0);
INSERT INTO "area" VALUES('EPSG','1683','India - mainland 90°E to 96°E','India - mainland onshore between 90°E and 96°E.',21.94,29.42,90.0,96.01,0);
INSERT INTO "area" VALUES('EPSG','1684','India - east of 96°E','India - east of 96°E.',27.1,29.47,96.0,97.42,0);
INSERT INTO "area" VALUES('EPSG','1685','Pakistan - 28°N to 35°35''N','Pakistan - between 28°N and 35°35''N.',28.0,35.59,60.86,77.83,0);
INSERT INTO "area" VALUES('EPSG','1686','Pakistan - onshore south of 28°N','Pakistan - onshore south of 28°N.',23.64,28.01,61.59,71.91,0);
INSERT INTO "area" VALUES('EPSG','1687','Pakistan - onshore west of 66°E','Pakistan - onshore west of 66°E.',24.98,29.87,60.86,66.01,0);
INSERT INTO "area" VALUES('EPSG','1688','Pakistan - onshore 66°E to 72°E','Pakistan - onshore between 66°E and 72°E.',23.64,36.56,66.0,72.01,0);
INSERT INTO "area" VALUES('EPSG','1689','Pakistan - east of 72°E','Pakistan - east of 72°E.',28.21,37.07,72.0,77.83,0);
INSERT INTO "area" VALUES('EPSG','1690','Malaysia - West Malaysia - onshore','Malaysia - West Malaysia onshore.',1.21,6.72,99.59,104.6,0);
INSERT INTO "area" VALUES('EPSG','1691','Malaysia - West Malaysia - onshore west of 102°E','Malaysia - West Malaysia onshore west of 102°E.',2.29,6.72,99.59,102.01,0);
INSERT INTO "area" VALUES('EPSG','1692','Malaysia - West Malaysia - east of 102°E','Malaysia - onshore West Malaysia east of 102°E and offshore east coast.',1.21,7.81,102.0,105.82,0);
INSERT INTO "area" VALUES('EPSG','1693','Venezuela - west of 72°W','Venezuela - west of 72°W.',7.02,11.62,-73.38,-71.99,0);
INSERT INTO "area" VALUES('EPSG','1694','Venezuela - 72°W and 66°W onshore','Venezuela - between 72°W and 66°W, onshore.',0.73,12.25,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','1695','Venezuela - east of 66°W onshore','Venezuela - onshore east of 66°W.',0.64,11.23,-66.0,-59.8,0);
INSERT INTO "area" VALUES('EPSG','1696','Gabon - north of equator and west of 12°E onshore','Gabon - onshore north of equator and west of 12°E.',0.0,2.32,9.25,12.0,0);
INSERT INTO "area" VALUES('EPSG','1697','Gabon - west of 12°E','Gabon - west of 12°E - onshore and offshore.',-6.37,2.32,7.03,12.01,0);
INSERT INTO "area" VALUES('EPSG','1698','Philippines - zone I','Philippines - west of 118°E onshore and offshore.',6.21,18.64,116.04,118.0,0);
INSERT INTO "area" VALUES('EPSG','1699','Philippines - zone II','Philippines - approximately between 118°E and 120°E - Palawan; Calamian Islands - onshore and offshore.',3.02,20.42,118.0,120.07,0);
INSERT INTO "area" VALUES('EPSG','1700','Philippines - zone III','Philippines - approximately between 120°E and 122°E, onshore and offshore. Luzon (west of 122°E); Mindoro.',3.0,21.62,119.7,122.21,0);
INSERT INTO "area" VALUES('EPSG','1701','Philippines - zone IV','Philippines - approximately between 122°E and 124°E onshore and offshore - southeast Luzon (east of 122°E); Tablas; Masbate; Panay; Cebu; Negros; west Mindanao (west of 122°E).',3.44,22.18,121.74,124.29,0);
INSERT INTO "area" VALUES('EPSG','1702','Philippines - zone V','Philippines - approximately between 124°E and 126°E, onshore and offshore - east Mindanao (east of 124°E); Bohol; Samar.',4.76,21.97,123.73,126.65,0);
INSERT INTO "area" VALUES('EPSG','1703','Morocco - north of 31.5°N','Morocco onshore north of 35 grads North (31°30''N).',31.49,35.97,-9.85,-1.01,0);
INSERT INTO "area" VALUES('EPSG','1704','Morocco - 27.9°N to 31.5°N','Morocco between 31 grads and 35 grads North (27°54''N and 31°30''N).',27.9,31.5,-13.0,-3.5,1);
INSERT INTO "area" VALUES('EPSG','1705','Morocco - south of 27.9°N','Morocco south of 31 grads North (27°54''N).',21.06,27.9,-17.0,-8.67,1);
INSERT INTO "area" VALUES('EPSG','1706','Austria - west of 11°50''E','Austria west of 11°50''E of Greenwich (29°30''E of Ferro).',46.77,47.61,9.53,11.84,0);
INSERT INTO "area" VALUES('EPSG','1707','Austria - 11°50''E to 14°50''E','Austria between 11°50''E and 14°50''E of Greenwich (29°30''E and 32°30''E of Ferro).',46.4,48.79,11.83,14.84,0);
INSERT INTO "area" VALUES('EPSG','1708','Austria - east of 14°50''E','Austria east of 14°50''E of Greenwich (32°30''E of Ferro).',46.56,49.02,14.83,17.17,0);
INSERT INTO "area" VALUES('EPSG','1709','Europe - former Yugoslavia onshore west of 16.5°E','Bosnia and Herzegovina - west of 16°30''E; Croatia - onshore west of 16°30''E; Slovenia - onshore.',42.95,46.88,13.38,16.5,0);
INSERT INTO "area" VALUES('EPSG','1710','Europe - former Yugoslavia onshore 16.5°E to 19.5°E','Bosnia and Herzegovina - between 16°30''E and 19°30''E; Croatia - onshore east of 16°30''E; Montenegro - onshore west of 19°30''E; Serbia - west of 19°30''E.',41.79,46.55,16.5,19.51,0);
INSERT INTO "area" VALUES('EPSG','1711','Europe - former Yugoslavia onshore 19.5°E to 22.5°E','Bosnia and Herzegovina - east of 19°30''E; Kosovo; Montenegro - east of 19°30''E; North Macedonia - west of 22°30''E; Serbia - between 19°30''E and 22°30''E.',40.85,46.19,19.5,22.51,0);
INSERT INTO "area" VALUES('EPSG','1712','Europe - former Yugoslavia onshore east of 22.5°E','North Macedonia - east of 22°30''E; Serbia - east of 22°30''E.',41.11,44.7,22.5,23.04,0);
INSERT INTO "area" VALUES('EPSG','1713','Nigeria - east of 10.5°E','Nigeria east of 10°30''E.',6.43,13.72,10.49,14.65,0);
INSERT INTO "area" VALUES('EPSG','1714','Nigeria - 6.5°E to 10.5°E','Nigeria between 6°30''E and 10°30''E, onshore and offshore shelf.',3.57,13.53,6.5,10.51,0);
INSERT INTO "area" VALUES('EPSG','1715','Nigeria - west of 6.5°E','Nigeria - onshore west of 6°30''E, onshore and offshore shelf.',3.57,13.9,2.69,6.5,0);
INSERT INTO "area" VALUES('EPSG','1716','Nigeria - offshore deep water - west of 6°E','Nigeria - offshore beyond continental shelf west of 6°E.',1.92,6.14,2.66,6.0,0);
INSERT INTO "area" VALUES('EPSG','1717','Nigeria - offshore deep water','Nigeria - offshore beyond continental shelf.',1.92,6.14,2.66,7.82,0);
INSERT INTO "area" VALUES('EPSG','1718','Italy - west of 12°E','Italy - onshore and offshore - west of 12°E.',36.53,47.04,5.94,12.0,0);
INSERT INTO "area" VALUES('EPSG','1719','Italy - east of 12°E','Italy - onshore and offshore - east of 12°E including San Marino and Vatican City State.',34.76,47.1,12.0,18.99,0);
INSERT INTO "area" VALUES('EPSG','1720','USA - Michigan - SPCS - E','United States (USA) - Michigan - counties of Alcona; Alpena; Arenac; Bay; Cheboygan; Chippewa; Clinton; Crawford; Genesee; Gladwin; Gratiot; Hillsdale; Huron; Ingham; Iosco; Jackson; Lapeer; Lenawee; Livingston; Macomb; Midland; Monroe; Montmorency; Oakland; Ogemaw; Oscoda; Otsego; Presque Isle; Roscommon; Saginaw; Sanilac; Shiawassee; St Clair; Tuscola; Washtenaw; Wayne.',41.69,46.04,-84.87,-82.13,0);
INSERT INTO "area" VALUES('EPSG','1721','USA - Michigan - SPCS - old central','United States (USA) - Michigan - counties of Alger; Allegan; Antrim; Barry; Benzie; Berrien; Branch; Calhoun; Cass; Charlevoix; Clare; Delta; Eaton; Emmet; Grand Traverse; Ionia; Isabella; Kalamazoo; Kalkaska; Kent; Lake; Leelanau; Luce; Mackinac; Manistee; Mason; Mecosta; Missaukee; Montcalm; Muskegon; Newaygo; Oceana; Osceola; Ottawa; St Joseph; Schoolcraft; Van Buren; Wexford.',41.75,46.11,-87.61,-84.6,0);
INSERT INTO "area" VALUES('EPSG','1722','USA - Michigan - SPCS - W','United States (USA) - Michigan - counties of Alger; Baraga; Chippewa; Delta; Dickinson; Gogebic; Houghton; Iron; Keweenaw; Luce; Mackinac; Marquette; Menominee; Ontonagon; Schoolcraft.',NULL,NULL,NULL,NULL,1);
INSERT INTO "area" VALUES('EPSG','1723','USA - Michigan - SPCS - N','United States (USA) - Michigan north of approximately 45°45''N - counties of Alger; Baraga; Chippewa; Delta; Dickinson; Gogebic; Houghton; Iron; Keweenaw; Luce; Mackinac; Marquette; Menominee; Ontonagon; Schoolcraft.',45.08,48.32,-90.42,-83.44,0);
INSERT INTO "area" VALUES('EPSG','1724','USA - Michigan - SPCS - C','United States (USA) - Michigan - counties of Alcona; Alpena; Antrim; Arenac; Benzie; Charlevoix; Cheboygan; Clare; Crawford; Emmet; Gladwin; Grand Traverse; Iosco; Kalkaska; Lake; Leelanau; Manistee; Mason; Missaukee; Montmorency; Ogemaw; Osceola; Oscoda; Otsego; Presque Isle; Roscommon; Wexford.',43.8,45.92,-87.06,-82.27,0);
INSERT INTO "area" VALUES('EPSG','1725','USA - Michigan - SPCS - S','United States (USA) - Michigan - counties of Allegan; Barry; Bay; Berrien; Branch; Calhoun; Cass; Clinton; Eaton; Genesee; Gratiot; Hillsdale; Huron; Ingham; Ionia; Isabella; Jackson; Kalamazoo; Kent; Lapeer; Lenawee; Livingston; Macomb; Mecosta; Midland; Monroe; Montcalm; Muskegon; Newaygo; Oakland; Oceana; Ottawa; Saginaw; Sanilac; Shiawassee; St Clair; St Joseph; Tuscola; Van Buren; Washtenaw; Wayne.',41.69,44.22,-87.2,-82.13,0);
INSERT INTO "area" VALUES('EPSG','1726','Mozambique - offshore','Mozambique - offshore.',-27.71,-10.09,32.64,43.03,0);
INSERT INTO "area" VALUES('EPSG','1727','Suriname - offshore','Suriname - offshore.',5.34,9.35,-57.25,-52.66,0);
INSERT INTO "area" VALUES('EPSG','1728','Algeria - north of 34°39''N','Algeria - onshore north of 38.5 grads North (34°39''N).',34.64,37.14,-2.22,8.64,0);
INSERT INTO "area" VALUES('EPSG','1729','Algeria - 31°30''N to 34°39''N','Algeria - 35 grads to 38.5 grads North (31°30''N to 34°39''N).',31.49,34.66,-3.85,9.22,0);
INSERT INTO "area" VALUES('EPSG','1730','North America - NAVD88','North America: Canada - Alberta; British Columbia (BC); Manitoba; New Brunswick (NB); Newfoundland and Labrador; Northwest Territories (NWT); Nova Scotia (NS); Nunavut; Ontario; Prince Edward Island (PEI); Quebec; Saskatchewan; Yukon. United States (USA) - Alabama; Alaska; Arizona; Arkansas; California; Colorado; Connecticut; Delaware; Florida; Georgia; Idaho; Illinois; Indiana; Iowa; Kansas; Kentucky; Louisiana; Maine; Maryland; Massachusetts; Michigan; Minnesota; Mississippi; Missouri; Montana; Nebraska; Nevada; New Hampshire; New Jersey; New Mexico; New York; North Carolina; North Dakota; Ohio; Oklahoma; Oregon; Pennsylvania; Rhode Island; South Carolina; South Dakota; Tennessee; Texas; Utah; Vermont; Virginia; Washington; West Virginia; Wisconsin; Wyoming.',25.0,58.0,-168.0,-52.0,1);
INSERT INTO "area" VALUES('EPSG','1731','France - mainland north of 48.15°N','France mainland onshore north of 53.5 grads North (48°09''N).',48.14,51.14,-4.87,8.23,0);
INSERT INTO "area" VALUES('EPSG','1732','France - mainland 45.45°N to 48.15°N','France mainland onshore between 50.5 grads and 53.5 grads North (45°27''N to 48°09''N).',45.44,48.15,-4.8,7.63,0);
INSERT INTO "area" VALUES('EPSG','1733','France - mainland south of 45.45°N','France - mainland onshore south of 50.5 grads North (45°27''N).',42.33,45.45,-1.79,7.71,0);
INSERT INTO "area" VALUES('EPSG','1734','France - mainland 45.45°N to 48.15°N. Also all mainland.','France mainland onshore between 50.5 grads and 53.5 grads North (45°27''N to 48°09''N). Also used over all onshore mainland France.',42.33,51.14,-4.87,8.23,0);
INSERT INTO "area" VALUES('EPSG','1735','Algeria - west of 6°W','Algeria - west of 6°W (of Greenwich).',25.73,29.85,-8.67,-6.0,0);
INSERT INTO "area" VALUES('EPSG','1736','Algeria - 6°W to 0°W onshore','Algeria - onshore between 6°W and 0°W (of Greenwich).',21.82,35.96,-6.0,0.0,0);
INSERT INTO "area" VALUES('EPSG','1737','Algeria - 0°E to 6°E onshore','Algeria - onshore between 0°E and 6°E (of Greenwich).',18.97,36.97,0.0,6.01,0);
INSERT INTO "area" VALUES('EPSG','1738','Algeria - east of 6°E onshore','Algeria - onshore east of 6°E (of Greenwich).',19.6,37.14,6.0,11.99,0);
INSERT INTO "area" VALUES('EPSG','1739','Kuwait - west of 48°E onshore','Kuwait - onshore west of 48°E.',28.53,30.09,46.54,48.0,0);
INSERT INTO "area" VALUES('EPSG','1740','Kuwait - east of 48°E onshore','Kuwait - onshore east of 48°E.',28.54,30.04,48.0,48.48,0);
INSERT INTO "area" VALUES('EPSG','1741','Norway - zone I','Norway - west of 3°30''W of Oslo (7°13''22.5"E of Greenwich).',57.93,63.06,4.68,7.23,0);
INSERT INTO "area" VALUES('EPSG','1742','Norway - zone II','Norway - between 3°30''W and 1°10'' W of Oslo (7°13''22.5"E and 9°33''22.5"E of Greenwich).',57.95,63.87,7.22,9.56,0);
INSERT INTO "area" VALUES('EPSG','1743','Norway - zone III','Norway - between 1°10''W and 1°15''E of Oslo (9°33''22.5"E and 11°58''22.5"E of Greenwich).',58.84,65.76,9.55,11.98,0);
INSERT INTO "area" VALUES('EPSG','1744','Norway - zone IV','Norway - between 1°15''E and 4°20''E of Oslo (11°58''22.5"E and 15°03''22.5"E of Greenwich).',59.88,69.06,11.97,15.06,0);
INSERT INTO "area" VALUES('EPSG','1745','Norway - zone V','Norway - between 4°20''E and 8°10''E of Oslo (15°03''22.5"E and 18°53''22.5"E of Greenwich).',66.15,70.19,15.05,18.89,0);
INSERT INTO "area" VALUES('EPSG','1746','Norway - zone VI','Norway - between 8°10''E and 12°10''E of Oslo (18°53''22.5"E and 22°53''22.5"E of Greenwich).',68.33,70.81,18.88,22.89,0);
INSERT INTO "area" VALUES('EPSG','1747','Norway - zone VII','Norway - between 12°10''E and 16°15''E of Oslo (22°53''22.5"E and 26°58''22.5"E of Greenwich).',68.58,71.21,22.88,26.98,0);
INSERT INTO "area" VALUES('EPSG','1748','Norway - zone VIII','Norway - east of 16°15''E of Oslo (26°58''22.5"E of Greenwich).',69.02,71.17,26.97,31.22,0);
INSERT INTO "area" VALUES('EPSG','1749','Asia - Middle East - Qatar offshore and UAE west of 54°E','Qatar - offshore. United Arab Emirates (UAE) - Abu Dhabi - onshore and offshore west of 54°E.',22.76,27.05,50.55,54.01,0);
INSERT INTO "area" VALUES('EPSG','1750','UAE - east of 54°E','United Arab Emirates (UAE) onshore and offshore east of 54°E - Abu Dhabi; Dubai; Sharjah; Ajman; Fujairah; Ras Al Kaimah; Umm Al Qaiwain.',22.63,26.27,54.0,57.13,0);
INSERT INTO "area" VALUES('EPSG','1751','Peru - east of 73°W','Peru - east of 73°W, onshore.',-18.39,-2.14,-73.0,-68.67,0);
INSERT INTO "area" VALUES('EPSG','1752','Peru - 79°W to 73°W','Peru - between 79°W and 73°W, onshore.',-16.57,-0.03,-79.0,-73.0,0);
INSERT INTO "area" VALUES('EPSG','1753','Peru - west of 79°W','Peru - west of 79°W.',-8.32,-3.38,-81.41,-79.0,0);
INSERT INTO "area" VALUES('EPSG','1754','Brazil - Amazon cone shelf','Brazil - offshore shelf - Amazon cone.',-1.05,5.6,-51.64,-48.0,0);
INSERT INTO "area" VALUES('EPSG','1755','South America - 84°W to 78°W, S hemisphere and PSAD56 by country','South America (Ecuador and Peru) between 84°W and 78°W, southern hemisphere, onshore.',-10.53,0.0,-81.41,-78.0,0);
INSERT INTO "area" VALUES('EPSG','1756','South America - 78°W to 72°W, N hemisphere and PSAD56 by country','South America (Ecuador; Venezuela) between 78°W and 72°W, northern hemisphere, onshore.',0.0,11.62,-78.0,-71.99,0);
INSERT INTO "area" VALUES('EPSG','1757','South America - 78°W to 72°W, S hemisphere and PSAD56 by country','South America (Chile - north of 45°S; Ecuador; Peru) between 78°W and 72°W, southern hemisphere, onshore.',-45.0,0.0,-78.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','1758','South America - 72°W to 66°W, N hemisphere and PSAD56 by country','South America (Aruba; Bonaire; Curacao; Venezuela) between 72°W and 66°W, northern hemisphere, onshore.',0.73,12.68,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','1759','South America - 72°W to 66°W, S hemisphere and PSAD56 by country','South America (Bolivia; Chile - north of 45°S; Peru) between 72°W and 66°W, southern hemisphere, onshore.',-45.0,-2.14,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','1760','South America - 66°W to 60°W, N hemisphere and PSAD56 by country','South America (Guyana; Venezuela) onshore between 66°W and 60°W, northern hemisphere.',0.64,11.23,-66.0,-59.99,0);
INSERT INTO "area" VALUES('EPSG','1761','Bolivia - 66°W to 60°W','Bolivia between 66°W and 60°W.',-22.87,-9.67,-66.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','1762','South America - 60°W to 54°W, N hemisphere and PSAD56 by country','South America (Guyana) onshore between 60°W and 54°W, northern hemisphere.',1.18,8.58,-60.0,-56.47,0);
INSERT INTO "area" VALUES('EPSG','1763','Russia - west of 24°E onshore','Russian Federation - onshore west of 24°E - Kaliningrad.',54.32,55.32,19.57,22.87,0);
INSERT INTO "area" VALUES('EPSG','1764','Russia - 24°E to 30°E onshore','Russian Federation - onshore between 24°E and 30°E.',55.69,69.47,26.61,30.0,0);
INSERT INTO "area" VALUES('EPSG','1765','Russia - 30°E to 36°E onshore','Russian Federation - onshore between 30°E and 36°E.',50.34,70.02,30.0,36.0,0);
INSERT INTO "area" VALUES('EPSG','1766','Russia - 36°E to 42°E onshore','Russian Federation - onshore between 36°E and 42°E.',43.18,69.23,36.0,42.01,0);
INSERT INTO "area" VALUES('EPSG','1767','Russia - 42°E to 48°E onshore','Russian Federation - onshore between 42°E and 48°E.',41.19,80.91,42.0,48.0,0);
INSERT INTO "area" VALUES('EPSG','1768','Russia - 48°E to 54°E onshore','Russian Federation - onshore between 48°E and 54°E.',41.39,81.4,48.0,54.0,0);
INSERT INTO "area" VALUES('EPSG','1769','Russia - 54°E to 60°E onshore','Russian Federation - onshore between 54°E and 60°E.',50.47,81.91,54.0,60.0,0);
INSERT INTO "area" VALUES('EPSG','1770','Russia - 60°E to 66°E onshore','Russian Federation - onshore between 60°E and 66°E.',50.66,81.77,60.0,66.0,0);
INSERT INTO "area" VALUES('EPSG','1771','Russia - 66°E to 72°E onshore','Russian Federation - onshore between 66°E and 72°E .',54.1,77.07,66.0,72.0,0);
INSERT INTO "area" VALUES('EPSG','1772','Russia - 72°E to 78°E onshore','Russian Federation - onshore between 72°E and 78°E.',53.17,79.71,72.0,78.0,0);
INSERT INTO "area" VALUES('EPSG','1773','Russia - 78°E to 84°E onshore','Russian Federation - onshore between 78°E and 84°E.',50.69,81.03,78.0,84.0,0);
INSERT INTO "area" VALUES('EPSG','1774','Russia - 84°E to 90°E onshore','Russian Federation - onshore between 84°E and 90°E.',49.07,81.27,84.0,90.0,0);
INSERT INTO "area" VALUES('EPSG','1775','Russia - 90°E to 96°E onshore','Russian Federation - onshore between 90°E and 96°E.',49.89,81.35,90.0,96.0,0);
INSERT INTO "area" VALUES('EPSG','1776','Russia - 96°E to 102°E onshore','Russian Federation - onshore between 96°E and 102°E.',49.73,81.32,96.0,102.0,0);
INSERT INTO "area" VALUES('EPSG','1777','Russia - 102°E to 108°E onshore','Russian Federation - onshore between 102°E and 108°E.',49.64,79.48,102.0,108.0,0);
INSERT INTO "area" VALUES('EPSG','1778','Russia - 108°E to 114°E onshore','Russian Federation - onshore between 108°E and 114°E.',49.14,76.81,108.0,114.0,0);
INSERT INTO "area" VALUES('EPSG','1779','Russia - 114°E to 120°E onshore','Russian Federation - onshore between 114°E and 120°E.',49.51,75.96,114.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','1780','Russia - 120°E to 126°E onshore','Russian Federation - onshore between 120°E and 126°E.',51.51,74.0,120.0,126.0,0);
INSERT INTO "area" VALUES('EPSG','1781','Russia - 126°E to 132°E onshore','Russian Federation - onshore between 126°E and 132°E.',42.25,73.61,126.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','1782','Russia - 132°E to 138°E onshore','Russian Federation - onshore between 132°E and 138°E.',42.63,76.15,132.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','1783','Russia - 138°E to 144°E onshore','Russian Federation - onshore between 138°E and 144°E.',45.84,76.27,138.0,144.0,0);
INSERT INTO "area" VALUES('EPSG','1784','Russia - 144°E to 150°E onshore','Russian Federation - onshore between 144°E and 150°E.',43.6,76.82,144.0,150.0,0);
INSERT INTO "area" VALUES('EPSG','1785','Russia - 150°E to 156°E onshore','Russian Federation - onshore between 150°E and 156°E.',45.77,76.26,150.0,156.0,0);
INSERT INTO "area" VALUES('EPSG','1786','Russia - 156°E to 162°E onshore','Russian Federation - onshore between 156°E and 162°E.',50.27,77.2,156.0,162.0,0);
INSERT INTO "area" VALUES('EPSG','1787','Russia - 162°E to 168°E onshore','Russian Federation - onshore between 162°E and 168°E.',54.47,70.03,162.0,168.0,0);
INSERT INTO "area" VALUES('EPSG','1788','Russia - 168°E to 174°E onshore','Russian Federation - onshore between 168°E and 174°E.',54.45,70.19,168.0,174.0,0);
INSERT INTO "area" VALUES('EPSG','1789','Russia - 174°E to 180°E onshore','Russian Federation - onshore between 174°E and 180°E .',61.65,71.59,174.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','1790','Russia - 180° to 174°W onshore','Russian Federation - onshore between 180°E and 174°W.',64.35,71.65,-180.0,-174.0,0);
INSERT INTO "area" VALUES('EPSG','1791','Russia - east of 174°W onshore','Russian Federation - onshore east of 174°W.',64.2,67.18,-174.0,-168.97,0);
INSERT INTO "area" VALUES('EPSG','1792','Europe - 12°E to 18°E onshore and S-42(58) by country','Germany (former DDR) - onshore east of 12°E. Poland - onshore west of 18°E. Czechia, Hungary and Slovakia - west of 18°E.',45.78,54.89,12.0,18.0,0);
INSERT INTO "area" VALUES('EPSG','1793','Europe - FSU onshore 18°E to 24°E and S-42 by country','Belarus, Estonia, Latvia, Lithuania and Ukraine - onshore west of 24°E. Russian Federation - Kaliningrad onshore.',47.95,59.44,19.57,24.0,0);
INSERT INTO "area" VALUES('EPSG','1794','Europe - FSU onshore 24°E to 30°E and S-42 by country','Estonia; Latvia and Lithuania - onshore east of 24°E; Belarus, Moldova, Russian Federation and Ukraine - onshore 24°E to 30°E.',45.18,69.47,24.0,30.01,0);
INSERT INTO "area" VALUES('EPSG','1795','Europe - FSU onshore 30°E to 36°E','Belarus and Moldova - east of 30°E; Russian Federation and Ukraine - onshore 30°E to 36°E.',44.32,70.02,30.0,36.0,0);
INSERT INTO "area" VALUES('EPSG','1796','Europe - FSU onshore 36°E to 42°E','Georgia - onshore west of 36°E; Russian Federation - onshore 36°E to 42°E; Ukraine - onshore east of 36°E.',41.43,69.23,36.0,42.0,0);
INSERT INTO "area" VALUES('EPSG','1797','Europe - FSU onshore 42°E to 48°E','Armenia - west of 48°E; Azerbaijan - west of 48°E; Georgia - east of 42°E; Kazakhstan - west of 48°E; Russian Federation - onshore 42°E to 48°E.',38.84,80.91,42.0,48.01,0);
INSERT INTO "area" VALUES('EPSG','1798','Asia - FSU onshore 48°E to 54°E','Azerbaijan - east of 48°E; Kazakhstan - 48°E to 54°E; Russian Federation - 48°E to 54°E; Turkmenistan - west of 54°E. Includes Caspian Sea (considered a lake rather than offshore).',37.34,81.4,48.0,54.0,0);
INSERT INTO "area" VALUES('EPSG','1799','Asia - FSU onshore 54°E to 60°E','Kazakhstan; Russian Federation - onshore; Turkmenistan - 54°E to 60°E; Uzbekistan - west of 60°E.',37.05,81.91,54.0,60.0,0);
INSERT INTO "area" VALUES('EPSG','1800','Asia - FSU onshore 60°E to 66°E','Kazakhstan; Russian Federation - onshore; Uzbekistan - 60°E to 66°E; Turkmenistan - east of 60°E.',35.14,81.77,60.0,66.0,0);
INSERT INTO "area" VALUES('EPSG','1801','Asia - FSU onshore 66°E to 72°E','Kazakhstan, Russian Federation onshore and Uzbekistan - 66°E to 72°E; Kyrgyzstan and Tajikistan - west of 72°E.',36.67,77.07,66.0,72.0,0);
INSERT INTO "area" VALUES('EPSG','1802','Asia - FSU onshore 72°E to 78°E','Kazakhstan; Kyrgyzstan; Russian Federation onshore - 72°E to 78°E; Tajikistan and Uzbekistan - east of 72°E.',36.79,79.71,72.0,78.0,0);
INSERT INTO "area" VALUES('EPSG','1803','Asia - FSU onshore 78°E to 84°E','Kazakhstan and Russian Federation onshore - 78°E to 84°E; Kyrgyzstan - east of 78°E.',41.04,81.03,78.0,84.01,0);
INSERT INTO "area" VALUES('EPSG','1804','Asia - FSU onshore 84°E to 90°E','Kazakhstan - east of 84°E; Russian Federation - onshore 84°E to 90°E.',46.82,81.27,84.0,90.0,0);
INSERT INTO "area" VALUES('EPSG','1805','Europe - 6°E to 12°E and Pulkovo by country','Czech Republic and Germany (former DDR) - west of 12°E.',50.21,54.18,9.93,12.0,1);
INSERT INTO "area" VALUES('EPSG','1806','South America - UTM 17S and SAD69 by country','South America - between 84°W and 78°W; southern hemisphere.',NULL,NULL,NULL,NULL,1);
INSERT INTO "area" VALUES('EPSG','1807','South America - UTM 18N and SAD69 by country','South America - between 78°W and 72°W; northern hemisphere.',NULL,NULL,NULL,NULL,1);
INSERT INTO "area" VALUES('EPSG','1808','South America - UTM 18S and SAD69 by country','South America - between 78°W and 72°W; southern hemisphere.',NULL,NULL,NULL,NULL,1);
INSERT INTO "area" VALUES('EPSG','1809','South America - UTM 19N and SAD69 by country','South America - between 72°W and 66°W; northern hemisphere.',NULL,NULL,NULL,NULL,1);
INSERT INTO "area" VALUES('EPSG','1810','South America - UTM 19S and SAD69 by country','South America - between 72°W and 66°W; southern hemisphere.',NULL,NULL,NULL,NULL,1);
INSERT INTO "area" VALUES('EPSG','1811','South America - UTM 20N and SAD69 by country','South America - between 66°W and 60°W; northern hemisphere.',NULL,NULL,NULL,NULL,1);
INSERT INTO "area" VALUES('EPSG','1812','South America - UTM 20S and SAD69 by country','South America - between 66°W and 60°W; southern hemisphere.',NULL,NULL,NULL,NULL,1);
INSERT INTO "area" VALUES('EPSG','1813','South America - UTM 21N and SAD69','South America - between 60°W and 54°W; northern hemisphere.',NULL,NULL,NULL,NULL,1);
INSERT INTO "area" VALUES('EPSG','1814','South America - 60°W to 54°W, S hemisphere and SAD69 by country','Brazil - between 60°W and 54°W, northern and southern hemispheres. In rest of South America between 60°W and 54°W southern hemisphere, onshore.',-38.91,4.51,-60.0,-53.99,0);
INSERT INTO "area" VALUES('EPSG','1815','South America - 54°W to 48°W, N hemisphere and SAD69 by country','Brazil - offshore deep water - Amazon cone. In remainder of South America, between 54°W and 48°W, northern hemisphere onshore but excluding most of the area southeast of a line between approximately 2°N, 54°W and 4°N, 52°W.',1.68,5.81,-54.0,-46.65,0);
INSERT INTO "area" VALUES('EPSG','1816','South America - 54°W to 48°W, S hemisphere and SAD69 by country','Brazil - onshore and offshore northern and southern hemispheres between 54°W and 48°W. In remainder of South America - between 54°W and 48°W, southern hemisphere, onshore.',-35.71,7.04,-54.0,-47.99,0);
INSERT INTO "area" VALUES('EPSG','1817','Brazil - 48°W to 42°W','Brazil - between 48°W and 42°W.',-26.3,0.0,-48.0,-42.0,1);
INSERT INTO "area" VALUES('EPSG','1818','Brazil - 42°W to 36°W onshore','Brazil - between 42°W and 36°W, onshore.',-22.96,-2.68,-42.0,-36.0,0);
INSERT INTO "area" VALUES('EPSG','1819','Brazil - 36°W to 30°W','Brazil - between 36°W and 30°W.',-10.05,-5.15,-36.0,-30.0,1);
INSERT INTO "area" VALUES('EPSG','1820','Falkland Islands - onshore west of 60°W','Falkland Islands (Malvinas) - onshore west of 60°W.',-52.33,-50.96,-61.55,-59.99,0);
INSERT INTO "area" VALUES('EPSG','1821','Falkland Islands - onshore east of 60°W','Falkland Islands (Malvinas) - onshore east of 60°W.',-52.51,-51.13,-60.0,-57.6,0);
INSERT INTO "area" VALUES('EPSG','1822','Namibia - offshore','Namibia - offshore.',-30.64,-17.24,8.24,16.46,0);
INSERT INTO "area" VALUES('EPSG','1823','South America - 84°W to 78°W, N hemisphere and SIRGAS95 by country','South America between 84°W and 78°W, northern hemisphere, onshore and offshore.',0.9,15.51,-84.0,-78.0,0);
INSERT INTO "area" VALUES('EPSG','1824','South America - 84°W to 78°W, S hemisphere','South America between 84°W and 78°W, southern hemisphere, onshore and offshore.',-56.45,0.0,-84.0,-78.0,0);
INSERT INTO "area" VALUES('EPSG','1825','South America - 78°W to 72°W, N hemisphere','South America between 78°W and 72°W, northern hemisphere, onshore and offshore.',0.0,15.04,-78.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','1826','South America - 78°W to 72°W, S hemisphere and SIRGAS 1995 by country','South America between 78°W and 72°W, southern hemisphere, onshore and offshore.',-59.36,0.0,-78.0,-71.99,0);
INSERT INTO "area" VALUES('EPSG','1827','South America - 72°W to 66°W, N hemisphere','South America between 72°W and 66°W, northern hemisphere, onshore and offshore.',0.0,15.64,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','1828','South America - 72°W to 66°W, S hemisphere','South America between 72°W and 66°W, southern hemisphere, onshore and offshore.',-59.87,0.0,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','1829','South America - 66°W to 60°W, N hemisphere','South America between 66°W and 60°W, northern hemisphere, onshore and offshore.',0.0,16.75,-66.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','1830','South America - 66°W to 60°W, S hemisphere','South America between 66°W and 60°W, southern hemisphere, onshore and offshore.',-58.39,0.0,-66.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','1831','South America - 60°W to 54°W, N hemisphere','South America between 60°W and 54°W, northern hemisphere, onshore and offshore.',0.0,10.7,-60.0,-54.0,0);
INSERT INTO "area" VALUES('EPSG','1832','South America - 60°W to 54°W, S hemisphere','South America onshore and offshore, southern hemisphere between 60°W and 54°W.',-44.82,0.0,-60.0,-54.0,0);
INSERT INTO "area" VALUES('EPSG','1833','South America - 54°W to 48°W, N hemisphere','South America between 54°W and 48°W, northern hemisphere, onshore and offshore.',0.0,9.24,-54.0,-48.0,0);
INSERT INTO "area" VALUES('EPSG','1834','South America - 54°W to 48°W, S hemisphere','South America between 54°W and 48°W, southern hemisphere, onshore and offshore.',-39.95,0.0,-54.0,-48.0,0);
INSERT INTO "area" VALUES('EPSG','1835','South America - 48°W to 42°W','South America - between 48°W and 42°W, southern hemisphere, onshore and offshore.',-33.5,0.0,-48.0,-42.0,0);
INSERT INTO "area" VALUES('EPSG','1836','South America - 42°W to 36°W','South America - between 42°W and 36°W, southern hemisphere, onshore and offshore.',-26.35,0.0,-42.0,-36.0,0);
INSERT INTO "area" VALUES('EPSG','1837','South America - 36°W to 30°W','South America - between 36°W and 30°W, southern hemisphere, onshore and offshore.',-20.11,0.0,-36.0,-30.0,0);
INSERT INTO "area" VALUES('EPSG','1838','Namibia - west of 12°E','Namibia - onshore west of 12°E.',-18.53,-17.15,11.66,12.0,0);
INSERT INTO "area" VALUES('EPSG','1839','Namibia - 12°E to 14°E','Namibia - onshore between 12°E and 14°E.',-21.9,-16.95,12.0,14.01,0);
INSERT INTO "area" VALUES('EPSG','1840','Namibia - 14°E to 16°E','Namibia - onshore between 14°E and 16°E.',-28.3,-17.38,14.0,16.0,0);
INSERT INTO "area" VALUES('EPSG','1841','Namibia - 16°E to 18°E','Namibia - onshore between 16°E and 18°E.',-28.83,-17.38,15.99,18.01,0);
INSERT INTO "area" VALUES('EPSG','1842','Namibia - 18°E to 20°E','Namibia - between 18°E and 20°E.',-28.97,-17.38,18.0,20.0,0);
INSERT INTO "area" VALUES('EPSG','1843','Namibia - 20°E to 22°E','Namibia - between 20°E and 22°E.',-22.01,-17.85,19.99,22.0,0);
INSERT INTO "area" VALUES('EPSG','1844','Namibia - 22°E to 24°E','Namibia - between 22°E and 24°E.',-18.49,-17.52,21.99,24.0,0);
INSERT INTO "area" VALUES('EPSG','1845','Namibia - east of 24°E','Namibia - east of 24°E.',-18.18,-17.47,24.0,25.27,0);
INSERT INTO "area" VALUES('EPSG','1846','Sudan - south - west of 30°E','Sudan south - west of 30°E.',NULL,NULL,NULL,NULL,1);
INSERT INTO "area" VALUES('EPSG','1847','Sudan - south - east of 30°E','Sudan south - east of 30°E.',NULL,NULL,NULL,NULL,1);
INSERT INTO "area" VALUES('EPSG','1848','Madagascar - nearshore - west of 48°E','Madagascar - nearshore west of 48°E.',-26.59,-13.0,42.53,48.0,0);
INSERT INTO "area" VALUES('EPSG','1849','Madagascar - nearshore - east of 48°E','Madagascar - nearshore east of 48°E.',-24.21,-11.69,48.0,51.03,0);
INSERT INTO "area" VALUES('EPSG','1850','UAE - Abu Dhabi - onshore west of 54°E','United Arab Emirates (UAE) - Abu Dhabi onshore west of 54°E.',22.76,24.32,51.56,54.01,0);
INSERT INTO "area" VALUES('EPSG','1851','Malaysia - East Malaysia onshore','Malaysia - onshore East Malaysia (Sabah; Sarawak).',0.85,7.41,109.54,119.33,0);
INSERT INTO "area" VALUES('EPSG','1852','Asia - Brunei and East Malaysia - 108°E to 114°E','Brunei - offshore west of 114°E; Malaysia - East Malaysia (Sarawak) onshore and offshore west of 114°E).',0.85,7.37,109.31,114.0,0);
INSERT INTO "area" VALUES('EPSG','1853','Asia - Brunei and East Malaysia - 114°E to 120°E','Brunei - onshore and offshore east of 114°E; Malaysia - East Malaysia (Sabah, Sarawak) onshore and offshore east of 114°E).',1.43,7.67,114.0,119.61,0);
INSERT INTO "area" VALUES('EPSG','1854','Japan - zone I','Japan - onshore - Kyushu west of approximately 130°E - Nagasaki-ken; islands of Kagoshima-ken between 27°N and 32°N and between 128°18''E and 130°E (between 128°18''E and 30°13''E for Amami islands).',26.96,34.74,128.17,130.46,0);
INSERT INTO "area" VALUES('EPSG','1855','Japan - zone II','Japan - onshore - Kyushu east of approximately 130°E - Fukuoka-ken; Saga-ken; Kumamoto-ken; Oita-ken; Miyazaki-ken; Kagoshima-ken (except for area within Japan Plane Rectangular Coordinate System zone I).',30.18,33.99,129.76,132.05,0);
INSERT INTO "area" VALUES('EPSG','1856','Japan - zone III','Japan - onshore - Honshu west of approximately 133°15''E - Yamaguchi-ken; Shimane-ken; Hiroshima-ken.',33.72,36.38,130.81,133.49,0);
INSERT INTO "area" VALUES('EPSG','1857','Japan - zone IV','Japan - onshore - Shikoku - Kagawa-ken; Ehime-ken; Tokushima-ken; Kochi-ken.',32.69,34.45,131.95,134.81,0);
INSERT INTO "area" VALUES('EPSG','1858','Japan - zone V','Japan - onshore - Honshu between approximately 133°15''E and 135°10''E - Hyogo-ken; Tottori-ken; Okayama-ken.',34.13,35.71,133.13,135.47,0);
INSERT INTO "area" VALUES('EPSG','1859','Japan - zone VI','Japan - onshore - Honshu between approximately 135°10''E and 136°45''E - Kyoto-fu; Osaka-fu; Fukui-ken; Shiga-ken; Mie-ken; Nara-ken; Wakayama-ken.',33.4,36.33,134.86,136.99,0);
INSERT INTO "area" VALUES('EPSG','1860','Japan - zone VII','Japan - onshore - Honshu between approximately 136°15''E and 137°45''E - Ishikawa-ken; Toyama-ken; Gifu-ken; Aichi-ken.',34.51,37.58,136.22,137.84,0);
INSERT INTO "area" VALUES('EPSG','1861','Japan - zone VIII','Japan - onshore - Honshu between approximately 137°45''E and 139°E - Niigata-ken; Nagano-ken; Yamanashi-ken; Shizuoka-ken.',34.54,38.58,137.32,139.91,0);
INSERT INTO "area" VALUES('EPSG','1862','Japan - zone IX','Japan - onshore - Honshu - Tokyo-to. (Excludes offshore island areas of Tokyo-to covered by Japan Plane Rectangular Coordinate System zones XIV, XVIII and XIX).',29.31,37.98,138.4,141.11,0);
INSERT INTO "area" VALUES('EPSG','1863','Japan - zone X','Japan - onshore - Honshu north of 38°N approximately - Aomori-ken; Akita-ken; Yamagata-ken; Iwate-ken; Miyagi-ken.',37.73,41.58,139.49,142.14,0);
INSERT INTO "area" VALUES('EPSG','1864','Japan - zone XI','Japan - onshore - Hokkaido west of approximately 141°E - Otaru city; Hakodate city; Date city; Usu-gun and Abuta-gun of Iburi-shicho; Hiyama-shicho; Shiribeshi-shicho; Oshima-shicho.',41.34,43.42,139.34,141.46,0);
INSERT INTO "area" VALUES('EPSG','1865','Japan - zone XII','Japan - onshore - Hokkaido between approximately 141°E and 143°E - Sapporo city; Asahikawa city; Wakkanai city; Rumoi city; Bibai city; Yubari city; Iwamizawa city; Tomakomai city; Muroran city; Shibetsu city; Nayoro city; Ashibetsu city; Akabira city; Mikasa city; Takikawa city; Sunagawa city; Ebetsu city; Chitose city; Utashinai city; Fukagawa city; Monbetsu city; Furano city; Noboribetsu city; Eniwa city; Ishikari-shicho; Monbetsu-gun of Abashiri-shicho; Kamikawa-shicho; Soya-shicho; Hidaka-shicho; Iburi-shicho (except Usu-gun and Abuta-gun); Sorachi-shicho; Rumoi-shicho.',42.15,45.54,140.89,143.61,0);
INSERT INTO "area" VALUES('EPSG','1866','Japan - zone XIII','Japan - onshore - Hokkaido east of approximately 143°E - Kitami city; Obihiro city; Kushiro city; Abashiri city; Nemuro city; Nemuro-shicho; Kushiro-shicho; Abashiri-shicho (except Monbetsu-gun); Tokachi-shicho.',41.87,44.4,142.61,145.87,0);
INSERT INTO "area" VALUES('EPSG','1867','Japan - zone XIV','Japan - onshore - Tokyo-to south of 28°N and between 140°30''E and 143°E.',24.67,27.8,141.2,142.33,0);
INSERT INTO "area" VALUES('EPSG','1868','Japan - zone XV','Japan - onshore - Okinawa-ken between 126°E and 130°E.',26.02,26.91,126.63,128.4,0);
INSERT INTO "area" VALUES('EPSG','1869','Japan - zone XVI','Japan - onshore - Okinawa-ken west of 126°E.',23.98,24.94,122.83,125.51,0);
INSERT INTO "area" VALUES('EPSG','1870','Japan - zone XVII','Japan - onshore Okinawa-ken east of 130°E.',24.4,26.01,131.12,131.38,0);
INSERT INTO "area" VALUES('EPSG','1871','Japan - zone XVIII','Japan - onshore - Tokyo-to south of 28°N and west of 140°30''E.',20.37,20.48,136.02,136.16,0);
INSERT INTO "area" VALUES('EPSG','1872','Japan - Minamitori-shima (Marcus Island) - onshore','Japan - onshore - Tokyo-to south of 28°N and east of 143°E - Minamitori-shima (Marcus Island).',24.22,24.35,153.91,154.05,0);
INSERT INTO "area" VALUES('EPSG','1873','World - N hemisphere - 180°W to 174°W','Between 180°W and 174°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-180.0,-174.0,0);
INSERT INTO "area" VALUES('EPSG','1874','World - S hemisphere - 180°W to 174°W','Between 180°W to 174°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-180.0,-174.0,0);
INSERT INTO "area" VALUES('EPSG','1875','World - N hemisphere - 174°W to 168°W','Between 174°W and 168°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-174.0,-168.0,0);
INSERT INTO "area" VALUES('EPSG','1876','World - S hemisphere - 174°W to 168°W','Between 174°W and 168°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-174.0,-168.0,0);
INSERT INTO "area" VALUES('EPSG','1877','World - N hemisphere - 168°W to 162°W','Between 168°W and 162°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-168.0,-162.0,0);
INSERT INTO "area" VALUES('EPSG','1878','World - S hemisphere - 168°W to 162°W','Between 168°W and 162°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-168.0,-162.0,0);
INSERT INTO "area" VALUES('EPSG','1879','World - N hemisphere - 162°W to 156°W','Between 162°W and 156°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-162.0,-156.0,0);
INSERT INTO "area" VALUES('EPSG','1880','World - S hemisphere - 162°W to 156°W','Between 162°W and 156°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-162.0,-156.0,0);
INSERT INTO "area" VALUES('EPSG','1881','World - N hemisphere - 156°W to 150°W','Between 156°W and 150°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-156.0,-150.0,0);
INSERT INTO "area" VALUES('EPSG','1882','World - S hemisphere - 156°W to 150°W','Between 156°W and 150°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-156.0,-150.0,0);
INSERT INTO "area" VALUES('EPSG','1883','World - N hemisphere - 150°W to 144°W','Between 150°W and 144°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-150.0,-144.0,0);
INSERT INTO "area" VALUES('EPSG','1884','World - S hemisphere - 150°W to 144°W','Between 150°W and 144°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-150.0,-144.0,0);
INSERT INTO "area" VALUES('EPSG','1885','World - N hemisphere - 144°W to 138°W','Between 144°W and 138°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-144.0,-138.0,0);
INSERT INTO "area" VALUES('EPSG','1886','World - S hemisphere - 144°W to 138°W','Between 144°W and 138°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-144.0,-138.0,0);
INSERT INTO "area" VALUES('EPSG','1887','World - N hemisphere - 138°W to 132°W','Between 138°W and 132°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-138.0,-132.0,0);
INSERT INTO "area" VALUES('EPSG','1888','World - S hemisphere - 138°W to 132°W','Between 138°W and 132°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-138.0,-132.0,0);
INSERT INTO "area" VALUES('EPSG','1889','World - N hemisphere - 132°W to 126°W','Between 132°W and 126°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-132.0,-126.0,0);
INSERT INTO "area" VALUES('EPSG','1890','World - S hemisphere - 132°W to 126°W','Between 132°W and 126°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-132.0,-126.0,0);
INSERT INTO "area" VALUES('EPSG','1891','World - N hemisphere - 126°W to 120°W','Between 126°W and 120°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-126.0,-120.0,0);
INSERT INTO "area" VALUES('EPSG','1892','World - S hemisphere - 126°W to 120°W','Between 126°W and 120°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-126.0,-120.0,0);
INSERT INTO "area" VALUES('EPSG','1893','World - N hemisphere - 120°W to 114°W','Between 120°W and 114°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-120.0,-114.0,0);
INSERT INTO "area" VALUES('EPSG','1894','World - S hemisphere - 120°W to 114°W','Between 120°W and 114°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-120.0,-114.0,0);
INSERT INTO "area" VALUES('EPSG','1895','World - N hemisphere - 114°W to 108°W','Between 114°W and 108°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-114.0,-108.0,0);
INSERT INTO "area" VALUES('EPSG','1896','World - S hemisphere - 114°W to 108°W','Between 114°W and 108°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-114.0,-108.0,0);
INSERT INTO "area" VALUES('EPSG','1897','World - N hemisphere - 108°W to 102°W','Between 108°W and 102°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-108.0,-102.0,0);
INSERT INTO "area" VALUES('EPSG','1898','World - S hemisphere - 108°W to 102°W','Between 108°W and 102°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-108.0,-102.0,0);
INSERT INTO "area" VALUES('EPSG','1899','World - N hemisphere - 102°W to 96°W','Between 102°W and 96°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-102.0,-96.0,0);
INSERT INTO "area" VALUES('EPSG','1900','World - S hemisphere - 102°W to 96°W','Between 102°W and 96°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-102.0,-96.0,0);
INSERT INTO "area" VALUES('EPSG','1901','World - N hemisphere - 96°W to 90°W','Between 96°W and 90°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-96.0,-90.0,0);
INSERT INTO "area" VALUES('EPSG','1902','World - S hemisphere - 96°W to 90°W','Between 96°W and 90°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-96.0,-90.0,0);
INSERT INTO "area" VALUES('EPSG','1903','World - N hemisphere - 90°W to 84°W','Between 90°W and 84°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-90.0,-84.0,0);
INSERT INTO "area" VALUES('EPSG','1904','World - S hemisphere - 90°W to 84°W','Between 90°W and 84°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-90.0,-84.0,0);
INSERT INTO "area" VALUES('EPSG','1905','World - N hemisphere - 84°W to 78°W','Between 84°W and 78°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-84.0,-78.0,0);
INSERT INTO "area" VALUES('EPSG','1906','World - S hemisphere - 84°W to 78°W','Between 84°W and 78°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-84.0,-78.0,0);
INSERT INTO "area" VALUES('EPSG','1907','World - N hemisphere - 78°W to 72°W','Between 78°W and 72°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-78.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','1908','World - S hemisphere - 78°W to 72°W','Between 78°W and 72°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-78.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','1909','World - N hemisphere - 72°W to 66°W','Between 72°W and 66°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','1910','World - S hemisphere - 72°W to 66°W','Between 72°W and 66°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','1911','World - N hemisphere - 66°W to 60°W','Between 66°W and 60°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-66.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','1912','World - S hemisphere - 66°W to 60°W','Between 66°W and 60°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-66.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','1913','World - N hemisphere - 60°W to 54°W','Between 60°W and 54°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-60.0,-54.0,0);
INSERT INTO "area" VALUES('EPSG','1914','World - S hemisphere - 60°W to 54°W','Between 60°W and 54°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-60.0,-54.0,0);
INSERT INTO "area" VALUES('EPSG','1915','World - N hemisphere - 54°W to 48°W','Between 54°W and 48°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-54.0,-48.0,0);
INSERT INTO "area" VALUES('EPSG','1916','World - S hemisphere - 54°W to 48°W','Between 54°W and 48°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-54.0,-48.0,0);
INSERT INTO "area" VALUES('EPSG','1917','World - N hemisphere - 48°W to 42°W','Between 48°W and 42°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-48.0,-42.0,0);
INSERT INTO "area" VALUES('EPSG','1918','World - S hemisphere - 48°W to 42°W','Between 48°W and 42°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-48.0,-42.0,0);
INSERT INTO "area" VALUES('EPSG','1919','World - N hemisphere - 42°W to 36°W','Between 42°W and 36°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-42.0,-36.0,0);
INSERT INTO "area" VALUES('EPSG','1920','World - S hemisphere - 42°W to 36°W','Between 42°W and 36°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-42.0,-36.0,0);
INSERT INTO "area" VALUES('EPSG','1921','World - N hemisphere - 36°W to 30°W','Between 36°W and 30°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-36.0,-30.0,0);
INSERT INTO "area" VALUES('EPSG','1922','World - S hemisphere - 36°W to 30°W','Between 36°W and 30°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-36.0,-30.0,0);
INSERT INTO "area" VALUES('EPSG','1923','World - N hemisphere - 30°W to 24°W','Between 30°W and 24°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-30.0,-24.0,0);
INSERT INTO "area" VALUES('EPSG','1924','World - S hemisphere - 30°W to 24°W','Between 30°W and 24°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-30.0,-24.0,0);
INSERT INTO "area" VALUES('EPSG','1925','World - N hemisphere - 24°W to 18°W','Between 24°W and 18°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-24.0,-18.0,0);
INSERT INTO "area" VALUES('EPSG','1926','World - S hemisphere - 24°W to 18°W','Between 24°W and 18°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-24.0,-18.0,0);
INSERT INTO "area" VALUES('EPSG','1927','World - N hemisphere - 18°W to 12°W','Between 18°W and 12°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-18.0,-12.0,0);
INSERT INTO "area" VALUES('EPSG','1928','World - S hemisphere - 18°W to 12°W','Between 18°W and 12°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-18.0,-12.0,0);
INSERT INTO "area" VALUES('EPSG','1929','World - N hemisphere - 12°W to 6°W','Between 12°W and 6°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-12.0,-6.0,0);
INSERT INTO "area" VALUES('EPSG','1930','World - S hemisphere - 12°W to 6°W','Between 12°W and 6°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-12.0,-6.0,0);
INSERT INTO "area" VALUES('EPSG','1931','World - N hemisphere - 6°W to 0°W','Between 6°W and 0°W, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-6.0,0.0,0);
INSERT INTO "area" VALUES('EPSG','1932','World - S hemisphere - 6°W to 0°W','Between 6°W and 0°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-6.0,0.0,0);
INSERT INTO "area" VALUES('EPSG','1933','World - N hemisphere - 0°E to 6°E','Between 0°E and 6°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,0.0,6.0,0);
INSERT INTO "area" VALUES('EPSG','1934','World - S hemisphere - 0°E to 6°E','Between 0°E and 6°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,0.0,6.0,0);
INSERT INTO "area" VALUES('EPSG','1935','World - N hemisphere - 6°E to 12°E','Between 6°E and 12°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,6.0,12.0,0);
INSERT INTO "area" VALUES('EPSG','1936','World - S hemisphere - 6°E to 12°E','Between 6°E and 12°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,6.0,12.0,0);
INSERT INTO "area" VALUES('EPSG','1937','World - N hemisphere - 12°E to 18°E','Between 12°E and 18°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,12.0,18.0,0);
INSERT INTO "area" VALUES('EPSG','1938','World - S hemisphere - 12°E to 18°E','Between 12°E and 18°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,12.0,18.0,0);
INSERT INTO "area" VALUES('EPSG','1939','World - N hemisphere - 18°E to 24°E','Between 18°E and 24°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,18.0,24.0,0);
INSERT INTO "area" VALUES('EPSG','1940','World - S hemisphere - 18°E to 24°E','Between 18°E and 24°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,18.0,24.0,0);
INSERT INTO "area" VALUES('EPSG','1941','World - N hemisphere - 24°E to 30°E','Between 24°E and 30°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,24.0,30.0,0);
INSERT INTO "area" VALUES('EPSG','1942','World - S hemisphere - 24°E to 30°E','Between 24°E and 30°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,24.0,30.0,0);
INSERT INTO "area" VALUES('EPSG','1943','World - N hemisphere - 30°E to 36°E','Between 30°E and 36°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,30.0,36.0,0);
INSERT INTO "area" VALUES('EPSG','1944','World - S hemisphere - 30°E to 36°E','Between 30°E and 36°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,30.0,36.0,0);
INSERT INTO "area" VALUES('EPSG','1945','World - N hemisphere - 36°E to 42°E','Between 36°E and 42°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,36.0,42.0,0);
INSERT INTO "area" VALUES('EPSG','1946','World - S hemisphere - 36°E to 42°E','Between 36°E and 42°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,36.0,42.0,0);
INSERT INTO "area" VALUES('EPSG','1947','World - N hemisphere - 42°E to 48°E','Between 42°E and 48°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,42.0,48.0,0);
INSERT INTO "area" VALUES('EPSG','1948','World - S hemisphere - 42°E to 48°E','Between 42°E and 48°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,42.0,48.0,0);
INSERT INTO "area" VALUES('EPSG','1949','World - N hemisphere - 48°E to 54°E','Between 48°E and 54°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,48.0,54.0,0);
INSERT INTO "area" VALUES('EPSG','1950','World - S hemisphere - 48°E to 54°E','Between 48°E and 54°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,48.0,54.0,0);
INSERT INTO "area" VALUES('EPSG','1951','World - N hemisphere - 54°E to 60°E','Between 54°E and 60°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,54.0,60.0,0);
INSERT INTO "area" VALUES('EPSG','1952','World - S hemisphere - 54°E to 60°E','Between 54°E and 60°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,54.0,60.0,0);
INSERT INTO "area" VALUES('EPSG','1953','World - N hemisphere - 60°E to 66°E','Between 60°E and 66°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,60.0,66.0,0);
INSERT INTO "area" VALUES('EPSG','1954','World - S hemisphere - 60°E to 66°E','Between 60°E and 66°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,60.0,66.0,0);
INSERT INTO "area" VALUES('EPSG','1955','World - N hemisphere - 66°E to 72°E','Between 66°E and 72°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,66.0,72.0,0);
INSERT INTO "area" VALUES('EPSG','1956','World - S hemisphere - 66°E to 72°E','Between 66°E and 72°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,66.0,72.0,0);
INSERT INTO "area" VALUES('EPSG','1957','World - N hemisphere - 72°E to 78°E','Between 72°E and 78°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,72.0,78.0,0);
INSERT INTO "area" VALUES('EPSG','1958','World - S hemisphere - 72°E to 78°E','Between 72°E and 78°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,72.0,78.0,0);
INSERT INTO "area" VALUES('EPSG','1959','World - N hemisphere - 78°E to 84°E','Between 78°E and 84°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,78.0,84.0,0);
INSERT INTO "area" VALUES('EPSG','1960','World - S hemisphere - 78°E to 84°E','Between 78°E and 84°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,78.0,84.0,0);
INSERT INTO "area" VALUES('EPSG','1961','World - N hemisphere - 84°E to 90°E','Between 84°E and 90°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,84.0,90.0,0);
INSERT INTO "area" VALUES('EPSG','1962','World - S hemisphere - 84°E to 90°E','Between 84°E and 90°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,84.0,90.0,0);
INSERT INTO "area" VALUES('EPSG','1963','World - N hemisphere - 90°E to 96°E','Between 90°E and 96°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,90.0,96.0,0);
INSERT INTO "area" VALUES('EPSG','1964','World - S hemisphere - 90°E to 96°E','Between 90°E and 96°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,90.0,96.0,0);
INSERT INTO "area" VALUES('EPSG','1965','World - N hemisphere - 96°E to 102°E','Between 96°E and 102°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,96.0,102.0,0);
INSERT INTO "area" VALUES('EPSG','1966','World - S hemisphere - 96°E to 102°E','Between 96°E and 102°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,96.0,102.0,0);
INSERT INTO "area" VALUES('EPSG','1967','World - N hemisphere - 102°E to 108°E','Between 102°E and 108°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,102.0,108.0,0);
INSERT INTO "area" VALUES('EPSG','1968','World - S hemisphere - 102°E to 108°E','Between 102°E and 108°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,102.0,108.0,0);
INSERT INTO "area" VALUES('EPSG','1969','World - N hemisphere - 108°E to 114°E','Between 108°E and 114°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,108.0,114.0,0);
INSERT INTO "area" VALUES('EPSG','1970','World - S hemisphere - 108°E to 114°E','Between 108°E and 114°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,108.0,114.0,0);
INSERT INTO "area" VALUES('EPSG','1971','World - N hemisphere - 114°E to 120°E','Between 114°E and 120°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,114.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','1972','World - S hemisphere - 114°E to 120°E','Between 114°E and 120°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,114.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','1973','World - N hemisphere - 120°E to 126°E','Between 120°E and 126°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,120.0,126.0,0);
INSERT INTO "area" VALUES('EPSG','1974','World - S hemisphere - 120°E to 126°E','Between 120°E and 126°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,120.0,126.0,0);
INSERT INTO "area" VALUES('EPSG','1975','World - N hemisphere - 126°E to 132°E','Between 126°E and 132°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,126.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','1976','World - S hemisphere - 126°E to 132°E','Between 126°E and 132°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,126.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','1977','World - N hemisphere - 132°E to 138°E','Between 132°E and 138°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,132.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','1978','World - S hemisphere - 132°E to 138°E','Between 132°E and 138°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,132.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','1979','World - N hemisphere - 138°E to 144°E','Between 138°E and 144°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,138.0,144.0,0);
INSERT INTO "area" VALUES('EPSG','1980','World - S hemisphere - 138°E to 144°E','Between 138°E and 144°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,138.0,144.0,0);
INSERT INTO "area" VALUES('EPSG','1981','World - N hemisphere - 144°E to 150°E','Between 144°E and 150°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,144.0,150.0,0);
INSERT INTO "area" VALUES('EPSG','1982','World - S hemisphere - 144°E to 150°E','Between 144°E and 150°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,144.0,150.0,0);
INSERT INTO "area" VALUES('EPSG','1983','World - N hemisphere - 150°E to 156°E','Between 150°E and 156°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,150.0,156.0,0);
INSERT INTO "area" VALUES('EPSG','1984','World - S hemisphere - 150°E to 156°E','Between 150°E and 156°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,150.0,156.0,0);
INSERT INTO "area" VALUES('EPSG','1985','World - N hemisphere - 156°E to 162°E','Between 156°E and 162°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,156.0,162.0,0);
INSERT INTO "area" VALUES('EPSG','1986','World - S hemisphere - 156°E to 162°E','Between 156°E and 162°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,156.0,162.0,0);
INSERT INTO "area" VALUES('EPSG','1987','World - N hemisphere - 162°E to 168°E','Between 162°E and 168°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,162.0,168.0,0);
INSERT INTO "area" VALUES('EPSG','1988','World - S hemisphere - 162°E to 168°E','Between 162°E and 168°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,162.0,168.0,0);
INSERT INTO "area" VALUES('EPSG','1989','World - N hemisphere - 168°E to 174°E','Between 168°E and 174°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,168.0,174.0,0);
INSERT INTO "area" VALUES('EPSG','1990','World - S hemisphere - 168°E to 174°E','Between 168°E and 174°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,168.0,174.0,0);
INSERT INTO "area" VALUES('EPSG','1991','World - N hemisphere - 174°E to 180°E','Between 174°E and 180°E, northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,174.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','1992','World - S hemisphere - 174°E to 180°E','Between 174°E and 180°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,174.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','1993','World - N hemisphere - 102°E to 108°E - by country and WGS 72BE','Between 102°E and 108°E, northern hemisphere between equator and 84°N, onshore and offshore. Vietnam - offshore.',0.0,84.0,102.0,108.0,0);
INSERT INTO "area" VALUES('EPSG','1994','World - N hemisphere - 108°E to 114°E - by country and WGS 72BE','Between 108°E and 114°E, northern hemisphere between equator and 84°N, onshore and offshore. Vietnam - offshore.',0.0,84.0,108.0,114.0,0);
INSERT INTO "area" VALUES('EPSG','1995','World - S hemisphere - 108°E to 114°E - by country and WGS 72BE','Between 108°E and 114°E, southern hemisphere between 80°S and equator, onshore and offshore. Indonesia - offshore.',-80.0,0.0,108.0,114.0,0);
INSERT INTO "area" VALUES('EPSG','1996','World - N hemisphere - north of 60°N','Northern hemisphere - north of 60°N onshore and offshore, including Arctic.',60.0,90.0,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','1997','World - S hemisphere - south of 60°S','Southern hemisphere - south of 60°S onshore and offshore - Antarctica.',-90.0,-60.0,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','1998','World - N hemisphere - 0°N to 84°N','Northern hemisphere between equator and 84°N, onshore and offshore.',0.0,84.0,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','1999','World - S hemisphere - 0°N to 80°S','Southern hemisphere between equator and 80°S, onshore and offshore.',-80.0,0.0,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','2000','World - N hemisphere - 180°W to 174°W - by country','Between 180°W and 174°W, northern hemisphere between equator and 84°N, onshore and offshore. Russian Federation; United States (USA) - Alaska (AK).',0.0,84.0,-180.0,-174.0,0);
INSERT INTO "area" VALUES('EPSG','2001','World - S hemisphere - 180°W to 174°W - by country','Between 180°W and 174°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-180.0,-174.0,0);
INSERT INTO "area" VALUES('EPSG','2002','World - N hemisphere - 174°W to 168°W - by country','Between 174°W and 168°W, northern hemisphere between equator and 84°N, onshore and offshore. Russian Federation; United States (USA) - Alaska (AK).',0.0,84.0,-174.0,-168.0,0);
INSERT INTO "area" VALUES('EPSG','2003','World - S hemisphere - 174°W to 168°W - by country','Between 174°W and 168°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-174.0,-168.0,0);
INSERT INTO "area" VALUES('EPSG','2004','World - N hemisphere - 168°W to 162°W - by country','Between 168°W and 162°W, northern hemisphere between equator and 84°N, onshore and offshore. United States (USA) - Alaska (AK).',0.0,84.0,-168.0,-162.0,0);
INSERT INTO "area" VALUES('EPSG','2005','World - S hemisphere - 168°W to 162°W - by country','Between 168°W and 162°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-168.0,-162.0,0);
INSERT INTO "area" VALUES('EPSG','2006','World - N hemisphere - 162°W to 156°W - by country','Between 162°W and 156°W, northern hemisphere between equator and 84°N, onshore and offshore. United States (USA) - Alaska (AK).',0.0,84.0,-162.0,-156.0,0);
INSERT INTO "area" VALUES('EPSG','2007','World - S hemisphere - 162°W to 156°W - by country','Between 162°W and 156°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-162.0,-156.0,0);
INSERT INTO "area" VALUES('EPSG','2008','World - N hemisphere - 156°W to 150°W - by country','Between 156°W and 150°W, northern hemisphere between equator and 84°N, onshore and offshore. United States (USA) - Alaska (AK).',0.0,84.0,-156.0,-150.0,0);
INSERT INTO "area" VALUES('EPSG','2009','World - S hemisphere - 156°W to 150°W - by country','Between 156°W and 150°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-156.0,-150.0,0);
INSERT INTO "area" VALUES('EPSG','2010','World - N hemisphere - 150°W to 144°W - by country','Between 150°W and 144°W, northern hemisphere between equator and 84°N, onshore and offshore. United States (USA) - Alaska (AK).',0.0,84.0,-150.0,-144.0,0);
INSERT INTO "area" VALUES('EPSG','2011','World - S hemisphere - 150°W to 144°W - by country','Between 150°W and 144°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-150.0,-144.0,0);
INSERT INTO "area" VALUES('EPSG','2012','World - N hemisphere - 144°W to 138°W - by country','Between 144°W and 138°W, northern hemisphere between equator and 84°N, onshore and offshore. Canada - British Columbia (BC); Yukon. United States (USA) - Alaska (AK).',0.0,84.0,-144.0,-138.0,0);
INSERT INTO "area" VALUES('EPSG','2013','World - S hemisphere - 144°W to 138°W - by country','Between 144°W and 138°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-144.0,-138.0,0);
INSERT INTO "area" VALUES('EPSG','2014','World - N hemisphere - 138°W to 132°W - by country','Between 138°W and 132°W, northern hemisphere between equator and 84°N, onshore and offshore. Canada - British Columbia (BC); Northwest Territiories (NWT); Yukon. United States (USA) - Alaska (AK).',0.0,84.0,-138.0,-132.0,0);
INSERT INTO "area" VALUES('EPSG','2015','World - S hemisphere - 138°W to 132°W - by country','Between 138°W and 132°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-138.0,-132.0,0);
INSERT INTO "area" VALUES('EPSG','2016','World - N hemisphere - 132°W to 126°W - by country','Between 132°W and 126°W, northern hemisphere between equator and 84°N, onshore and offshore. Canada - British Columbia (BC); NorthW Territories (NWT); Yukon. United States (USA) - Alaska (AK).',0.0,84.0,-132.0,-126.0,0);
INSERT INTO "area" VALUES('EPSG','2017','World - S hemisphere - 132°W to 126°W - by country','Between 132°W and 126°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-132.0,-126.0,0);
INSERT INTO "area" VALUES('EPSG','2018','World - N hemisphere - 126°W to 120°W - by country','Between 126°W and 120°W, northern hemisphere between equator and 84°N, onshore and offshore. Canada - British Columbia (BC); Northwest Territories (NWT); Nunavut; Yukon. United States (USA) - Alaska (AK).',0.0,84.0,-126.0,-120.0,0);
INSERT INTO "area" VALUES('EPSG','2019','World - S hemisphere - 126°W to 120°W - by country','Between 126°W and 120°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-126.0,-120.0,0);
INSERT INTO "area" VALUES('EPSG','2020','World - N hemisphere - 120°W to 114°W - by country','Between 120°W and 114°W, northern hemisphere between equator and 84°N, onshore and offshore. Canada - Alberta; British Columbia (BC); Northwest Territories (NWT); Nunavut. Mexico. United States (USA).',0.0,84.0,-120.0,-114.0,0);
INSERT INTO "area" VALUES('EPSG','2021','World - S hemisphere - 120°W to 114°W - by country','Between 120°W and 114°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-120.0,-114.0,0);
INSERT INTO "area" VALUES('EPSG','2022','World - N hemisphere - 114°W to 108°W - by country','Between 114°W and 108°W, northern hemisphere between equator and 84°N, onshore and offshore. Canada - Alberta; Northwest Territories (NWT); Nunavut; Saskatchewan. Mexico. United States (USA).',0.0,84.0,-114.0,-108.0,0);
INSERT INTO "area" VALUES('EPSG','2023','World - S hemisphere - 114°W to 108°W - by country','Between 114°W and 108°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-114.0,-108.0,0);
INSERT INTO "area" VALUES('EPSG','2024','World - N hemisphere - 108°W to 102°W - by country','Between 108°W and 102°W, northern hemisphere between equator and 84°N, onshore and offshore. Canada - Northwest Territories (NWT); Nunavut; Saskatchewan. Mexico. United States (USA).',0.0,84.0,-108.0,-102.0,0);
INSERT INTO "area" VALUES('EPSG','2025','World - S hemisphere - 108°W to 102°W - by country','Between 108°W and 102°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-108.0,-102.0,0);
INSERT INTO "area" VALUES('EPSG','2026','World - N hemisphere - 102°W to 96°W - by country','Between 102°W and 96°W, northern hemisphere between equator and 84°N, onshore and offshore. Canada - Manitoba; Nunavut; Saskatchewan. Mexico. United States (USA).',0.0,84.0,-102.0,-96.0,0);
INSERT INTO "area" VALUES('EPSG','2027','World - S hemisphere - 102°W to 96°W - by country','Between 102°W and 96°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-102.0,-96.0,0);
INSERT INTO "area" VALUES('EPSG','2028','World - N hemisphere - 96°W to 90°W - by country','Between 96°W and 90°W, northern hemisphere between equator and 84°N, onshore and offshore. Canada - Manitoba; Nunavut; Ontario. Ecuador -Galapagos. Guatemala. Mexico. United States (USA).',0.0,84.0,-96.0,-90.0,0);
INSERT INTO "area" VALUES('EPSG','2029','World - S hemisphere - 96°W to 90°W - by country','Between 96°W and 90°W, southern hemisphere between 80°S and equator, onshore and offshore. Ecuador - Galapagos.',-80.0,0.0,-96.0,-90.0,0);
INSERT INTO "area" VALUES('EPSG','2030','World - N hemisphere - 90°W to 84°W - by country','Between 90°W and 84°W, northern hemisphere between equator and 84°N, onshore and offshore. Belize. Canada - Manitoba; Nunavut; Ontario. Costa Rica. Cuba. Ecuador - Galapagos. El Salvador. Guatemala. Honduras. Mexico. Nicaragua. United States (USA).',0.0,84.0,-90.0,-84.0,0);
INSERT INTO "area" VALUES('EPSG','2031','World - S hemisphere - 90°W to 84°W - by country','Between 90°W and 84°W, southern hemisphere between 80°S and equator, onshore and offshore. Ecuador - Galapagos.',-80.0,0.0,-90.0,-84.0,0);
INSERT INTO "area" VALUES('EPSG','2032','World - N hemisphere - 84°W to 78°W - by country','Between 84°W and 78°W, northern hemisphere between equator and 84°N, onshore and offshore. Bahamas. Ecuador - north of equator. Canada - Nunavut; Ontario; Quebec. Cayman Islands. Colombia. Costa Rica. Cuba. Jamaica. Nicaragua. Panama. United States (USA).',0.0,84.0,-84.0,-78.0,0);
INSERT INTO "area" VALUES('EPSG','2033','World - S hemisphere - 84°W to 78°W - by country','Between 84°W and 78°W, southern hemisphere between 80°S and equator, onshore and offshore. Ecuador. Peru.',-80.0,0.0,-84.0,-78.0,0);
INSERT INTO "area" VALUES('EPSG','2034','World - N hemisphere - 78°W to 72°W - by country','Between 78°W and 72°W, northern hemisphere between equator and 84°N, onshore and offshore. Bahamas. Canada - Nunavut; Ontario; Quebec. Colombia. Cuba. Ecuador. Greenland. Haiti. Jamica. Panama. Turks and Caicos Islands. United States (USA). Venezuela.',0.0,84.0,-78.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','2035','World - S hemisphere - 78°W to 72°W - by country','Between 78°W and 72°W, southern hemisphere between 80°S and equator, onshore and offshore. Argentina. Brazil. Chile. Colombia. Ecuador. Peru.',-80.0,0.0,-78.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','2036','World - N hemisphere - 72°W to 66°W - by country','Between 72°W and 66°W, northern hemisphere between equator and 84°N, onshore and offshore. Aruba. Bahamas. Brazil. Canada - New Brunswick (NB); Labrador; Nunavut; Nova Scotia (NS); Quebec. Colombia. Dominican Republic. Greenland. Netherlands Antilles. Puerto Rico. Turks and Caicos Islands. United States. Venezuela.',0.0,84.0,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','2037','World - S hemisphere - 72°W to 66°W - by country','Between 72°W and 66°W, southern hemisphere between 80°S and equator, onshore and offshore. Argentina. Bolivia. Brazil. Chile. Colombia. Peru.',-80.0,0.0,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','2038','World - N hemisphere - 66°W to 60°W - by country','Between 66°W and 60°W, northern hemisphere between equator and 84°N, onshore and offshore. Anguilla. Antigua and Barbuda. Bermuda. Brazil. British Virgin Islands. Canada - New Brunswick; Labrador; Nova Scotia; Nunavut; Prince Edward Island; Quebec. Dominica. Greenland. Grenada. Guadeloupe. Guyana. Martinique. Montserrat. Puerto Rico. St Kitts and Nevis. St Lucia. St Vncent and the Grenadines. Trinidad and Tobago. Venezuela. US Virgin Islands.',0.0,84.0,-66.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','2039','World - S hemisphere - 66°W to 60°W - by country','Between 66°W and 60°W, southern hemisphere between 80°S and equator, onshore and offshore. Argentina. Bolivia. Brazil. Falkland Islands (Malvinas). Paraguay.',-80.0,0.0,-66.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','2040','World - N hemisphere - 60°W to 54°W - by country','Between 60°W and 54°W, northern hemisphere between equator and 84°N, onshore and offshore. Barbados. Brazil. Canada - Newfoundland and Labrador, Quebec. French Guiana. Greenland. Guyana. St Pierre and Miquelon. Suriname.',0.0,84.0,-60.0,-54.0,0);
INSERT INTO "area" VALUES('EPSG','2041','World - S hemisphere - 60°W to 54°W - by country','Between 60°W and 54°W, southern hemisphere between 80°S and equator, onshore and offshore. Argentina. Bolivia. Brazil. Falkland Islands (Malvinas). Paraguay. Uruguay.',-80.0,0.0,-60.0,-54.0,0);
INSERT INTO "area" VALUES('EPSG','2042','World - N hemisphere - 54°W to 48°W - by country','Between 54°W and 48°W, northern hemisphere between equator and 84°N, onshore and offshore. Brazil. Canada - Newfoundland. French Guiana. Greenland.',0.0,84.0,-54.0,-48.0,0);
INSERT INTO "area" VALUES('EPSG','2043','World - S hemisphere - 54°W to 48°W - by country','Between 54°W and 48°W, southern hemisphere between 80°S and equator, onshore and offshore. Brazil. Uruguay.',-80.0,0.0,-54.0,-48.0,0);
INSERT INTO "area" VALUES('EPSG','2044','World - N hemisphere - 48°W to 42°W - by country','Between 48°W and 42°W, northern hemisphere between equator and 84°N, onshore and offshore. Greenland.',0.0,84.0,-48.0,-42.0,0);
INSERT INTO "area" VALUES('EPSG','2045','World - S hemisphere - 48°W to 42°W - by country','Between 48°W and 42°W, southern hemisphere between 80°S and equator, onshore and offshore. Brazil.',-80.0,0.0,-48.0,-42.0,0);
INSERT INTO "area" VALUES('EPSG','2046','World - N hemisphere - 42°W to 36°W - by country','Between 42°W and 36°W, northern hemisphere between equator and 84°N, onshore and offshore. Greenland.',0.0,84.0,-42.0,-36.0,0);
INSERT INTO "area" VALUES('EPSG','2047','World - S hemisphere - 42°W to 36°W - by country','Between 42°W and 36°W, southern hemisphere between 80°S and equator, onshore and offshore. Brazil. South Georgia and the South Sandwich Islands.',-80.0,0.0,-42.0,-36.0,0);
INSERT INTO "area" VALUES('EPSG','2048','World - N hemisphere - 36°W to 30°W - by country','Between 36°W and 30°W, northern hemisphere between equator and 84°N, onshore and offshore. Greenland.',0.0,84.0,-36.0,-30.0,0);
INSERT INTO "area" VALUES('EPSG','2049','World - S hemisphere - 36°W to 30°W - by country','Between 36°W and 30°W, southern hemisphere between 80°S and equator, onshore and offshore. Brazil.',-80.0,0.0,-36.0,-30.0,0);
INSERT INTO "area" VALUES('EPSG','2050','World - N hemisphere - 30°W to 24°W - by country','Between 30°W and 24°W, northern hemisphere between equator and 84°N, onshore and offshore. Greenland. Iceland.',0.0,84.0,-30.0,-24.0,0);
INSERT INTO "area" VALUES('EPSG','2051','World - S hemisphere - 30°W to 24°W - by country','Between 30°W and 24°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-30.0,-24.0,0);
INSERT INTO "area" VALUES('EPSG','2052','World - N hemisphere - 24°W to 18°W - by country','Between 24°W and 18°W, northern hemisphere between equator and 84°N, onshore and offshore. Greenland. Iceland.',0.0,84.0,-24.0,-18.0,0);
INSERT INTO "area" VALUES('EPSG','2053','World - S hemisphere - 24°W to 18°W - by country','Between 24°W and 18°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-24.0,-18.0,0);
INSERT INTO "area" VALUES('EPSG','2054','World - N hemisphere - 18°W to 12°W - by country','Between 18°W and 12°W, northern hemisphere between equator and 84°N, onshore and offshore. Gambia. Greenland. Guinea. Guinea-Bissau. Iceland. Ireland - offshore Porcupine Basin. Mauritania. Morocco. Senegal. Sierra Leone. Western Sahara.',0.0,84.0,-18.0,-12.0,0);
INSERT INTO "area" VALUES('EPSG','2055','World - S hemisphere - 18°W to 12°W - by country','Between 18°W and 12°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-18.0,-12.0,0);
INSERT INTO "area" VALUES('EPSG','2056','World - N hemisphere - 12°W to 6°W - by country','Between 12°W and 6°W, northern hemisphere between equator and 84°N, onshore and offshore. Algeria. Côte D''Ivoire (Ivory Coast). Faroe Islands. Guinea. Ireland. Jan Mayen. Mali. Mauritania. Morocco. Portugal. Sierra Leone. Spain. United Kingdom (UK). Western Sahara.',0.0,84.0,-12.0,-6.0,0);
INSERT INTO "area" VALUES('EPSG','2057','World - S hemisphere - 12°W to 6°W - by country','Between 12°W and 6°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-12.0,-6.0,0);
INSERT INTO "area" VALUES('EPSG','2058','World - N hemisphere - 6°W to 0°W - by country','Between 6°W and 0°W, northern hemisphere between equator and 84°N, onshore and offshore. Algeria. Burkina Faso. Côte'' Ivoire (Ivory Coast). Faroe Islands - offshore. France. Ghana. Gibraltar. Ireland - offshore Irish Sea. Mali. Mauritania. Morocco. Spain. United Kingdom (UK).',0.0,84.0,-6.0,0.0,0);
INSERT INTO "area" VALUES('EPSG','2059','World - S hemisphere - 6°W to 0°W - by country','Between 6°W and 0°W, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,-6.0,0.0,0);
INSERT INTO "area" VALUES('EPSG','2060','World - N hemisphere - 0°E to 6°E - by country','Between 0°E and 6°E, northern hemisphere between equator and 84°N, onshore and offshore. Algeria. Andorra. Belgium. Benin. Burkina Faso. Denmark - North Sea. France. Germany - North Sea. Ghana. Luxembourg. Mali. Netherlands. Niger. Nigeria. Norway. Spain. Togo. United Kingdom (UK) - North Sea.',0.0,84.0,0.0,6.0,0);
INSERT INTO "area" VALUES('EPSG','2061','World - S hemisphere - 0°E to 6°E - by country','Between 0°E and 6°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,0.0,6.0,0);
INSERT INTO "area" VALUES('EPSG','2062','World - N hemisphere - 6°E to 12°E - by country','Between 6°E and 12°E, northern hemisphere between equator and 84°N, onshore and offshore. Algeria. Austria. Cameroon. Denmark. Equatorial Guinea. France. Gabon. Germany. Italy. Libya. Liechtenstein. Monaco. Netherlands. Niger. Nigeria. Norway. Sao Tome and Principe. Svalbard. Sweden. Switzerland. Tunisia. Vatican City State.',0.0,84.0,6.0,12.0,0);
INSERT INTO "area" VALUES('EPSG','2063','World - S hemisphere - 6°E to 12°E - by country','Between 6°E and 12°E, southern hemisphere between 80°S and equator, onshore and offshore. Angola. Congo. Gabon. Namibia.',-80.0,0.0,6.0,12.0,0);
INSERT INTO "area" VALUES('EPSG','2064','World - N hemisphere - 12°E to 18°E - by country','Between 12°E and 18°E, northern hemisphere between equator and 84°N, onshore and offshore. Austria. Bosnia and Herzegovina. Cameroon. Central African Republic. Chad. Congo. Croatia. Czechia. Democratic Republic of the Congo (Zaire). Gabon. Germany. Hungary. Italy. Libya. Malta. Niger. Nigeria. Norway. Poland. San Marino. Slovakia. Slovenia. Svalbard. Sweden. Vatican City State.',0.0,84.0,12.0,18.0,0);
INSERT INTO "area" VALUES('EPSG','2065','World - S hemisphere - 12°E to 18°E - by country','Between 12°E and 18°E, southern hemisphere between 80°S and equator, onshore and offshore. Angola. Congo. Democratic Republic of the Congo (Zaire). Gabon. Namibia. South Africa.',-80.0,0.0,12.0,18.0,0);
INSERT INTO "area" VALUES('EPSG','2066','World - N hemisphere - 18°E to 24°E - by country','Between 18°E and 24°E, northern hemisphere between equator and 84°N, onshore and offshore. Albania. Belarus. Bosnia and Herzegovina. Bulgaria. Central African Republic. Chad. Croatia. Democratic Republic of the Congo (Zaire). Estonia. Finland. Greece. Hungary. Italy. Kosovo. Latvia. Libya. Lithuania. Montenegro. North Macedonia. Norway, including Svalbard and Bjornoys. Poland. Romania. Russian Federation. Serbia. Slovakia. Sudan. Sweden. Ukraine.',0.0,84.0,18.0,24.0,0);
INSERT INTO "area" VALUES('EPSG','2067','World - S hemisphere - 18°E to 24°E - by country','Between 18°E and 24°E, southern hemisphere between 80°S and equator, onshore and offshore. Angola. Botswana. Democratic Republic of the Congo (Zaire). Namibia. South Africa. Zambia.',-80.0,0.0,18.0,24.0,0);
INSERT INTO "area" VALUES('EPSG','2068','World - N hemisphere - 24°E to 30°E - by country','Between 24°E and 30°E, northern hemisphere between equator and 84°N, onshore and offshore. Belarus. Bulgaria. Central African Republic. Democratic Republic of the Congo (Zaire). Egypt. Estonia. Finland. Greece. Latvia. Lesotho. Libya. Lithuania. Moldova. Norway. Poland. Romania. Russian Federation. Sudan. Svalbard. Turkey. Uganda. Ukraine.',0.0,84.0,24.0,30.0,0);
INSERT INTO "area" VALUES('EPSG','2069','World - S hemisphere - 24°E to 30°E - by country','Between 24°E and 30°E, southern hemisphere between 80°S and equator, onshore and offshore. Botswana. Burundi. Democratic Republic of the Congo (Zaire). Rwanda. South Africa. Tanzania. Uganda. Zambia. Zimbabwe.',-80.0,0.0,24.0,30.0,0);
INSERT INTO "area" VALUES('EPSG','2070','World - N hemisphere - 30°E to 36°E - by country','Between 30°E and 36°E, northern hemisphere between equator and 84°N, onshore and offshore. Belarus. Cyprus. Egypt. Ethiopia. Finland. Israel. Jordan. Kenya. Lebanon. Moldova. Norway. Russian Federation. Saudi Arabia. Sudan. Syria. Turkey. Uganda. Ukraine.',0.0,84.0,30.0,36.0,0);
INSERT INTO "area" VALUES('EPSG','2071','World - S hemisphere - 30°E to 36°E - by country','Between 30°E and 36°E, southern hemisphere between 80°S and equator, onshore and offshore. Burundi. Eswatini (Swaziland). Kenya. Malawi. Mozambique. Rwanda. South Africa. Tanzania. Uganda. Zambia. Zimbabwe.',-80.0,0.0,30.0,36.0,0);
INSERT INTO "area" VALUES('EPSG','2072','World - N hemisphere - 36°E to 42°E - by country','Between 36°E and 42°E, northern hemisphere between equator and 84°N, onshore and offshore. Djibouti. Egypt. Eritrea. Ethiopia. Georgia. Iraq. Jordan. Kenya. Lebanon. Russian Federation. Saudi Arabia. Somalia. Sudan. Syria. Turkey. Ukraine.',0.0,84.0,36.0,42.0,0);
INSERT INTO "area" VALUES('EPSG','2073','World - S hemisphere - 36°E to 42°E - by country','Between 36°E and 42°E, southern hemisphere between 80°S and equator, onshore and offshore. Kenya. Mozambique. Tanzania.',-80.0,0.0,36.0,42.0,0);
INSERT INTO "area" VALUES('EPSG','2074','World - N hemisphere - 42°E to 48°E - by country','Between 42°E and 48°E, northern hemisphere between equator and 84°N, onshore and offshore. Armenia. Azerbaijan. Djibouti. Eritrea. Ethiopia. Georgia. Islamic Republic of Iran. Iraq. kazakhstan. Kuwait. Russian Federation. Saudi Arabia. Somalia. Turkey. Yemen.',0.0,84.0,42.0,48.0,0);
INSERT INTO "area" VALUES('EPSG','2075','World - S hemisphere - 42°E to 48°E - by country','Between 42°E and 48°E, southern hemisphere between 80°S and equator, onshore and offshore. Madagascar.',-80.0,0.0,42.0,48.0,0);
INSERT INTO "area" VALUES('EPSG','2076','World - N hemisphere - 48°E to 54°E - by country','Between 48°E and 54°E, northern hemisphere between equator and 84°N, onshore and offshore. Azerbaijan. Bahrain. Islamic Republic of Iran. Iraq. Kazakhstan. Kuwait. Oman. Qatar. Russian Federation. Saudi Arabia. Somalia. Turkmenistan. United Arab Emirates. Yemen.',0.0,84.0,48.0,54.0,0);
INSERT INTO "area" VALUES('EPSG','2077','World - S hemisphere - 48°E to 54°E - by country','Between 48°E and 54°E, southern hemisphere between 80°S and equator, onshore and offshore. Madagascar.',-80.0,0.0,48.0,54.0,0);
INSERT INTO "area" VALUES('EPSG','2078','World - N hemisphere - 54°E to 60°E - by country','Between 54°E and 60°E, northern hemisphere between equator and 84°N, onshore and offshore. Islamic Republic of Iran. kazakhstan. Oman. Russian Federation. Saudi Arabia. Turkmenistan. United Arab Emirates. Uzbekistan.',0.0,84.0,54.0,60.0,0);
INSERT INTO "area" VALUES('EPSG','2079','World - S hemisphere - 54°E to 60°E - by country','Between 54°E and 60°E, southern hemisphere between 80°S and equator, onshore and offshore. Seychelles.',-80.0,0.0,54.0,60.0,0);
INSERT INTO "area" VALUES('EPSG','2080','World - N hemisphere - 60°E to 66°E - by country','Between 60°E and 66°E, northern hemisphere between equator and 84°N, onshore and offshore. Afghanistan. Islamic Republic of Iran. kazakhstan. Pakistan. Russian Federation. Turkmenistan. Uzbekistan.',0.0,84.0,60.0,66.0,0);
INSERT INTO "area" VALUES('EPSG','2081','World - S hemisphere - 60°E to 66°E - by country','Between 60°E and 66°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,60.0,66.0,0);
INSERT INTO "area" VALUES('EPSG','2082','World - N hemisphere - 66°E to 72°E - by country','Between 66°E and 72°E, northern hemisphere between equator and 84°N, onshore and offshore. Afghanistan. India. Kazakhstan. Kyrgyzstan. Pakistan. Russian Federation. Tajikistan. Uzbekistan.',0.0,84.0,66.0,72.0,0);
INSERT INTO "area" VALUES('EPSG','2083','World - S hemisphere - 66°E to 72°E - by country','Between 66°E and 72°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,66.0,72.0,0);
INSERT INTO "area" VALUES('EPSG','2084','World - N hemisphere - 72°E to 78°E - by country','Between 72°E and 78°E, northern hemisphere between equator and 84°N, onshore and offshore. China. India. Kazakhstan. Kyrgyzstan. Maldives. Pakistan. Russian Federation. Tajikistan.',0.0,84.0,72.0,78.0,0);
INSERT INTO "area" VALUES('EPSG','2085','World - S hemisphere - 72°E to 78°E - by country','Between 72°E and 78°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,72.0,78.0,0);
INSERT INTO "area" VALUES('EPSG','2086','World - N hemisphere - 78°E to 84°E - by country','Between 78°E and 84°E, northern hemisphere between equator and 84°N, onshore and offshore. China. India. Kazakhstan. Kyrgyzstan. Nepal. Russian Federation. Sri Lanka.',0.0,84.0,78.0,84.0,0);
INSERT INTO "area" VALUES('EPSG','2087','World - S hemisphere - 78°E to 84°E - by country','Between 78°E and 84°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,78.0,84.0,0);
INSERT INTO "area" VALUES('EPSG','2088','World - N hemisphere - 84°E to 90°E - by country','Between 84°E and 90°E, northern hemisphere between equator and 84°N, onshore and offshore. Bangladesh. Bhutan. China. India. Kazakhstan. Mongolia. Nepal. Russian Federation.',0.0,84.0,84.0,90.0,0);
INSERT INTO "area" VALUES('EPSG','2089','World - S hemisphere - 84°E to 90°E - by country','Between 84°E and 90°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,84.0,90.0,0);
INSERT INTO "area" VALUES('EPSG','2090','World - N hemisphere - 90°E to 96°E - by country','Between 90°E and 96°E, northern hemisphere between equator and 84°N, onshore and offshore. Bangladesh. Bhutan. China. Indonesia. Mongolia. Myanmar (Burma). Russian Federation.',0.0,84.0,90.0,96.0,0);
INSERT INTO "area" VALUES('EPSG','2091','World - S hemisphere - 90°E to 96°E - by country','Between 90°E and 96°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,90.0,96.0,0);
INSERT INTO "area" VALUES('EPSG','2092','World - N hemisphere - 96°E to 102°E - by country','Between 96°E and 102°E, northern hemisphere between equator and 84°N, onshore and offshore. China. Indonesia. Laos. Malaysia - West Malaysia. Mongolia. Myanmar (Burma). Russian Federation. Thailand.',0.0,84.0,96.0,102.0,0);
INSERT INTO "area" VALUES('EPSG','2093','World - S hemisphere - 96°E to 102°E - by country','Between 96°E and 102°E, southern hemisphere between 80°S and equator, onshore and offshore. Indonesia.',-80.0,0.0,96.0,102.0,0);
INSERT INTO "area" VALUES('EPSG','2094','World - N hemisphere - 102°E to 108°E - by country','Between 102°E and 108°E, northern hemisphere between equator and 84°N, onshore and offshore. Cambodia. China. Indonesia. Laos. Malaysia - West Malaysia. Mongolia. Russian Federation. Singapore. Thailand. Vietnam.',0.0,84.0,102.0,108.0,0);
INSERT INTO "area" VALUES('EPSG','2095','World - S hemisphere - 102°E to 108°E - by country','Between 102°E and 108°E, southern hemisphere between 80°S and equator, onshore and offshore. Indonesia.',-80.0,0.0,102.0,108.0,0);
INSERT INTO "area" VALUES('EPSG','2096','World - N hemisphere - 108°E to 114°E - by country','Between 108°E and 114°E, northern hemisphere between equator and 84°N, onshore and offshore. China. Hong Kong. Indonesia. Macao. Malaysia - East Malaysia - Sarawak. Mongolia. Russian Federation. Vietnam.',0.0,84.0,108.0,114.0,0);
INSERT INTO "area" VALUES('EPSG','2097','World - S hemisphere - 108°E to 114°E - by country','Between 108°E and 114°E, southern hemisphere between 80°S and equator, onshore and offshore. Australia. Indonesia.',-80.0,0.0,108.0,114.0,0);
INSERT INTO "area" VALUES('EPSG','2098','World - N hemisphere - 114°E to 120°E - by country','Between 114°E and 120°E, northern hemisphere between equator and 84°N, onshore and offshore. Brunei. China. Hong Kong. Indonesia. Malaysia - East Malaysia - Sarawak. Mongolia. Philippines. Russian Federation. Taiwan.',0.0,84.0,114.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','2099','World - S hemisphere - 114°E to 120°E - by country','Between 114°E and 120°E, southern hemisphere between 80°S and equator, onshore and offshore. Australia. Indonesia.',-80.0,0.0,114.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','2100','World - N hemisphere - 120°E to 126°E - by country','Between 120°E and 126°E, northern hemisphere between equator and 84°N, onshore and offshore. China. Indonesia. Japan. North Korea. Philippines. Russian Federation. South Korea. Taiwan.',0.0,84.0,120.0,126.0,0);
INSERT INTO "area" VALUES('EPSG','2101','World - S hemisphere - 120°E to 126°E - by country','Between 120°E and 126°E, southern hemisphere between 80°S and equator, onshore and offshore. Australia. East Timor. Indonesia.',-80.0,0.0,120.0,126.0,0);
INSERT INTO "area" VALUES('EPSG','2102','World - N hemisphere - 126°E to 132°E - by country','Between 126°E and 132°E, northern hemisphere between equator and 84°N, onshore and offshore. China. Indonesia. Japan. North Korea. Russian Federation. South Korea.',0.0,84.0,126.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','2103','World - S hemisphere - 126°E to 132°E - by country','Between 126°E and 132°E, southern hemisphere between 80°S and equator, onshore and offshore. Australia. East Timor. Indonesia.',-80.0,0.0,126.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','2104','World - N hemisphere - 132°E to 138°E - by country','Between 132°E and 138°E, northern hemisphere between equator and 84°N, onshore and offshore. China. Japan. Russian Federation.',0.0,84.0,132.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','2105','World - S hemisphere - 132°E to 138°E - by country','Between 132°E and 138°E, southern hemisphere between 80°S and equator, onshore and offshore. Australia. Indonesia.',-80.0,0.0,132.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','2106','World - N hemisphere - 138°E to 144°E - by country','Between 138°E and 144°E, northern hemisphere between equator and 84°N, onshore and offshore. Japan. Russian Federation.',0.0,84.0,138.0,144.0,0);
INSERT INTO "area" VALUES('EPSG','2107','World - S hemisphere - 138°E to 144°E - by country','Between 138°E and 144°E, southern hemisphere between 80°S and equator, onshore and offshore. Australia. Indonesia. Papua New Guinea.',-80.0,0.0,138.0,144.0,0);
INSERT INTO "area" VALUES('EPSG','2108','World - N hemisphere - 144°E to 150°E - by country','Between 144°E and 150°E, northern hemisphere between equator and 84°N, onshore and offshore. Japan. Russian Federation.',0.0,84.0,144.0,150.0,0);
INSERT INTO "area" VALUES('EPSG','2109','World - S hemisphere - 144°E to 150°E - by country','Between 144°E and 150°E, southern hemisphere between 80°S and equator, onshore and offshore. Australia. Papua New Guinea.',-80.0,0.0,144.0,150.0,0);
INSERT INTO "area" VALUES('EPSG','2110','World - N hemisphere - 150°E to 156°E - by country','Between 150°E and 156°E, northern hemisphere between equator and 84°N, onshore and offshore. Russian Federation.',0.0,84.0,150.0,156.0,0);
INSERT INTO "area" VALUES('EPSG','2111','World - S hemisphere - 150°E to 156°E - by country','Between 150°E and 156°E, southern hemisphere between 80°S and equator, onshore and offshore. Australia. Papua New Guinea.',-80.0,0.0,150.0,156.0,0);
INSERT INTO "area" VALUES('EPSG','2112','World - N hemisphere - 156°E to 162°E - by country','Between 156°E and 162°E, northern hemisphere between equator and 84°N, onshore and offshore. Russian Federation.',0.0,84.0,156.0,162.0,0);
INSERT INTO "area" VALUES('EPSG','2113','World - S hemisphere - 156°E to 162°E - by country','Between 156°E and 162°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,156.0,162.0,0);
INSERT INTO "area" VALUES('EPSG','2114','World - N hemisphere - 162°E to 168°E - by country','Between 162°E and 168°E, northern hemisphere between equator and 84°N, onshore and offshore. Russian Federation.',0.0,84.0,162.0,168.0,0);
INSERT INTO "area" VALUES('EPSG','2115','World - S hemisphere - 162°E to 168°E - by country','Between 162°E and 168°E, southern hemisphere between 80°S and equator, onshore and offshore.',-80.0,0.0,162.0,168.0,0);
INSERT INTO "area" VALUES('EPSG','2116','World - N hemisphere - 168°E to 174°E - by country','Between 168°E and 174°E, northern hemisphere between equator and 84°N, onshore and offshore. Russian Federation; United States (USA) - Alaska.',0.0,84.0,168.0,174.0,0);
INSERT INTO "area" VALUES('EPSG','2117','World - S hemisphere - 168°E to 174°E - by country','Between 168°E and 174°E, southern hemisphere between 80°S and equator, onshore and offshore. New Zealand.',-80.0,0.0,168.0,174.0,0);
INSERT INTO "area" VALUES('EPSG','2118','World - N hemisphere - 174°E to 180°E - by country','Between 174°E and 180°E, northern hemisphere between equator and 84°N, onshore and offshore. Russian Federation; United States (USA) - Alaska (AK).',0.0,84.0,174.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','2119','World - S hemisphere - 174°E to 180°E - by country','Between 174°E and 180°E, southern hemisphere between 80°S and equator, onshore and offshore. New Zealand.',-80.0,0.0,174.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','2120','Guatemala - north of 15°51''30"N','Guatemala - north of 15°51''30"N.',15.85,17.83,-91.86,-88.34,0);
INSERT INTO "area" VALUES('EPSG','2121','Guatemala - south of 15°51''30"N','Guatemala - south of 15°51''30"N.',13.69,15.86,-92.29,-88.19,0);
INSERT INTO "area" VALUES('EPSG','2122','Europe - 18°W to 12°W and ETRS89 by country','Europe between 18°W and 12°W: Faroe Islands - offshore; Ireland - offshore; Jan Mayen - offshore; Portugal - offshore mainland; Spain - offshore mainland; United Kingdom (UKCS) - offshore.',34.93,72.44,-16.1,-11.99,0);
INSERT INTO "area" VALUES('EPSG','2123','Europe - 12°W to 6°W and ETRS89 by country','Europe between 12°W and 6°W: Faroe Islands - onshore and offshore; Ireland - offshore; Jan Mayen - onshore and offshore; Portugal - onshore and offshore; Spain - onshore and offshore; United Kingdom - UKCS offshore.',34.91,74.13,-12.0,-6.0,0);
INSERT INTO "area" VALUES('EPSG','2124','Europe - 6°W to 0°W and ETRS89 by country','Europe between 6°W and 0°W: Faroe Islands offshore; Ireland - offshore; Jan Mayen - offshore; Norway including Svalbard - offshore; Spain - onshore and offshore.',35.26,80.53,-6.0,0.0,0);
INSERT INTO "area" VALUES('EPSG','2125','Europe - 0°E to 6°E and ETRS89 by country','Europe between 0°E and 6°E: Andorra; Belgium - onshore and offshore; Denmark - offshore; Germany - offshore; Jan Mayen - offshore; Norway including Svalbard - onshore and offshore; Spain - onshore and offshore.',37.0,82.41,0.0,6.01,0);
INSERT INTO "area" VALUES('EPSG','2126','Europe - 6°E to 12°E and ETRS89 by country','Europe between 6°E and 12°E: Austria; Belgium; Denmark - onshore and offshore; Germany - onshore and offshore; Norway including - onshore and offshore; Spain - offshore.',38.76,83.92,6.0,12.0,0);
INSERT INTO "area" VALUES('EPSG','2127','Europe - 12°E to 18°E and ETRS89 by country','Europe between 12°E and 18°E: Austria; Denmark - offshore and offshore; Germany - onshore and offshore; Norway including Svalbard - onshore and offshore.',46.4,84.01,12.0,18.01,0);
INSERT INTO "area" VALUES('EPSG','2128','Europe - 18°E to 24°E and ETRS89 by country','Europe between 18°E and 24°E: Finland - onshore and offshore; Norway including Svalbard - onshore and offshore.',58.84,84.0,18.0,24.0,0);
INSERT INTO "area" VALUES('EPSG','2129','Europe - 24°E to 30°E and ETRS89 by country','Europe between 24°E and 30°E: Finland - onshore and offshore; Norway including Svalbard - onshore and offshore.',59.64,84.01,24.0,30.0,0);
INSERT INTO "area" VALUES('EPSG','2130','Europe - 30°E to 36°E and ETRS89 by country','Europe between 30°E and 36°E: Finland - onshore and offshore; Norway including Svalbard - onshore and offshore.',61.73,83.89,30.0,36.01,0);
INSERT INTO "area" VALUES('EPSG','2131','Europe - 36°E to 42°E and ETRS89 by country','Europe between 36°E and 42°E: Norway including Svalbard - offshore.',71.27,79.09,36.0,39.65,0);
INSERT INTO "area" VALUES('EPSG','2132','Europe - 42°E to 48°E and ETRS89 by country','Europe - between 42°E and 48°E.',37.0,41.65,42.0,48.0,1);
INSERT INTO "area" VALUES('EPSG','2133','USA - 168°W to 162°W - AK, OCS','United States (USA) - between 168°W and 162°W - Alaska and offshore continental shelf (OCS).',49.52,74.29,-168.0,-161.99,0);
INSERT INTO "area" VALUES('EPSG','2134','USA - 162°W to 156°W - AK, OCS','United States (USA) - between 162°W and 156°W - Alaska and offshore continental shelf (OCS).',50.98,74.71,-162.0,-155.99,0);
INSERT INTO "area" VALUES('EPSG','2135','USA - 156°W to 150°W - AK, OCS','United States (USA) - between 156°W and 150°W - Alaska and offshore continental shelf (OCS).',52.15,74.71,-156.0,-149.99,0);
INSERT INTO "area" VALUES('EPSG','2136','USA - 150°W to 144°W - AK, OCS','United States (USA) - between 150°W and 144°W - Alaska and offshore continental shelf (OCS).',54.05,74.13,-150.0,-143.99,0);
INSERT INTO "area" VALUES('EPSG','2137','North America - 144°W to 138°W and NAD27 by country','North America - between 144°W and 138°W. Canada - British Columbia; Yukon. United States (USA) - Alaska. Onshore for western Canada & but onshore and offshore for Alaska.',53.47,73.59,-144.0,-138.0,0);
INSERT INTO "area" VALUES('EPSG','2138','North America - 138°W to 132°W and NAD27 by country - onshore','North America - between 138°W and 132°W - onshore. Canada - British Columbia; Northwest Territiories; Yukon. United States (USA) - Alaska.  Onshore for Canadian British Columbia & Arctic and for US Pacific coast including Alaska panhandle.',52.58,73.04,-138.0,-132.0,0);
INSERT INTO "area" VALUES('EPSG','2139','North America - 132°W to 126°W and NAD27 by country - onshore','North America - between 132°W and 126°W - onshore. Canada - British Columbia; Northwest Territories; Yukon. United States (USA) - Alaska.   Onshore for Canadian British Colombia & Arctic coasts and for the US Pacific coast including Alaska panhandle.',49.18,72.03,-132.0,-126.0,0);
INSERT INTO "area" VALUES('EPSG','2140','North America - 126°W to 120°W and NAD27 by country - onshore','North America - between 126°W and 120°W - onshore. Canada - British Columbia; Northwest Territories; Nunavut; Yukon. United States (USA) - California; Oregon; Washington.',34.4,77.13,-126.0,-120.0,0);
INSERT INTO "area" VALUES('EPSG','2141','North America - 120°W to 114°W and NAD27 by country - onshore','North America - between 120°W and 114°W - onshore. Canada - Alberta; British Columbia; Northwest Territories; Nunavut. Mexico. United States (USA) - California; Idaho; Nevada; Oregon; Washington.',26.93,78.13,-120.0,-114.0,0);
INSERT INTO "area" VALUES('EPSG','2142','North America - 114°W to 108°W and NAD27 by country','North America - between 114°W and 108°W. Canada - Alberta; Northwest Territories; Nunavut; Saskatchewan. Mexico. United States (USA) - Arizona; Colorado; Idaho; Montana; New Mexico; Utah; Wyoming. Onshore for Mexican Pacific  and Canadian Arctic coasts.',18.66,78.81,-114.0,-108.0,0);
INSERT INTO "area" VALUES('EPSG','2143','North America - 108°W to 102°W and NAD27 by country','North America - between 108°W and 102°W. Canada - Northwest Territories; Nunavut; Saskatchewan. Mexico. United States (USA) - Colorado; Montana; Nebraska; New Mexico; North Dakota; Oklahoma; South Dakota; Texas; Wyoming. Onshore for Mexican Pacific and Canadian Arctic coasts.',17.86,79.42,-108.0,-102.0,0);
INSERT INTO "area" VALUES('EPSG','2144','North America - 102°W to 96°W and NAD27 by country','North America - between 102°W and 96°W. Canada - Manitoba; Nunavut; Saskatchewan. Mexico. United States (USA) - Iowa; Kansas; Minnesota; Nebraska; North Dakota; Oklahoma; South Dakota; Texas. Onshore for Mexican Pacific coast and Canadian Arctic but onshore and offshore for US & Mexico Gulf of Mexico and Caribbean coasts.',15.59,80.74,-102.0,-96.0,0);
INSERT INTO "area" VALUES('EPSG','2145','North America - 96°W to 90°W and NAD27 by country','North America - between 96°W and 90°W. Canada - Manitoba; Nunavut; Ontario. Guatemala. Mexico. United States (USA) - Arkansas; Illinois; Iowa; Kansas; Louisiana; Michigan; Minnesota; Mississippi; Missouri; Nebraska; Oklahoma; Tennessee; Texas; Wisconsin. Onshore for Canadian Arctic and Central America, onshore and offshore for Gulf of Mexico (both US and Mexican sectors).',13.63,81.96,-96.0,-90.0,0);
INSERT INTO "area" VALUES('EPSG','2146','North America - 90°W to 84°W and NAD27 by country','North America - between 90°W and 84°W. Belize. Canada - Manitoba; Nunavut; Ontario. Costa Rica. Cuba. El Salvador. Guatemala. Honduras. Mexico. Nicaragua. United States (USA) - Alabama; Arkansas; Florida; Georgia; Indiana; Illinois; Kentucky; Louisiana; Michigan; Minnesota; Mississippi; Missouri; North Carolina; Ohio; Tennessee; Wisconsin. Onshore for Canadian Arctic and Central America, onshore and offshore for Cuba and Gulf of Mexico (both US and Mexican sectors).',9.27,82.54,-90.01,-84.0,0);
INSERT INTO "area" VALUES('EPSG','2147','North America - 84°W to 78°W and NAD27 by country','North America - between 84°W and 78°W. Bahamas. Canada - Nunavut; Ontario; Quebec. Costa Rica. Cuba. Honduras. Nicaragua. United States (USA) - Florida; Georgia; Kentucky; Maryland; Michigan; New York; North Carolina; Ohio; Pennsylvania; South Carolina; Tennessee; Virginia; West Virginia. Onshore for Canadian Arctic. onshore and offshore for US east coast and Cuba, with usage in Bahamas onshore plus offshore over internal continental shelf only.',7.98,83.03,-84.0,-78.0,0);
INSERT INTO "area" VALUES('EPSG','2148','North America - 78°W to 72°W and NAD27 by country','North America - between 78°W and 72°W. Bahamas. Canada - Nunavut; Ontario; Quebec. Cuba. United States (USA) - Connecticut; Delaware; Maryland; Massachusetts; New Hampshire; New Jersey; New York; North Carolina; Pennsylvania; Virginia; Vermont. Onshore for Canadian arctic. onshore and offshore for US east coast and Cuba, with usage in Bahamas onshore plus offshore over internal continental shelf only.',18.83,83.16,-78.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','2149','North America - 72°W to 66°W and NAD27 by country','North America - between 72°W and 66°W. Canada - New Brunswick; Labrador; Nunavut; Nova Scotia; Quebec. United States (USA) - Connecticut; Maine; Massachusetts; New Hampshire; New York (Long Island); Rhode Island; Vermont. Onshore and offshore for US and Canadian east coasts.',33.61,83.17,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','2150','North America - 66°W to 60°W and NAD27 by country','North America - between 66°W and 60°W - onshore and offshore. Canada - New Brunswick; Labrador; Nova Scotia; Nunavut; Prince Edward Island; Quebec. United States (USA) offshore Atlantic.',39.85,82.97,-66.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','2151','Canada - 60°W to 54°W','Canada between 60°W and 54°W - Newfoundland and Labrador; Nunavut; Quebec.',40.57,84.0,-60.0,-54.0,0);
INSERT INTO "area" VALUES('EPSG','2152','Canada - 54°W to 48°W','Canada between 54°W and 48°W onshore and offshore - Newfoundland and Labrador.',43.27,57.65,-54.0,-48.0,0);
INSERT INTO "area" VALUES('EPSG','2153','Canada - 48°W to 42°W','Canada offshore Atlantic - east of 48°W.',46.46,49.18,-48.0,-47.74,0);
INSERT INTO "area" VALUES('EPSG','2154','USA - Alabama - SPCS - E','United States (USA) - Alabama east of approximately 86°37''W - counties Barbour; Bullock; Calhoun; Chambers; Cherokee; Clay; Cleburne; Coffee; Coosa; Covington; Crenshaw; Dale; De Kalb; Elmore; Etowah; Geneva; Henry; Houston; Jackson; Lee; Macon; Madison; Marshall; Montgomery; Pike; Randolph; Russell; StClair; Talladega; Tallapoosa.',30.99,35.0,-86.79,-84.89,0);
INSERT INTO "area" VALUES('EPSG','2155','USA - Alabama - SPCS - W','United States (USA) - Alabama west of approximately 86°37''W - counties Autauga; Baldwin; Bibb; Blount; Butler; Chilton; Choctaw; Clarke; Colbert; Conecuh; Cullman; Dallas; Escambia; Fayette; Franklin; Greene; Hale; Jefferson; Lamar; Lauderdale; Lawrence; Limestone; Lowndes; Marengo; Marion; Mobile; Monroe; Morgan; Perry; Pickens; Shelby; Sumter; Tuscaloosa; Walker; Washington; Wilcox; Winston.',30.14,35.02,-88.48,-86.3,0);
INSERT INTO "area" VALUES('EPSG','2156','USA - Alaska - Panhandle','United States (USA) - Alaska - east of 141°W; i.e. Panhandle.',54.61,60.35,-141.0,-129.99,0);
INSERT INTO "area" VALUES('EPSG','2157','USA - Alaska - Aleutian Islands','United States (USA) - Alaska - Aleutian Islands onshore.',51.3,54.34,172.42,-164.84,0);
INSERT INTO "area" VALUES('EPSG','2158','USA - Alaska - 144°W to 141°W','United States (USA) - Alaska - between 144°W and 141°W, onshore.',59.72,70.16,-144.01,-140.98,0);
INSERT INTO "area" VALUES('EPSG','2159','USA - Alaska - 148°W to 144°W','United States (USA) - Alaska - between 148°W and 144°W.',59.72,70.38,-148.0,-144.0,0);
INSERT INTO "area" VALUES('EPSG','2160','USA - Alaska - 152°W to 148°W','United States (USA) - Alaska - between 152°W and 148°W, onshore.',59.11,70.63,-152.01,-147.99,0);
INSERT INTO "area" VALUES('EPSG','2161','USA - Alaska - 156°W to 152°W','United States (USA) - Alaska - between 156°W and 152°W.',55.72,71.28,-156.0,-151.86,0);
INSERT INTO "area" VALUES('EPSG','2162','USA - Alaska - 160°W to 156°W','United States (USA) - Alaska - between 160°W and 156°W, onshore.',54.89,71.4,-160.0,-155.99,0);
INSERT INTO "area" VALUES('EPSG','2163','USA - Alaska - 164°W to 160°W','United States (USA) - Alaska - between 164°W and 160°W, onshore.',54.32,70.74,-164.01,-160.0,0);
INSERT INTO "area" VALUES('EPSG','2164','USA - Alaska - north of 54.5°N; 168°W to 164°W','United States (USA) - Alaska onshore north of 54°30''N and between 168°W and 164°W.',54.34,69.05,-168.26,-164.0,0);
INSERT INTO "area" VALUES('EPSG','2165','USA - Alaska - north of 54.5°N; west of 168°W','United States (USA) - Alaska onshore north of 54°30''N and west of 168°W.',56.49,65.82,-173.16,-168.0,0);
INSERT INTO "area" VALUES('EPSG','2166','USA - Arizona - SPCS - C','United States (USA) - Arizona - counties Coconino; Maricopa; Pima; Pinal; Santa Cruz; Yavapai.',31.33,37.01,-113.35,-110.44,0);
INSERT INTO "area" VALUES('EPSG','2167','USA - Arizona - SPCS - E','United States (USA) - Arizona - counties Apache; Cochise; Gila; Graham; Greenlee; Navajo.',31.33,37.01,-111.71,-109.04,0);
INSERT INTO "area" VALUES('EPSG','2168','USA - Arizona - SPCS - W','United States (USA) - Arizona - counties of La Paz; Mohave; Yuma.',32.05,37.0,-114.81,-112.52,0);
INSERT INTO "area" VALUES('EPSG','2169','USA - Arkansas - SPCS - N','United States (USA) - Arkansas - counties of Baxter; Benton; Boone; Carroll; Clay; Cleburne; Conway; Craighead; Crawford; Crittenden; Cross; Faulkner; Franklin; Fulton; Greene; Independence; Izard; Jackson; Johnson; Lawrence; Logan; Madison; Marion; Mississippi; Newton; Perry; Poinsett; Pope; Randolph; Scott; Searcy; Sebastian; Sharp; St Francis; Stone; Van Buren; Washington; White; Woodruff; Yell.',34.67,36.5,-94.62,-89.64,0);
INSERT INTO "area" VALUES('EPSG','2170','USA - Arkansas - SPCS - S','United States (USA) - Arkansas - counties Arkansas; Ashley; Bradley; Calhoun; Chicot; Clark; Cleveland; Columbia; Dallas; Desha; Drew; Garland; Grant; Hempstead; Hot Spring; Howard; Jefferson; Lafayette; Lee; Lincoln; Little River; Lonoke; Miller; Monroe; Montgomery; Nevada; Ouachita; Phillips; Pike; Polk; Prairie; Pulaski; Saline; Sevier; Union.',33.01,35.1,-94.48,-90.4,0);
INSERT INTO "area" VALUES('EPSG','2171','USA - GoM OCS - west of 96°W','United States (USA) - Gulf of Mexico outer continental shelf (GoM OCS) west of approximately 96°W - protraction areas Corpus Christi; Port Isabel.',25.97,28.43,-97.22,-95.87,0);
INSERT INTO "area" VALUES('EPSG','2172','USA - GoM OCS - 96°W to 90°W','United States (USA) - Gulf of Mexico outer continental shelf (GoM OCS) between approximately 96°W and 90°W - protraction areas East Breaks; Alaminos Canyon; Garden Banks; Keathley Canyon; Sigsbee Escarpment; Ewing Bank; Green Canyon; Walker Ridge; Amery Terrace.',25.61,29.73,-96.0,-89.86,0);
INSERT INTO "area" VALUES('EPSG','2173','USA - GoM OCS - 90°W to 84°W','United States (USA) - Gulf of Mexico outer continental shelf (GoM OCS) between approximately 90°W and 84°W - protraction areas Mobile; Viosca Knoll; Mississippi Canyon; Atwater Valley; Lund; Lund South; Pensacola; Destin Dome; De Soto Canyon; Lloyd Ridge; Henderson; Florida Plain; Campeche Escarpment; Apalachicola; Florida Middle Ground; The Elbow; Vernon Basin; Howell Hook; Rankin.',23.95,30.25,-90.01,-83.91,0);
INSERT INTO "area" VALUES('EPSG','2174','USA - GoM OCS - east of 84°W','United States (USA) - Gulf of Mexico outer continental shelf (GoM OCS) east of approximately 84°W - protraction areas Gainesville; Tarpon Springs; St Petersburg; Charlotte Harbor; Pulley Ridge; Dry Tortugas; Tortugas Valley; Miami; Key West.',23.82,29.94,-84.09,-81.17,0);
INSERT INTO "area" VALUES('EPSG','2175','USA - California - SPCS - 1','United States (USA) - California - counties Del Norte; Humboldt; Lassen; Modoc; Plumas; Shasta; Siskiyou; Tehama; Trinity.',39.59,42.01,-124.45,-119.99,0);
INSERT INTO "area" VALUES('EPSG','2176','USA - California - SPCS - 2','United States (USA) - California - counties of Alpine; Amador; Butte; Colusa; El Dorado; Glenn; Lake; Mendocino; Napa; Nevada; Placer; Sacramento; Sierra; Solano; Sonoma; Sutter; Yolo; Yuba.',38.02,40.16,-124.06,-119.54,0);
INSERT INTO "area" VALUES('EPSG','2177','USA - California - SPCS - 3','United States (USA) - California - counties Alameda; Calaveras; Contra Costa; Madera; Marin; Mariposa; Merced; Mono; San Francisco; San Joaquin; San Mateo; Santa Clara; Santa Cruz; Stanislaus; Tuolumne.',36.73,38.71,-123.02,-117.83,0);
INSERT INTO "area" VALUES('EPSG','2178','USA - California - SPCS - 4','United States (USA) - California - counties Fresno; Inyo; Kings; Monterey; San Benito; Tulare.',35.78,37.58,-122.01,-115.62,0);
INSERT INTO "area" VALUES('EPSG','2179','USA - California - SPCS27 - 5','United States (USA) - California - counties of Kern; San Bernardino; San Luis Obispo; Santa Barbara; Ventura.',32.76,35.81,-121.43,-114.12,0);
INSERT INTO "area" VALUES('EPSG','2180','USA - California - SPCS - 6','United States (USA) - California - counties Imperial; Orange; Riverside; San Diego.',32.53,34.08,-118.15,-114.42,0);
INSERT INTO "area" VALUES('EPSG','2181','USA - California - SPCS27 - 7','United States (USA) - California - Los Angeles county.',33.66,34.83,-118.96,-117.63,0);
INSERT INTO "area" VALUES('EPSG','2182','USA - California - SPCS83 - 5','United States (USA) - California - counties Kern; Los Angeles; San Bernardino; San Luis Obispo; Santa Barbara; Ventura.',32.76,35.81,-121.42,-114.12,0);
INSERT INTO "area" VALUES('EPSG','2183','USA - Colorado - SPCS - C','United States (USA) - Colorado - counties Arapahoe; Chaffee; Cheyenne; Clear Creek; Delta; Denver; Douglas; Eagle; El Paso; Elbert; Fremont; Garfield; Gunnison; Jefferson; Kit Carson; Lake; Lincoln; Mesa; Park; Pitkin; Summit; Teller.',38.14,40.09,-109.06,-102.04,0);
INSERT INTO "area" VALUES('EPSG','2184','USA - Colorado - SPCS - N','United States (USA) - Colorado - counties Adams; Boulder; Gilpin; Grand; Jackson; Larimer; Logan; Moffat; Morgan; Phillips; Rio Blanco; Routt; Sedgwick; Washington; Weld; Yuma.',39.56,41.01,-109.06,-102.04,0);
INSERT INTO "area" VALUES('EPSG','2185','USA - Colorado - SPCS - S','United States (USA) - Colorado - counties Alamosa; Archuleta; Baca; Bent; Conejos; Costilla; Crowley; Custer; Dolores; Hinsdale; Huerfano; Kiowa; La Plata; Las Animas; Mineral; Montezuma; Montrose; Otero; Ouray; Prowers; Pueblo; Rio Grande; Saguache; San Juan; San Miguel.',36.98,38.68,-109.06,-102.04,0);
INSERT INTO "area" VALUES('EPSG','2186','USA - Florida - SPCS - E','United States (USA) - Florida - counties of Brevard; Broward; Clay; Collier; Dade; Duval; Flagler; Glades; Hendry; Highlands; Indian River; Lake; Martin; Monroe; Nassau; Okeechobee; Orange; Osceola; Palm Beach; Putnam; Seminole; St Johns; St Lucie; Volusia.',24.41,30.83,-82.33,-79.97,0);
INSERT INTO "area" VALUES('EPSG','2187','USA - Florida - SPCS - N','United States (USA) - Florida - counties of Alachua; Baker; Bay; Bradford; Calhoun; Columbia; Dixie; Escambia; Franklin; Gadsden; Gilchrist; Gulf; Hamilton; Holmes; Jackson; Jefferson; Lafayette; Leon; Liberty; Madison; Okaloosa; Santa Rosa; Suwannee; Taylor; Union; Wakulla; Walton; Washington.',29.21,31.01,-87.63,-82.04,0);
INSERT INTO "area" VALUES('EPSG','2188','USA - Florida - SPCS - W','United States (USA) - Florida - counties of Charlotte; Citrus; De Soto; Hardee; Hernando; Hillsborough; Lee; Levy; Manatee; Marion; Pasco; Pinellas; Polk; Sarasota; Sumter.',26.27,29.6,-83.34,-81.13,0);
INSERT INTO "area" VALUES('EPSG','2189','USA - Georgia - SPCS - E','United States (USA) - Georgia - counties of Appling; Atkinson; Bacon; Baldwin; Brantley; Bryan; Bulloch; Burke; Camden; Candler; Charlton; Chatham; Clinch; Coffee; Columbia; Dodge; Echols; Effingham; Elbert; Emanuel; Evans; Franklin; Glascock; Glynn; Greene; Hancock; Hart; Jeff Davis; Jefferson; Jenkins; Johnson; Lanier; Laurens; Liberty; Lincoln; Long; Madison; McDuffie; McIntosh; Montgomery; Oglethorpe; Pierce; Richmond; Screven; Stephens; Taliaferro; Tattnall; Telfair; Toombs; Treutlen; Ware; Warren; Washington; Wayne; Wheeler; Wilkes; Wilkinson.',30.36,34.68,-83.47,-80.77,0);
INSERT INTO "area" VALUES('EPSG','2190','USA - Georgia - SPCS - W','United States (USA) - Georgia - counties of Baker; Banks; Barrow; Bartow; Ben Hill; Berrien; Bibb; Bleckley; Brooks; Butts; Calhoun; Carroll; Catoosa; Chattahoochee; Chattooga; Cherokee; Clarke; Clay; Clayton; Cobb; Colquitt; Cook; Coweta; Crawford; Crisp; Dade; Dawson; De Kalb; Decatur; Dooly; Dougherty; Douglas; Early; Fannin; Fayette; Floyd; Forsyth; Fulton; Gilmer; Gordon; Grady; Gwinnett; Habersham; Hall; Haralson; Harris; Heard; Henry; Houston; Irwin; Jackson; Jasper; Jones; Lamar; Lee; Lowndes; Lumpkin; Macon; Marion; Meriwether; Miller; Mitchell; Monroe; Morgan; Murray; Muscogee; Newton; Oconee; Paulding; Peach; Pickens; Pike; Polk; Pulaski; Putnam; Quitman; Rabun; Randolph; Rockdale; Schley; Seminole; Spalding; Stewart; Sumter; Talbot; Taylor; Terrell; Thomas; Tift; Towns; Troup; Turner; Twiggs; Union; Upson; Walker; Walton; Webster; White; Whitfield; Wilcox; Worth.',30.62,35.01,-85.61,-82.99,0);
INSERT INTO "area" VALUES('EPSG','2191','USA - Idaho - SPCS - C','United States (USA) - Idaho - counties of Blaine; Butte; Camas; Cassia; Custer; Gooding; Jerome; Lemhi; Lincoln; Minidoka; Twin Falls.',41.99,45.7,-115.3,-112.68,0);
INSERT INTO "area" VALUES('EPSG','2192','USA - Idaho - SPCS - E','United States (USA) - Idaho - counties of Bannock; Bear Lake; Bingham; Bonneville; Caribou; Clark; Franklin; Fremont; Jefferson; Madison; Oneida; Power; Teton.',41.99,44.75,-113.24,-111.04,0);
INSERT INTO "area" VALUES('EPSG','2193','USA - Idaho - SPCS - W','United States (USA) - Idaho - counties of Ada; Adams; Benewah; Boise; Bonner; Boundary; Canyon; Clearwater; Elmore; Gem; Idaho; Kootenai; Latah; Lewis; Nez Perce; Owyhee; Payette; Shoshone; Valley; Washington.',41.99,49.01,-117.24,-114.32,0);
INSERT INTO "area" VALUES('EPSG','2194','USA - Illinois - SPCS - E','United States (USA) - Illinois - counties of Boone; Champaign; Clark; Clay; Coles; Cook; Crawford; Cumberland; De Kalb; De Witt; Douglas; Du Page; Edgar; Edwards; Effingham; Fayette; Ford; Franklin; Gallatin; Grundy; Hamilton; Hardin; Iroquois; Jasper; Jefferson; Johnson; Kane; Kankakee; Kendall; La Salle; Lake; Lawrence; Livingston; Macon; Marion; Massac; McHenry; McLean; Moultrie; Piatt; Pope; Richland; Saline; Shelby; Vermilion; Wabash; Wayne; White; Will; Williamson.',37.06,42.5,-89.28,-87.02,0);
INSERT INTO "area" VALUES('EPSG','2195','USA - Illinois - SPCS - W','United States (USA) - Illinois - counties of Adams; Alexander; Bond; Brown; Bureau; Calhoun; Carroll; Cass; Christian; Clinton; Fulton; Greene; Hancock; Henderson; Henry; Jackson; Jersey; Jo Daviess; Knox; Lee; Logan; Macoupin; Madison; Marshall; Mason; McDonough; Menard; Mercer; Monroe; Montgomery; Morgan; Ogle; Peoria; Perry; Pike; Pulaski; Putnam; Randolph; Rock Island; Sangamon; Schuyler; Scott; St Clair; Stark; Stephenson; Tazewell; Union; Warren; Washington; Whiteside; Winnebago; Woodford.',36.98,42.51,-91.52,-88.93,0);
INSERT INTO "area" VALUES('EPSG','2196','USA - Indiana - SPCS - E','United States (USA) - Indiana - counties of Adams; Allen; Bartholomew; Blackford; Brown; Cass; Clark; De Kalb; Dearborn; Decatur; Delaware; Elkhart; Fayette; Floyd; Franklin; Fulton; Grant; Hamilton; Hancock; Harrison; Henry; Howard; Huntington; Jackson; Jay; Jefferson; Jennings; Johnson; Kosciusko; Lagrange; Madison; Marion; Marshall; Miami; Noble; Ohio; Randolph; Ripley; Rush; Scott; Shelby; St Joseph; Steuben; Switzerland; Tipton; Union; Wabash; Washington; Wayne; Wells; Whitley.',37.95,41.77,-86.59,-84.78,0);
INSERT INTO "area" VALUES('EPSG','2197','USA - Indiana - SPCS - W','United States (USA) - Indiana - counties of Benton; Boone; Carroll; Clay; Clinton; Crawford; Daviess; Dubois; Fountain; Gibson; Greene; Hendricks; Jasper; Knox; La Porte; Lake; Lawrence; Martin; Monroe; Montgomery; Morgan; Newton; Orange; Owen; Parke; Perry; Pike; Porter; Posey; Pulaski; Putnam; Spencer; Starke; Sullivan; Tippecanoe; Vanderburgh; Vermillion; Vigo; Warren; Warrick; White.',37.77,41.77,-88.06,-86.24,0);
INSERT INTO "area" VALUES('EPSG','2198','USA - Iowa - SPCS - N','United States (USA) - Iowa - counties of Allamakee; Benton; Black Hawk; Boone; Bremer; Buchanan; Buena Vista; Butler; Calhoun; Carroll; Cerro Gordo; Cherokee; Chickasaw; Clay; Clayton; Crawford; Delaware; Dickinson; Dubuque; Emmet; Fayette; Floyd; Franklin; Greene; Grundy; Hamilton; Hancock; Hardin; Howard; Humboldt; Ida; Jackson; Jones; Kossuth; Linn; Lyon; Marshall; Mitchell; Monona; O''Brien; Osceola; Palo Alto; Plymouth; Pocahontas; Sac; Sioux; Story; Tama; Webster; Winnebago; Winneshiek; Woodbury; Worth; Wright.',41.85,43.51,-96.65,-90.15,0);
INSERT INTO "area" VALUES('EPSG','2199','USA - Iowa - SPCS - S','United States (USA) - Iowa - counties of Adair; Adams; Appanoose; Audubon; Cass; Cedar; Clarke; Clinton; Dallas; Davis; Decatur; Des Moines; Fremont; Guthrie; Harrison; Henry; Iowa; Jasper; Jefferson; Johnson; Keokuk; Lee; Louisa; Lucas; Madison; Mahaska; Marion; Mills; Monroe; Montgomery; Muscatine; Page; Polk; Pottawattamie; Poweshiek; Ringgold; Scott; Shelby; Taylor; Union; Van Buren; Wapello; Warren; Washington; Wayne.',40.37,42.04,-96.14,-90.14,0);
INSERT INTO "area" VALUES('EPSG','2200','USA - Kansas - SPCS - N','United States (USA) - Kansas - counties of Atchison; Brown; Cheyenne; Clay; Cloud; Decatur; Dickinson; Doniphan; Douglas; Ellis; Ellsworth; Geary; Gove; Graham; Jackson; Jefferson; Jewell; Johnson; Leavenworth; Lincoln; Logan; Marshall; Mitchell; Morris; Nemaha; Norton; Osborne; Ottawa; Phillips; Pottawatomie; Rawlins; Republic; Riley; Rooks; Russell; Saline; Shawnee; Sheridan; Sherman; Smith; Thomas; Trego; Wabaunsee; Wallace; Washington; Wyandotte.',38.52,40.01,-102.06,-94.58,0);
INSERT INTO "area" VALUES('EPSG','2201','USA - Kansas - SPCS - S','United States (USA) - Kansas - counties of Allen; Anderson; Barber; Barton; Bourbon; Butler; Chase; Chautauqua; Cherokee; Clark; Coffey; Comanche; Cowley; Crawford; Edwards; Elk; Finney; Ford; Franklin; Grant; Gray; Greeley; Greenwood; Hamilton; Harper; Harvey; Haskell; Hodgeman; Kearny; Kingman; Kiowa; Labette; Lane; Linn; Lyon; Marion; McPherson; Meade; Miami; Montgomery; Morton; Neosho; Ness; Osage; Pawnee; Pratt; Reno; Rice; Rush; Scott; Sedgwick; Seward; Stafford; Stanton; Stevens; Sumner; Wichita; Wilson; Woodson.',36.99,38.88,-102.05,-94.6,0);
INSERT INTO "area" VALUES('EPSG','2202','USA - Kentucky - SPCS - N','United States (USA) - Kentucky - counties of Anderson; Bath; Boone; Bourbon; Boyd; Bracken; Bullitt; Campbell; Carroll; Carter; Clark; Elliott; Fayette; Fleming; Franklin; Gallatin; Grant; Greenup; Harrison; Henry; Jefferson; Jessamine; Kenton; Lawrence; Lewis; Mason; Menifee; Montgomery; Morgan; Nicholas; Oldham; Owen; Pendleton; Robertson; Rowan; Scott; Shelby; Spencer; Trimble; Woodford.',37.71,39.15,-85.96,-82.47,0);
INSERT INTO "area" VALUES('EPSG','2203','USA - Kentucky - SPCS - S','United States (USA) - Kentucky - counties of Adair; Allen; Ballard; Barren; Bell; Boyle; Breathitt; Breckinridge; Butler; Caldwell; Calloway; Carlisle; Casey; Christian; Clay; Clinton; Crittenden; Cumberland; Daviess; Edmonson; Estill; Floyd; Fulton; Garrard; Graves; Grayson; Green; Hancock; Hardin; Harlan; Hart; Henderson; Hickman; Hopkins; Jackson; Johnson; Knott; Knox; Larue; Laurel; Lee; Leslie; Letcher; Lincoln; Livingston; Logan; Lyon; Madison; Magoffin; Marion; Marshall; Martin; McCracken; McCreary; McLean; Meade; Mercer; Metcalfe; Monroe; Muhlenberg; Nelson; Ohio; Owsley; Perry; Pike; Powell; Pulaski; Rockcastle; Russell; Simpson; Taylor; Todd; Trigg; Union; Warren; Washington; Wayne; Webster; Whitley; Wolfe.',36.49,38.17,-89.57,-81.95,0);
INSERT INTO "area" VALUES('EPSG','2204','USA - Louisiana - SPCS - N','United States (USA) - Louisiana - counties of Avoyelles; Bienville; Bossier; Caddo; Caldwell; Catahoula; Claiborne; Concordia; De Soto; East Carroll; Franklin; Grant; Jackson; La Salle; Lincoln; Madison; Morehouse; Natchitoches; Ouachita; Rapides; Red River; Richland; Sabine; Tensas; Union; Vernon; Webster; West Carroll; Winn.',30.85,33.03,-94.05,-90.86,0);
INSERT INTO "area" VALUES('EPSG','2205','USA - Louisiana - SPCS27 - S','United States (USA) - Louisiana - counties of Acadia; Allen; Ascension; Assumption; Beauregard; Calcasieu; Cameron; East Baton Rouge; East Feliciana; Evangeline; Iberia; Iberville; Jefferson; Jefferson Davis; Lafayette; LaFourche; Livingston; Orleans; Plaquemines; Pointe Coupee; St Bernard; St Charles; St Helena; St James; St John the Baptist; St Landry; St Martin; St Mary; St Tammany; Tangipahoa; Terrebonne; Vermilion; Washington; West Baton Rouge; West Feliciana. Also Gulf of Mexico outer continental shelf (GoM OCS) protraction areas Sabine Pass (LA); West Cameron; East Cameron; Vermilion; South Marsh Island; Eugene Island; Ship Shoal; South Pelto; Bay Marchand; South Timbalier; Grand Isle; West Delta; South Pass; Main Pass; Breton Sound; Chandeleur.',27.82,31.07,-93.94,-87.76,0);
INSERT INTO "area" VALUES('EPSG','2206','USA - Maine - SPCS - E','United States (USA) - Maine - counties of Aroostook; Hancock; Knox; Penobscot; Piscataquis; Waldo; Washington.',43.88,47.47,-70.03,-66.91,0);
INSERT INTO "area" VALUES('EPSG','2207','USA - Maine - SPCS - W','United States (USA) - Maine - counties of Androscoggin; Cumberland; Franklin; Kennebec; Lincoln; Oxford; Sagadahoc; Somerset; York.',43.04,46.58,-71.09,-69.26,0);
INSERT INTO "area" VALUES('EPSG','2208','USA - Massachusetts - SPCS - islands','United States (USA) - Massachusetts offshore - counties of Dukes; Nantucket.',41.19,41.51,-70.91,-69.89,0);
INSERT INTO "area" VALUES('EPSG','2209','USA - Massachusetts - SPCS - mainland','United States (USA) - Massachusetts onshore - counties of Barnstable; Berkshire; Bristol; Essex; Franklin; Hampden; Hampshire; Middlesex; Norfolk; Plymouth; Suffolk; Worcester.',41.46,42.89,-73.5,-69.86,0);
INSERT INTO "area" VALUES('EPSG','2210','USA - Montana - SPCS27 - C','United States (USA) - Montana - counties of Cascade; Dawson; Fergus; Garfield; Judith Basin; Lake; Lewis and Clark; McCone; Meagher; Mineral; Missoula; Petroleum; Powell; Prairie; Richland; Sanders; Wibaux.',46.17,48.26,-116.06,-104.04,0);
INSERT INTO "area" VALUES('EPSG','2211','USA - Montana - SPCS27 - N','United States (USA) - Montana north of approximately 47°50''N - counties of Blaine; Chouteau; Daniels; Flathead; Glacier; Hill; Liberty; Lincoln; Phillips; Pondera; Roosevelt; Sheridan; Teton; Toole; Valley.',47.41,49.01,-116.07,-104.04,0);
INSERT INTO "area" VALUES('EPSG','2212','USA - Montana - SPCS27 - S','United States (USA) - Montana - counties of Beaverhead; Big Horn; Broadwater; Carbon; Carter; Custer; Deer Lodge; Fallon; Gallatin; Golden Valley; Granite; Jefferson; Madison; Musselshell; Park; Powder River; Ravalli; Rosebud; Silver Bow; Stillwater; Sweet Grass; Treasure; Wheatland; Yellowstone.',44.35,46.87,-114.57,-104.04,0);
INSERT INTO "area" VALUES('EPSG','2213','USA - Minnesota - SPCS - C','United States (USA) - Minnesota - counties of Aitkin; Becker; Benton; Carlton; Cass; Chisago; Clay; Crow Wing; Douglas; Grant; Hubbard; Isanti; Kanabec; Mille Lacs; Morrison; Otter Tail; Pine; Pope; Stearns; Stevens; Todd; Traverse; Wadena; Wilkin.',45.28,47.48,-96.86,-92.29,0);
INSERT INTO "area" VALUES('EPSG','2214','USA - Minnesota - SPCS - N','United States (USA) - Minnesota - counties of Beltrami; Clearwater; Cook; Itasca; Kittson; Koochiching; Lake; Lake of the Woods; Mahnomen; Marshall; Norman; Pennington; Polk; Red Lake; Roseau; St Louis.',46.64,49.38,-97.22,-89.49,0);
INSERT INTO "area" VALUES('EPSG','2215','USA - Minnesota - SPCS - S','United States (USA) - Minnesota - counties of Anoka; Big Stone; Blue Earth; Brown; Carver; Chippewa; Cottonwood; Dakota; Dodge; Faribault; Fillmore; Freeborn; Goodhue; Hennepin; Houston; Jackson; Kandiyohi; Lac Qui Parle; Le Sueur; Lincoln; Lyon; Martin; McLeod; Meeker; Mower; Murray; Nicollet; Nobles; Olmsted; Pipestone; Ramsey; Redwood; Renville; Rice; Rock; Scott; Sherburne; Sibley; Steele; Swift; Wabasha; Waseca; Washington; Watonwan; Winona; Wright; Yellow Medicine.',43.49,45.59,-96.85,-91.21,0);
INSERT INTO "area" VALUES('EPSG','2216','USA - Mississippi - SPCS - E','United States (USA) - Mississippi - counties of Alcorn; Attala; Benton; Calhoun; Chickasaw; Choctaw; Clarke; Clay; Covington; Forrest; George; Greene; Hancock; Harrison; Itawamba; Jackson; Jasper; Jones; Kemper; Lafayette; Lamar; Lauderdale; Leake; Lee; Lowndes; Marshall; Monroe; Neshoba; Newton; Noxubee; Oktibbeha; Pearl River; Perry; Pontotoc; Prentiss; Scott; Smith; Stone; Tippah; Tishomingo; Union; Wayne; Webster; Winston.',30.01,35.01,-89.97,-88.09,0);
INSERT INTO "area" VALUES('EPSG','2217','USA - Mississippi - SPCS - W','United States (USA) - Mississippi - counties of Adams; Amite; Bolivar; Carroll; Claiborne; Coahoma; Copiah; De Soto; Franklin; Grenada; Hinds; Holmes; Humphreys; Issaquena; Jefferson; Jefferson Davis; Lawrence; Leflore; Lincoln; Madison; Marion; Montgomery; Panola; Pike; Quitman; Rankin; Sharkey; Simpson; Sunflower; Tallahatchie; Tate; Tunica; Walthall; Warren; Washington; Wilkinson; Yalobusha; Yazoo.',31.0,35.01,-91.65,-89.37,0);
INSERT INTO "area" VALUES('EPSG','2218','USA - Missouri - SPCS - C','United States (USA) - Missouri - counties of Adair; Audrain; Benton; Boone; Callaway; Camden; Carroll; Chariton; Christian; Cole; Cooper; Dallas; Douglas; Greene; Grundy; Hickory; Howard; Howell; Knox; Laclede; Linn; Livingston; Macon; Maries; Mercer; Miller; Moniteau; Monroe; Morgan; Osage; Ozark; Pettis; Phelps; Polk; Pulaski; Putnam; Randolph; Saline; Schuyler; Scotland; Shelby; Stone; Sullivan; Taney; Texas; Webster; Wright.',36.48,40.61,-93.79,-91.41,0);
INSERT INTO "area" VALUES('EPSG','2219','USA - Missouri - SPCS - E','United States (USA) - Missouri - counties of Bollinger; Butler; Cape Girardeau; Carter; Clark; Crawford; Dent; Dunklin; Franklin; Gasconade; Iron; Jefferson; Lewis; Lincoln; Madison; Marion; Mississippi; Montgomery; New Madrid; Oregon; Pemiscot; Perry; Pike; Ralls; Reynolds; Ripley; Scott; Shannon; St Charles; St Francois; St Louis; Ste. Genevieve; Stoddard; Warren; Washington; Wayne.',35.98,40.61,-91.97,-89.1,0);
INSERT INTO "area" VALUES('EPSG','2220','USA - Missouri - SPCS - W','United States (USA) - Missouri - counties of Andrew; Atchison; Barry; Barton; Bates; Buchanan; Caldwell; Cass; Cedar; Clay; Clinton; Dade; Daviess; De Kalb; Gentry; Harrison; Henry; Holt; Jackson; Jasper; Johnson; Lafayette; Lawrence; McDonald; Newton; Nodaway; Platte; Ray; St Clair; Vernon; Worth.',36.48,40.59,-95.77,-93.48,0);
INSERT INTO "area" VALUES('EPSG','2221','USA - Nebraska - SPCS27 - N','United States (USA) - Nebraska - counties of Antelope; Blaine; Box Butte; Boyd; Brown; Burt; Cedar; Cherry; Cuming; Dakota; Dawes; Dixon; Garfield; Grant; Holt; Hooker; Keya Paha; Knox; Loup; Madison; Pierce; Rock; Sheridan; Sioux; Stanton; Thomas; Thurston; Wayne; Wheeler.',41.68,43.01,-104.06,-96.07,0);
INSERT INTO "area" VALUES('EPSG','2222','USA - Nebraska - SPCS27 - S','United States (USA) - Nebraska - counties of Adams; Arthur; Banner; Boone; Buffalo; Butler; Cass; Chase; Cheyenne; Clay; Colfax; Custer; Dawson; Deuel; Dodge; Douglas; Dundy; Fillmore; Franklin; Frontier; Furnas; Gage; Garden; Gosper; Greeley; Hall; Hamilton; Harlan; Hayes; Hitchcock; Howard; Jefferson; Johnson; Kearney; Keith; Kimball; Lancaster; Lincoln; Logan; McPherson; Merrick; Morrill; Nance; Nemaha; Nuckolls; Otoe; Pawnee; Perkins; Phelps; Platte; Polk; Red Willow; Richardson; Saline; Sarpy; Saunders; Scotts Bluff; Seward; Sherman; Thayer; Valley; Washington; Webster; York.',39.99,42.01,-104.06,-95.3,0);
INSERT INTO "area" VALUES('EPSG','2223','USA - Nevada - SPCS - C','United States (USA) - Nevada - counties of Lander; Nye.',36.0,41.0,-118.19,-114.99,0);
INSERT INTO "area" VALUES('EPSG','2224','USA - Nevada - SPCS - E','United States (USA) - Nevada - counties of Clark; Elko; Eureka; Lincoln; White Pine.',34.99,42.0,-117.01,-114.03,0);
INSERT INTO "area" VALUES('EPSG','2225','USA - Nevada - SPCS - W','United States (USA) - Nevada - counties of Churchill; Douglas; Esmeralda; Humboldt; Lyon; Mineral; Pershing; Storey; Washoe.',36.95,42.0,-120.0,-116.99,0);
INSERT INTO "area" VALUES('EPSG','2226','Canada - Newfoundland - east of 54.5°W','Canada - Newfoundland - onshore east of 54°30''W.',46.56,49.71,-54.5,-52.54,0);
INSERT INTO "area" VALUES('EPSG','2227','Canada - Newfoundland and Labrador - 57.5°W to 54.5°W','Canada - Newfoundland and Labrador between 57°30''W and 54°30''W.',46.81,54.71,-57.5,-54.49,0);
INSERT INTO "area" VALUES('EPSG','2228','USA - New Mexico - SPCS - E','United States (USA) - New Mexico - counties of Chaves; Colfax; Curry; De Baca; Eddy; Guadalupe; Harding; Lea; Mora; Quay; Roosevelt; San Miguel; Union.',32.0,37.0,-105.72,-102.99,0);
INSERT INTO "area" VALUES('EPSG','2229','USA - New Mexico - SPCS27 - C','United States (USA) - New Mexico - counties of Bernalillo; Dona Ana; Lincoln; Los Alamos; Otero; Rio Arriba; Sandoval; Santa Fe; Socorro; Taos; Torrance.',31.78,37.0,-107.73,-104.83,0);
INSERT INTO "area" VALUES('EPSG','2230','USA - New Mexico - SPCS27 - W','United States (USA) - New Mexico - counties of Catron; Cibola; Grant; Hidalgo; Luna; McKinley; San Juan; Sierra; Valencia.',31.33,37.0,-109.06,-106.32,0);
INSERT INTO "area" VALUES('EPSG','2231','USA - New Mexico - SPCS83 - C','United States (USA) - New Mexico - counties of Bernalillo; Dona Ana; Lincoln; Los Alamos; Otero; Rio Arriba; Sandoval; Santa Fe; Socorro; Taos; Torrance; Valencia.',31.78,37.0,-107.73,-104.84,0);
INSERT INTO "area" VALUES('EPSG','2232','USA - New Mexico - SPCS83 - W','United States (USA) - New Mexico - counties of Catron; Cibola; Grant; Hidalgo; Luna; McKinley; San Juan; Sierra.',31.33,37.0,-109.06,-106.32,0);
INSERT INTO "area" VALUES('EPSG','2233','USA - New York - SPCS - C','United States (USA) - New York - counties of Broome; Cayuga; Chemung; Chenango; Cortland; Jefferson; Lewis; Madison; Oneida; Onondaga; Ontario; Oswego; Schuyler; Seneca; Steuben; Tioga; Tompkins; Wayne; Yates.',41.99,44.41,-77.75,-75.04,0);
INSERT INTO "area" VALUES('EPSG','2234','USA - New York - SPCS - E','United States (USA) - New York mainland - counties of Albany; Clinton; Columbia; Delaware; Dutchess; Essex; Franklin; Fulton; Greene; Hamilton; Herkimer; Montgomery; Orange; Otsego; Putnam; Rensselaer; Rockland; Saratoga; Schenectady; Schoharie; St Lawrence; Sullivan; Ulster; Warren; Washington; Westchester.',40.88,45.02,-75.87,-73.23,0);
INSERT INTO "area" VALUES('EPSG','2235','USA - New York - SPCS - Long Island','United States (USA) - New York - counties of Bronx; Kings; Nassau; New York; Queens; Richmond; Suffolk.',40.47,41.3,-74.26,-71.8,0);
INSERT INTO "area" VALUES('EPSG','2236','USA - New York - SPCS - W','United States (USA) - New York - counties of Allegany; Cattaraugus; Chautauqua; Erie; Genesee; Livingston; Monroe; Niagara; Orleans; Wyoming.',41.99,43.64,-79.77,-77.36,0);
INSERT INTO "area" VALUES('EPSG','2237','USA - North Dakota - SPCS - N','United States (USA) - North Dakota - counties of Benson; Bottineau; Burke; Cavalier; Divide; Eddy; Foster; Grand Forks; Griggs; McHenry; McKenzie; McLean; Mountrial; Nelson; Pembina; Pierce; Ramsey; Renville; Rolette; Sheridan; Steele; Towner; Traill; Walsh; Ward; Wells; Williams.',47.15,49.01,-104.07,-96.83,0);
INSERT INTO "area" VALUES('EPSG','2238','USA - North Dakota - SPCS - S','United States (USA) - North Dakota - counties of Adams; Barnes; Billings; Bowman; Burleigh; Cass; Dickey; Dunn; Emmons; Golden Valley; Grant; Hettinger; Kidder; La Moure; Logan; McIntosh; Mercer; Morton; Oliver; Ransom; Richland; Sargent; Sioux; Slope; Stark; Stutsman.',45.93,47.83,-104.05,-96.55,0);
INSERT INTO "area" VALUES('EPSG','2239','USA - Ohio - SPCS - N','United States (USA) - Ohio - counties of Allen;Ashland; Ashtabula; Auglaize; Carroll; Columbiana; Coshocton; Crawford; Cuyahoga; Defiance; Delaware; Erie; Fulton; Geauga; Hancock; Hardin; Harrison; Henry; Holmes; Huron; Jefferson; Knox; Lake; Logan; Lorain; Lucas; Mahoning; Marion; Medina; Mercer; Morrow; Ottawa; Paulding; Portage; Putnam; Richland; Sandusky; Seneca; Shelby; Stark; Summit; Trumbull; Tuscarawas; Union; Van Wert; Wayne; Williams; Wood; Wyandot.',40.1,42.33,-84.81,-80.51,0);
INSERT INTO "area" VALUES('EPSG','2240','USA - Ohio - SPCS - S','United States (USA) - Ohio - counties of Adams; Athens; Belmont; Brown; Butler; Champaign; Clark; Clermont; Clinton; Darke; Fairfield; Fayette; Franklin; Gallia; Greene; Guernsey; Hamilton; Highland; Hocking; Jackson; Lawrence; Licking; Madison; Meigs; Miami; Monroe; Montgomery; Morgan; Muskingum; Noble; Perry; Pickaway; Pike; Preble; Ross; Scioto; Vinton; Warren; Washington.',38.4,40.36,-84.83,-80.7,0);
INSERT INTO "area" VALUES('EPSG','2241','USA - Oklahoma - SPCS - N','United States (USA) - Oklahoma - counties of Adair; Alfalfa; Beaver; Blaine; Canadian; Cherokee; Cimarron; Craig; Creek; Custer; Delaware; Dewey; Ellis; Garfield; Grant; Harper; Kay; Kingfisher; Lincoln; Logan; Major; Mayes; Muskogee; Noble; Nowata; Okfuskee; Oklahoma; Okmulgee; Osage; Ottawa; Pawnee; Payne; Roger Mills; Rogers; Sequoyah; Texas; Tulsa; Wagoner; Washington; Woods; Woodward.',35.27,37.01,-103.0,-94.42,0);
INSERT INTO "area" VALUES('EPSG','2242','USA - Oklahoma - SPCS - S','United States (USA) - Oklahoma - counties of Atoka; Beckham; Bryan; Caddo; Carter; Choctaw; Cleveland; Coal; Comanche; Cotton; Garvin; Grady; Greer; Harmon; Haskell; Hughes; Jackson; Jefferson; Johnston; Kiowa; Latimer; Le Flore; Love; Marshall; McClain; McCurtain; McIntosh; Murray; Pittsburg; Pontotoc; Pottawatomie; Pushmataha; Seminole; Stephens; Tillman; Washita.',33.62,35.57,-100.0,-94.42,0);
INSERT INTO "area" VALUES('EPSG','2243','USA - Oregon - SPCS - N','United States (USA) - Oregon - counties of Baker; Benton; Clackamas; Clatsop; Columbia; Gilliam; Grant; Hood River; Jefferson; Lincoln; Linn; Marion; Morrow; Multnomah; Polk; Sherman; Tillamook; Umatilla; Union; Wallowa; Wasco; Washington; Wheeler; Yamhill.',43.95,46.26,-124.17,-116.47,0);
INSERT INTO "area" VALUES('EPSG','2244','USA - Oregon - SPCS - S','United States (USA) - Oregon - counties of Coos; Crook; Curry; Deschutes; Douglas; Harney; Jackson; Josephine; Klamath; Lake; Lane; Malheur.',41.98,44.56,-124.6,-116.9,0);
INSERT INTO "area" VALUES('EPSG','2245','USA - Pennsylvania - SPCS - N','United States (USA) - Pennsylvania - counties of Bradford; Cameron; Carbon; Centre; Clarion; Clearfield; Clinton; Columbia; Crawford; Elk; Erie; Forest; Jefferson; Lackawanna; Luzerne; Lycoming; McKean; Mercer; Monroe; Montour; Northumberland; Pike; Potter; Sullivan; Susquehanna; Tioga; Union; Venango; Warren; Wayne; Wyoming.',40.6,42.53,-80.53,-74.7,0);
INSERT INTO "area" VALUES('EPSG','2246','USA - Pennsylvania - SPCS - S','United States (USA) - Pennsylvania - counties of Adams; Allegheny; Armstrong; Beaver; Bedford; Berks; Blair; Bucks; Butler; Cambria; Chester; Cumberland; Dauphin; Delaware; Fayette; Franklin; Fulton; Greene; Huntingdon; Indiana; Juniata; Lancaster; Lawrence; Lebanon; Lehigh; Mifflin; Montgomery; Northampton; Perry; Philadelphia; Schuylkill; Snyder; Somerset; Washington; Westmoreland; York.',39.71,41.18,-80.53,-74.72,0);
INSERT INTO "area" VALUES('EPSG','2247','USA - South Carolina - SPCS27 - N','United States (USA) - South Carolina - counties of Abbeville; Anderson; Calhoun; Cherokee; Chester; Chesterfield; Darlington; Dillon; Edgefield; Fairfield; Florence; Greenville; Greenwood; Horry; Kershaw; Lancaster; Laurens; Lee; Lexington; Marion; Marlboro; McCormick; Newberry; Oconee; Pickens; Richland; Saluda; Spartanburg; Sumter; Union; York.',33.46,35.21,-83.36,-78.52,0);
INSERT INTO "area" VALUES('EPSG','2248','USA - South Carolina - SPCS27 - S','United States (USA) - South Carolina - counties of Aiken; Allendale; Bamberg; Barnwell; Beaufort; Berkeley; Charleston; Clarendon; Colleton; Dorchester; Georgetown; Hampton; Jasper; Orangeburg; Williamsburg.',32.05,33.95,-82.03,-78.95,0);
INSERT INTO "area" VALUES('EPSG','2249','USA - South Dakota - SPCS - N','United States (USA) - South Dakota - counties of Beadle; Brookings; Brown; Butte; Campbell; Clark; Codington; Corson; Day; Deuel; Dewey; Edmunds; Faulk; Grant; Hamlin; Hand; Harding; Hyde; Kingsbury; Lawrence; Marshall; McPherson; Meade; Perkins; Potter; Roberts; Spink; Sully; Walworth; Ziebach.',44.14,45.95,-104.07,-96.45,0);
INSERT INTO "area" VALUES('EPSG','2250','USA - South Dakota - SPCS - S','United States (USA) - South Dakota - counties of Aurora; Bennett; Bon Homme; Brule; Buffalo; Charles Mix; Clay; Custer; Davison; Douglas; Fall River; Gregory; Haakon; Hanson; Hughes; Hutchinson; Jackson; Jerauld; Jones; Lake; Lincoln; Lyman; McCook; Mellette; Miner; Minnehaha; Moody; Pennington; Sanborn; Shannon; Stanley; Todd; Tripp; Turner; Union; Yankton.',42.48,44.79,-104.06,-96.43,0);
INSERT INTO "area" VALUES('EPSG','2251','Caribbean - Puerto Rico and US Virgin Islands','Puerto Rico and US Virgin Islands - onshore and offshore.',14.92,21.86,-68.49,-63.88,0);
INSERT INTO "area" VALUES('EPSG','2252','USA - Texas - SPCS - C','United States (USA) - Texas - counties of Anderson; Angelina; Bastrop; Bell; Blanco; Bosque; Brazos; Brown; Burleson; Burnet; Cherokee; Coke; Coleman; Comanche; Concho; Coryell; Crane; Crockett; Culberson; Ector; El Paso; Falls; Freestone; Gillespie; Glasscock; Grimes; Hamilton; Hardin; Houston; Hudspeth; Irion; Jasper; Jeff Davis; Kimble; Lampasas; Lee; Leon; Liberty; Limestone; Llano; Loving; Madison; Mason; McCulloch; McLennan; Menard; Midland; Milam; Mills; Montgomery; Nacogdoches; Newton; Orange; Pecos; Polk; Reagan; Reeves; Robertson; Runnels; Sabine; San Augustine; San Jacinto; San Saba; Schleicher; Shelby; Sterling; Sutton; Tom Green; Travis; Trinity; Tyler; Upton; Walker; Ward; Washington; Williamson; Winkler.',29.78,32.27,-106.66,-93.5,0);
INSERT INTO "area" VALUES('EPSG','2253','USA - Texas - SPCS - N','United States (USA) - Texas - counties of: Armstrong; Briscoe; Carson; Castro; Childress; Collingsworth; Dallam; Deaf Smith; Donley; Gray; Hall; Hansford; Hartley; Hemphill; Hutchinson; Lipscomb; Moore; Ochiltree; Oldham; Parmer; Potter; Randall; Roberts; Sherman; Swisher; Wheeler.',34.3,36.5,-103.03,-99.99,0);
INSERT INTO "area" VALUES('EPSG','2254','USA - Texas - SPCS - NC','United States (USA) - Texas - counties of: Andrews; Archer; Bailey; Baylor; Borden; Bowie; Callahan; Camp; Cass; Clay; Cochran; Collin; Cooke; Cottle; Crosby; Dallas; Dawson; Delta; Denton; Dickens; Eastland; Ellis; Erath; Fannin; Fisher; Floyd; Foard; Franklin; Gaines; Garza; Grayson; Gregg; Hale; Hardeman; Harrison; Haskell; Henderson; Hill; Hockley; Hood; Hopkins; Howard; Hunt; Jack; Johnson; Jones; Kaufman; Kent; King; Knox; Lamar; Lamb; Lubbock; Lynn; Marion; Martin; Mitchell; Montague; Morris; Motley; Navarro; Nolan; Palo Pinto; Panola; Parker; Rains; Red River; Rockwall; Rusk; Scurry; Shackelford; Smith; Somervell; Stephens; Stonewall; Tarrant; Taylor; Terry; Throckmorton; Titus; Upshur; Van Zandt; Wichita; Wilbarger; Wise; Wood; Yoakum; Young.',31.72,34.58,-103.07,-94.0,0);
INSERT INTO "area" VALUES('EPSG','2255','USA - Texas - SPCS27 - S','United States (USA) - Texas - counties of Brooks; Cameron; Duval; Hidalgo; Jim Hogg; Jim Wells; Kenedy; Kleberg; Nueces; San Patricio; Starr; Webb; Willacy; Zapata. Gulf of Mexico outer continental shelf (GoM OCS) protraction areas: South Padre Island; North Padre Island; Mustang Island.',25.83,28.21,-100.2,-95.37,0);
INSERT INTO "area" VALUES('EPSG','2256','USA - Texas - SPCS27 - SC','United States (USA) - Texas - counties of Aransas; Atascosa; Austin; Bandera; Bee; Bexar; Brazoria; Brewster; Caldwell; Calhoun; Chambers; Colorado; Comal; De Witt; Dimmit; Edwards; Fayette; Fort Bend; Frio; Galveston; Goliad; Gonzales; Guadalupe; Harris; Hays; Jackson; Jefferson; Karnes; Kendall; Kerr; Kinney; La Salle; Lavaca; Live Oak; Matagorda; Maverick; McMullen; Medina; Presidio; Real; Refugio; Terrell; Uvalde; Val Verde; Victoria; Waller; Wharton; Wilson; Zavala. Gulf of Mexico outer continental shelf (GoM OCS) protraction areas: Matagorda Island; Brazos; Galveston; High Island, Sabine Pass (TX).',27.78,30.67,-105.0,-93.41,0);
INSERT INTO "area" VALUES('EPSG','2257','USA - Utah - SPCS - C','United States (USA) - Utah - counties of Carbon; Duchesne; Emery; Grand; Juab; Millard; Salt Lake; Sanpete; Sevier; Tooele; Uintah; Utah; Wasatch.',38.49,41.08,-114.05,-109.04,0);
INSERT INTO "area" VALUES('EPSG','2258','USA - Utah - SPCS - N','United States (USA) - Utah - counties of Box Elder; Cache; Daggett; Davis; Morgan; Rich; Summit; Weber.',40.55,42.01,-114.04,-109.04,0);
INSERT INTO "area" VALUES('EPSG','2259','USA - Utah - SPCS - S','United States (USA) - Utah - counties of Beaver; Garfield; Iron; Kane; Piute; San Juan; Washington; Wayne.',36.99,38.58,-114.05,-109.04,0);
INSERT INTO "area" VALUES('EPSG','2260','USA - Virginia - SPCS - N','United States (USA) - Virginia - counties of Arlington; Augusta; Bath; Caroline; Clarke; Culpeper; Fairfax; Fauquier; Frederick; Greene; Highland; King George; Loudoun; Madison; Orange; Page; Prince William; Rappahannock; Rockingham; Shenandoah; Spotsylvania; Stafford; Warren; Westmoreland.',37.77,39.46,-80.06,-76.51,0);
INSERT INTO "area" VALUES('EPSG','2261','USA - Virginia - SPCS - S','United States (USA) - Virginia - counties of Accomack; Albemarle; Alleghany; Amelia; Amherst; Appomattox; Bedford; Bland; Botetourt; Bristol; Brunswick; Buchanan; Buckingham; Campbell; Carroll; Charles City; Charlotte; Chesapeake; Chesterfield; Colonial Heights; Craig; Cumberland; Dickenson; Dinwiddie; Essex; Floyd; Fluvanna; Franklin; Giles; Gloucester; Goochland; Grayson; Greensville; Halifax; Hampton; Hanover; Henrico; Henry; Isle of Wight; James City; King and Queen; King William; Lancaster; Lee; Louisa; Lunenburg; Lynchburg; Mathews; Mecklenburg; Middlesex; Montgomery; Nelson; New Kent; Newport News; Norfolk; Northampton; Northumberland; Norton; Nottoway; Patrick; Petersburg; Pittsylvania; Portsmouth; Powhatan; Prince Edward; Prince George; Pulaski; Richmond; Roanoke; Rockbridge; Russell; Scott; Smyth; Southampton; Suffolk; Surry; Sussex; Tazewell; Washington; Wise; Wythe; York.',36.54,38.28,-83.68,-75.31,0);
INSERT INTO "area" VALUES('EPSG','2262','USA - Washington - SPCS27 - N','United States (USA) - Washington - counties of Chelan; Clallam; Douglas; Ferry; Island; Jefferson; King; Kitsap; Lincoln; Okanogan; Pend Oreille; San Juan; Skagit; Snohomish; Spokane; Stevens; Whatcom.',47.08,49.05,-124.79,-117.02,0);
INSERT INTO "area" VALUES('EPSG','2263','USA - Washington - SPCS27 - S','United States (USA) - Washington - counties of Adams; Asotin; Benton; Clark; Columbia; Cowlitz; Franklin; Garfield; Grant; Grays Harbor; Kittitas; Klickitat; Lewis; Mason; Pacific; Pierce; Skamania; Thurston; Wahkiakum; Walla Walla; Whitman; Yakima.',45.54,47.96,-124.4,-116.91,0);
INSERT INTO "area" VALUES('EPSG','2264','USA - West Virginia - SPCS - N','United States (USA) - West Virginia - counties of Barbour; Berkeley; Brooke; Doddridge; Grant; Hampshire; Hancock; Hardy; Harrison; Jefferson; Marion; Marshall; Mineral; Monongalia; Morgan; Ohio; Pleasants; Preston; Ritchie; Taylor; Tucker; Tyler; Wetzel; Wirt; Wood.',38.76,40.64,-81.76,-77.72,0);
INSERT INTO "area" VALUES('EPSG','2265','USA - West Virginia - SPCS - S','United States (USA) - West Virginia - counties of Boone; Braxton; Cabell; Calhoun; Clay; Fayette; Gilmer; Greenbrier; Jackson; Kanawha; Lewis; Lincoln; Logan; Mason; McDowell; Mercer; Mingo; Monroe; Nicholas; Pendleton; Pocahontas; Putnam; Raleigh; Randolph; Roane; Summers; Upshur; Wayne; Webster; Wyoming.',37.2,39.17,-82.65,-79.05,0);
INSERT INTO "area" VALUES('EPSG','2266','USA - Wisconsin - SPCS - C','United States (USA) - Wisconsin - counties of Barron; Brown; Buffalo; Chippewa; Clark; Door; Dunn; Eau Claire; Jackson; Kewaunee; Langlade; Lincoln; Marathon; Marinette; Menominee; Oconto; Outagamie; Pepin; Pierce; Polk; Portage; Rusk; Shawano; St Croix; Taylor; Trempealeau; Waupaca; Wood.',43.98,45.8,-92.89,-86.25,0);
INSERT INTO "area" VALUES('EPSG','2267','USA - Wisconsin - SPCS - N','United States (USA) - Wisconsin - counties of Ashland; Bayfield; Burnett; Douglas; Florence; Forest; Iron; Oneida; Price; Sawyer; Vilas; Washburn.',45.37,47.31,-92.89,-88.05,0);
INSERT INTO "area" VALUES('EPSG','2268','USA - Wisconsin - SPCS - S','United States (USA) - Wisconsin - counties of Adams; Calumet; Columbia; Crawford; Dane; Dodge; Fond Du Lac; Grant; Green; Green Lake; Iowa; Jefferson; Juneau; Kenosha; La Crosse; Lafayette; Manitowoc; Marquette; Milwaukee; Monroe; Ozaukee; Racine; Richland; Rock; Sauk; Sheboygan; Vernon; Walworth; Washington; Waukesha; Waushara; Winnebago.',42.48,44.33,-91.43,-86.95,0);
INSERT INTO "area" VALUES('EPSG','2269','USA - Wyoming - SPCS - E','United States (USA) - Wyoming - counties of Albany; Campbell; Converse; Crook; Goshen; Laramie; Niobrara; Platte; Weston.',40.99,45.01,-106.33,-104.05,0);
INSERT INTO "area" VALUES('EPSG','2270','USA - Wyoming - SPCS - EC','United States (USA) - Wyoming - counties of Big Horn; Carbon; Johnson; Natrona; Sheridan; Washakie.',40.99,45.01,-108.63,-106.0,0);
INSERT INTO "area" VALUES('EPSG','2271','USA - Wyoming - SPCS - W','United States (USA) - Wyoming - counties of Lincoln; Sublette; Teton; Uinta.',40.99,44.67,-111.06,-109.04,0);
INSERT INTO "area" VALUES('EPSG','2272','USA - Wyoming - SPCS - WC','United States (USA) - Wyoming - counties of Fremont; Hot Springs; Park; Sweetwater.',40.99,45.01,-111.06,-107.5,0);
INSERT INTO "area" VALUES('EPSG','2273','USA - Washington - SPCS83 - N','United States (USA) - Washington - counties of Chelan; Clallam; Douglas; Ferry; Grant north of approximately 47°30''N; Island; Jefferson; King; Kitsap; Lincoln; Okanogan; Pend Oreille; San Juan; Skagit; Snohomish; Spokane; Stevens; Whatcom.',47.08,49.05,-124.79,-117.02,0);
INSERT INTO "area" VALUES('EPSG','2274','USA - Washington - SPCS83 - S','United States (USA) - Washington - counties of Adams; Asotin; Benton; Clark; Columbia; Cowlitz; Franklin; Garfield; Grant south of approximately 47°30''N; Grays Harbor; Kittitas; Klickitat; Lewis; Mason; Pacific; Pierce; Skamania; Thurston; Wahkiakum; Walla Walla; Whitman; Yakima.',45.54,47.61,-124.4,-116.91,0);
INSERT INTO "area" VALUES('EPSG','2275','Canada - Newfoundland and Labrador - 60°W to 57.5°W','Canada - Newfoundland west of 57°30''W.',47.5,50.54,-59.48,-57.5,0);
INSERT INTO "area" VALUES('EPSG','2276','Canada - Quebec and Labrador - 63°W to 60°W','Canada - Quebec and Labrador between 63°W and 60°W.',47.16,58.92,-63.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','2277','Canada - Quebec and Labrador - 66°W to 63°W','Canada - Quebec and Labrador between 66°W and 63°W.',47.95,60.52,-66.0,-63.0,0);
INSERT INTO "area" VALUES('EPSG','2278','Canada - Quebec and Labrador - 69°W to 66°W','Canada - Quebec and Labrador between 69°W and 66°W.',47.31,59.0,-69.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','2279','Canada - Quebec and Ontario - 75°W to 72°W','Canada - Quebec between 75°W and 72°W.; Canada - Ontario - east of 75°W.',44.98,62.53,-75.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','2280','Canada - Quebec and Ontario - 78°W to 75°W','Canada - Quebec and Ontario - between 78°W and 75°W.',43.63,62.65,-78.0,-75.0,0);
INSERT INTO "area" VALUES('EPSG','2281','Canada - Quebec and Ontario - MTM zone 10','Canada - Quebec west of 78°W; Canada - Ontario - between 79°30''W and 78°W in area to north of 47°N; between 80°15''W and 78°W in area between 46°N and 47°N; between 81°W and 78°W in area south of 46°N.',42.26,62.45,-81.0,-78.0,0);
INSERT INTO "area" VALUES('EPSG','2282','Cote d''Ivoire (Ivory Coast) - Abidjan area','Côte d''Ivoire (Ivory Coast) - Abidjan area.',5.15,5.54,-4.22,-3.85,0);
INSERT INTO "area" VALUES('EPSG','2283','Australia - Australian Capital Territory','Australia - Australian Capital Territory.',-35.93,-35.12,148.76,149.4,0);
INSERT INTO "area" VALUES('EPSG','2284','Australia - Northern Territory','Australia - Northern Territory.',-26.01,-10.86,128.99,138.0,0);
INSERT INTO "area" VALUES('EPSG','2285','Australia - Victoria','Australia - Victoria.',-39.2,-33.98,140.96,150.04,0);
INSERT INTO "area" VALUES('EPSG','2286','Australia - New South Wales and Victoria','Australia - New South Wales and Victoria.',-39.2,-28.15,140.96,153.69,0);
INSERT INTO "area" VALUES('EPSG','2287','Australia - SE Australia (ACT NSW Vic)','Australia - Australian Capital Territory, New South Wales, Victoria.',-39.2,-28.15,140.96,153.69,0);
INSERT INTO "area" VALUES('EPSG','2288','American Samoa - Tutuila island','American Samoa - Tutuila island.',-14.43,-14.2,-170.88,-170.51,0);
INSERT INTO "area" VALUES('EPSG','2289','American Samoa - Ofu, Olesega and Ta''u islands','American Samoa - Ofu, Olesega and Ta''u islands.',-14.31,-14.11,-169.73,-169.38,0);
INSERT INTO "area" VALUES('EPSG','2290','Canada - Quebec, Newfoundland and Labrador - MTM zone 3','Canada - Newfoundland and Labrador between 60°W and 57°30''W; Canada - Quebec east of 60°W.',47.5,55.38,-60.0,-57.1,0);
INSERT INTO "area" VALUES('EPSG','2291','Australasia - Australia and PNG - 150°E to 156°E','Australia - onshore and offshore between 150°E and 156°E. Papua New Guinea onshore east of 150°E.',-46.44,-2.32,150.0,156.0,0);
INSERT INTO "area" VALUES('EPSG','2292','Asia - Bangladesh; Myanmar - onshore 15°N to 21°N','Bangladesh - onshore south of 21°N; Myanmar (Burma) - onshore between 15°N and 21°N.',15.0,21.01,92.1,100.65,0);
INSERT INTO "area" VALUES('EPSG','2293','Myanmar (Burma) - onshore south of 15°N','Myanmar (Burma) - onshore south of 15°N.',9.78,15.0,97.74,99.66,0);
INSERT INTO "area" VALUES('EPSG','2294','Asia - Middle East - Iraq zone','Iran - onshore south of 36°N. Iraq - onshore. Kuwait - onshore.',25.02,37.39,38.79,63.34,0);
INSERT INTO "area" VALUES('EPSG','2295','Caribbean - Windward and Leeward Islands','Windward Islands - Dominica; Grenada; St Lucia; St Vincent; Leeward Islands - Anguilla; Antigua (excluding Barbuda); Montserrat; St Kitts and Nevis; Barbados.',11.94,18.33,-63.22,-59.37,0);
INSERT INTO "area" VALUES('EPSG','2296','Cote d''Ivoire (Ivory Coast) - offshore','Côte d''Ivoire (Ivory Coast) - offshore.',1.02,5.19,-7.55,-3.11,0);
INSERT INTO "area" VALUES('EPSG','2297','USA - California - north of 36.5°N','United States (USA) - California north of 36.5°N.',36.5,42.01,-124.44,-116.54,0);
INSERT INTO "area" VALUES('EPSG','2298','USA - California - south of 36.5°N','United States (USA) - California south of 36.5°N',32.53,36.5,-121.98,-114.12,0);
INSERT INTO "area" VALUES('EPSG','2299','World - N hemisphere - 3-degree CM 003°E','Between 1°30''E and 4°30''E, northern hemisphere.',0.0,84.0,1.5,4.5,0);
INSERT INTO "area" VALUES('EPSG','2300','World - N hemisphere - 3-degree CM 006°E','Between 4°30''E and 7°30''E, northern hemisphere.',0.0,84.0,4.5,7.5,0);
INSERT INTO "area" VALUES('EPSG','2301','World - N hemisphere - 3-degree CM 009°E','Between 7°30''E and 10°30''E, northern hemisphere.',0.0,84.0,7.5,10.5,0);
INSERT INTO "area" VALUES('EPSG','2302','World - N hemisphere - 3-degree CM 012°E','Between 10°30''E and 13°30''E, northern hemisphere.',0.0,84.0,10.5,13.5,0);
INSERT INTO "area" VALUES('EPSG','2303','World - N hemisphere - 3-degree CM 015°E','Between 13°30''E and 16°30''E, northern hemisphere.',0.0,84.0,13.5,16.5,0);
INSERT INTO "area" VALUES('EPSG','2304','World - N hemisphere - 3-degree CM 018°E','Between 16°30''E and 19°30''E, northern hemisphere.',0.0,84.0,16.5,19.5,0);
INSERT INTO "area" VALUES('EPSG','2305','World - N hemisphere - 3-degree CM 021°E','Between 19°30''E and 22°30''E, northern hemisphere.',0.0,84.0,19.5,22.5,0);
INSERT INTO "area" VALUES('EPSG','2306','World - N hemisphere - 3-degree CM 024°E','Between 22°30''E and 25°30''E, northern hemisphere.',0.0,84.0,22.5,25.5,0);
INSERT INTO "area" VALUES('EPSG','2307','Brazil - Campos; Espirito Santo and Santos basins','Brazil - offshore - Campos; Espirito Santo and Santos basins.',-28.41,-17.59,-48.8,-35.18,0);
INSERT INTO "area" VALUES('EPSG','2308','Brazil - Tucano basin north','Brazil - Tucano basin north.',-9.8,-8.39,-39.04,-37.09,0);
INSERT INTO "area" VALUES('EPSG','2309','Brazil - Tucano basin central','Brazil - Tucano basin central.',-10.61,-9.79,-39.14,-37.99,0);
INSERT INTO "area" VALUES('EPSG','2310','Brazil - Tucano basin south','Brazil - Tucano basin south.',-12.27,-10.6,-39.07,-37.98,0);
INSERT INTO "area" VALUES('EPSG','2311','Africa - Kenya and Tanzania','Kenya; Tanzania.',-11.75,4.63,29.34,41.91,0);
INSERT INTO "area" VALUES('EPSG','2312','Africa - Botswana, Eswatini, Lesotho, Malawi, Zambia, Zimbabwe','Botswana; Eswatini (Swaziland); Lesotho; Malawi; Zambia; Zimbabwe.',-30.66,-8.19,19.99,35.93,0);
INSERT INTO "area" VALUES('EPSG','2313','Canada - Nova Scotia','Canada - Nova Scotia onshore.',43.41,47.08,-66.28,-59.73,0);
INSERT INTO "area" VALUES('EPSG','2314','Asia - FSU - Caspian states','Azerbaijan; Kazakhstan; Russian Federation; Turkmenistan - Caspian Sea.',35.15,81.85,26.0,90.0,1);
INSERT INTO "area" VALUES('EPSG','2315','Colombia - Cusiana','Colombia - Casanare province BP Cusiana/Cupiagua field areas. Also used by Total in Rivera and Gatanas blocks.',4.75,5.68,-73.0,-72.25,0);
INSERT INTO "area" VALUES('EPSG','2316','Angola - offshore block 5','Angola - offshore block 5.',-8.59,-7.75,12.58,13.4,0);
INSERT INTO "area" VALUES('EPSG','2317','Angola - offshore block 2','Angola - offshore block 2.',-7.01,-6.01,12.08,12.84,0);
INSERT INTO "area" VALUES('EPSG','2318','Angola - offshore block 3','Angola - offshore block 3.',-7.34,-6.66,11.74,12.5,0);
INSERT INTO "area" VALUES('EPSG','2319','Angola - offshore block 7','Angola - offshore block 7.',-10.09,-9.41,12.66,13.39,0);
INSERT INTO "area" VALUES('EPSG','2320','Angola - offshore blocks 7 8 24 + WGC spec','Angola - offshore blocks 7 and 8. Also used rounded to integer metre in offshore block 24 and for GSI/HGS/Western Geophysical speculative seismic data throughout offshore Angola.',-17.26,-6.01,8.2,13.86,0);
INSERT INTO "area" VALUES('EPSG','2321','Angola - offshore blocks 1 and 16','Angola - offshore blocks 1 and 16.',-7.26,-6.03,11.08,12.09,0);
INSERT INTO "area" VALUES('EPSG','2322','Angola - offshore blocks 3  7  15 and 17','Angola - offshore blocks 3, 7,15 and 17.',-10.09,-6.03,10.83,13.39,0);
INSERT INTO "area" VALUES('EPSG','2323','Angola - offshore blocks 1 16 and 18','Angola - offshore blocks 1, 16 and 18.',-8.34,-6.03,11.08,12.75,0);
INSERT INTO "area" VALUES('EPSG','2324','Angola - offshore blocks 2  3 17-18 and 31-33','Angola - offshore blocks 2, 3, 17, 18, 31, 32 and 33.',-8.59,-6.01,10.41,12.84,0);
INSERT INTO "area" VALUES('EPSG','2325','Argentina - Neuquen province Chos Malal area','Argentina - Neuquen province - Chos Malal area.',-37.5,-36.14,-70.5,-70.03,0);
INSERT INTO "area" VALUES('EPSG','2326','Germany - West Germany all states','Germany - states of former West Germany onshore - Baden-Wurtemberg, Bayern, Bremen, Hamburg, Hessen, Niedersachsen, Nordrhein-Westfalen, Rheinland-Pfalz, Saarland, Schleswig-Holstein.',47.27,55.09,5.87,13.84,0);
INSERT INTO "area" VALUES('EPSG','2327','Syria - Al Whaleed area','Syria - Al Whaleed area',35.33,35.9,39.15,40.41,0);
INSERT INTO "area" VALUES('EPSG','2328','Syria - Shaddadeh area','Syria - Shaddadeh area (36°N, 41°E)',35.79,36.5,40.5,41.39,0);
INSERT INTO "area" VALUES('EPSG','2329','Syria - Deir area','Syria - Deir area (35°22''N, 40°06''E)',34.49,35.9,39.3,40.81,0);
INSERT INTO "area" VALUES('EPSG','2330','Europe - North Sea','Denmark - North Sea; Germany - North Sea; Netherlands - offshore; Norway - North Sea south of 62°N; United Kingdom (UKCS) - North Sea south of 62°N.',51.03,62.01,-5.05,11.14,0);
INSERT INTO "area" VALUES('EPSG','2331','Norway - offshore north of 65°N','Norway - offshore north of 65°N.',65.0,72.0,-0.5,32.02,1);
INSERT INTO "area" VALUES('EPSG','2332','Norway - offshore north of 65°N; Svalbard','Norway - offshore north of 65°N. Also Svalbard.',65.0,84.17,-3.7,39.65,0);
INSERT INTO "area" VALUES('EPSG','2333','Norway - offshore 62°N to 65°N and west of 5°E','Norway - offshore between 62°N and 65°N and west of 5°E.',62.0,65.0,-0.49,5.0,0);
INSERT INTO "area" VALUES('EPSG','2334','Norway - North Sea - offshore south of 62°N','Norway - offshore south of 62°N - North Sea.',56.08,62.0,1.37,11.14,0);
INSERT INTO "area" VALUES('EPSG','2335','Spain - Balearic Islands','Spain - Balearic Islands.',38.59,40.11,1.14,4.39,0);
INSERT INTO "area" VALUES('EPSG','2336','Spain - mainland except northwest','Spain - onshore mainland except northwest (north of 41°30''N and west of 4°30''W).',35.26,43.56,-7.54,3.39,0);
INSERT INTO "area" VALUES('EPSG','2337','Spain - mainland northwest','Spain - onshore mainland north of 41°30''N and west of 4°30'' W.',41.5,43.82,-9.37,-4.5,0);
INSERT INTO "area" VALUES('EPSG','2338','Europe - Portugal and Spain','Portugal; Spain - mainland.',35.26,43.82,-9.56,3.39,0);
INSERT INTO "area" VALUES('EPSG','2339','Italy - Sardinia onshore','Italy - Sardinia onshore.',38.82,41.31,8.08,9.89,0);
INSERT INTO "area" VALUES('EPSG','2340','Italy - Sicily onshore','Italy - Sicily onshore.',36.59,38.35,12.36,15.71,0);
INSERT INTO "area" VALUES('EPSG','2341','Egypt - Gulf of Suez','Egypt - Gulf of Suez.',27.19,30.01,32.34,34.27,0);
INSERT INTO "area" VALUES('EPSG','2342','Europe - common offshore','Denmark - offshore North Sea; Ireland - offshore; Netherlands - offshore; United Kingdom - UKCS offshore.',47.42,63.89,-16.1,10.86,0);
INSERT INTO "area" VALUES('EPSG','2343','Europe - British Isles and Channel Islands onshore','Channel islands - onshore. Ireland - onshore. Isle of Man - onshore. United Kingdom (UK) -  onshore - England; Scotland; Wales; Northern Ireland.',49.11,60.9,-10.56,1.84,0);
INSERT INTO "area" VALUES('EPSG','2344','Europe - Finland and Norway - onshore','Finland and Norway - onshore.',57.93,71.21,4.68,31.59,0);
INSERT INTO "area" VALUES('EPSG','2345','Asia - Middle East - Iraq; Israel; Jordan; Lebanon; Kuwait; Saudi Arabia; Syria','Iraq, Israel, Jordan, Lebanon, Kuwait, Saudi Arabia and Syria - onshore.',15.61,37.39,34.17,55.67,0);
INSERT INTO "area" VALUES('EPSG','2346','World - WGS72 BE to WGS 84 - by country','World. Vietnam - offshore.',-90.0,90.0,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','2347','Algeria - north of 31.5°N','Algeria - onshore north of 35 grads North (31°30''N).',31.5,37.14,-3.85,9.22,0);
INSERT INTO "area" VALUES('EPSG','2348','Brunei - offshore','Brunei Darussalam - offshore.',4.58,6.37,112.5,115.24,1);
INSERT INTO "area" VALUES('EPSG','2349','Brunei - onshore','Brunei Darussalam - onshore.',4.01,5.11,114.09,115.37,0);
INSERT INTO "area" VALUES('EPSG','2350','Mozambique - A','Mozambique - Maputo province and southern part of Gaza province; i.e. south of approximately 24°S.',-26.87,-23.91,31.91,34.5,0);
INSERT INTO "area" VALUES('EPSG','2351','Mozambique - B','Mozambique - provinces of Gaza; Inhambane and southern parts of Sofala and Manhica; i.e. between approximately 24°S and 20°S.',-24.91,-19.74,31.29,35.65,0);
INSERT INTO "area" VALUES('EPSG','2352','Mozambique - C','Mozambique - provinces of Sofala north of Beira corridor; Manhica; Tete and Zambezia; i.e. between approximately 20°S and 16°S.',-19.91,-14.01,30.21,39.18,0);
INSERT INTO "area" VALUES('EPSG','2353','Mozambique - D','Mozambique - provinces of Nampula; Niassa; Cabo Delgado; i.e. north of approximately 16°S.',-16.94,-10.42,34.36,40.9,0);
INSERT INTO "area" VALUES('EPSG','2354','Indonesia - Kalimantan','Indonesia - Kalimantan.',-4.24,4.37,108.79,119.06,0);
INSERT INTO "area" VALUES('EPSG','2355','Falkland Islands - East Falkland Island','Falkland Islands (Malvinas) - East Falkland Island.',-52.51,-51.16,-59.98,-57.61,0);
INSERT INTO "area" VALUES('EPSG','2356','Ecuador - Galapagos onshore','Ecuador - Baltra; Galapagos - onshore.',-1.41,0.18,-91.72,-89.19,0);
INSERT INTO "area" VALUES('EPSG','2357','Argentina - Tierra del Fuego onshore','Argentina - Tierra del Fuego onshore.',-55.11,-52.59,-68.64,-63.73,0);
INSERT INTO "area" VALUES('EPSG','2358','Thailand - Bongkot field','Thailand - Bongkot field.',6.74,8.16,102.16,103.05,0);
INSERT INTO "area" VALUES('EPSG','2359','Vietnam - 14°N to 18°N onshore','Vietnam - onshore between 14°N and 18°N.',14.0,18.0,105.61,109.32,0);
INSERT INTO "area" VALUES('EPSG','2360','Vietnam - Con Son Island','Vietnam - Con Son Island.',8.58,8.83,106.49,106.79,0);
INSERT INTO "area" VALUES('EPSG','2361','Myanmar (Burma) - Moattama area','Myanmar (Burma) - Moattama area.',9.48,17.87,93.94,99.66,0);
INSERT INTO "area" VALUES('EPSG','2362','Iran - Kangan district','Iran - Kangan district.',27.3,28.2,51.8,53.01,0);
INSERT INTO "area" VALUES('EPSG','2363','Venezuela - east','Venezuela - east - Delta Amacuro; Anzoategui; Bolivar; Monagas; Sucre states.',3.56,10.8,-67.49,-59.8,0);
INSERT INTO "area" VALUES('EPSG','2364','Philippines - onshore excluding Mindanao','Philippines - onshore excluding Mindanao.',7.75,19.45,116.89,125.88,0);
INSERT INTO "area" VALUES('EPSG','2365','Philippines - Mindanao onshore','Philippines - Mindanao onshore.',4.99,10.52,119.76,126.65,0);
INSERT INTO "area" VALUES('EPSG','2366','Spain - mainland onshore','Spain - mainland onshore.',35.95,43.82,-9.37,3.39,0);
INSERT INTO "area" VALUES('EPSG','2367','Spain - mainland northeast','Spain - onshore mainland north of the parallel of approximately 41°58''N from approximately 6°35''W to the meridian of 4°W of Greenwich and then a line from 41°58''N, 4°W through 40°N, 0°E of Greenwich.',39.96,43.82,-9.37,3.39,0);
INSERT INTO "area" VALUES('EPSG','2368','Spain - mainland southwest','Spain - onshore mainland south of the parallel of approximately 41°58''N from approximately 6°35''W to the meridian of 4°W of Greenwich and then a line from 41°58''N, 4°W through 40°N, 0°E of Greenwich.',35.95,41.98,-7.54,0.28,0);
INSERT INTO "area" VALUES('EPSG','2369','Seychelles - Mahe Island','Seychelles - Mahe Island.',-4.86,-4.5,55.3,55.59,0);
INSERT INTO "area" VALUES('EPSG','2370','Europe - former Yugoslavia onshore','Boznia and Herzegovina; Croatia - onshore; Kosovo; Montenegro - onshore; North Macedonia; Serbia; Slovenia - onshore.',40.85,46.88,13.38,23.04,0);
INSERT INTO "area" VALUES('EPSG','2371','Nigeria - south','Nigeria - onshore south.',4.22,6.95,4.35,9.45,0);
INSERT INTO "area" VALUES('EPSG','2372','Italy - mainland','Italy - mainland including San Marino and Vatican City State.',37.86,47.1,6.62,18.58,0);
INSERT INTO "area" VALUES('EPSG','2373','USA - Alaska including EEZ','United States (USA) - Alaska including EEZ.',47.88,74.71,167.65,-129.99,0);
INSERT INTO "area" VALUES('EPSG','2374','USA - CONUS including EEZ','United States (USA) - CONUS including EEZ -onshore and offshore - Alabama; Arizona; Arkansas; California; Colorado; Connecticut; Delaware; Florida; Georgia; Idaho; Illinois; Indiana; Iowa; Kansas; Kentucky; Louisiana; Maine; Maryland; Massachusetts; Michigan; Minnesota; Mississippi; Missouri; Montana; Nebraska; Nevada; New Hampshire; New Jersey; New Mexico; New York; North Carolina; North Dakota; Ohio; Oklahoma; Oregon; Pennsylvania; Rhode Island; South Carolina; South Dakota; Tennessee; Texas; Utah; Vermont; Virginia; Washington; West Virginia; Wisconsin; Wyoming. US Gulf of Mexico (GoM) OCS.',23.81,49.38,-129.17,-65.69,0);
INSERT INTO "area" VALUES('EPSG','2375','Canada - Saskatchewan','Canada - Saskatchewan.',49.0,60.01,-110.0,-101.34,0);
INSERT INTO "area" VALUES('EPSG','2376','Canada - Alberta','Canada - Alberta.',48.99,60.0,-120.0,-109.98,0);
INSERT INTO "area" VALUES('EPSG','2377','USA - Delaware and Maryland','United States (USA) - Delaware and Maryland.',37.97,39.85,-79.49,-74.97,0);
INSERT INTO "area" VALUES('EPSG','2378','USA - New England - south (CT, MA, NH, RI, VT)','United States (USA) - Connecticut; Massachusetts; New Hampshire; Rhode Island; Vermont.',40.98,45.31,-73.73,-69.86,0);
INSERT INTO "area" VALUES('EPSG','2379','USA - Texas east of 100°W','United States (USA) - Texas east of 100°W.',25.83,34.58,-100.0,-93.5,0);
INSERT INTO "area" VALUES('EPSG','2380','USA - Texas west of 100°W','United States (USA) - Texas west of 100°W.',28.04,36.5,-106.66,-100.0,0);
INSERT INTO "area" VALUES('EPSG','2381','USA - Oregon and Washington','United States (USA) - Oregon and Washington.',41.98,49.05,-124.79,-116.47,0);
INSERT INTO "area" VALUES('EPSG','2382','USA - Idaho and Montana - east of 113°W','United States (USA) - Idaho and Montana - east of 113°W.',41.99,49.01,-113.0,-104.04,0);
INSERT INTO "area" VALUES('EPSG','2383','USA - Idaho and Montana - west of 113°W','United States (USA) - Idaho and Montana - west of 113°W.',41.99,49.01,-117.24,-113.0,0);
INSERT INTO "area" VALUES('EPSG','2384','Canada - Alberta and British Columbia','Canada - Alberta; British Columbia.',48.25,60.01,-139.04,-109.98,0);
INSERT INTO "area" VALUES('EPSG','2385','Panama - Canal Zone','Panama - Canal Zone.',8.82,9.45,-80.07,-79.46,0);
INSERT INTO "area" VALUES('EPSG','2386','Greenland - Hayes Peninsula','Greenland - Hayes Peninsula.',75.86,79.2,-73.29,-60.98,0);
INSERT INTO "area" VALUES('EPSG','2387','USA - Alaska - Aleutian Islands east of 180°E','United States (USA) - Alaska - Aleutian Islands onshore east of 180°E.',51.54,54.34,-178.3,-164.84,0);
INSERT INTO "area" VALUES('EPSG','2388','USA - Alaska - Aleutian Islands west of 180°W','United States (USA) - Alaska - Aleutian Islands onshore west of 180°W.',51.3,53.07,172.42,179.86,0);
INSERT INTO "area" VALUES('EPSG','2389','USA - CONUS east of Mississippi River - onshore','United States (USA) - CONUS east of Mississippi River - onshore - including entire states of Louisiana; Missouri; Minnesota as well as Alabama; Connecticut; Delaware; Florida; Georgia; Illinois; Indiana; Kentucky; Maine; Maryland; Massachusetts; Michigan; Mississippi; New Hampshire; New Jersey; New York; North Carolina; Ohio; Pennsylvania; Rhode Island; South Carolina; Tennessee; Vermont; Virginia; West Virginia; Wisconsin.',24.41,49.38,-97.22,-66.91,0);
INSERT INTO "area" VALUES('EPSG','2390','USA - CONUS west of Mississippi River - onshore','United States (USA) - CONUS west of Mississippi River - onshore - excludes those states covered under Area 2389 - Includes Arizona; Arkansas; California; Colorado; Idaho; Iowa; Kansas; Montana; Nebraska; Nevada; New Mexico; North Dakota; Oklahoma; Oregon; South Dakota; Texas; Utah; Washington; Wyoming.',25.83,49.05,-124.79,-89.64,0);
INSERT INTO "area" VALUES('EPSG','2391','Oman - Masirah Island','Oman - Masirah Island.',20.12,20.74,58.58,59.01,0);
INSERT INTO "area" VALUES('EPSG','2392','UAE - Abu al Bu Khoosh','United Arab Emirates (UAE) - Abu Dhabi offshore - Abu al Bu Khoosh.',25.33,25.54,53.03,53.4,0);
INSERT INTO "area" VALUES('EPSG','2393','Algeria - Hassi Messaoud','Algeria - Hassi Messaoud.',31.48,32.09,5.59,6.5,0);
INSERT INTO "area" VALUES('EPSG','2394','UK - Great Britain and UKCS','United Kingdom (UKCS) - Great Britain (GB) - England; Scotland; Wales; UKCS including North Sea.',49.15,63.83,-6.0,3.4,1);
INSERT INTO "area" VALUES('EPSG','2395','UK - England','United Kingdom (UK) - England onshore.',49.81,55.85,-6.5,1.84,0);
INSERT INTO "area" VALUES('EPSG','2396','UK - England and Wales, Isle of Man','United Kingdom (UK) - England and Wales; Isle of Man - onshore.',49.81,55.85,-6.5,1.84,0);
INSERT INTO "area" VALUES('EPSG','2397','UK - Scotland','United Kingdom (UK) - Scotland (including Orkney and Shetland Islands), onshore and nearshore.',54.57,60.9,-8.74,-0.65,0);
INSERT INTO "area" VALUES('EPSG','2398','UK - Wales','United Kingdom (UK) - Wales onshore.',51.28,53.48,-5.34,-2.65,0);
INSERT INTO "area" VALUES('EPSG','2399','South America - Bolivia; Chile; Ecuador; Guyana; Peru; Venezuela','Bolivia; Chile - onshore north of 43°30''S; Ecuador - mainland onshore; Guyana - onshore; Peru - onshore; Venezuela - onshore.',-43.5,12.25,-81.41,-56.47,0);
INSERT INTO "area" VALUES('EPSG','2400','Bolivia - Madidi','Bolivia - Madidi.',-14.43,-13.56,-68.96,-67.79,0);
INSERT INTO "area" VALUES('EPSG','2401','Bolivia - Block 20','Bolivia - Block 20.',-21.71,-21.09,-63.44,-62.95,0);
INSERT INTO "area" VALUES('EPSG','2402','Chile - onshore north of 21°30''S','Chile - onshore north of 21°30''S.',-21.51,-17.5,-70.49,-68.18,0);
INSERT INTO "area" VALUES('EPSG','2403','Chile - onshore 39°S to 43°30''S','Chile - onshore between 39°S and 43°30''S.',-43.5,-38.99,-74.48,-71.38,0);
INSERT INTO "area" VALUES('EPSG','2404','Oman - block 4','Oman - block 4.',19.58,21.17,56.5,59.02,0);
INSERT INTO "area" VALUES('EPSG','2405','Kazakhstan - Caspian Sea','Kazakhstan - Caspian Sea.',41.15,46.97,48.9,53.15,0);
INSERT INTO "area" VALUES('EPSG','2406','Qatar - offshore','Qatar - offshore.',24.64,27.05,50.55,53.04,0);
INSERT INTO "area" VALUES('EPSG','2407','Greenland - south of 72°N','Greenland - south of 72°N.',59.75,72.0,-55.0,-40.0,1);
INSERT INTO "area" VALUES('EPSG','2408','Japan - Okinawa','Japan - onshore Okinawa.',23.98,26.91,122.83,131.38,0);
INSERT INTO "area" VALUES('EPSG','2409','Asia - Japan and South Korea','Japan - onshore; South Korea - onshore.',20.37,45.54,122.83,145.87,0);
INSERT INTO "area" VALUES('EPSG','2410','Canada - NWT; Nunavut; Saskatchewan','Canada - Northwest Territories; Nunavut; Saskatchewan.',49.0,83.17,-136.46,-60.72,0);
INSERT INTO "area" VALUES('EPSG','2411','Asia - India mainland and Nepal','India - mainland onshore; Nepal.',8.02,35.51,68.13,97.42,0);
INSERT INTO "area" VALUES('EPSG','2412','USA - Alaska mainland','United States (USA) - Alaska mainland.',54.34,71.4,-168.26,-129.99,0);
INSERT INTO "area" VALUES('EPSG','2413','Bahamas - main islands onshore','Bahamas - onshore southwest of a line from 27°30''N, 77°30''W through 23°15''N, 74°30''W to 22°30''N, 72°30''W.',20.86,27.29,-79.04,-72.68,0);
INSERT INTO "area" VALUES('EPSG','2414','Bahamas (San Salvador Island) - onshore','Bahamas (San Salvador Island) - onshore.',23.9,24.19,-74.6,-74.37,0);
INSERT INTO "area" VALUES('EPSG','2415','Canada - Manitoba and Ontario','Canada - Manitoba; Ontario.',41.67,60.01,-102.0,-74.35,0);
INSERT INTO "area" VALUES('EPSG','2416','Canada - eastern provinces','Canada - onshore - New Brunswick; Newfoundland and Labrador; Nova Scotia; Prince Edward Island; Quebec.',43.41,62.62,-79.85,-52.54,0);
INSERT INTO "area" VALUES('EPSG','2417','Canada - Yukon','Canada - Yukon.',59.99,69.7,-141.01,-123.91,0);
INSERT INTO "area" VALUES('EPSG','2418','Caribbean - central (DMA tfm)','Antigua; Barbados; Barbuda; Cuba; Dominican Republic; Grand Cayman; Jamaica; Turks and Caicos Islands. Note: does not include other islands within this geographic area.',13.0,23.25,-85.01,-59.37,0);
INSERT INTO "area" VALUES('EPSG','2419','Central America - Belize to Costa Rica','Onshore Belize, Costa Rica, El Salvador, Guatemala, Honduras and Nicaragua.',7.98,18.49,-92.29,-82.53,0);
INSERT INTO "area" VALUES('EPSG','2420','Europe - west (DMA ED50 mean)','Austria; Belgium; Denmark; Finland; Faroe islands; France; Germany (west); Gibraltar; Greece; Italy; Luxembourg; Netherlands; Norway; Portugal; Spain; Sweden; Switzerland.',34.88,71.21,-9.56,31.59,0);
INSERT INTO "area" VALUES('EPSG','2421','Europe - west central (by country)','Austria; Denmark; France; Germany (west); Netherlands; Switzerland.',42.33,57.8,-4.87,17.17,0);
INSERT INTO "area" VALUES('EPSG','2422','Slovenia - Gorenjska - central','Slovenia - central Gorenjska (Upper Carniola) with part of the Kamnik or Savinja Alps.',46.14,46.45,14.01,14.61,0);
INSERT INTO "area" VALUES('EPSG','2423','Europe - FSU onshore','Armenia; Azerbaijan; Belarus; Estonia - onshore; Georgia - onshore; Kazakhstan; Kyrgyzstan; Latvia - onshore; Lithuania - onshore; Moldova; Russian Federation - onshore; Tajikistan; Turkmenistan; Ukraine - onshore; Uzbekistan.',35.14,81.91,19.57,-168.97,0);
INSERT INTO "area" VALUES('EPSG','2424','USA - HARN','American Samoa; Puerto Rico and the Virgin Islands; United States (USA) - Alabama; Alaska; Arizona; Arkansas; California; Colorado; Connecticut; Delaware; Florida; Georgia; Hawaii; Idaho; Illinois; Indiana; Iowa; Kansas; Kentucky; Louisiana; Maine; Maryland; Massachusetts; Michigan; Minnesota; Mississippi; Missouri; Montana; Nebraska; Nevada; New Hampshire; New Jersey; New Mexico; New York; North Carolina; North Dakota; Ohio; Oklahoma; Oregon; Pennsylvania; Rhode Island; South Carolina; South Dakota; Tennessee; Texas; Utah; Vermont; Virginia; Washington; West Virginia; Wisconsin; Wyoming.',NULL,NULL,NULL,NULL,1);
INSERT INTO "area" VALUES('EPSG','2425','Japan - 45°20''N to 46°N; 141°E to 142°E','Japan - onshore mainland 45°20''N to 46°N; 141°E to 142°E.',45.33,45.54,141.56,142.0,0);
INSERT INTO "area" VALUES('EPSG','2426','Japan - 45°20''N to 46°N; 142°E to 143°E','Japan - onshore 45°20''N to 46°N; 142°E to 143°E.',45.33,45.54,142.0,142.27,0);
INSERT INTO "area" VALUES('EPSG','2427','Japan - 44°40''N to 45°20''N; 141°E to 142°E','Japan - onshore mainland 44°40''N to 45°20''N; 141°E to 142°E.',44.66,45.34,141.5,142.0,0);
INSERT INTO "area" VALUES('EPSG','2428','Japan - 44°40''N to 45°20''N; 142°E to 143°E','Japan - onshore 44°40''N to 45°20''N; 142°E to 143°E.',44.66,45.34,142.0,142.97,0);
INSERT INTO "area" VALUES('EPSG','2429','Japan - 44°N to 44°40''N; 141°E to 142°E','Japan - onshore mainland 44°N to 44°40''N; 141°E to 142°E.',43.99,44.67,141.58,142.0,0);
INSERT INTO "area" VALUES('EPSG','2430','Japan - 44°N to 44°40''N; 142°E to 143°E','Japan - 44°N to 44°40''N; 142°E to 143°E.',43.99,44.67,142.0,143.0,0);
INSERT INTO "area" VALUES('EPSG','2431','Japan - 44°N to 44°40''N; 143°E to 144°E','Japan - onshore 44°N to 44°40''N; 143°E to 144°E.',43.99,44.65,143.0,144.0,0);
INSERT INTO "area" VALUES('EPSG','2432','Japan - 44°N to 44°40''N; 144°E to 145°E','Japan - onshore 44°N to 44°40''N; 144°E to 145°E.',43.99,44.19,144.0,145.0,0);
INSERT INTO "area" VALUES('EPSG','2433','Japan - 43°20''N to 44°N; 141°E to 142°E','Japan - onshore 43°20''N to 44°N; 141°E to 142°E.',43.33,44.0,141.26,142.0,0);
INSERT INTO "area" VALUES('EPSG','2434','Japan - 43°20''N to 44°N; 142°E to 143°E','Japan - 43°20''N to 44°N; 142°E to 143°E.',43.33,44.0,142.0,143.0,0);
INSERT INTO "area" VALUES('EPSG','2435','Japan - 43°20''N to 44°N; 143°E to 144°E','Japan - 43°20''N to 44°N; 143°E to 144°E.',43.33,44.0,143.0,144.0,0);
INSERT INTO "area" VALUES('EPSG','2436','Japan - 43°20''N to 44°N; 144°E to 145°E','Japan - 43°20''N to 44°N; 144°E to 145°E.',43.33,44.0,144.0,145.0,0);
INSERT INTO "area" VALUES('EPSG','2437','Japan - north of 43°20''N; 145°E to 146°E','Japan - onshore north of 43°20''N and west of 145°E.',43.33,44.4,145.0,145.87,0);
INSERT INTO "area" VALUES('EPSG','2438','Japan - 42°40''N to 43°25''N; 140°E to 141°E','Japan - onshore 42°40''N to 43°25''N; 140°E to 141°E.',42.66,43.42,140.0,141.0,0);
INSERT INTO "area" VALUES('EPSG','2439','Japan - 42°40''N to 43°20''N; 141°E to 142°E','Japan - 42°40''N to 43°20''N; 141°E to 142°E.',42.66,43.34,141.0,142.0,0);
INSERT INTO "area" VALUES('EPSG','2440','Japan - 42°40''N to 43°20''N; 142°E to 143°E','Japan - 42°40''N to 43°20''N; 142°E to 143°E.',42.66,43.34,142.0,143.0,0);
INSERT INTO "area" VALUES('EPSG','2441','Japan - 42°40''N to 43°20''N; 143°E to 144°E','Japan - 42°40''N to 43°20''N; 143°E to 144°E.',42.66,43.34,143.0,144.0,0);
INSERT INTO "area" VALUES('EPSG','2442','Japan - 42°40''N to 43°20''N; 144°E to 145°E','Japan - onshore 42°40''N to 43°20''N; 144°E to 145°E.',42.84,43.34,144.0,145.0,0);
INSERT INTO "area" VALUES('EPSG','2443','Japan - 42°40''N to 43°20''N; 145°E to 146°E','Japan - onshore 42°40''N to 43°20''N; 145°E to 146°E.',42.93,43.34,145.0,145.87,0);
INSERT INTO "area" VALUES('EPSG','2444','Japan - north of 42°N; west of 140°E','Japan - onshore mainland north of 42°N and west of 140°E.',42.05,42.73,139.7,140.0,0);
INSERT INTO "area" VALUES('EPSG','2445','Japan - 42°N to 42°40''N; 140°E to 141°E','Japan - 42°N to 42°40''N; 140°E to 141°E.',41.99,42.67,140.0,141.0,0);
INSERT INTO "area" VALUES('EPSG','2446','Japan - 42°N to 42°40''N; 141°E to 142°E','Japan - onshore 42°N to 42°40''N; 141°E to 142°E.',42.24,42.67,141.0,142.0,0);
INSERT INTO "area" VALUES('EPSG','2447','Japan - 42°N to 42°40''N; 142°E to 143°E','Japan - onshore 42°N to 42°40''N; 142°E to 143°E.',42.02,42.67,142.0,143.0,0);
INSERT INTO "area" VALUES('EPSG','2448','Japan - south of 42°40''N; 143°E to 144°E','Japan - onshore south of 42°40''N; east of 143°E.',41.87,42.67,143.0,143.76,0);
INSERT INTO "area" VALUES('EPSG','2449','Japan - 41°20''N to 42°N; west of 141°E','Japan - onshore mainland 41°20''N to 42°N; west of 141°E.',41.33,42.0,139.91,141.0,0);
INSERT INTO "area" VALUES('EPSG','2450','Japan - 41°20''N to 42°N; 141°E to 142°E','Japan - onshore 41°20''N to 42°N; 141°E to 142°E.',41.33,41.96,141.0,141.53,0);
INSERT INTO "area" VALUES('EPSG','2451','Japan - 40°40''N to 41°20''N; 140°E to 141°E','Japan - 40°40''N to 41°20''N; 140°E to 141°E.',40.66,41.34,140.0,141.0,0);
INSERT INTO "area" VALUES('EPSG','2452','Japan - 40°40''N to 41°20''N; 141°E to 142°E','Japan - onshore 40°40''N to 41°20''N; 141°E to 142°E.',40.66,41.34,141.0,141.53,0);
INSERT INTO "area" VALUES('EPSG','2453','Japan - 40°N to 40°48''N; 139°E to 140°E','Japan - onshore 40°N to 40°48''N; 139°E to 140°E.',39.99,40.8,139.63,140.0,0);
INSERT INTO "area" VALUES('EPSG','2454','Japan - 40°N to 40°40''N; 140°E to 141°E','Japan - 40°N to 40°40''N; 140°E to 141°E.',39.99,40.67,140.0,141.0,0);
INSERT INTO "area" VALUES('EPSG','2455','Japan - 40°N to 40°40''N; 141°E to 142°E','Japan - 40°N to 40°40''N; 141°E to 142°E.',39.99,40.67,141.0,142.0,0);
INSERT INTO "area" VALUES('EPSG','2456','Japan - 39°20''N to 40°N; 139°E to 140°E','Japan - onshore 39°20''N to 40°N; 139°E to 140°E.',39.33,40.0,139.63,140.0,0);
INSERT INTO "area" VALUES('EPSG','2457','Japan - 39°20''N to 40°N; 140°E to 141°E','Japan - 39°20''N to 40°N; 140°E to 141°E.',39.33,40.0,140.0,141.0,0);
INSERT INTO "area" VALUES('EPSG','2458','Japan - 39°20''N to 40°N; east of 141°E','Japan - onshore 39°20''N to 40°N; east of 141°E.',39.33,40.0,141.0,142.14,0);
INSERT INTO "area" VALUES('EPSG','2459','Japan - 38°40''N to 39°20''N; 139°E to 140°E','Japan - onshore 38°40''N to 39°20''N; 139°E to 140°E.',38.66,39.34,139.55,140.0,0);
INSERT INTO "area" VALUES('EPSG','2460','Japan - 38°40''N to 39°20''N; 140°E to 141°E','Japan - 38°40''N to 39°20''N; 140°E to 141°E.',38.66,39.34,140.0,141.0,0);
INSERT INTO "area" VALUES('EPSG','2461','Japan - 38°40''N to 39°20''N; 141°E to 142°E','Japan - onshore 38°40''N to 39°20''N; 141°E to 142°E.',38.66,39.34,141.0,141.99,0);
INSERT INTO "area" VALUES('EPSG','2462','Japan - 38°N to 38°40''N; 139°E to 140°E','Japan - onshore 38°N to 38°40''N; 139°E to 140°E.',37.99,38.67,139.11,140.0,0);
INSERT INTO "area" VALUES('EPSG','2463','Japan - 38°N to 38°40''N; 140°E to 141°E','Japan - 38°N to 38°40''N; 140°E to 141°E.',37.99,38.67,140.0,141.0,0);
INSERT INTO "area" VALUES('EPSG','2464','Japan - 38°N to 38°40''N; 141°E to 142°E','Japan - onshore 38°N to 38°40''N; 141°E to 142°E.',38.08,38.67,141.0,141.62,0);
INSERT INTO "area" VALUES('EPSG','2465','Japan - 37°20''N to 38°N; 136°E to 137°E','Japan - onshore 37°20''N to 38°N; 136°E to 137°E.',37.33,37.47,136.67,137.0,0);
INSERT INTO "area" VALUES('EPSG','2466','Japan - 37°20''N to 38°N; 137°E to 138°E','Japan - onshore 37°20''N to 38°N; 137°E to 138°E.',37.33,37.58,137.0,137.43,0);
INSERT INTO "area" VALUES('EPSG','2467','Japan - 37°20''N to 38°N; 138°E to 139°E','Japan - onshore mainland 37°20''N to 38°N; 138°E to 139°E.',37.33,37.97,138.39,139.0,0);
INSERT INTO "area" VALUES('EPSG','2468','Japan - 37°20''N to 38°N; 139°E to 140°E','Japan - 37°20''N to 38°N; 139°E to 140°E.',37.33,38.0,139.0,140.0,0);
INSERT INTO "area" VALUES('EPSG','2469','Japan - 37°20''N to 38°N; 140°E to 141°E','Japan - 37°20''N to 38°N; 140°E to 141°E.',37.33,38.0,140.0,141.0,0);
INSERT INTO "area" VALUES('EPSG','2470','Japan - 37°20''N to 38°N; 141°E to 142°E','Japan - onshore 37°20''N to 38°N; 141°E to 142°E.',37.33,37.87,141.0,141.11,0);
INSERT INTO "area" VALUES('EPSG','2471','Japan - 36°40''N to 37°20''N; 136°E to 137°E','Japan - onshore 36°40''N to 37°20''N; 136°E to 137°E.',36.66,37.34,136.58,137.0,0);
INSERT INTO "area" VALUES('EPSG','2472','Japan - 36°40''N to 37°20''N; 137°E to 138°E','Japan - 36°40''N to 37°20''N; 137°E to 138°E.',36.66,37.34,137.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','2473','Japan - 36°40''N to 37°20''N; 138°E to 139°E','Japan - 36°40''N to 37°20''N; 138°E to 139°E.',36.66,37.34,138.0,139.0,0);
INSERT INTO "area" VALUES('EPSG','2474','Japan - 36°40''N to 37°20''N; 139°E to 140°E','Japan - 36°40''N to 37°20''N; 139°E to 140°E.',36.66,37.34,139.0,140.0,0);
INSERT INTO "area" VALUES('EPSG','2475','Japan - 36°40''N to 37°20''N; east of 140°E','Japan - onshore between 36°40''N and 37°20''N; east of 140°E.',36.66,37.34,140.0,141.1,0);
INSERT INTO "area" VALUES('EPSG','2476','Japan - 36°N to 36°40''N; west of137°E','Japan - onshore between 36°N and 36°40''N; west of 137°E.',35.99,36.67,135.9,137.0,0);
INSERT INTO "area" VALUES('EPSG','2477','Japan - 36°N to 36°40''N; 137°E to 138°E','Japan - 36°N to 36°40''N; 137°E to 138°E.',35.99,36.67,137.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','2478','Japan - 36°N to 36°40''N; 138°E to 139°E','Japan - 36°N to 36°40''N; 138°E to 139°E.',35.99,36.67,138.0,139.0,0);
INSERT INTO "area" VALUES('EPSG','2479','Japan - 36°N to 36°40''N; 139°E to 140°E','Japan - 36°N to 36°40''N; 139°E to 140°E.',35.99,36.67,139.0,140.0,0);
INSERT INTO "area" VALUES('EPSG','2480','Japan - 36°N to 36°40''N; 140°E to 141°E','Japan - onshore 36°N to 36°40''N; 140°E to 141°E.',35.99,36.67,140.0,140.77,0);
INSERT INTO "area" VALUES('EPSG','2481','Japan - 35°20''N to 36°N; 132°E to 133°E','Japan - onshore mainland 35°20''N to 36°N; 132°E to 133°E.',35.33,35.58,132.56,133.0,0);
INSERT INTO "area" VALUES('EPSG','2482','Japan - 35°20''N to 36°N; 133°E to 134°E','Japan - onshore mainland 35°20''N to 36°N; 133°E to 134°E.',35.33,35.64,133.0,134.0,0);
INSERT INTO "area" VALUES('EPSG','2483','Japan - 35°20''N to 36°N; 134°E to 135°E','Japan - onshore 35°20''N to 36°N; 134°E to 135°E.',35.33,35.73,134.0,135.0,0);
INSERT INTO "area" VALUES('EPSG','2484','Japan - 35°20''N to 36°N; 135°E to 136°E','Japan - 35°20''N to 36°N; 135°E to 136°E.',35.33,36.0,135.0,136.0,0);
INSERT INTO "area" VALUES('EPSG','2485','Japan - 35°20''N to 36°N; 136°E to 137°E','Japan - 35°20''N to 36°N; 136°E to 137°E.',35.33,36.0,136.0,137.0,0);
INSERT INTO "area" VALUES('EPSG','2486','Japan - 35°20''N to 36°N; 137°E to 138°E','Japan - 35°20''N to 36°N; 137°E to 138°E.',35.33,36.0,137.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','2487','Japan - 35°20''N to 36°N; 138°E to 139°E','Japan - 35°20''N to 36°N; 138°E to 139°E.',35.33,36.0,138.0,139.0,0);
INSERT INTO "area" VALUES('EPSG','2488','Japan - 35°20''N to 36°N; 139°E to 140°E','Japan - 35°20''N to 36°N; 139°E to 140°E.',35.33,36.0,139.0,140.0,0);
INSERT INTO "area" VALUES('EPSG','2489','Japan - 35°20''N to 36°N; 140°E to 141°E','Japan - onshore 35°20''N to 36°N; 140°E to 141°E.',35.33,36.0,140.0,140.9,0);
INSERT INTO "area" VALUES('EPSG','2490','Japan - 34°40''N to 35°20''N; 132°E to 133°E','Japan - 34°40''N to 35°20''N; 132°E to 133°E.',34.66,35.34,132.0,133.0,0);
INSERT INTO "area" VALUES('EPSG','2491','Japan - 34°40''N to 35°20''N; 133°E to 134°E','Japan - 34°40''N to 35°20''N; 133°E to 134°E.',34.66,35.34,133.0,134.0,0);
INSERT INTO "area" VALUES('EPSG','2492','Japan - 34°40''N to 35°20''N; 134°E to 135°E','Japan - 34°40''N to 35°20''N; 134°E to 135°E.',34.66,35.34,134.0,135.0,0);
INSERT INTO "area" VALUES('EPSG','2493','Japan - 34°40N'' to 35°20''N; 135°E to 136°E','Japan - 34°40N'' to 35°20''N; 135°E to 136°E.',34.66,35.34,135.0,136.0,0);
INSERT INTO "area" VALUES('EPSG','2494','Japan - 34°40''N to 35°20''N; 136°E to 137°E','Japan - 34°40''N to 35°20''N; 136°E to 137°E.',34.66,35.34,136.0,137.0,0);
INSERT INTO "area" VALUES('EPSG','2495','Japan - 34°40''N to 35°20''N; 137°E to 138°E','Japan - 34°40''N to 35°20''N; 137°E to 138°E.',34.66,35.34,137.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','2496','Japan - 34°40''N to 35°20''N; 138°E to 139°E','Japan - 34°40''N to 35°20''N; 138°E to 139°E.',34.66,35.34,138.0,139.0,0);
INSERT INTO "area" VALUES('EPSG','2497','Japan - 34°40''N to 35°20''N; 139°E to 140°E','Japan - onshore mainland 34°40''N to 35°20''N; 139°E to 140°E.',34.66,35.34,139.0,140.0,0);
INSERT INTO "area" VALUES('EPSG','2498','Japan - 34°40''N to 35°20''N; 140°E to 141°E','Japan - onshore 34°40''N to 35°20''N; 140°E to 141°E.',34.87,35.34,140.0,140.48,0);
INSERT INTO "area" VALUES('EPSG','2499','Japan - 34°N to 34°40''N; 130°E to 131°E','Japan - onshore 34°N to 34°40''N; 130°E to 131°E.',33.99,34.48,130.81,131.0,0);
INSERT INTO "area" VALUES('EPSG','2500','Japan - north of 34°N; 131°E to 132°E','Japan - onshore north of 34°N; between 131°E and 132°E.',33.99,34.9,131.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','2501','Japan - 34°N to 34°40''N; 132°E to 133°E','Japan - 34°N to 34°40''N; 132°E to 133°E.',33.99,34.67,132.0,133.0,0);
INSERT INTO "area" VALUES('EPSG','2502','Japan - 34°N to 34°40''N; 133°E to 134°E','Japan - 34°N to 34°40''N; 133°E to 134°E.',33.99,34.67,133.0,134.0,0);
INSERT INTO "area" VALUES('EPSG','2503','Japan - 34°N to 34°40''N; 134°E to 135°E','Japan - 34°N to 34°40''N; 134°E to 135°E.',33.99,34.67,134.0,135.0,0);
INSERT INTO "area" VALUES('EPSG','2504','Japan - 34°N to 34°40''N; 135°E to 136°E','Japan - 34°N to 34°40''N; 135°E to 136°E.',33.99,34.67,135.0,136.0,0);
INSERT INTO "area" VALUES('EPSG','2505','Japan - 34°N to 34°40''N; 136°E to 137°E','Japan - 34°N to 34°40''N; 136°E to 137°E.',33.99,34.67,136.0,137.0,0);
INSERT INTO "area" VALUES('EPSG','2506','Japan - 34°N to 34°40''N; 137°E to 138°E','Japan - onshore 34°N to 34°40''N; 137°E to 138°E.',34.51,34.67,137.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','2507','Japan - 34°N to 34°40''N; 138°E to 139°E','Japan - onshore 34°N to 34°40''N; 138°E to 139°E.',34.54,34.67,138.0,139.0,0);
INSERT INTO "area" VALUES('EPSG','2508','Japan - 33°20''N to 34°N; 129°E to 130°E','Japan - onshore mainland 33°20''N to 34°N; 129°E to 130°E.',33.33,33.59,129.38,130.0,0);
INSERT INTO "area" VALUES('EPSG','2509','Japan - 33°20''N to 34°N; 130°E to 131°E','Japan - onshore mainland 33°20''N to 34°N; 130°E to 131°E.',33.33,34.0,130.0,131.0,0);
INSERT INTO "area" VALUES('EPSG','2510','Japan - 33°20''N to 34°N; 131°E to 132°E','Japan - 33°20''N to 34°N; 131°E to 132°E.',33.33,34.0,131.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','2511','Japan - 33°20''N to 34°N; 132°E to 133°E','Japan - 33°20''N to 34°N; 132°E to 133°E.',33.33,34.0,132.0,133.0,0);
INSERT INTO "area" VALUES('EPSG','2512','Japan - 33°20''N to 34°N; 133°E to 134°E','Japan - 33°20''N to 34°N; 133°E to 134°E.',33.33,34.0,133.0,134.0,0);
INSERT INTO "area" VALUES('EPSG','2513','Japan - 33°20''N to 34°N; 134°E to 135°E','Japan - onshore 33°20''N to 34°N; 134°E to 135°E.',33.33,34.0,134.0,134.81,0);
INSERT INTO "area" VALUES('EPSG','2514','Japan - 33°20''N to 34°N; 135°E to 136°E','Japan - onshore 33°20''N to 34°N; 135°E to 136°E.',33.4,34.0,135.0,136.0,0);
INSERT INTO "area" VALUES('EPSG','2515','Japan - 33°20''N to 34°N; 136°E to 137°E','Japan - onshore 33°20''N to 34°N; 136°E to 137°E.',33.54,34.0,136.0,136.34,0);
INSERT INTO "area" VALUES('EPSG','2516','Japan - 32°40''N to 33°20''N; 129°E to 130°E','Japan - onshore mainland 32°40''N to 33°20''N; 129°E to 130°E.',32.51,33.34,129.3,130.0,0);
INSERT INTO "area" VALUES('EPSG','2517','Japan - 32°40''N to 33°20''N; 130°E to 131°E','Japan - 32°40''N to 33°20''N; 130°E to 131°E.',32.66,33.34,130.0,131.0,0);
INSERT INTO "area" VALUES('EPSG','2518','Japan - 32°40''N to 33°20''N; 131°E to 132°E','Japan - 32°40''N to 33°20''N; 131°E to 132°E.',32.66,33.34,131.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','2519','Japan - 32°40''N to 33°20''N; 132°E to 133°E','Japan - onshore mainland 32°40''N to 33°20''N; 132°E to 133°E.',32.69,33.34,132.0,133.0,0);
INSERT INTO "area" VALUES('EPSG','2520','Japan - 32°40''N to 33°20''N; 133°E to 134°E','Japan - onshore 32°40''N to 33°20''N; 133°E to 134°E.',32.7,33.34,133.0,134.0,0);
INSERT INTO "area" VALUES('EPSG','2521','Japan - 32°40''N to 33°20''N; 134°E to 135°E','Japan - onshore 32°40''N to 33°20''N; 134°E to 135°E.',33.19,33.34,134.0,134.27,0);
INSERT INTO "area" VALUES('EPSG','2522','Japan - 32°N to 32°40''N; 129°54''E to 131°E','Japan - onshore 32°N to 32°40''N; 129°54''E to 131°E.',31.99,32.67,129.89,131.0,0);
INSERT INTO "area" VALUES('EPSG','2523','Japan - 32°N to 32°40''N; 131°E to 132°E','Japan - onshore 32°N to 32°40''N; 131°E to 132°E.',31.99,32.67,131.0,131.91,0);
INSERT INTO "area" VALUES('EPSG','2524','Japan - 31°20''N to 32°N; 130°E to 131°E','Japan - onshore mainland 31°20''N to 32°N; 130°E to 131°E.',31.33,32.0,130.1,131.0,0);
INSERT INTO "area" VALUES('EPSG','2525','Japan - 31°20''N to 32°N; 131°E to 132°E','Japan - onshore 31°20''N to 32°N; 131°E to 132°E.',31.33,32.0,131.0,131.55,0);
INSERT INTO "area" VALUES('EPSG','2526','Japan - onshore mainland south of 31°20''N','Japan - onshore mainland south of 31°20''N.',30.94,31.34,130.14,131.19,0);
INSERT INTO "area" VALUES('EPSG','2527','USA - Texas - SPCS83 - SC','United States (USA) - Texas - counties of Aransas; Atascosa; Austin; Bandera; Bee; Bexar; Brazoria; Brewster; Caldwell; Calhoun; Chambers; Colorado; Comal; De Witt; Dimmit; Edwards; Fayette; Fort Bend; Frio; Galveston; Goliad; Gonzales; Guadalupe; Harris; Hays; Jackson; Jefferson; Karnes; Kendall; Kerr; Kinney; La Salle; Lavaca; Live Oak; Matagorda; Maverick; McMullen; Medina; Presidio; Real; Refugio; Terrell; Uvalde; Val Verde; Victoria; Waller; Wharton; Wilson; Zavala.',27.78,30.67,-105.0,-93.76,0);
INSERT INTO "area" VALUES('EPSG','2528','USA - Texas - SPCS83 - S','United States (USA) - Texas - counties of Brooks; Cameron; Duval; Hidalgo; Jim Hogg; Jim Wells; Kenedy; Kleberg; Nueces; San Patricio; Starr; Webb; Willacy; Zapata.',25.83,28.21,-100.2,-96.85,0);
INSERT INTO "area" VALUES('EPSG','2529','USA - Louisiana - SPCS83 - S','United States (USA) - Louisiana - counties of Acadia; Allen; Ascension; Assumption; Beauregard; Calcasieu; Cameron; East Baton Rouge; East Feliciana; Evangeline; Iberia; Iberville; Jefferson; Jefferson Davis; Lafayette; LaFourche; Livingston; Orleans; Plaquemines; Pointe Coupee; St Bernard; St Charles; St Helena; St James; St John the Baptist; St Landry; St Martin; St Mary; St Tammany; Tangipahoa; Terrebonne; Vermilion; Washington; West Baton Rouge; West Feliciana.',28.85,31.07,-93.94,-88.75,0);
INSERT INTO "area" VALUES('EPSG','2530','UK - Northern Ireland - onshore','United Kingdom (UK) - Northern Ireland (Ulster) - onshore.',53.96,55.36,-8.18,-5.34,0);
INSERT INTO "area" VALUES('EPSG','2531','Denmark - onshore Jutland and Funen','Denmark - Jutland and Funen - onshore.',54.67,57.8,8.0,11.29,0);
INSERT INTO "area" VALUES('EPSG','2532','Denmark - onshore Zealand and Lolland','Denmark - Zealand and Lolland (onshore).',54.51,56.18,10.79,12.69,0);
INSERT INTO "area" VALUES('EPSG','2533','Denmark - onshore Bornholm','Denmark - Bornholm onshore.',54.94,55.36,14.59,15.24,0);
INSERT INTO "area" VALUES('EPSG','2534','World - N hemisphere - 3-degree CM 027°E','Between 25°30''E and 28°30''E, northern hemisphere.',0.0,84.0,25.5,28.5,0);
INSERT INTO "area" VALUES('EPSG','2535','World - N hemisphere - 3-degree CM 030°E','Between 28°30''E and 31°30''E, northern hemisphere.',0.0,84.0,28.5,31.5,0);
INSERT INTO "area" VALUES('EPSG','2536','World - N hemisphere - 3-degree CM 033°E','Between 31°30''E and 34°30''E, northern hemisphere.',0.0,84.0,31.5,34.5,0);
INSERT INTO "area" VALUES('EPSG','2537','World - N hemisphere - 3-degree CM 036°E','Between 34°30''E and 37°30''E, northern hemisphere.',0.0,84.0,34.5,37.5,0);
INSERT INTO "area" VALUES('EPSG','2538','World - N hemisphere - 3-degree CM 039°E','Between 37°30''E and 40°30''E, northern hemisphere.',0.0,84.0,37.5,40.5,0);
INSERT INTO "area" VALUES('EPSG','2539','World - N hemisphere - 3-degree CM 042°E','Between 40°30''E and 43°30''E, northern hemisphere.',0.0,84.0,40.5,43.5,0);
INSERT INTO "area" VALUES('EPSG','2540','World - N hemisphere - 3-degree CM 045°E','Between 43°30''E and 46°30''E, northern hemisphere.',0.0,84.0,43.5,46.5,0);
INSERT INTO "area" VALUES('EPSG','2541','Germany - West Germany N','Germany - states of former West Germany - onshore north of 52°20''N.',52.33,55.09,6.58,11.59,0);
INSERT INTO "area" VALUES('EPSG','2542','Germany - West Germany C','Germany - states of former West Germany - between 50°20''N and 52°20''N.',50.33,52.34,5.86,12.03,0);
INSERT INTO "area" VALUES('EPSG','2543','Germany - West Germany S','Germany - states of former West Germany - south of 50°20''N.',47.27,50.34,6.11,13.84,0);
INSERT INTO "area" VALUES('EPSG','2544','Germany - Thuringen','Germany - Thuringen.',50.2,51.64,9.92,12.56,0);
INSERT INTO "area" VALUES('EPSG','2545','Germany - Saxony','Germany - Sachsen.',50.2,51.66,11.89,15.04,0);
INSERT INTO "area" VALUES('EPSG','2546','Romania - offshore','Romania - offshore.',43.44,45.2,28.64,31.41,0);
INSERT INTO "area" VALUES('EPSG','2547','Serbia and Montenegro - Montenegro','Serbia and Montenegro - Montenegro.',41.82,43.53,18.44,20.37,1);
INSERT INTO "area" VALUES('EPSG','2548','Africa - AOF west of 10°W','French West Africa onshore west of 10°W - Guinea, Mali, Mauritania, Senegal.',8.29,26.01,-17.59,-10.0,0);
INSERT INTO "area" VALUES('EPSG','2549','Africa - AOF 10°W to 3.5°W','French West Africa between 10°W and 3°30''W - Burkina Faso, Côte d''Ivoire (Ivory Coast), Guinea, Mali, Mauritania.',4.29,27.3,-10.0,-3.49,0);
INSERT INTO "area" VALUES('EPSG','2550','Africa - AOF 3.5°W to 4°E','French West Africa onshore between 3°30''W and 4°E - Benin, Burkina Faso, Côte d''Ivoire (Ivory Coast), Mali, Niger, Togo.',5.03,24.18,-3.5,4.0,0);
INSERT INTO "area" VALUES('EPSG','2551','Africa - AOF 4°E to 9°E','French West Africa between 4°E and 9°E - Mali, Niger.',12.82,21.79,4.0,9.0,0);
INSERT INTO "area" VALUES('EPSG','2552','Africa - AEF 9°E to 14°E','French Equatorial Africa onshore west of 14°E - Cameroon, Chad, Congo, Gabon, Niger - between 9°E and 14°E.',-5.06,23.53,8.45,14.0,0);
INSERT INTO "area" VALUES('EPSG','2553','Africa - AEF 14°E to 21°E','French Equatorial Africa between 14°E and 21°E - Cameroon, Central African Republic, Chad, Congo, Gabon, Niger.',-4.91,23.46,14.0,21.0,0);
INSERT INTO "area" VALUES('EPSG','2554','Africa - AEF east of 21°E','French Equatorial Africa east of 21°E - Central African Republic, Chad.',4.12,21.06,21.0,27.46,0);
INSERT INTO "area" VALUES('EPSG','2555','Cameroon - coastal area','Cameroon - coastal area.',2.16,4.99,8.45,10.4,0);
INSERT INTO "area" VALUES('EPSG','2556','Greenland - north of 81°N','Greenland - onshore north of 81°N.',81.0,83.67,-65.06,-11.81,0);
INSERT INTO "area" VALUES('EPSG','2557','Greenland - east - 78°N to 81°N','Greenland - east of 44°W and between 78°N and 81°N, onshore.',78.0,81.0,-44.0,-14.33,0);
INSERT INTO "area" VALUES('EPSG','2558','Greenland - east - 75°N to 78°N','Greenland - east of 44°W and between 75°N and 78°N, onshore.',75.0,78.0,-44.0,-17.12,0);
INSERT INTO "area" VALUES('EPSG','2559','Greenland - east - 72°N to 75°N','Greenland - east of 38°W and between 72°N and 75°N, onshore.',72.0,75.0,-38.0,-17.21,0);
INSERT INTO "area" VALUES('EPSG','2560','Greenland - east - 69°N to 72°N','Greenland - east of 38°W and between 69°N and 72°N, onshore.',69.0,72.0,-38.0,-21.32,0);
INSERT INTO "area" VALUES('EPSG','2561','Greenland - east - 66°N to 69°N','Greenland - east of 42°W and between 66°N and 69°N, onshore.',66.0,69.0,-42.0,-25.14,0);
INSERT INTO "area" VALUES('EPSG','2562','Greenland - east - 63°N to 66°N','Greenland - east of 46°W and between 63°N and 66°N, onshore.',63.0,66.0,-46.0,-36.0,0);
INSERT INTO "area" VALUES('EPSG','2563','Greenland - west - 78°N to 81°N','Greenland - west of 44°W and between 78°N and 81°N, onshore.',78.0,81.0,-73.29,-44.0,0);
INSERT INTO "area" VALUES('EPSG','2564','Greenland - west - 75°N to 78°N','Greenland - west of 44°W and between 75°N and 78°N, onshore.',75.0,78.0,-72.79,-44.0,0);
INSERT INTO "area" VALUES('EPSG','2565','Greenland - west - 72°N to 75°N','Greenland - west of 38°W and between 72°N and 75°N, onshore.',72.0,75.0,-58.21,-38.0,0);
INSERT INTO "area" VALUES('EPSG','2566','Greenland - west - 69°N to 72°N','Greenland - west of 38°W and between 69°N and 72°N, onshore.',69.0,72.0,-56.06,-38.0,0);
INSERT INTO "area" VALUES('EPSG','2567','Greenland - west - 66°N to 69°N','Greenland - west of 42°W and between 66°N and 69°N, onshore.',66.0,69.0,-54.09,-42.0,0);
INSERT INTO "area" VALUES('EPSG','2568','Greenland - west - 63°N to 66°N','Greenland - west of 46°W and between 63°N and 66°N, onshore.',63.0,66.0,-53.7,-46.0,0);
INSERT INTO "area" VALUES('EPSG','2569','Greenland - south of 63°N','Greenland - onshore south of 63°N.',59.74,63.0,-50.72,-41.33,0);
INSERT INTO "area" VALUES('EPSG','2570','Greenland - Scoresbysund area','Greenland - Scoresbysund area onshore.',68.66,74.58,-29.69,-19.89,0);
INSERT INTO "area" VALUES('EPSG','2571','Greenland - Ammassalik area','Greenland - Ammassalik area onshore.',65.52,65.91,-38.86,-36.81,0);
INSERT INTO "area" VALUES('EPSG','2572','Greenland - southwest coast east of 48°W','Greenland - southwest coast east of 48°W.',59.74,62.05,-48.0,-42.52,0);
INSERT INTO "area" VALUES('EPSG','2573','Greenland - southwest coast 54°W to 48°W','Greenland - southwest coast between 54°W and 48°W.',60.63,73.05,-54.0,-48.0,0);
INSERT INTO "area" VALUES('EPSG','2574','Congo - coastal area and offshore','Congo - coastal area and offshore.',-6.91,-3.55,8.84,12.34,0);
INSERT INTO "area" VALUES('EPSG','2575','Australia - onshore','Australia - Australian Capital Territory; New South Wales; Northern Territory; Queensland; South Australia; Tasmania; Western Australia; Victoria.',-43.7,-9.86,112.85,153.69,0);
INSERT INTO "area" VALUES('EPSG','2576','Australia - AGD84','Australia - Queensland, South Australia, Western Australia, federal areas offshore west of 129°E.',-38.53,-9.37,109.23,153.61,0);
INSERT INTO "area" VALUES('EPSG','2577','Indonesia - Java Sea - offshore northwest Java','Indonesia - southern Java Sea offshore northwest Java.',-6.89,-4.07,105.77,110.01,0);
INSERT INTO "area" VALUES('EPSG','2578','Slovenia - upper Soca Valley','Slovenia - upper Soca Valley and Julian Alps.',46.16,46.49,13.38,13.87,0);
INSERT INTO "area" VALUES('EPSG','2579','Slovenia - Gorica','Slovenia - Gorica region including the Trnovo Forest, Nanos and Idrija Mountains.',45.77,46.18,13.47,14.11,0);
INSERT INTO "area" VALUES('EPSG','2580','Slovenia - upper Savinja','Slovenia - upper Savinja region with part of Koroska (Slovene Carinthia).',46.21,46.56,14.55,15.0,0);
INSERT INTO "area" VALUES('EPSG','2581','Slovenia - Suha Krajina','Slovenia - Suha Krajina with the Ribnica and Zuzemberk area.',45.66,45.89,14.57,15.08,0);
INSERT INTO "area" VALUES('EPSG','2582','Slovenia - Karst','Slovenia - The Karst with part of the Gorica area.',45.64,45.9,13.57,14.12,0);
INSERT INTO "area" VALUES('EPSG','2583','Slovenia - Littoral onshore','Slovenia - the Slovene Littoral with parts of the Karst and the Brkini Hills - onshore.',45.44,45.73,13.5,14.24,0);
INSERT INTO "area" VALUES('EPSG','2584','Slovenia - Bela Krajina','Slovenia - Bela Krajina including the broad region of Crnomelj and Metlika.',45.42,45.74,15.06,15.36,0);
INSERT INTO "area" VALUES('EPSG','2585','Slovenia - Pohorje','Slovenia - Pohorje with the Paski Kozjak and Konjiska Gora (Mountain).',46.28,46.58,15.15,15.54,0);
INSERT INTO "area" VALUES('EPSG','2586','Slovenia - lower Posavje','Slovenia - lower Posavje (the Sava Basin) with part of the Kozjansko region.',45.81,46.17,15.2,15.73,0);
INSERT INTO "area" VALUES('EPSG','2587','Slovenia - Maribor and Ptuj','Slovenia - Maribor and Ptuj with parts of the Kozjak range and the Slovenske Gorice (the Slovene Humpback).',46.33,46.74,15.44,16.0,0);
INSERT INTO "area" VALUES('EPSG','2588','Indonesia - Bali Sea west','Indonesia - offshore Madura Strait and western Bali Sea.',-8.46,-6.8,112.8,117.01,0);
INSERT INTO "area" VALUES('EPSG','2589','Indonesia - West Papua - Tangguh','Indonesia - West Papua (formerly Irian Jaya) - Tangguh.',-2.94,-1.97,131.89,133.82,0);
INSERT INTO "area" VALUES('EPSG','2590','Cameroon - Garoua area','Cameroon - Garoua area.',8.92,9.87,12.9,14.19,0);
INSERT INTO "area" VALUES('EPSG','2591','Cameroon - N''Djamena area','Cameroon - N''Djamena area.',11.7,12.77,14.17,15.09,0);
INSERT INTO "area" VALUES('EPSG','2592','Azerbaijan - offshore and Sangachal','Azerbaijan - Caspian offshore and onshore Sangachal terminal.',37.89,42.59,48.66,51.73,0);
INSERT INTO "area" VALUES('EPSG','2593','Asia - FSU - Azerbaijan and Georgia','Azerbaijan (including Caspian) and Georgia onshore.',37.89,43.59,39.99,51.73,0);
INSERT INTO "area" VALUES('EPSG','2594','Azerbaijan - coastal area Baku to Astara','Azerbaijan - coastal area Baku to Astara.',38.31,40.33,48.93,50.4,0);
INSERT INTO "area" VALUES('EPSG','2595','Egypt - Western Desert','Egypt - Western Desert.',25.71,31.68,24.7,30.0,0);
INSERT INTO "area" VALUES('EPSG','2596','Argentina - Tierra del Fuego offshore west of 66°W','Argentina - Tierra del Fuego offshore Atlantic west of 66°W.',-54.61,-51.65,-68.62,-66.0,0);
INSERT INTO "area" VALUES('EPSG','2597','Argentina - Tierra del Fuego offshore east of 66°W','Argentina - Tierra del Fuego offshore Atlantic east of 66°W.',-54.93,-51.36,-66.0,-61.49,0);
INSERT INTO "area" VALUES('EPSG','2598','Algeria - District 3','Algeria - District 3 (In Salah).',25.0,32.0,1.0,3.3,0);
INSERT INTO "area" VALUES('EPSG','2599','Algeria - In Amenas','Algeria - In Amenas block.',27.5,28.3,8.83,9.92,0);
INSERT INTO "area" VALUES('EPSG','2600','Algeria - Hassi Bir Reikaz','Algeria - Hassi Bir Reikaz.',31.75,32.42,7.16,8.0,0);
INSERT INTO "area" VALUES('EPSG','2601','Norway - offshore north of 62°N; Svalbard','Norway - offshore north of 62°N. Also Svalbard.',62.0,84.17,-3.7,39.65,0);
INSERT INTO "area" VALUES('EPSG','2602','Palestine Territory','Palestine Territory.',31.21,32.55,34.17,35.58,0);
INSERT INTO "area" VALUES('EPSG','2603','Asia - Middle East - Israel and Palestine Territory onshore','Israel - onshore; Palestine Territory - onshore.',29.45,33.28,34.17,35.69,0);
INSERT INTO "area" VALUES('EPSG','2604','World - N hemisphere - 3-degree CM 048°E','Between 46°30''E and 49°30''E, northern hemisphere.',0.0,84.0,46.5,49.5,0);
INSERT INTO "area" VALUES('EPSG','2605','World - N hemisphere - 3-degree CM 051°E','Between 49°30''E and 52°30''E, northern hemisphere.',0.0,84.0,49.5,52.5,0);
INSERT INTO "area" VALUES('EPSG','2606','World - N hemisphere - 3-degree CM 054°E','Between 52°30''E and 55°30''E, northern hemisphere.',0.0,84.0,52.5,55.5,0);
INSERT INTO "area" VALUES('EPSG','2607','World - N hemisphere - 3-degree CM 057°E','Between 55°30''E and 58°30''E, northern hemisphere.',0.0,84.0,55.5,58.5,0);
INSERT INTO "area" VALUES('EPSG','2608','World - N hemisphere - 3-degree CM 060°E','Between 58°30''E and 61°30''E, northern hemisphere.',0.0,84.0,58.5,61.5,0);
INSERT INTO "area" VALUES('EPSG','2609','World - N hemisphere - 3-degree CM 063°E','Between 61°30''E and 64°30''E, northern hemisphere.',0.0,84.0,61.5,64.5,0);
INSERT INTO "area" VALUES('EPSG','2610','World - N hemisphere - 3-degree CM 066°E','Between 64°30''E and 67°30''E, northern hemisphere.',0.0,84.0,64.5,67.5,0);
INSERT INTO "area" VALUES('EPSG','2611','World - N hemisphere - 3-degree CM 069°E','Between 67°30''E and 70°30''E, northern hemisphere.',0.0,84.0,67.5,70.5,0);
INSERT INTO "area" VALUES('EPSG','2612','World - N hemisphere - 3-degree CM 072°E','Between 70°30''E and 73°30''E, northern hemisphere.',0.0,84.0,70.5,73.5,0);
INSERT INTO "area" VALUES('EPSG','2613','World - N hemisphere - 3-degree CM 075°E','Between 73°30''E and 76°30''E, northern hemisphere.',0.0,84.0,73.5,76.5,0);
INSERT INTO "area" VALUES('EPSG','2614','World - N hemisphere - 3-degree CM 078°E','Between 76°30''E and 79°30''E, northern hemisphere.',0.0,84.0,76.5,79.5,0);
INSERT INTO "area" VALUES('EPSG','2615','World - N hemisphere - 3-degree CM 081°E','Between 79°30''E and 82°30''E, northern hemisphere.',0.0,84.0,79.5,82.5,0);
INSERT INTO "area" VALUES('EPSG','2616','World - N hemisphere - 3-degree CM 084°E','Between 82°30''E and 85°30''E, northern hemisphere.',0.0,84.0,82.5,85.5,0);
INSERT INTO "area" VALUES('EPSG','2617','World - N hemisphere - 3-degree CM 087°E','Between 85°30''E and 88°30''E, northern hemisphere.',0.0,84.0,85.5,88.5,0);
INSERT INTO "area" VALUES('EPSG','2618','World - N hemisphere - 3-degree CM 090°E','Between 88°30''E and 91°30''E, northern hemisphere.',0.0,84.0,88.5,91.5,0);
INSERT INTO "area" VALUES('EPSG','2619','World - N hemisphere - 3-degree CM 093°E','Between 91°30''E and 94°30''E, northern hemisphere.',0.0,84.0,91.5,94.5,0);
INSERT INTO "area" VALUES('EPSG','2620','World - N hemisphere - 3-degree CM 096°E','Between 94°30''E and 97°30''E, northern hemisphere.',0.0,84.0,94.5,97.5,0);
INSERT INTO "area" VALUES('EPSG','2621','World - N hemisphere - 3-degree CM 099°E','Between 97°30''E and 100°30''E, northern hemisphere.',0.0,84.0,97.5,100.5,0);
INSERT INTO "area" VALUES('EPSG','2622','World - N hemisphere - 3-degree CM 102°E','Between 100°30''E and 103°30''E, northern hemisphere.',0.0,84.0,100.5,103.5,0);
INSERT INTO "area" VALUES('EPSG','2623','World - N hemisphere - 3-degree CM 105°E','Between 103°30''E and 106°30''E, northern hemisphere.',0.0,84.0,103.5,106.5,0);
INSERT INTO "area" VALUES('EPSG','2624','World - N hemisphere - 3-degree CM 108°E','Between 106°30''E and 109°30''E, northern hemisphere.',0.0,84.0,106.5,109.5,0);
INSERT INTO "area" VALUES('EPSG','2625','World - N hemisphere - 3-degree CM 111°E','Between 109°30''Eand 112°30''E, northern hemisphere.',0.0,84.0,109.5,112.5,0);
INSERT INTO "area" VALUES('EPSG','2626','World - N hemisphere - 3-degree CM 114°E','Between 112°30''E and 115°30''E, northern hemisphere.',0.0,84.0,112.5,115.5,0);
INSERT INTO "area" VALUES('EPSG','2627','World - N hemisphere - 3-degree CM 117°E','Between 115°30''E and 118°30''E, northern hemisphere.',0.0,84.0,115.5,118.5,0);
INSERT INTO "area" VALUES('EPSG','2628','World - N hemisphere - 3-degree CM 120°E','Between 118°30''E and 121°30''E, northern hemisphere.',0.0,84.0,118.5,121.5,0);
INSERT INTO "area" VALUES('EPSG','2629','World - N hemisphere - 3-degree CM 123°E','Between 121°30''E and 124°30''E, northern hemisphere.',0.0,84.0,121.5,124.5,0);
INSERT INTO "area" VALUES('EPSG','2630','World - N hemisphere - 3-degree CM 126°E','Between 124°30''E and 127°30''E, northern hemisphere.',0.0,84.0,124.5,127.5,0);
INSERT INTO "area" VALUES('EPSG','2631','World - N hemisphere - 3-degree CM 129°E','Between 127°30''E and 130°30''E, northern hemisphere.',0.0,84.0,127.5,130.5,0);
INSERT INTO "area" VALUES('EPSG','2632','World - N hemisphere - 3-degree CM 132°E','Between 130°30''E and 133°30''E, northern hemisphere.',0.0,84.0,130.5,133.5,0);
INSERT INTO "area" VALUES('EPSG','2633','World - N hemisphere - 3-degree CM 135°E','Between 133°30''E and 136°30''E, northern hemisphere.',0.0,84.0,133.5,136.5,0);
INSERT INTO "area" VALUES('EPSG','2634','World - N hemisphere - 3-degree CM 138°E','Between 136°30''E and 139°30''E, northern hemisphere.',0.0,84.0,136.5,139.5,0);
INSERT INTO "area" VALUES('EPSG','2635','World - N hemisphere - 3-degree CM 141°E','Between 139°30''E and 142°30''E, northern hemisphere.',0.0,84.0,139.5,142.5,0);
INSERT INTO "area" VALUES('EPSG','2636','World - N hemisphere - 3-degree CM 144°E','Between 142°30''E and 145°30''E, northern hemisphere.',0.0,84.0,142.5,145.5,0);
INSERT INTO "area" VALUES('EPSG','2637','World - N hemisphere - 3-degree CM 147°E','Between 145°30''E and 148°30''E, northern hemisphere.',0.0,84.0,145.5,148.5,0);
INSERT INTO "area" VALUES('EPSG','2638','World - N hemisphere - 3-degree CM 150°E','Between 148°30''E and 151°30''E, northern hemisphere.',0.0,84.0,148.5,151.5,0);
INSERT INTO "area" VALUES('EPSG','2639','World - N hemisphere - 3-degree CM 153°E','Between 151°30''E and 154°30''E, northern hemisphere.',0.0,84.0,151.5,154.5,0);
INSERT INTO "area" VALUES('EPSG','2640','World - N hemisphere - 3-degree CM 156°E','Between 154°30''E and 157°30''E, northern hemisphere.',0.0,84.0,154.5,157.5,0);
INSERT INTO "area" VALUES('EPSG','2641','World - N hemisphere - 3-degree CM 159°E','Between 157°30''E and 160°30''E, northern hemisphere.',0.0,84.0,157.5,160.5,0);
INSERT INTO "area" VALUES('EPSG','2642','World - N hemisphere - 3-degree CM 162°E','Between 160°30''E and 163°30''E, northern hemisphere.',0.0,84.0,160.5,163.5,0);
INSERT INTO "area" VALUES('EPSG','2643','World - N hemisphere - 3-degree CM 165°E','Between 163°30''E and 166°30''E, northern hemisphere.',0.0,84.0,163.5,166.5,0);
INSERT INTO "area" VALUES('EPSG','2644','World - N hemisphere - 3-degree CM 168°E','Between 166°30''E and 169°30''E, northern hemisphere.',0.0,84.0,166.5,169.5,0);
INSERT INTO "area" VALUES('EPSG','2645','World - N hemisphere - 3-degree CM 171°E','Between 169°30''E and 172°30''E, northern hemisphere.',0.0,84.0,169.5,172.5,0);
INSERT INTO "area" VALUES('EPSG','2646','World - N hemisphere - 3-degree CM 174°E','Between 172°30''E and 175°30''E, northern hemisphere.',0.0,84.0,172.5,175.5,0);
INSERT INTO "area" VALUES('EPSG','2647','World - N hemisphere - 3-degree CM 177°E','Between 175°30''E and 178°30''E, northern hemisphere.',0.0,84.0,175.5,178.5,0);
INSERT INTO "area" VALUES('EPSG','2648','World - N hemisphere - 3-degree CM 180°E','Between 178°30''E and 178°30''W, northern hemisphere.',0.0,84.0,178.5,-178.5,0);
INSERT INTO "area" VALUES('EPSG','2649','World - N hemisphere - 3-degree CM 177°W','Between 178°30''W and 175°30''W, northern hemisphere.',0.0,84.0,-178.5,-175.5,0);
INSERT INTO "area" VALUES('EPSG','2650','World - N hemisphere - 3-degree CM 174°W','Between 175°30''W and 172°30''W, northern hemisphere.',0.0,84.0,-175.5,-172.5,0);
INSERT INTO "area" VALUES('EPSG','2651','World - N hemisphere - 3-degree CM 171°W','Between 172°30''W and 169°30''W, northern hemisphere.',0.0,84.0,-172.5,-169.5,0);
INSERT INTO "area" VALUES('EPSG','2652','World - N hemisphere - 3-degree CM 168°W','Between 169°30''W and 166°30''W, northern hemisphere.',0.0,84.0,-169.5,-166.5,0);
INSERT INTO "area" VALUES('EPSG','2653','Europe - FSU - 19.5°E to 22.5°E onshore','Estonia, Latvia, Lithuania, Russian Federation (Kaliningrad) and Ukraine - onshore between 19°30''E and 22°30''E.',48.24,59.1,19.57,22.5,0);
INSERT INTO "area" VALUES('EPSG','2654','Europe - FSU - 22.5°E to 25.5°E onshore','Belarus, Estonia, Latvia, Lithuania, Russian Federation (Kaliningrad) and Ukraine - onshore between 22°30''E and 25°30''E.',47.71,59.75,22.5,25.5,0);
INSERT INTO "area" VALUES('EPSG','2655','Europe - FSU - 25.5°E to 28.5°E onshore','Belarus, Estonia, Latvia, Lithuania, Moldova, Russian Federation and Ukraine - onshore between 25°30''E and 28°30''E.',45.26,68.93,25.49,28.51,0);
INSERT INTO "area" VALUES('EPSG','2656','Europe - FSU - 28.5°E to 31.5°E onshore','Belarus, Moldova, Russian Federation and Ukraine - onshore between 28°30''E and 31°30''E.',45.18,69.85,28.5,31.5,0);
INSERT INTO "area" VALUES('EPSG','2657','Europe - FSU - 31.5°E to 34.5°E onshore','Belarus, Russian Federation and Ukraine - onshore between 31°30''E and 34°30''E.',44.32,70.02,31.5,34.5,0);
INSERT INTO "area" VALUES('EPSG','2658','Europe - FSU - 34.5°E to 37.5°E onshore','Russian Federation and Ukraine - onshore between 34°30''E and 37°30''E.',44.61,69.39,34.5,37.5,0);
INSERT INTO "area" VALUES('EPSG','2659','Europe - FSU - 37.5°E to 40.5°E onshore','Georgia, Russian Federation and Ukraine - onshore between 37°30''E and 40°30''E.',43.07,68.8,37.5,40.5,0);
INSERT INTO "area" VALUES('EPSG','2660','Europe - FSU - 40.5°E to 43.5°E onshore','Georgia, Russian Federation - onshore between 40°30''E and 43°30''E.',41.01,68.74,40.5,43.51,0);
INSERT INTO "area" VALUES('EPSG','2661','Europe - FSU - 43.5°E to 46.5°E onshore','Armenia, Azerbaijan, Georgia and Russian Federation onshore - between 43°30''E and 46°30''E.',38.84,80.8,43.5,46.5,0);
INSERT INTO "area" VALUES('EPSG','2662','Europe - FSU - 46.5°E to 49.5°E onshore','Azerbaijan, Georgia, Kazakhstan and Russian Federation onshore - between 46°30''E and 49°30''E.',38.31,80.91,46.5,49.5,0);
INSERT INTO "area" VALUES('EPSG','2663','Asia - FSU - 49.5°E to 52.5°E onshore','Azerbaijan, Kazakhstan and Russian Federation onshore - between 49°30''E and 52°30''E.',37.66,81.22,49.5,52.5,0);
INSERT INTO "area" VALUES('EPSG','2664','Asia - FSU - 52.5°E to 55.5°E onshore','Kazakhstan, Russian Federation onshore and Turkmenistan - between 52°30''E and 55°30''E.',37.33,81.41,52.5,55.5,0);
INSERT INTO "area" VALUES('EPSG','2665','Asia - FSU - 55.5°E to 58.5°E onshore','Kazakhstan, Russian Federation onshore, Turkmenistan and Uzbekistan - between 55°30''E and 58°30''E.',37.64,81.89,55.5,58.5,0);
INSERT INTO "area" VALUES('EPSG','2666','Asia - FSU - 58.5°E to 61.5°E onshore','Kazakhstan, Russian Federation onshore, Turkmenistan and Uzbekistan - between 58°30''E and 61°30''E.',35.51,81.91,58.5,61.5,0);
INSERT INTO "area" VALUES('EPSG','2667','Asia - FSU - 61.5°E to 64.5°E onshore','Kazakhstan, Russian Federation onshore, Turkmenistan and Uzbekistan - between 61°30''E and 64°30''E.',35.14,81.77,61.5,64.5,0);
INSERT INTO "area" VALUES('EPSG','2668','Asia - FSU - 64.5°E to 67.5°E onshore','Kazakhstan, Russian Federation onshore, Tajikistan, Turkmenistan and Uzbekistan - between 64°30''E and 67°30''E.',36.27,81.25,64.5,67.5,0);
INSERT INTO "area" VALUES('EPSG','2669','Asia - FSU - 67.5°E to 70.5°E onshore','Kazakhstan, Kyrgyzstan, Russian Federation onshore, Tajikistan and Uzbekistan - between 67°30''E and 70°30''E.',36.93,77.07,67.5,70.5,0);
INSERT INTO "area" VALUES('EPSG','2670','Asia - FSU - 70.5°E to 73.5°E onshore','Kazakhstan, Kyrgyzstan, Russian Federation onshore, Tajikistan and Uzbekistan - between 70°30''E and 73°30''E.',36.67,73.57,70.5,73.5,0);
INSERT INTO "area" VALUES('EPSG','2671','Asia - FSU - 73.5°E to 76.5°E onshore','Kazakhstan, Kyrgyzstan, Russian Federation onshore and Tajikistan - between 73°30''E and 76°30''E.',37.22,79.71,73.5,76.5,0);
INSERT INTO "area" VALUES('EPSG','2672','Asia - FSU - 76.5°E to 79.5°E onshore','Kazakhstan, Kyrgyzstan and Russian Federation onshore - between 76°30''E and 79°30''E.',40.44,81.03,76.5,79.5,0);
INSERT INTO "area" VALUES('EPSG','2673','Asia - FSU - 79.5°E to 82.5°E onshore','Kazakhstan, Kyrgyzstan and Russian Federation onshore - between 79°30''E and 82°30''E.',41.82,81.03,79.5,82.5,0);
INSERT INTO "area" VALUES('EPSG','2674','Asia - FSU - 82.5°E to 85.5°E onshore','Kazakhstan and Russian Federation onshore - between 82°30''E and 85°30''E.',45.11,77.56,82.5,85.5,0);
INSERT INTO "area" VALUES('EPSG','2675','Asia - FSU - 85.5°E to 88.5°E onshore','Kazakhstan and Russian Federation onshore - between 85°30''E and 88°30''E.',47.05,77.16,85.5,88.5,0);
INSERT INTO "area" VALUES('EPSG','2676','Russia - 88.5°E to 91.5°E onshore','Russian Federation - onshore between 88°30''E and 91°30''E.',49.44,81.28,88.5,91.5,0);
INSERT INTO "area" VALUES('EPSG','2677','Russia - 91.5°E to 94.5°E onshore','Russian Federation - onshore between 91°30''E and 94°30''E.',50.16,81.26,91.5,94.5,0);
INSERT INTO "area" VALUES('EPSG','2678','Russia - 94.5°E to 97.5°E onshore','Russian Federation - onshore between 94°30''E and 97°30''E.',49.73,81.35,94.5,97.5,0);
INSERT INTO "area" VALUES('EPSG','2679','Russia - 97.5°E to 100.5°E onshore','Russian Federation - onshore between 97°30''E and 100°30''E.',49.79,80.9,97.5,100.5,0);
INSERT INTO "area" VALUES('EPSG','2680','Russia - 100.5°E to 103.5°E onshore','Russian Federation - onshore between 100°30''E and 103°30''E.',50.17,79.71,100.5,103.5,0);
INSERT INTO "area" VALUES('EPSG','2681','Russia - 103.5°E to 106.5°E onshore','Russian Federation - onshore between 103°30''E and 106°30''E.',50.13,79.21,103.5,106.5,0);
INSERT INTO "area" VALUES('EPSG','2682','Russia - 106.5°E to 109.5°E onshore','Russian Federation - onshore between 106°30''E and 109°30''E.',49.25,78.4,106.5,109.5,0);
INSERT INTO "area" VALUES('EPSG','2683','Russia - 109.5°E to 112.5°E onshore','Russian Federation - onshore between 109°30''E and 112°30''E.',49.14,76.81,109.5,112.5,0);
INSERT INTO "area" VALUES('EPSG','2684','Russia - 112.5°E to 115.5°E onshore','Russian Federation - onshore between 112°30''E and 115°30''E.',49.49,76.7,112.5,115.5,0);
INSERT INTO "area" VALUES('EPSG','2685','Russia - 115.5°E to 118.5°E onshore','Russian Federation - onshore between 115°30''E and 118°30''E.',49.51,74.43,115.5,118.5,0);
INSERT INTO "area" VALUES('EPSG','2686','Russia - 118.5°E to 121.5°E onshore','Russian Federation - onshore between 118°30''E and 121°30''E.',49.87,73.63,118.5,121.5,0);
INSERT INTO "area" VALUES('EPSG','2687','Russia - 121.5°E to 124.5°E onshore','Russian Federation - onshore between 121°30''E and 124°30''E.',53.18,74.0,121.5,124.5,0);
INSERT INTO "area" VALUES('EPSG','2688','Russia - 124.5°E to 127.5°E onshore','Russian Federation - onshore between 124°30''E and 127°30''E.',49.88,74.0,124.5,127.5,0);
INSERT INTO "area" VALUES('EPSG','2689','Russia - 127.5°E to 130.5°E onshore','Russian Federation - onshore between 127°30''E and 130°30''E.',42.67,73.59,127.5,130.5,0);
INSERT INTO "area" VALUES('EPSG','2690','Russia - 130.5°E to 133.5°E onshore','Russian Federation - onshore between 130°30''E and 133°30''E.',42.25,71.99,130.5,133.5,0);
INSERT INTO "area" VALUES('EPSG','2691','Russia - 133.5°E to 136.5°E onshore','Russian Federation - onshore between 133°30''E and 136°30''E.',42.74,75.9,133.5,136.5,0);
INSERT INTO "area" VALUES('EPSG','2692','Russia - 136.5°E to 139.5°E onshore','Russian Federation - onshore between 136°30''E and 139°30''E.',44.76,76.27,136.5,139.5,0);
INSERT INTO "area" VALUES('EPSG','2693','Russia - 139.5°E to 142.5°E onshore','Russian Federation - onshore between 139°30''E and 142°30''E.',45.84,76.23,139.5,142.5,0);
INSERT INTO "area" VALUES('EPSG','2694','Russia - 142.5°E to 145.5°E onshore','Russian Federation - onshore between 142°30''E and 145°30''E.',43.61,75.98,142.5,145.5,0);
INSERT INTO "area" VALUES('EPSG','2695','Russia - 145.5°E to 148.5°E onshore','Russian Federation - onshore between 145°30''E and 148°30''E.',43.6,76.76,145.5,148.5,0);
INSERT INTO "area" VALUES('EPSG','2696','Russia - 148.5°E to 151.5°E onshore','Russian Federation - onshore between 148°30''E and 151°30''E.',45.21,76.82,148.5,151.5,0);
INSERT INTO "area" VALUES('EPSG','2697','Russia - 151.5°E to 154.5°E onshore','Russian Federation - onshore between 151°30''E and 154°30''E.',46.72,76.26,151.5,154.5,0);
INSERT INTO "area" VALUES('EPSG','2698','Russia - 154.5°E to 157.5°E onshore','Russian Federation - onshore between 154°30''E and 157°30''E.',49.02,77.2,154.5,157.5,0);
INSERT INTO "area" VALUES('EPSG','2699','Russia - 157.5°E to 160.5°E onshore','Russian Federation - onshore between 157°30''E and 160°30''E.',51.36,71.12,157.5,160.5,0);
INSERT INTO "area" VALUES('EPSG','2700','Russia - 160.5°E to 163.5°E onshore','Russian Federation - onshore between 160°30''E and 163°30''E.',54.34,70.98,160.5,163.5,0);
INSERT INTO "area" VALUES('EPSG','2701','Russia - 163.5°E to 166.5°E onshore','Russian Federation - onshore between 163°30''E and 166°30''E.',54.69,69.82,163.5,166.5,0);
INSERT INTO "area" VALUES('EPSG','2702','Russia - 166.5°E to 169.5°E onshore','Russian Federation - onshore between 166°30''E and 169°30''E.',54.45,70.07,166.5,169.5,0);
INSERT INTO "area" VALUES('EPSG','2703','Russia - 169.5°E to 172.5°E onshore','Russian Federation - onshore between 169°30''E and 172°30''E.',59.86,70.19,169.5,172.5,0);
INSERT INTO "area" VALUES('EPSG','2704','Russia - 172.5°E to 175.5°E onshore','Russian Federation - onshore between 172°30''E and 175°30''E.',60.99,70.02,172.5,175.5,0);
INSERT INTO "area" VALUES('EPSG','2705','Russia - 175.5°E to 178.5°E onshore','Russian Federation - onshore between 175°30''E and 178°30''E.',62.09,71.1,175.5,178.5,0);
INSERT INTO "area" VALUES('EPSG','2706','Russia - 178.5°E to 178.5°W onshore','Russian Federation - onshore between 178°30''E and 178°30''W.',62.24,71.65,178.5,-178.5,0);
INSERT INTO "area" VALUES('EPSG','2707','Russia - 178.5°W to 175.5°W onshore','Russian Federation - onshore between 178°30''W and 175°30''W.',64.74,71.61,-178.5,-175.5,0);
INSERT INTO "area" VALUES('EPSG','2708','Russia - 175.5°W to 172.5°W onshore','Russian Federation - onshore between 175°30''W and 172°30''W.',64.2,67.78,-175.5,-172.5,0);
INSERT INTO "area" VALUES('EPSG','2709','Russia - 172.5°W to 169.5°W onshore','Russian Federation - onshore between 172°30''W and 169°30''W.',64.35,67.06,-172.5,-169.57,0);
INSERT INTO "area" VALUES('EPSG','2710','Russia - east of 169.5°W onshore','Russian Federation - onshore between 169°30''W and 166°30''W.',65.7,65.86,-169.22,-168.97,0);
INSERT INTO "area" VALUES('EPSG','2711','China - west of 76.5°E','China - west of 76°30''E.',35.81,40.65,73.62,76.5,0);
INSERT INTO "area" VALUES('EPSG','2712','China - 76.5°E to 79.5°E','China - between 76°30''E and 79°30''E.',31.03,41.83,76.5,79.5,0);
INSERT INTO "area" VALUES('EPSG','2713','China - 79.5°E to 82.5°E','China - between 79°30''E and 82°30''E.',29.95,45.88,79.5,82.51,0);
INSERT INTO "area" VALUES('EPSG','2714','China - 82.5°E to 85.5°E','China - between 82°30''E and 85°30''E.',28.26,47.23,82.5,85.5,0);
INSERT INTO "area" VALUES('EPSG','2715','China - 85.5°E to 88.5°E','China - between 85°30''E and 88°30''E.',27.8,49.18,85.5,88.5,0);
INSERT INTO "area" VALUES('EPSG','2716','China - 88.5°E to 91.5°E','China - between 88°30''E and 91°30''E.',27.32,48.42,88.49,91.51,0);
INSERT INTO "area" VALUES('EPSG','2717','China - 91.5°E to 94.5°E','China - between 91°30''E and 94°30''E.',27.71,45.13,91.5,94.5,0);
INSERT INTO "area" VALUES('EPSG','2718','China - 94.5°E to 97.5°E','China - between 94°30''E and 97°30''E.',28.23,44.5,94.5,97.51,0);
INSERT INTO "area" VALUES('EPSG','2719','China - 97.5°E to 100.5°E','China - between 97°30''E and 100°30''E.',21.43,42.76,97.5,100.5,0);
INSERT INTO "area" VALUES('EPSG','2720','China - 100.5°E to 103.5°E','China - between 100°30''E and 103°30''E.',21.13,42.69,100.5,103.5,0);
INSERT INTO "area" VALUES('EPSG','2721','China - 103.5°E to 106.5°E','China - between 103°30''E and 106°30''E.',22.5,42.21,103.5,106.5,0);
INSERT INTO "area" VALUES('EPSG','2722','China - 106.5°E to 109.5°E onshore','China - onshore between 106°30''E and 109°30''E.',18.19,42.47,106.5,109.5,0);
INSERT INTO "area" VALUES('EPSG','2723','China - 109.5°E to 112.5°E onshore','China - onshore between 109°30''E and 112°30''E.',18.11,45.11,109.5,112.5,0);
INSERT INTO "area" VALUES('EPSG','2724','China - 112.5°E to 115.5°E onshore','China - onshore between 112°30''E and 115°30''E.',21.52,45.45,112.5,115.5,0);
INSERT INTO "area" VALUES('EPSG','2725','China - 115.5°E to 118.5°E onshore','China - onshore between 115°30''E and 118°30''E.',22.6,49.88,115.5,118.5,0);
INSERT INTO "area" VALUES('EPSG','2726','China - 118.5°E to 121.5°E onshore','China - onshore between 118°30''E and 121°30''E.',24.43,53.33,118.5,121.5,0);
INSERT INTO "area" VALUES('EPSG','2727','China - 121.5°E to 124.5°E onshore','China - onshore between 121°30''E and 124°30''E.',28.22,53.56,121.5,124.5,0);
INSERT INTO "area" VALUES('EPSG','2728','China - 124.5°E to 127.5°E onshore','China - onshore between 124°30''E and 127°30''E.',40.19,53.2,124.5,127.5,0);
INSERT INTO "area" VALUES('EPSG','2729','China - 127.5°E to 130.5°E','China - between 127°30''E and 130°30''E.',41.37,50.25,127.5,130.5,0);
INSERT INTO "area" VALUES('EPSG','2730','China - 130.5°E to 133.5°E','China - between 130°30''E and 133°30''E.',42.42,48.88,130.5,133.5,0);
INSERT INTO "area" VALUES('EPSG','2731','China - east of 133.5°E','China - east of 133°30''E.',45.85,48.4,133.5,134.77,0);
INSERT INTO "area" VALUES('EPSG','2732','World - 6-degree CM 081°W','Between 84°W and 78°W.',-80.0,84.0,-84.0,-78.0,0);
INSERT INTO "area" VALUES('EPSG','2733','World - 6-degree CM 075°W','Between 78°W and 72°W.',-80.0,84.0,-78.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','2734','World - 6-degree CM 069°W','Between 72°W and 66°W.',-80.0,84.0,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','2735','World - 6-degree CM 063°W','Between 66°W and 60°W.',-80.0,84.0,-66.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','2736','World - 6-degree CM 057°W','Between 60°W and 54°W.',-80.0,84.0,-60.0,-54.0,0);
INSERT INTO "area" VALUES('EPSG','2737','World - 6-degree CM 051°W','Between 54°W and 48°W.',-80.0,84.0,-54.0,-48.0,0);
INSERT INTO "area" VALUES('EPSG','2738','World - 6-degree CM 045°W','Between 48°W and 42°W.',-80.0,84.0,-48.0,-42.0,0);
INSERT INTO "area" VALUES('EPSG','2739','World - 6-degree CM 039°W','Between 42°W and 36°W.',-80.0,84.0,-42.0,-36.0,0);
INSERT INTO "area" VALUES('EPSG','2740','World - 6-degree CM 033°W','Between 36°W and 30°W.',-80.0,84.0,-36.0,-30.0,0);
INSERT INTO "area" VALUES('EPSG','2741','World - 6-degree CM 009°E','Between 6°E and 12°E.',-80.0,84.0,6.0,12.0,0);
INSERT INTO "area" VALUES('EPSG','2742','World - 6-degree CM 015°E','Between 12°E and 18°E.',-80.0,84.0,12.0,18.0,0);
INSERT INTO "area" VALUES('EPSG','2743','World - 6-degree CM 021°E','Between 18°E and 24°E.',-80.0,84.0,18.0,24.0,0);
INSERT INTO "area" VALUES('EPSG','2744','World - 6-degree CM 027°E','Between 24°E and 30°E.',-80.0,84.0,24.0,30.0,0);
INSERT INTO "area" VALUES('EPSG','2745','World - 6-degree CM 033°E','Between 30°E and 36°E.',-80.0,84.0,30.0,36.0,0);
INSERT INTO "area" VALUES('EPSG','2746','World - 6-degree CM 039°E','Between 36°E and 42°E.',-80.0,84.0,36.0,42.0,0);
INSERT INTO "area" VALUES('EPSG','2747','Russia - 19.5°E to 22.5°E onshore','Russian Federation - Kaliningrad - onshore between 19°30''E and 22°30''E.',54.32,55.32,19.57,22.5,0);
INSERT INTO "area" VALUES('EPSG','2748','Russia - 22.5°E to 25.5°E onshore','Russian Federation - onshore between 22°30''E and 25°30''E - Kaliningrad.',54.34,55.07,22.5,22.87,0);
INSERT INTO "area" VALUES('EPSG','2749','Russia - 25.5°E to 28.5°E onshore','Russian Federation - onshore between 25°30''E and 28°30''E.',56.05,68.93,26.61,28.51,0);
INSERT INTO "area" VALUES('EPSG','2750','Russia - 28.5°E to 31.5°E onshore','Russian Federation - onshore between 28°30''E and 31°30''E.',52.85,69.85,28.5,31.5,0);
INSERT INTO "area" VALUES('EPSG','2751','Russia - 31.5°E to 34.5°E onshore','Russian Federation - onshore between 31°30''E and 34°30''E.',51.24,70.02,31.5,34.5,0);
INSERT INTO "area" VALUES('EPSG','2752','Russia - 34.5°E to 37.5°E onshore','Russian Federation - onshore between 34°30''E and 37°30''E.',44.61,69.39,34.5,37.51,0);
INSERT INTO "area" VALUES('EPSG','2753','Russia - 37.5°E to 40.5°E onshore','Russian Federation - onshore between 37°30''E and 40°30''E.',43.33,68.8,37.5,40.5,0);
INSERT INTO "area" VALUES('EPSG','2754','Russia - 40.5°E to 43.5°E onshore','Russian Federation - onshore between 40°30''E and 43°30''E.',42.87,68.74,40.5,43.5,0);
INSERT INTO "area" VALUES('EPSG','2755','Russia - 43.5°E to 46.5°E onshore','Russian Federation - onshore between 43°30''E and 46°30''E.',41.89,80.8,43.5,46.5,0);
INSERT INTO "area" VALUES('EPSG','2756','Russia - 46.5°E to 49.5°E onshore','Russian Federation - onshore between 46°30''E and 49°30''E.',41.19,80.91,46.5,49.5,0);
INSERT INTO "area" VALUES('EPSG','2757','Russia - 49.5°E to 52.5°E onshore','Russian Federation - onshore between 49°30''E and 52°30''E.',42.36,81.22,49.5,52.5,0);
INSERT INTO "area" VALUES('EPSG','2758','Russia - 52.5°E to 55.5°E onshore','Russian Federation - onshore between 52°30''E and 55°30''E.',50.52,81.41,52.5,55.5,0);
INSERT INTO "area" VALUES('EPSG','2759','Russia - 55.5°E to 58.5°E onshore','Russian Federation - onshore between 55°30''E and 58°30''E.',50.53,81.89,55.5,58.5,0);
INSERT INTO "area" VALUES('EPSG','2760','Russia - 58.5°E to 61.5°E onshore','Russian Federation - onshore between 58°30''E and 61°30''E.',50.47,81.91,58.5,61.5,0);
INSERT INTO "area" VALUES('EPSG','2761','Russia - 61.5°E to 64.5°E onshore','Russian Federation - onshore between 61°30''E and 64°30''E.',51.03,81.77,61.5,64.5,0);
INSERT INTO "area" VALUES('EPSG','2762','Russia - 64.5°E to 67.5°E onshore','Russian Federation - onshore between 64°30''E and 67°30''E.',54.31,81.25,64.5,67.5,0);
INSERT INTO "area" VALUES('EPSG','2763','Russia - 67.5°E to 70.5°E onshore','Russian Federation - onshore between 67°30''E and 70°30''E.',54.85,77.07,67.5,70.5,0);
INSERT INTO "area" VALUES('EPSG','2764','Russia - 70.5°E to 73.5°E onshore','Russian Federation - onshore between 70°30''E and 73°30''E.',53.43,73.57,70.5,73.5,0);
INSERT INTO "area" VALUES('EPSG','2765','Russia - 73.5°E to 76.5°E onshore','Russian Federation - onshore between 73°30''E and 76°30''E.',53.47,79.71,73.5,76.5,0);
INSERT INTO "area" VALUES('EPSG','2766','Russia - 76.5°E to 79.5°E onshore','Russian Federation - onshore between 76°30''E and 79°30''E.',51.49,81.03,76.5,79.5,0);
INSERT INTO "area" VALUES('EPSG','2767','Russia - 79.5°E to 82.5°E onshore','Russian Federation - onshore between 79°30''E and 82°30''E.',50.7,81.03,79.5,82.5,0);
INSERT INTO "area" VALUES('EPSG','2768','Russia - 82.5°E to 85.5°E onshore','Russian Federation - onshore between 82°30''E and 85°30''E.',49.58,77.56,82.5,85.5,0);
INSERT INTO "area" VALUES('EPSG','2769','Russia - 85.5°E to 88.5°E onshore','Russian Federation - onshore between 85°30''E and 88°30''E.',49.07,77.16,85.5,88.5,0);
INSERT INTO "area" VALUES('EPSG','2770','Indonesia - northeast Kalimantan','Indonesia - northeast Kalimantan.',-0.07,4.29,116.96,119.06,0);
INSERT INTO "area" VALUES('EPSG','2771','Niger - southeast','Niger - southeast',12.8,16.7,7.81,14.9,0);
INSERT INTO "area" VALUES('EPSG','2772','Asia - FSU - CS63 zone A1','Armenia and Georgia onshore west of 43°02''E.',41.37,43.59,39.99,43.04,0);
INSERT INTO "area" VALUES('EPSG','2773','Asia - FSU - CS63 zone A2','Armenia and Georgia between 43°02''E and 46°02''E; Azerbaijan west of 46°02''E.',38.87,43.05,43.03,46.04,0);
INSERT INTO "area" VALUES('EPSG','2774','Asia - FSU - CS63 zone A3','Armenia and Georgia east of 46°02''E; Azerbaijan between 46°02'' and 49°02''E.',38.38,42.1,46.03,49.04,0);
INSERT INTO "area" VALUES('EPSG','2775','Asia - FSU - CS63 zone A4','Azerbaijan east of 49°02''E.',37.89,42.59,49.03,51.73,0);
INSERT INTO "area" VALUES('EPSG','2776','Asia - FSU - CS63 zone K2','Kazakhstan between 49°16''E and 52°16''E.',41.15,51.77,49.26,52.27,0);
INSERT INTO "area" VALUES('EPSG','2777','Asia - FSU - CS63 zone K3','Kazakhstan between 52°16''E and 55°16''E.',41.46,51.79,52.26,55.27,0);
INSERT INTO "area" VALUES('EPSG','2778','Asia - FSU - CS63 zone K4','Kazakhstan between 55°16''E and 58°16''E.',41.26,51.14,55.26,58.27,0);
INSERT INTO "area" VALUES('EPSG','2779','Portugal - Selvagens onshore','Portugal - Selvagens islands (Madeira province) - onshore.',29.98,30.21,-16.11,-15.79,0);
INSERT INTO "area" VALUES('EPSG','2780','Malaysia - East Malaysia - offshore SCS','Malaysia - East Malaysia (Sabah; Sarawak) - offshore South China Sea.',1.56,7.67,109.31,117.31,0);
INSERT INTO "area" VALUES('EPSG','2781','Iran - Kharg Island','Iran - Kharg Island.',29.16,29.39,50.22,50.42,0);
INSERT INTO "area" VALUES('EPSG','2782','Iran - Lavan Island and Balal field','Iran - Lavan Island and Balal field.',26.21,26.87,52.49,53.43,0);
INSERT INTO "area" VALUES('EPSG','2783','Iran - South Pars blocks 2 and 3','Iran - South Pars field phases 2 and 3.',26.58,26.71,52.07,52.28,0);
INSERT INTO "area" VALUES('EPSG','2784','Canada - south of 60°N','Canada south of 60°N - Alberta, British Columbia (BC), Manitoba, New Brunswick (NB), Newfoundland and Labrador, Nova Scotia (NS), Ontario, Prince Edward Island (PEI), Quebec and Saskatchewan.',41.68,60.0,-139.05,-52.62,1);
INSERT INTO "area" VALUES('EPSG','2785','Libya - Murzuq and En Naga','Libya - Murzuq and En Naga fields.',27.32,27.67,18.37,18.72,0);
INSERT INTO "area" VALUES('EPSG','2786','Libya - Mabruk','Libya - Mabruk field.',29.61,30.07,17.13,17.51,0);
INSERT INTO "area" VALUES('EPSG','2787','Morocco - south of 31.5°N','Morocco onshore south of 35 grads North (31°30''N).',27.66,31.51,-13.24,-3.59,0);
INSERT INTO "area" VALUES('EPSG','2788','Western Sahara - north of 24.3°N','Western Sahara - onshore north of 27grads North (24°18''N).',24.29,27.67,-15.42,-8.66,0);
INSERT INTO "area" VALUES('EPSG','2789','Western Sahara - south of 24.3°N','Western Sahara - onshore south of 27grads North (24°18''N).',20.71,24.31,-17.16,-12.0,0);
INSERT INTO "area" VALUES('EPSG','2790','Africa - 12th parallel N','Senegal - central, Mali - southwest, Burkina Faso - central, Niger - southwest, Nigeria - north, Chad - central. All in proximity to the parallel of latitude of 12°N.',10.26,15.7,-17.19,30.42,0);
INSERT INTO "area" VALUES('EPSG','2791','Africa - Burkina Faso and SW Niger','Burkina Faso - central; Niger - southwest, in proximity to the parallel of latitude of 12°N.',11.83,14.23,-4.64,4.0,0);
INSERT INTO "area" VALUES('EPSG','2792','UK - Great Britain mainland onshore','United Kingdom (UK) - Great Britain onshore - England and Wales - mainland; Scotland - mainland and Inner Hebrides.',49.93,58.71,-7.06,1.8,0);
INSERT INTO "area" VALUES('EPSG','2793','UK - Orkney Islands onshore','United Kingdom (UK) - Great Britain - Scotland - Orkney Islands onshore.',58.72,59.41,-3.48,-2.34,0);
INSERT INTO "area" VALUES('EPSG','2794','UK - Fair Isle onshore','United Kingdom (UK) - Great Britain - Scotland - Fair Isle onshore.',59.45,59.6,-1.76,-1.5,0);
INSERT INTO "area" VALUES('EPSG','2795','UK - Shetland Islands onshore','United Kingdom (UK) - Great Britain - Scotland - Shetland Islands onshore.',59.83,60.87,-1.78,-0.67,0);
INSERT INTO "area" VALUES('EPSG','2796','UK - Foula onshore','United Kingdom (UK) - Great Britain - Scotland - Foula onshore.',60.06,60.2,-2.21,-1.95,0);
INSERT INTO "area" VALUES('EPSG','2797','UK - Sule Skerry onshore','United Kingdom (UK) - Great Britain - Scotland - Sule Skerry onshore.',59.05,59.13,-4.5,-4.3,0);
INSERT INTO "area" VALUES('EPSG','2798','UK - North Rona onshore','United Kingdom (UK) - Great Britain - Scotland - North Rona onshore.',59.07,59.19,-5.92,-5.73,0);
INSERT INTO "area" VALUES('EPSG','2799','UK - Outer Hebrides onshore','United Kingdom (UK) - Great Britain - Scotland - Outer Hebrides onshore.',56.76,58.54,-7.72,-6.1,0);
INSERT INTO "area" VALUES('EPSG','2800','UK - St. Kilda onshore','United Kingdom (UK) - Great Britain - Scotland - St Kilda onshore.',57.74,57.93,-8.74,-8.41,0);
INSERT INTO "area" VALUES('EPSG','2801','UK - Flannan Isles onshore','United Kingdom (UK) - Great Britain - Scotland - Flannan Isles onshore.',58.21,58.35,-7.75,-7.46,0);
INSERT INTO "area" VALUES('EPSG','2802','UK - Scilly Isles onshore','United Kingdom (UK) - Great Britain - England - Isles of Scilly onshore.',49.86,49.99,-6.41,-6.23,0);
INSERT INTO "area" VALUES('EPSG','2803','Isle of Man - onshore','Isle of Man - onshore.',54.02,54.44,-4.87,-4.27,0);
INSERT INTO "area" VALUES('EPSG','2804','Europe - Austria and FR Yugoslavia','Austria; Boznia and Herzegovina; Croatia; Czech Republic; FYR Macedonia; Montenegro; Serbia; Slovakia; Slovenia.',40.86,51.05,9.53,23.03,1);
INSERT INTO "area" VALUES('EPSG','2805','Chile - Tierra del Fuego','Chile - Tierra del Fuego onshore.',-55.96,-51.99,-74.83,-66.33,0);
INSERT INTO "area" VALUES('EPSG','2806','Iran - northern Gulf coast','Iran - northern Gulf coast area.',29.0,31.67,47.75,50.83,1);
INSERT INTO "area" VALUES('EPSG','2807','Comoros - Njazidja (Grande Comore)','Comoros - Njazidja (Grande Comore).',-11.99,-11.31,43.16,43.55,0);
INSERT INTO "area" VALUES('EPSG','2808','Comoros - Nzwani','Comoros - Nzwani.',-12.43,-12.02,44.16,44.59,0);
INSERT INTO "area" VALUES('EPSG','2809','Comoros - Mwali','Comoros - Mwali.',-12.44,-12.19,43.57,43.92,0);
INSERT INTO "area" VALUES('EPSG','2810','French Polynesia - Marquesas Islands - Nuku Hiva','French Polynesia - Marquesas Islands - Nuku Hiva.',-9.01,-8.72,-140.31,-139.96,0);
INSERT INTO "area" VALUES('EPSG','2811','French Polynesia - Society Islands - Moorea and Tahiti','French Polynesia - Society Islands - Moorea and Tahiti.',-17.93,-17.41,-150.0,-149.11,0);
INSERT INTO "area" VALUES('EPSG','2812','French Polynesia - Society Islands - Bora Bora, Huahine, Raiatea, Tahaa','French Polynesia - Society Islands - Bora Bora, Huahine, Raiatea and Tahaa.',-16.96,-16.17,-151.91,-150.89,0);
INSERT INTO "area" VALUES('EPSG','2813','New Caledonia - Ouvea','New Caledonia - Loyalty Islands - Ouvea.',-20.77,-20.34,166.44,166.71,0);
INSERT INTO "area" VALUES('EPSG','2814','New Caledonia - Lifou','New Caledonia - Loyalty Islands - Lifou.',-21.24,-20.62,166.98,167.52,0);
INSERT INTO "area" VALUES('EPSG','2815','Wallis and Futuna - Wallis','Wallis and Futuna - Wallis.',-13.41,-13.16,-176.25,-176.07,0);
INSERT INTO "area" VALUES('EPSG','2816','French Southern Territories - Kerguelen onshore','French Southern Territories - Kerguelen onshore.',-49.78,-48.6,68.69,70.62,0);
INSERT INTO "area" VALUES('EPSG','2817','Antarctica - Adelie Land - Petrels island','Antarctica - Adelie Land - Petrels island.',-66.78,-66.1,139.44,141.5,0);
INSERT INTO "area" VALUES('EPSG','2818','Antarctica - Adelie Land coastal area','Antarctica - Adelie Land - coastal area between 136°E and 142°E.',-67.13,-65.61,136.0,142.0,0);
INSERT INTO "area" VALUES('EPSG','2819','New Caledonia - Mare','New Caledonia - Loyalty Islands - Mare.',-21.71,-21.32,167.75,168.19,0);
INSERT INTO "area" VALUES('EPSG','2820','New Caledonia - Ile des Pins','New Caledonia - Ile des Pins.',-22.73,-22.49,167.36,167.61,0);
INSERT INTO "area" VALUES('EPSG','2821','New Caledonia - Belep','New Caledonia - Belep.',-19.85,-19.5,163.54,163.75,0);
INSERT INTO "area" VALUES('EPSG','2822','New Caledonia - Grande Terre','New Caledonia - Grande Terre.',-22.45,-20.03,163.92,167.09,0);
INSERT INTO "area" VALUES('EPSG','2823','New Caledonia - Grande Terre - Noumea','New Caledonia - Grande Terre - Noumea district.',-22.37,-22.19,166.35,166.54,0);
INSERT INTO "area" VALUES('EPSG','2824','Caribbean - French Antilles','French Antilles onshore and offshore - Guadeloupe (including Grande Terre, Basse Terre, Marie Galante, Les Saintes, Iles de la Petite Terre, La Desirade, St Barthélemy, and northern St Martin) and Martinique.',14.08,18.54,-63.66,-57.52,0);
INSERT INTO "area" VALUES('EPSG','2825','Africa - Ethiopia and Sudan - 30°E to 36°E','Ethiopia - west of 36°E. South Sudan - east of 30°E. Sudan - between 30°E and 36°E.',3.49,22.24,29.99,36.0,0);
INSERT INTO "area" VALUES('EPSG','2826','Africa - South Sudan and Sudan - west of 24°E','South Sudan and Sudan - west of 24°E.',8.7,15.76,21.82,24.01,0);
INSERT INTO "area" VALUES('EPSG','2827','Africa - South Sudan and Sudan - 24°E to 30°E','South Sudan and Sudan - between 24°E and 30°E.',4.21,22.01,23.99,30.01,0);
INSERT INTO "area" VALUES('EPSG','2828','Guadeloupe - St Martin and St Barthelemy - onshore','Guadeloupe - onshore - St Martin and St Barthélemy islands.',17.82,18.17,-63.21,-62.73,0);
INSERT INTO "area" VALUES('EPSG','2829','Guadeloupe - Grande-Terre and surrounding islands - onshore','Guadeloupe - onshore - Basse-Terre, Grande-Terre, La Desirade, Marie-Galante, Les Saintes.',15.8,16.55,-61.85,-60.97,0);
INSERT INTO "area" VALUES('EPSG','2830','World (by country)','World: Afghanistan, Albania, Algeria, American Samoa, Andorra, Angola, Anguilla, Antarctica, Antigua and Barbuda, Argentina, Armenia, Aruba, Australia, Austria, Azerbaijan, Bahamas, Bahrain, Bangladesh, Barbados, Belgium, Belgium, Belize, Benin, Bermuda, Bhutan, Bolivia, Bonaire, Saint Eustasius and Saba, Bosnia and Herzegovina, Botswana, Bouvet Island, Brazil, British Indian Ocean Territory, British Virgin Islands, Brunei Darussalam, Bulgaria, Burkina Faso, Burundi, Cambodia, Cameroon, Canada, Cape Verde, Cayman Islands, Central African Republic, Chad, Chile, China, Christmas Island, Cocos (Keeling) Islands, Comoros, Congo, Cook Islands, Costa Rica, Côte d''Ivoire (Ivory Coast), Croatia, Cuba, Curacao, Cyprus, Czechia, Denmark, Djibouti, Dominica, Dominican Republic, East Timor, Ecuador, Egypt, El Salvador, Equatorial Guinea, Eritrea, Estonia, Eswatini (Swaziland), Ethiopia, Falkland Islands (Malvinas), Faroe Islands, Fiji, Finland, France, French Guiana, French Polynesia, French Southern Territories, Gabon, Gambia, Georgia, Germany, Ghana, Gibraltar, Greece, Greenland, Grenada, Guadeloupe, Guam, Guatemala, Guinea, Guinea-Bissau, Guyana, Haiti, Heard Island and McDonald Islands, Holy See (Vatican City State), Honduras, China - Hong Kong, Hungary, Iceland, India, Indonesia, Islamic Republic of Iran, Iraq, Ireland, Israel, Italy, Jamaica, Japan, Jordan, Kazakhstan, Kenya, Kiribati, Democratic People''s Republic of Korea (North Korea), Republic of Korea (South Korea), Kosovo, Kuwait, Kyrgyzstan, Lao People''s Democratic Republic (Laos), Latvia, Lebanon, Lesotho, Liberia, Libyan Arab Jamahiriya, Liechtenstein, Lithuania, Luxembourg, China - Macao, Madagascar, Malawi, Malaysia, Maldives, Mali, Malta, Marshall Islands, Martinique, Mauritania, Mauritius, Mayotte, Mexico, Federated States of Micronesia, Monaco, Mongolia, Montenegro, Montserrat, Morocco, Mozambique, Myanmar (Burma), Namibia, Nauru, Nepal, Netherlands, New Caledonia, New Zealand, Nicaragua, Niger, Nigeria, Niue, Norfolk Island, North Macedonia, Northern Mariana Islands, Norway, Oman, Pakistan, Palau, Panama, Papua New Guinea (PNG), Paraguay, Peru, Philippines, Pitcairn, Poland, Portugal, Puerto Rico, Qatar, Reunion, Romania, Russian Federation, Rwanda, Saint Kitts and Nevis, Saint Helena, Ascension and Tristan da Cunha, Saint Lucia, Saint Pierre and Miquelon, Saint Vincent and the Grenadines, Samoa, San Marino, Sao Tome and Principe, Saudi Arabia, Senegal, Serbia, Seychelles, Sierra Leone, Singapore, Slovakia (Slovak Republic), Slovenia, Sint Maarten, Solomon Islands, Somalia, South Africa, South Georgia and the South Sandwich Islands, South Sudan, Spain, Sri Lanka, Sudan, Suriname, Svalbard and Jan Mayen, Sweden, Switzerland, Syrian Arab Republic, Taiwan, Tajikistan, United Republic of Tanzania, Thailand, The Democratic Republic of the Congo (Zaire), Togo, Tokelau, Tonga, Trinidad and Tobago, Tunisia, Turkey, Turkmenistan, Turks and Caicos Islands, Tuvalu, Uganda, Ukraine, United Arab Emirates (UAE), United Kingdom (UK), United States (USA), United States Minor Outlying Islands, Uruguay, Uzbekistan, Vanuatu, Venezuela, Vietnam, US Virgin Islands, Wallis and Futuna, Western Sahara, Yemen, Zambia, Zimbabwe.',-90.0,90.0,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','2831','Canada - Atlantic offshore','Canada - offshore Newfoundland and Labrador, New Brunswick and Nova Scotia.',40.04,64.21,-67.75,-47.74,0);
INSERT INTO "area" VALUES('EPSG','2832','Canada - British Columbia','Canada - British Columbia.',48.25,60.01,-139.04,-114.08,0);
INSERT INTO "area" VALUES('EPSG','2833','Sweden - 12 00','Sweden - communes west of approximately 12°45''E and south of approximately 60°N. See information source for map.',56.74,60.13,10.93,13.11,0);
INSERT INTO "area" VALUES('EPSG','2834','Sweden - 13 30','Sweden - communes between approximately 12°45''E and 14°15''E and south of approximately 62°10''N. See information source for map.',55.28,62.28,12.12,14.79,0);
INSERT INTO "area" VALUES('EPSG','2835','Sweden - 15 00','Sweden - communes between approximately 14°15''E and 15°45''E and south of approximately 61°30''N. See information source for map.',55.95,61.62,13.54,16.15,0);
INSERT INTO "area" VALUES('EPSG','2836','Sweden - 16 30','Sweden - communes between approximately 15°45''E and 17°15''E and south of approximately 62°20''N. See information source for map.',56.15,62.26,15.41,17.63,0);
INSERT INTO "area" VALUES('EPSG','2837','Sweden - 18 00','Sweden - communes east of approximately 17°15''E between approximately 60°40''N and 58°50''N. See information source for map.',58.66,60.7,17.08,19.61,0);
INSERT INTO "area" VALUES('EPSG','2838','Sweden - 14 15','Sweden - communes west of approximately 15°E and between approximately 61°35''N and 64°25''N. See information source for map.',61.55,64.39,11.93,15.55,0);
INSERT INTO "area" VALUES('EPSG','2839','Sweden - 15 45','Sweden - communes between approximately 15°E and 16°30''E and between approximately 60°30''N and 65°N. See information source for map.',60.44,65.13,13.66,17.01,0);
INSERT INTO "area" VALUES('EPSG','2840','Sweden - 17 15','Sweden - communes between approximately 14°20''E and 18°50''E and between approximately 67°10''N and 62°05''N. See information source for map.',62.12,67.19,14.31,19.04,0);
INSERT INTO "area" VALUES('EPSG','2841','Sweden - 18 45','Sweden - mainland communes between approximately 18°E and 19°30''E and between approximately 62°50''N and 66°N. Also Gotland. See information source for map.',56.86,66.17,17.18,20.22,0);
INSERT INTO "area" VALUES('EPSG','2842','Sweden - 20 15','Sweden - communes in Vaasterbotten east of approximately 19°30''E and (i) north of 63°30''N and (ii) south of approximately 65°05''N. Also Norbotten west of approximately 23°20''E. See information source for map.',63.45,69.07,16.08,23.28,0);
INSERT INTO "area" VALUES('EPSG','2843','Sweden - 21 45','Sweden - communes in Norbotten east of approximately 19°30''E and south of approximately 65°50''N. See information source for map.',65.01,66.43,19.63,22.91,0);
INSERT INTO "area" VALUES('EPSG','2844','Sweden - 23 15','Sweden - communes east of approximately 21°50''E. See information source for map.',65.49,68.14,21.85,24.17,0);
INSERT INTO "area" VALUES('EPSG','2845','Sweden - 7.5 gon W','Sweden - communes west of approximately 12°26''E. See information source for map.',57.29,59.73,10.93,12.91,0);
INSERT INTO "area" VALUES('EPSG','2846','Sweden - 5 gon W','Sweden - communes between approximately 12°26''E and 14°40''E. See information source for map.',55.28,64.39,11.81,15.44,0);
INSERT INTO "area" VALUES('EPSG','2847','Sweden - 2.5 gon W','Sweden. For medium and small scale applications:- all country. For large scale applications:- communes between approximately 14°40''E and 16°55''E. See information source for map.',55.95,67.18,13.66,17.73,0);
INSERT INTO "area" VALUES('EPSG','2848','Sweden - 0 gon','Sweden - communes between approximately 16°55''E and 19°10''E; Gotland. See information source for map.',56.86,68.54,16.08,20.22,0);
INSERT INTO "area" VALUES('EPSG','2849','Sweden - 2.5 gon E','Sweden - communes between approximately 19°10''E and 21°25''E. See information source for map.',63.37,69.07,18.4,22.2,0);
INSERT INTO "area" VALUES('EPSG','2850','Sweden - 5 gon E','Sweden - east of approximately 21°26''E. See information source for map.',65.24,68.58,21.34,24.17,0);
INSERT INTO "area" VALUES('EPSG','2851','Iceland - onshore west of 24°W','Iceland - onshore west of 24°W.',64.71,65.86,-24.66,-24.0,0);
INSERT INTO "area" VALUES('EPSG','2852','Iceland - onshore 24°W to 18°W','Iceland - onshore between 24°W and 18°W.',63.34,66.52,-24.0,-18.0,0);
INSERT INTO "area" VALUES('EPSG','2853','Iceland - onshore east of 18°W','Iceland - onshore east of 18°W.',63.45,66.59,-18.0,-13.38,0);
INSERT INTO "area" VALUES('EPSG','2854','Europe - 36°W to 30°W','Europe - between 36°W and 30°W.',39.3,39.85,-36.0,-30.0,1);
INSERT INTO "area" VALUES('EPSG','2855','Europe - 30°W to 24°W','Europe - between 30°W and 24°W.',25.1,65.8,-30.0,-24.0,1);
INSERT INTO "area" VALUES('EPSG','2856','Europe - 24°W to 18°W','Europe - between 24°W and 18°W.',27.6,66.5,-24.0,-18.0,1);
INSERT INTO "area" VALUES('EPSG','2857','Europe - 18°W to 12°W','Europe - between 18°W and 12°W.',27.6,66.55,-18.0,-12.0,1);
INSERT INTO "area" VALUES('EPSG','2858','Europe - 12°W to 6°W','Europe - between 12°W and 6°W.',36.0,62.33,-12.0,-6.0,1);
INSERT INTO "area" VALUES('EPSG','2859','Europe - 6°W to 0°W','Europe - between 6°W and 0°W.',34.75,62.33,-6.0,0.0,1);
INSERT INTO "area" VALUES('EPSG','2860','Germany - west of 6°E','Germany - onshore and offshore west of 6°E.',50.97,55.92,3.34,6.0,0);
INSERT INTO "area" VALUES('EPSG','2861','Germany - 6°E to 12°E','Germany - onshore and offshore between 6°E and 12°E, including Mecklenburg-Vorpommern west of 12°E and Schleswig-Holstein.',47.27,55.47,6.0,12.0,0);
INSERT INTO "area" VALUES('EPSG','2862','Germany - east of 12°E','Germany - onshore and offshore east of 12°E, including Brandenburg (all state, including that part west of 12°E) and Mecklenburg-Vorpommern east of 12°E.',47.46,55.03,11.57,15.04,0);
INSERT INTO "area" VALUES('EPSG','2863','Europe - 18°E to 24°E','Europe - between 18°E and 24°E.',34.8,75.0,18.0,24.0,1);
INSERT INTO "area" VALUES('EPSG','2864','Europe - 24°E to 30°E','Europe - between 24°E and 30°E.',34.8,75.0,24.0,30.0,1);
INSERT INTO "area" VALUES('EPSG','2865','Europe - 30°E to 36°E','Europe - between 30°E and 36°E.',34.5,75.0,30.0,36.0,1);
INSERT INTO "area" VALUES('EPSG','2866','Europe - 36°E to 42°E','Europe - between 36°E and 42°E.',35.75,75.0,36.0,42.0,1);
INSERT INTO "area" VALUES('EPSG','2867','Europe - 42°E to 48°E','Europe - between 42°E and 48°E.',36.95,75.0,42.0,48.0,1);
INSERT INTO "area" VALUES('EPSG','2868','Europe - 48°E to 54°E','Europe - between 48°E and 54°E.',36.0,75.0,48.0,54.0,1);
INSERT INTO "area" VALUES('EPSG','2869','Jan Mayen - onshore','Jan Mayen - onshore.',70.75,71.24,-9.17,-7.87,0);
INSERT INTO "area" VALUES('EPSG','2870','Portugal - Madeira and Porto Santo islands onshore','Portugal - Madeira and Porto Santo islands onshore.',32.58,33.15,-17.31,-16.23,0);
INSERT INTO "area" VALUES('EPSG','2871','Portugal - Azores E - S Miguel onshore','Portugal - eastern Azores - Sao Miguel island onshore.',37.65,37.96,-25.92,-25.08,0);
INSERT INTO "area" VALUES('EPSG','2872','Portugal - Azores C - Terceira onshore','Portugal - central Azores - Terceira island onshore.',38.57,38.86,-27.44,-26.97,0);
INSERT INTO "area" VALUES('EPSG','2873','Portugal - Azores C - Faial onshore','Portugal - central Azores - Faial island onshore.',38.46,38.7,-28.9,-28.54,0);
INSERT INTO "area" VALUES('EPSG','2874','Portugal - Azores C - Pico onshore','Portugal - central Azores - Pico island onshore.',38.32,38.61,-28.61,-27.98,0);
INSERT INTO "area" VALUES('EPSG','2875','Portugal - Azores C - S Jorge onshore','Portugal - central Azores - Sao Jorge island onshore.',38.48,38.8,-28.37,-27.71,0);
INSERT INTO "area" VALUES('EPSG','2876','Asia - Middle East - Iraq-Kuwait boundary','Iraq - Kuwait boundary.',29.06,30.32,46.36,48.61,0);
INSERT INTO "area" VALUES('EPSG','2877','Slovenia - Slovenska Bistrica','Slovenia - Slovenska Bistrica with the Dravinja River Basin, area of Boc and parts of the Haloze and the Kozjansko region.',46.14,46.46,15.31,16.0,0);
INSERT INTO "area" VALUES('EPSG','2878','Slovenia - Slovenske Gorice','Slovenia - Slovenske Gorice (the Slovene Humpback) with the broad region of Ormoz.',46.29,46.76,15.9,16.3,0);
INSERT INTO "area" VALUES('EPSG','2879','Germany - offshore North Sea','Germany - offshore North Sea.',53.6,55.92,3.34,8.88,0);
INSERT INTO "area" VALUES('EPSG','2880','Antarctica - Australian sector north of 80°S','Antarctica - north of 80°S and between 45°E and 136°E and between 142°E and 160°E - Australian sector north of 80°S.',-80.0,-60.0,45.0,160.0,0);
INSERT INTO "area" VALUES('EPSG','2881','Europe - LCC & LAEA','Europe - European Union (EU) countries and candidates. Europe - onshore and offshore: Albania; Andorra; Austria; Belgium; Bosnia and Herzegovina; Bulgaria; Croatia; Cyprus; Czechia; Denmark; Estonia; Faroe Islands; Finland; France; Germany; Gibraltar; Greece; Hungary; Iceland; Ireland; Italy; Kosovo; Latvia; Liechtenstein; Lithuania; Luxembourg; Malta; Monaco; Montenegro; Netherlands; North Macedonia; Norway including Svalbard and Jan Mayen; Poland; Portugal including Madeira and Azores; Romania; San Marino; Serbia; Slovakia; Slovenia; Spain including Canary Islands; Sweden; Switzerland; Turkey; United Kingdom (UK) including Channel Islands and Isle of Man; Vatican City State.',24.6,84.17,-35.58,44.83,0);
INSERT INTO "area" VALUES('EPSG','2882','Italy - Adriatic - North Ancona','Italy - offshore - Adriatic Sea - North Ancona.',43.62,45.73,12.22,13.96,0);
INSERT INTO "area" VALUES('EPSG','2883','Italy - Adriatic - South Ancona / North Gargano','Italy - offshore - Adriatic Sea - South Ancona and North Gargano.',41.95,44.04,13.61,16.14,0);
INSERT INTO "area" VALUES('EPSG','2884','Italy - Adriatic - South Gargano','Italy - offshore - Adriatic Sea - South Gargano.',40.72,42.28,15.95,18.63,0);
INSERT INTO "area" VALUES('EPSG','2885','Italy - Otranto channel','Italy - offshore - Otranto channel.',39.77,41.03,17.95,18.99,0);
INSERT INTO "area" VALUES('EPSG','2886','Italy - north Ionian Sea','Italy - offshore - north Ionian Sea.',37.67,40.47,16.55,18.93,0);
INSERT INTO "area" VALUES('EPSG','2887','Italy - Sicily Strait east of 13°E','Italy - offshore - Strait of Sicily - east of 13°E (of Greenwich).',35.22,37.48,13.0,15.16,0);
INSERT INTO "area" VALUES('EPSG','2888','Italy - Sicily Strait west of 13°E','Italy - offshore - Strait of Sicily - west of 13°E (of Greenwich).',35.28,38.45,10.68,13.01,0);
INSERT INTO "area" VALUES('EPSG','2889','New Zealand - Chatham Islands group','New Zealand - Chatham Islands group - onshore.',-44.64,-43.3,-177.25,-175.54,0);
INSERT INTO "area" VALUES('EPSG','2890','Guadeloupe - St Martin - onshore','Guadeloupe - onshore - St Martin island.',18.01,18.17,-63.21,-62.96,0);
INSERT INTO "area" VALUES('EPSG','2891','Guadeloupe - St Barthelemy - onshore','Guadeloupe - onshore - St Barthelemy island.',17.82,17.98,-62.92,-62.73,0);
INSERT INTO "area" VALUES('EPSG','2892','Guadeloupe - Grande-Terre and Basse-Terre - onshore','Guadeloupe - onshore - Basse-Terre and Grande-Terre.',15.88,16.55,-61.85,-61.15,0);
INSERT INTO "area" VALUES('EPSG','2893','Guadeloupe - La Desirade - onshore','Guadeloupe - onshore - La Desirade.',16.26,16.38,-61.13,-60.97,0);
INSERT INTO "area" VALUES('EPSG','2894','Guadeloupe - Marie-Galante - onshore','Guadeloupe - onshore - Marie-Galante.',15.8,16.05,-61.39,-61.13,0);
INSERT INTO "area" VALUES('EPSG','2895','Guadeloupe - Les Saintes - onshore','Guadeloupe - onshore - Les Saintes.',15.8,15.94,-61.68,-61.52,0);
INSERT INTO "area" VALUES('EPSG','2896','Asia - Middle East - Israel, Palestine Territory, Turkey - offshore','Israel and Palestine Territory - offshore Mediterranean Sea; Turkey - offshore Black Sea.',31.35,43.45,28.03,41.47,0);
INSERT INTO "area" VALUES('EPSG','2897','Asia - Middle East - Israel and Palestine Territory offshore','Israel and Palestine Territory - offshore Mediterranean Sea.',31.33,33.1,33.5,35.1,1);
INSERT INTO "area" VALUES('EPSG','2898','Germany - Berlin','Germany - Berlin.',52.33,52.65,13.09,13.76,0);
INSERT INTO "area" VALUES('EPSG','2899','Australia - 126°E to 132°E, 8°S to 12°S (SC52) onshore','Australia - onshore mainland between 8°S and 12°S and 126°E and 132°E.',-12.0,-11.07,131.02,132.0,0);
INSERT INTO "area" VALUES('EPSG','2900','Australia - 132°E to 138°E, 8°S to 12°S (SC53) onshore','Australia - onshore mainland between 8°S and 12°S and 132°E and 138°E.',-12.0,-10.92,132.0,136.83,0);
INSERT INTO "area" VALUES('EPSG','2901','Australia - 138°E to 144°E, 8°S to 12°S (SC54) onshore','Australia - onshore mainland between 8°S and 12°S and 138°E and 144°E.',-12.0,-10.65,141.77,143.31,0);
INSERT INTO "area" VALUES('EPSG','2902','Australia - 120°E to 126°E, 12°S to 16°S (SD51) onshore','Australia - onshore mainland between 12°S and 16°S and 120°E and 126°E.',-16.0,-13.87,124.17,126.0,0);
INSERT INTO "area" VALUES('EPSG','2903','Australia - 126°E to 132°E, 12°S to 16°S (SD52) onshore','Australia - onshore mainland between 12°S and 16°S and 126°E and 132°E.',-16.0,-12.0,126.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','2904','Australia - 132°E to 138°E, 12°S to 16°S (SD53) onshore','Australia - onshore mainland between 12°S and 16°S and 132°E and 138°E.',-16.0,-12.0,132.0,137.28,0);
INSERT INTO "area" VALUES('EPSG','2905','Australia - 138°E to 144°E, 12°S to 16°S (SD54) onshore','Australia - onshore mainland between 12°S and 16°S and 138°E and 144°E.',-16.0,-12.0,141.34,144.01,0);
INSERT INTO "area" VALUES('EPSG','2906','Australia - 144°E to 150°E, 12°S to 16°S (SD55) onshore','Australia - onshore mainland between 12°S and 16°S and 144°E and 150°E.',-16.0,-14.01,144.0,145.49,0);
INSERT INTO "area" VALUES('EPSG','2907','Australia - 114°E to 120°E, 16°S to 20°S (SE50) onshore','Australia - onshore mainland between 16°S and 20°S and 114°E and 120°E.',-20.0,-19.88,118.94,120.0,0);
INSERT INTO "area" VALUES('EPSG','2908','Australia - 120°E to 126°E, 16°S to 20°S (SE51) onshore','Australia - onshore mainland between 16°S and 20°S and 120°E and 126°E.',-20.0,-16.0,120.0,126.0,0);
INSERT INTO "area" VALUES('EPSG','2909','Australia - 126°E to 132°E, 16°S to 20°S (SE52)','Australia - between 16°S and 20°S and 126°E and 132°E.',-20.0,-16.0,126.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','2910','Australia - 132°E to 138°E, 16°S to 20°S (SE53) onshore','Australia - onshore between 16°S and 20°S and 132°E and 138°E.',-20.0,-16.0,132.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','2911','Australia - 138°E to 144°E, 16°S to 20°S (SE54) onshore','Australia - onshore mainland between 16°S and 20°S and 138°E and 144°E.',-20.0,-16.0,138.0,144.0,0);
INSERT INTO "area" VALUES('EPSG','2912','Australia - 144°E to 150°E, 16°S to 20°S (SE55) onshore','Australia - onshore mainland between 16°S and 20°S and 144°E and 150°E.',-20.0,-16.0,144.0,148.97,0);
INSERT INTO "area" VALUES('EPSG','2913','Australia - 108°E to 114°E, 20°S to 24°S (SF49) onshore','Australia - onshore mainland between 20°S and 24°S and 108°E and 114°E.',-24.0,-21.8,113.39,114.0,0);
INSERT INTO "area" VALUES('EPSG','2914','Australia - 114°E to 120°E, 20°S to 24°S (SF50) onshore','Australia - onshore mainland between 20°S and 24°S and 114°E and 120°E.',-24.0,-20.0,114.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','2915','Australia - 120°E to 126°E, 20°S to 24°S (SF51)','Australia - between 20°S and 24°S and 120°E and 126°E.',-24.0,-20.0,120.0,126.0,0);
INSERT INTO "area" VALUES('EPSG','2916','Australia - 126°E to 132°E, 20°S to 24°S (SF52)','Australia - between 20°S and 24°S and 126°E and 132°E.',-24.0,-20.0,126.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','2917','Australia - 132°E to 138°E, 20°S to 24°S (SF53)','Australia - between 20°S and 24°S and 132°E and 138°E.',-24.0,-20.0,132.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','2918','Australia - 138°E to 144°E, 20°S to 24°S (SF54)','Australia - between 20°S and 24°S and 138°E and 144°E.',-24.0,-20.0,138.0,144.0,0);
INSERT INTO "area" VALUES('EPSG','2919','Australia - 144°E to 150°E, 20°S to 24°S (SF55) onshore','Australia - onshore mainland between 20°S and 24°S and 144°E and 150°E.',-24.0,-20.0,144.0,150.0,0);
INSERT INTO "area" VALUES('EPSG','2920','Australia - 150°E to 156°E, 20°S to 24°S (SF56) onshore','Australia - onshore mainland between 20°S and 24°S and 150°E and 156°E.',-24.0,-22.0,150.0,151.82,0);
INSERT INTO "area" VALUES('EPSG','2921','Australia - 108°E to 114°E, 24°S to 28°S (SG49) onshore','Australia - onshore mainland between 24°S and 28°S and 108°E and 114°E.',-27.44,-24.0,112.85,114.0,0);
INSERT INTO "area" VALUES('EPSG','2922','Australia - 114°E to 120°E, 24°S to 28°S (SG50) onshore','Australia - onshore mainland between 24°S and 28°S and 114°E and 120°E.',-28.0,-24.0,114.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','2923','Australia - 120°E to 126°E, 24°S to 28°S (SG51)','Australia - between 24°S and 28°S and 120°E and 126°E.',-28.0,-24.0,120.0,126.0,0);
INSERT INTO "area" VALUES('EPSG','2924','Australia - 126°E to 132°E, 24°S to 28°S (SG52)','Australia - between 24°S and 28°S and 126°E and 132°E.',-28.0,-24.0,126.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','2925','Australia - 132°E to 138°E, 24°S to 28°S (SG53)','Australia - between 24°S and 28°S and 132°E and 138°E.',-28.0,-24.0,132.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','2926','Australia - 138°E to 144°E, 24°S to 28°S (SG54)','Australia - between 24°S and 28°S and 138°E and 144°E.',-28.0,-24.0,138.0,144.0,0);
INSERT INTO "area" VALUES('EPSG','2927','Australia - 144°E to 150°E, 24°S to 28°S (SG55)','Australia - between 24°S and 28°S and 144°E and 150°E.',-28.0,-24.0,144.0,150.0,0);
INSERT INTO "area" VALUES('EPSG','2928','Australia - 150°E to 156°E, 24°S to 28°S (SG56) onshore','Australia - onshore mainland between 24°S and 28°S and 150°E and 156°E.',-28.0,-24.0,150.0,153.6,0);
INSERT INTO "area" VALUES('EPSG','2929','Australia - 108°E to 114°E, 28°S to 32°S (SH49)','Australia - between 28°S and 32°S and 108°E and 114°E.',-32.0,-28.0,108.0,114.0,1);
INSERT INTO "area" VALUES('EPSG','2930','Australia - 114°E to 120°E, 28°S to 32°S (SH50) onshore','Australia - onshore mainland between 28°S and 32°S and 114°E and 120°E.',-32.0,-28.0,114.07,120.0,0);
INSERT INTO "area" VALUES('EPSG','2931','Australia - 120°E to 126°E, 28°S to 32°S (SH51)','Australia - between 28°S and 32°S and 120°E and 126°E.',-32.0,-28.0,120.0,126.0,0);
INSERT INTO "area" VALUES('EPSG','2932','Australia - 126°E to 132°E, south of 28°S (SH52) onshore','Australia - onshore mainland south of 28°S and between 126°E and 132°E.',-32.37,-28.0,126.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','2933','Australia - 132°E to 138°E, 28°S to 32°S (SH53) onshore','Australia - onshore between 28°S and 32°S and 132°E and 138°E.',-32.0,-28.0,132.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','2934','Australia - 138°E to 144°E, 28°S to 32°S (SH54)','Australia - between 28°S and 32°S and 138°E and 144°E.',-32.0,-28.0,138.0,144.0,0);
INSERT INTO "area" VALUES('EPSG','2935','Australia - 144°E to 150°E, 28°S to 32°S (SH55)','Australia - between 28°S and 32°S and 144°E and 150°E.',-32.0,-28.0,144.0,150.0,0);
INSERT INTO "area" VALUES('EPSG','2936','Australia - 150°E to 156°E, 28°S to 32°S (SH56) onshore','Australia - onshore mainland between 28°S and 32°S and 150°E and 156°E.',-32.0,-28.0,150.0,153.69,0);
INSERT INTO "area" VALUES('EPSG','2937','Australia - 114°E to 120°E, 32°S to 36°S (SI50) onshore','Australia - onshore mainland between 32°S and 36°S and 114°E and 120°E.',-35.19,-32.0,114.89,120.0,0);
INSERT INTO "area" VALUES('EPSG','2938','Australia - 120°E to 126°E, 32°S to 36°S (SI51) onshore','Australia - onshore mainland between 32°S and 36°S and 120°E and 126°E.',-34.16,-32.0,120.0,126.0,0);
INSERT INTO "area" VALUES('EPSG','2939','Australia - 132°E to 138°E, 32°S to 36°S (SI53) onshore','Australia - onshore mainland and Kangaroo Island between 32°S and 36°S and 132°E and 138°E.',-36.0,-32.0,132.08,138.0,0);
INSERT INTO "area" VALUES('EPSG','2940','Australia - 138°E to 144°E, 32°S to 36°S (SI54) onshore','Australia - onshore between 32°S and 36°S and 138°E and 144°E.',-36.0,-32.0,138.0,144.0,0);
INSERT INTO "area" VALUES('EPSG','2941','Australia - 144°E to 150°E, 32°S to 36°S (SI55)','Australia - between 32°S and 36°S and 144°E and 150°E.',-36.0,-32.0,144.0,150.0,0);
INSERT INTO "area" VALUES('EPSG','2942','Australia - 150°E to 156°E, 32°S to 36°S (SI56) onshore','Australia - onshore mainland between 32°S and 36°S and 150°E and 156°E.',-36.0,-32.0,150.0,152.66,0);
INSERT INTO "area" VALUES('EPSG','2943','Australia - 132°E to 138°E, 36°S to 40°S (SJ53) onshore','Australia - onshore Kangaroo Island between 36°S and 40°S and 132°E and 138°E.',-36.14,-36.0,136.57,137.68,0);
INSERT INTO "area" VALUES('EPSG','2944','Australia - 138°E to 144°E, 36°S to 40°S (SJ54) onshore','Australia - onshore mainland between 36°S and 40°S and 138°E and 144°E.',-38.91,-36.0,139.38,144.0,0);
INSERT INTO "area" VALUES('EPSG','2945','Australia - 144°E to 150°E, 36°S to 40°S (SJ55) onshore','Australia - onshore mainland between 36°S and 40°S and 144°E and 150°E.',-39.2,-36.0,144.0,150.0,0);
INSERT INTO "area" VALUES('EPSG','2946','Australia - 150°E to 156°E, 36°S to 40°S (SJ56) onshore','Australia - onshore mainland between 36°S and 40°S and 150°E and 156°E.',-37.57,-36.0,150.0,150.22,0);
INSERT INTO "area" VALUES('EPSG','2947','Australia - Tasmania mainland onshore','Australia - Tasmania mainland - onshore.',-43.7,-40.24,144.55,148.44,0);
INSERT INTO "area" VALUES('EPSG','2948','USA - CONUS east of 89°W - onshore','United States (USA) - CONUS east of 89°W - onshore - Alabama; Connecticut; Delaware; Florida; Georgia; llinois; Indiana; Kentucky; Maine; Maryland; Massachusetts; Michigan; Mississippi; New Hampshire; New Jersey; New York; North Carolina; Ohio; Pennsylvania; Rhode Island; South Carolina; Tennessee; Vermont; Virginia; West Virginia; Wisconsin.',24.41,48.32,-89.0,-66.91,0);
INSERT INTO "area" VALUES('EPSG','2949','USA - CONUS 89°W-107°W - onshore','United States (USA) - CONUS between 89°W and 107°W - onshore - Arkansas; Colorado; Illinois; Iowa; Kansas; Louisiana; Michigan; Minnesota; Mississippi; Missouri; Montana; Nebraska; New Mexico; North Dakota; Oklahoma; South Dakota; Tennessee; Texas; Wisconsin; Wyoming.',25.83,49.38,-107.0,-89.0,0);
INSERT INTO "area" VALUES('EPSG','2950','USA - CONUS west of 107°W - onshore','United States (USA) - CONUS west of 107°W - onshore - Arizona; California; Colorado; Idaho; Montana; Nevada; New Mexico; Oregon; Utah; Washington; Wyoming.',31.33,49.05,-124.79,-107.0,0);
INSERT INTO "area" VALUES('EPSG','2951','Japan - 120°E to 126°E onshore','Japan - onshore west of 126°E.',23.98,24.94,123.62,125.51,0);
INSERT INTO "area" VALUES('EPSG','2952','Japan - 126°E to 132°E onshore','Japan - onshore between 126°E and 132°E.',24.4,34.9,126.63,132.0,0);
INSERT INTO "area" VALUES('EPSG','2953','Japan - 132°E to 138°E onshore','Japan - onshore between 132°E and 138°E.',20.37,37.58,132.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','2954','Japan - 138°E to 144°E onshore','Japan - onshore between 138°E and 144°E.',24.67,45.54,138.0,144.0,0);
INSERT INTO "area" VALUES('EPSG','2955','Japan - 144°E to 150°E onshore','Japan - onshore east of 144°E.',42.84,44.4,144.0,145.87,0);
INSERT INTO "area" VALUES('EPSG','2956','Kuwait - north of 29.25°N','Kuwait - onshore north of a line between Al Jahra'' and the Kuwait/Iraq/Saudi Arabia border tripoint.',29.1,30.09,46.54,48.42,0);
INSERT INTO "area" VALUES('EPSG','2957','Kuwait - south of 29.25°N','Kuwait - onshore south of a line between Al Jahra'' and the Kuwait/Iraq/Saudi Arabia border tripoint.',28.53,29.45,46.54,48.48,0);
INSERT INTO "area" VALUES('EPSG','2958','USA - Maine - CS2000 - W','United States (USA) - Maine west of approximately 69°40''W. The area is bounded by the following: Beginning at the point determined by the intersection of the Maine State line and the County Line between Aroostook and Somerset Counties, thence following the Somerset County line Easterly to the Northwest corner of the Somerset and Piscataquis county line, thence Southerly along this county line to the northeast corner of the Athens town line, thence westerly along the town line between Brighton Plantation and Athens to the westerly corner of Athens, and continuing southerly to the southwest corner of the town of Athens where it meets the Cornville town line, thence westerly along the Cornville - Solon town line to the intersection of the Cornville - Madison town line, thence southerly and westerly following the Madison town line to the intersection of the Norridgewock - Skowhegan town line, thence southerly along the Skowhegan town line to the Fairfield town line, thence easterly along the Fairfield town line to the Clinton town line (being determined by the Kennebec River), thence southerly along the Kennebec River to the Augusta city line, thence easterly along the city line to the Windsor town line, thence southerly along the Augusta - Windsor town line to the northwest corner of the Lincoln County line, thence southerly along the westerly Lincoln county line to the boundary of the State of Maine as determined by Maritime law, thence following the State boundary on the westerly side of the state to the point of beginning.',43.07,46.58,-71.09,-69.61,0);
INSERT INTO "area" VALUES('EPSG','2959','USA - Maine - CS2000 - C','United States (USA) - Maine between approximately 69°40''W and 68°25''W. The area is bounded by the following: Beginning at the point determined by the intersection of the Maine State line and the County Line between Aroostook and Somerset Counties, thence northeasterly along the state line to the intersection of the Fort Kent - Frenchville town line, thence southerly along this town line to the intersection with the New Canada Plantation - T17 R5 WELS town line, thence continuing southerly along town lines to the northeast corner of Penobscot County, thence continuing southerly along the Penobscot County line to the intersection of the Woodville - Mattawamkeag town line (being determined by the Penobscot River), thence along the Penobscot River to the Enfield - Lincoln town line, thence southeasterly along the Enfield - Lincoln town line and the Enfield - Lowell town line to the Passadumkeag - Edinburg town line, thence south-southeasterly along town lines to the intersection of the Hancock County line, thence southerly along the county line to the intersection of the Otis - Mariaville town line, thence southerly along the Otis - Mariaville town line to the Ellsworth city line, thence southerly along the Ellsworth city line to the intersection of the Surry - Trenton town line, thence southerly along the easterly town lines of Surry, Blue Hill, Brooklin, Deer Isle, and Stonington to the Knox County line, thence following the Knox County line to the boundary of the State of Maine as determined by Maritime law, thence following the State boundary westerly to the intersection of the Sagadahoc - Lincoln county line, thence northerly along the easterly boundary of the Maine 2000 West Zone, as defined, to the point of beginning.',43.75,47.47,-70.03,-68.33,0);
INSERT INTO "area" VALUES('EPSG','2960','USA - Maine - CS2000 - E','United States (USA) - Maine east of approximately 68°25''W. The area is bounded by the following: Beginning at the point determined by the intersection of the Maine State line and the Fort Kent - Frenchville town line, thence continuing easterly and then southerly along the state line to the boundary of the State of Maine as determined by Maritime law, thence following the State boundary westerly to the intersection of the Knox and Hancock County line, thence northerly along the easterly boundary of the Maine 2000 Central Zone, as defined, to the point of beginning.',44.18,47.37,-68.58,-66.91,0);
INSERT INTO "area" VALUES('EPSG','2961','Ireland - Corrib and Errigal','Ireland - offshore - Corrib and Errigal fields.',53.75,55.76,-12.5,-9.49,0);
INSERT INTO "area" VALUES('EPSG','2962','Brazil - Santos','Brazil - offshore - Santos basin.',-28.41,-22.66,-48.8,-40.2,0);
INSERT INTO "area" VALUES('EPSG','2963','Brazil - Campos','Brazil - offshore - Campos basin.',-25.91,-20.45,-42.04,-37.11,0);
INSERT INTO "area" VALUES('EPSG','2964','Brazil - Espirito Santo and Mucuri','Brazil - offshore - Espirito Santo and Mucuri basins.',-22.04,-17.59,-40.37,-35.18,0);
INSERT INTO "area" VALUES('EPSG','2965','Brazil - Pelotas','Brazil - offshore - Pelotas basin.',-35.71,-28.11,-53.38,-44.71,0);
INSERT INTO "area" VALUES('EPSG','2966','Brazil - offshore 18°S to 34°S','Brazil - offshore between 18°S and 34°S.',-34.0,-18.0,-53.38,-35.19,0);
INSERT INTO "area" VALUES('EPSG','2967','Mauritania - north coast','Mauritania - coastal area north of Cape Timiris.',19.37,21.34,-17.08,-15.88,0);
INSERT INTO "area" VALUES('EPSG','2968','Mauritania - central coast','Mauritania - coastal area south of Cape Timiris.',16.81,19.41,-16.57,-15.59,0);
INSERT INTO "area" VALUES('EPSG','2969','Mauritania - east of 6°W','Mauritania - east of 6°W.',15.49,25.74,-6.0,-4.8,0);
INSERT INTO "area" VALUES('EPSG','2970','Mauritania - 12°W to 6°W','Mauritania - between 12°W and 6°W.',14.75,27.3,-12.0,-6.0,0);
INSERT INTO "area" VALUES('EPSG','2971','Mauritania - west of 12°W onshore','Mauritania - onshore west of 12°W.',14.72,23.46,-17.08,-12.0,0);
INSERT INTO "area" VALUES('EPSG','2972','Mauritania - Nouakchutt','Mauritania - Nouakchutt.',17.89,18.25,-16.11,-15.83,0);
INSERT INTO "area" VALUES('EPSG','2973','USA - CONUS south of 41°N, west of 112°W - onshore','United States (USA) - CONUS onshore south of 41°N and west of 112°W - Arizona west of 112°W; California and Nevada south of 41°N; Utah south of 41°N and west of 112°W.',31.64,41.0,-124.45,-112.0,0);
INSERT INTO "area" VALUES('EPSG','2974','USA - CONUS south of 41°N, 112°W to 95°W - onshore','United States (USA) - CONUS onshore south of 41°N and between 112°W and 95°W - Colorado and New Mexico; Arizona east of 112°W; Utah south of 41°N and east of 112°W; Nebraska south of 41°N; Iowa south of 41°N and west of 95°W; Kansas, Missouri, Oklahoma and Texas west of 95°W.',25.83,41.01,-112.0,-94.99,0);
INSERT INTO "area" VALUES('EPSG','2975','USA - CONUS south of 41°N, 95°W to 78°W - onshore','United States (USA) - CONUS onshore south of 41°N and between 95°W and 78°W - Alabama, Arkansas, Florida, Georgia, Kentucky, Louisiana, Mississippi, South Carolina and Tennessee; Kansas, Missouri, Oklahoma and Texas east of 95°W; Iowa south of 41°N and east of 95°W; Illinois, Indiana and Ohio south of 41°N; Pennsylvania south of 41°N and west of 78°W; Maryland, North Carolina, Virginia and West Virginia west of 78°W.',24.41,41.01,-95.0,-77.99,0);
INSERT INTO "area" VALUES('EPSG','2976','USA - CONUS south of 41°N, east of 78°W - onshore','United States (USA) - CONUS onshore - south of 41°N and east of 78°W - Delaware; Maryland, North Carolina, Virginia and West Virginia east of 78°W; Pennsylvania south of 41°N and east of 78°W; New Jersey and New York south of 41°N.',33.84,41.01,-78.0,-71.9,0);
INSERT INTO "area" VALUES('EPSG','2977','USA - CONUS north of 41°N, west of 112°W - onshore','United States (USA) - CONUS onshore north of 41°N and west of 112°W - Oregon and Washington; California and Nevada north of 41°N; Utah north of 41°N and west of 112°W; Idaho and Montana west of 112°W.',41.0,49.05,-124.79,-112.0,0);
INSERT INTO "area" VALUES('EPSG','2978','USA - CONUS north of 41°N, 112°W to 95°W','United States (USA) - CONUS north of 41°N and between 112°W and 95°W - North Dakota, South Dakota and Wyoming; Idaho and Montana east of 112°W; Utah north of 41°N and east of 112°W; Nebraska north of 41°N; Iowa north of 41°N and west of 95°W; Minnesota west of 95°W.',41.0,49.38,-112.0,-95.0,0);
INSERT INTO "area" VALUES('EPSG','2979','USA - CONUS north of 41°N, 95°W to 78°W','United States (USA) - CONUS north of 41°N and between 95°W and 78°W - Michigan and Wisconsin; Minnesota east of 95°W; Iowa north of 41°N and east of 95°W; Illinois, Indiana and Ohio north of 41°N; Pennsylvania north of 41°N and west of 78°W; New York west of 78°W.',41.0,49.37,-95.0,-77.99,0);
INSERT INTO "area" VALUES('EPSG','2980','USA - CONUS north of 41°N, east of 78°W - onshore','United States (USA) - CONUS onshore north of 41°N and east of 78°W -  Connecticut, Maine, Massachusetts, New Hampshire, Rhode Island and Vermont; New Jersey north of 41°N; New York and Pennsylvania north of 41°N and east of 78°W.',41.0,47.47,-78.0,-66.91,0);
INSERT INTO "area" VALUES('EPSG','2981','Nigeria - offshore','Nigeria - offshore.',1.92,6.38,2.66,8.49,0);
INSERT INTO "area" VALUES('EPSG','2982','Pakistan - Karachi','Pakistan - Karachi licence area.',24.69,25.76,66.83,68.0,0);
INSERT INTO "area" VALUES('EPSG','2983','Pakistan - East Sind','Pakistan - East Sind.',24.16,28.61,68.27,71.14,0);
INSERT INTO "area" VALUES('EPSG','2984','Pakistan - Badin and Mehran','Pakistan - Badin and Mehran blocks.',24.0,25.64,67.74,69.87,0);
INSERT INTO "area" VALUES('EPSG','2985','Pakistan - offshore Indus','Pakistan - offshore Indus fan.',21.05,25.39,64.0,68.24,0);
INSERT INTO "area" VALUES('EPSG','2986','Australia - SA','Australia - South Australia.',-38.13,-25.99,128.99,141.01,0);
INSERT INTO "area" VALUES('EPSG','2987','Libya - Amal','Libya - Amal field.',29.1,29.8,20.8,21.4,0);
INSERT INTO "area" VALUES('EPSG','2988','Channel Islands - Jersey, Les Ecrehos and Les Minquiers','Channel Islands - Jersey, Les Ecrehos and Les Minquiers - onshore and offshore.',48.77,49.44,-2.72,-1.81,0);
INSERT INTO "area" VALUES('EPSG','2989','Channel Islands - Guernsey, Alderney, Sark','Channel Islands - Guernsey, Alderney, Sark, Herm, Brecqhou, Jethou, Lihou - onshore and offshore.',49.11,50.16,-3.73,-2.02,0);
INSERT INTO "area" VALUES('EPSG','2990','Australia - Brisbane','Australia - Brisbane area. Local authorities in south-east Queensland: Gold Coast, Logan, Beaudesert, Redcliffe, Redlands, Pine Rivers, Caboolture, Caloundra, Maroochy, Noosa, Maryborough; local authorities in north-east New South Wales: Tweed, Byron, Lismore, Ballina and Richmond Valley.',-29.88,-24.64,151.19,153.69,0);
INSERT INTO "area" VALUES('EPSG','2991','Antarctica - 60°S to 64°S, 72°W to 60°W (SP19-20)','Antarctica - 60°S to 64°S and 72°W to 60°W.',-64.0,-60.0,-72.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','2992','Antarctica - 60°S to 64°S, 60°W to 48°W (SP21-22)','Antarctica - 60°S to 64°S and 60°W to 48°W.',-64.0,-60.0,-60.0,-48.0,0);
INSERT INTO "area" VALUES('EPSG','2993','Antarctica - 60°S to 64°S, 48°W to 36°W (SP23-24)','Antarctica - 60°S to 64°S and 48°W to 36°W.',-64.0,-60.0,-48.0,-36.0,0);
INSERT INTO "area" VALUES('EPSG','2994','Antarctica - 64°S to 68°S, 180°W to 168°W (SQ01-02)','Antarctica - 64°S to 68°S and 180°W to 168°W.',-68.0,-64.0,-180.0,-168.0,0);
INSERT INTO "area" VALUES('EPSG','2995','Antarctica - 64°S to 68°S, 72°W to 60°W (SQ19-20)','Antarctica - 64°S to 68°S and 72°W to 60°W.',-68.0,-64.0,-72.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','2996','Antarctica - 64°S to 68°S, 60°W to 48°W (SQ21-22)','Antarctica - 64°S to 68°S and 60°W to 48°W.',-68.0,-64.0,-60.0,-48.0,0);
INSERT INTO "area" VALUES('EPSG','2997','Antarctica - 64°S to 68°S, 36°E to 48°E (SQ37-38)','Antarctica - 64°S to 68°S and 36°E to 48°E.',-68.0,-64.0,36.0,48.0,0);
INSERT INTO "area" VALUES('EPSG','2998','Antarctica - 64°S to 68°S, 48°E to 60°E (SQ39-40)','Antarctica - 64°S to 68°S and 48°E to 60°E.',-68.0,-64.0,48.0,60.0,0);
INSERT INTO "area" VALUES('EPSG','2999','Antarctica - 64°S to 68°S, 60°E to 72°E (SQ41-42)','Antarctica - 64°S to 68°S and 60°E to 72°E.',-68.0,-64.0,60.0,72.0,0);
INSERT INTO "area" VALUES('EPSG','3000','Antarctica - 64°S to 68°S, 72°E to 84°E (SQ43-44)','Antarctica - 64°S to 68°S and 72°E to 84°E.',-68.0,-64.0,72.0,84.0,0);
INSERT INTO "area" VALUES('EPSG','3001','Antarctica - 64°S to 68°S, 84°E to 96°E (SQ45-46)','Antarctica - 64°S to 68°S and 84°E to 96°E.',-68.0,-64.0,84.0,96.0,0);
INSERT INTO "area" VALUES('EPSG','3002','Antarctica - 64°S to 68°S, 96°E to 108°E (SQ47-48)','Antarctica - 64°S to 68°S and 96°E to 108°E.',-68.0,-64.0,96.0,108.0,0);
INSERT INTO "area" VALUES('EPSG','3003','Antarctica - 64°S to 68°S, 108°E to 120°E (SQ49-50)','Antarctica - 64°S to 68°S and 108°E to 120°E.',-68.0,-64.0,108.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','3004','Antarctica - 64°S to 68°S, 120°E to 132°E (SQ51-52)','Antarctica - 64°S to 68°S and 120°E to 132°E.',-68.0,-64.0,120.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','3005','Antarctica - 64°S to 68°S, 132°E to 144°E (SQ53-54)','Antarctica - 64°S to 68°S and 132°E to 144°E.',-68.0,-64.0,132.0,144.0,0);
INSERT INTO "area" VALUES('EPSG','3006','Antarctica - 64°S to 68°S, 144°E to 156°E (SQ55-56)','Antarctica - 64°S to 68°S and 144°E to 156°E.',-68.0,-64.0,144.0,156.0,0);
INSERT INTO "area" VALUES('EPSG','3007','Antarctica - 64°S to 68°S, 156°E to 168°E (SQ57-58)','Antarctica - 64°S to 68°S and 156°E to 168°E.',-68.0,-64.0,156.0,168.0,0);
INSERT INTO "area" VALUES('EPSG','3008','Antarctica - 68°S to 72°S, 108°W to 96°W (SR13-14)','Antarctica - 68°S to 72°S and 108°W to 96°W.',-72.0,-68.0,-108.0,-96.0,0);
INSERT INTO "area" VALUES('EPSG','3009','Antarctica - 68°S to 72°S, 96°W to 84°W (SR15-16)','Antarctica - 68°S to 72°S and 96°W to 84°W.',-72.0,-68.0,-96.0,-84.0,0);
INSERT INTO "area" VALUES('EPSG','3010','Antarctica - 68°S to 72°S, 84°W to 72°W (SR17-18)','Antarctica - 68°S to 72°S and 84°W to 72°W.',-72.0,-68.0,-84.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','3011','Antarctica - 68°S to 72°S, 72°W to 60°W (SR19-20)','Antarctica - 68°S to 72°S and 72°W to 60°W.',-72.0,-68.0,-72.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','3012','Antarctica - 68°S to 72°S, 24°W to 12°W (SR27-28)','Antarctica - 68°S to 72°S and 24°W to 12°W.',-72.0,-68.0,-24.0,-12.0,0);
INSERT INTO "area" VALUES('EPSG','3013','Antarctica - 68°S to 72°S, 12°W to 0°W (SR29-30)','Antarctica - 68°S to 72°S and 12°W to 0°W.',-72.0,-68.0,-12.0,0.0,0);
INSERT INTO "area" VALUES('EPSG','3014','Antarctica - 68°S to 72°S, 0°E to 12°E (SR31-32)','Antarctica - 68°S to 72°S and 0°E to 12°E.',-72.0,-68.0,0.0,12.0,0);
INSERT INTO "area" VALUES('EPSG','3015','Antarctica - 68°S to 72°S, 12°E to 24°E (SR33-34)','Antarctica - 68°S to 72°S and 12°E to 24°E.',-72.0,-68.0,12.0,24.0,0);
INSERT INTO "area" VALUES('EPSG','3016','Antarctica - 68°S to 72°S, 24°E to 36°E (SR35-36)','Antarctica - 68°S to 72°S and 24°E to 36°E.',-72.0,-68.0,24.0,36.0,0);
INSERT INTO "area" VALUES('EPSG','3017','Antarctica - 68°S to 72°S, 36°E to 48°E (SR37-38)','Antarctica - 68°S to 72°S and 36°E to 48°E.',-72.0,-68.0,36.0,48.0,0);
INSERT INTO "area" VALUES('EPSG','3018','Antarctica - 68°S to 72°S, 48°E to 60°E (SR39-40)','Antarctica - 68°S to 72°S and 48°E to 60°E.',-72.0,-68.0,48.0,60.0,0);
INSERT INTO "area" VALUES('EPSG','3019','Antarctica - 68°S to 72°S, 60°E to 72°E (SR41-42)','Antarctica - 68°S to 72°S and 60°E to 72°E.',-72.0,-68.0,60.0,72.0,0);
INSERT INTO "area" VALUES('EPSG','3020','Antarctica - 68°S to 72°S, 72°E to 84°E (SR43-44)','Antarctica - 68°S to 72°S and 72°E to 84°E.',-72.0,-68.0,72.0,84.0,0);
INSERT INTO "area" VALUES('EPSG','3021','Antarctica - 68°S to 72°S, 84°E to 96°E (SR45-46)','Antarctica - 68°S to 72°S and 84°E to 96°E.',-72.0,-68.0,84.0,96.0,0);
INSERT INTO "area" VALUES('EPSG','3022','Antarctica - 68°S to 72°S, 96°E to 108°E (SR47-48)','Antarctica - 68°S to 72°S and 96°E to 108°E.',-72.0,-68.0,96.0,108.0,0);
INSERT INTO "area" VALUES('EPSG','3023','Antarctica - 68°S to 72°S, 108°E to 120°E (SR49-50)','Antarctica - 68°S to 72°S and 108°E to 120°E.',-72.0,-68.0,108.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','3024','Antarctica - 68°S to 72°S, 120°E to 132°E (SR51-52)','Antarctica - 68°S to 72°S and 120°E to 132°E.',-72.0,-68.0,120.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','3025','Antarctica - 68°S to 72°S, 132°E to 144°E (SR53-54)','Antarctica - 68°S to 72°S and 132°E to 144°E.',-72.0,-68.0,132.0,144.0,0);
INSERT INTO "area" VALUES('EPSG','3026','Antarctica - 68°S to 72°S, 144°E to 156°E (SR55-56)','Antarctica - 68°S to 72°S and 144°E to 156°E.',-72.0,-68.0,144.0,156.0,0);
INSERT INTO "area" VALUES('EPSG','3027','Antarctica - 68°S to 72°S, 156°E to 168°E (SR57-58)','Antarctica - 68°S to 72°S and 156°E to 168°E.',-72.0,-68.0,156.0,168.0,0);
INSERT INTO "area" VALUES('EPSG','3028','Antarctica - 68°S to 72°S, 168°E to 180°E (SR59-60)','Antarctica - 68°S to 72°S and 168°E to 180°E.',-72.0,-68.0,168.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','3029','Antarctica - 72°S to 76°S, 162°W to 144°W (SS04-06)','Antarctica - 72°S to 76°S and 162°W to 144°W.',-76.0,-72.0,-162.0,-144.0,0);
INSERT INTO "area" VALUES('EPSG','3030','Antarctica - 72°S to 76°S, 144°W to 126°W (SS07-09)','Antarctica - 72°S to 76°S and 144°W to 126°W.',-76.0,-72.0,-144.0,-126.0,0);
INSERT INTO "area" VALUES('EPSG','3031','Antarctica - 72°S to 76°S, 126°W to 108°W (SS10-12)','Antarctica - 72°S to 76°S and 126°W to 108°W.',-76.0,-72.0,-126.0,-108.0,0);
INSERT INTO "area" VALUES('EPSG','3032','Antarctica - 72°S to 76°S, 108°W to 90°W (SS13-15)','Antarctica - 72°S to 76°S and 108°W to 90°W.',-76.0,-72.0,-108.0,-90.0,0);
INSERT INTO "area" VALUES('EPSG','3033','Antarctica - 72°S to 76°S, 90°W to 72°W (SS16-18)','Antarctica - 72°S to 76°S and 90°W to 72°W.',-76.0,-72.0,-90.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','3034','Antarctica - 72°S to 76°S, 72°W to 54°W (SS19-21)','Antarctica - 72°S to 76°S and 72°W to 54°W.',-76.0,-72.0,-72.0,-54.0,0);
INSERT INTO "area" VALUES('EPSG','3035','Antarctica - 72°S to 76°S, 36°W to 18°W (SS25-27)','Antarctica - 72°S to 76°S and 36°W to 18°W.',-76.0,-72.0,-36.0,-18.0,0);
INSERT INTO "area" VALUES('EPSG','3036','Antarctica - 72°S to 76°S, 18°W to 0°W (SS28-30)','Antarctica - 72°S to 76°S and 18°W to 0°W.',-76.0,-72.0,-18.0,0.0,0);
INSERT INTO "area" VALUES('EPSG','3037','Antarctica - 72°S to 76°S, 0°E to 18°E (SS31-33)','Antarctica - 72°S to 76°S and 0°E to 18°E.',-76.0,-72.0,0.0,18.0,0);
INSERT INTO "area" VALUES('EPSG','3038','Antarctica - 72°S to 76°S, 18°E to 36°E (SS34-36)','Antarctica - 72°S to 76°S and 18°E to 36°E.',-76.0,-72.0,18.0,36.0,0);
INSERT INTO "area" VALUES('EPSG','3039','Antarctica - 72°S to 76°S, 36°E to 54°E (SS37-39)','Antarctica - 72°S to 76°S and 36°E to 54°E.',-76.0,-72.0,36.0,54.0,0);
INSERT INTO "area" VALUES('EPSG','3040','Antarctica - 72°S to 76°S, 54°E to 72°E (SS40-42)','Antarctica - 72°S to 76°S and 54°E to 72°E.',-76.0,-72.0,54.0,72.0,0);
INSERT INTO "area" VALUES('EPSG','3041','Antarctica - 72°S to 76°S, 72°E to 90°E (SS43-45)','Antarctica - 72°S to 76°S and 72°E to 90°E.',-76.0,-72.0,72.0,90.0,0);
INSERT INTO "area" VALUES('EPSG','3042','Antarctica - 72°S to 76°S, 90°E to 108°E (SS46-48)','Antarctica - 72°S to 76°S and 90°E to 108°E.',-76.0,-72.0,90.0,108.0,0);
INSERT INTO "area" VALUES('EPSG','3043','Antarctica - 72°S to 76°S, 108°E to 126°E (SS49-51)','Antarctica - 72°S to 76°S and 108°E to 126°E.',-76.0,-72.0,108.0,126.0,0);
INSERT INTO "area" VALUES('EPSG','3044','Antarctica - 72°S to 76°S, 126°E to 144°E (SS52-54)','Antarctica - 72°S to 76°S and 126°E to 144°E.',-76.0,-72.0,126.0,144.0,0);
INSERT INTO "area" VALUES('EPSG','3045','Antarctica - 72°S to 76°S, 144°E to 162°E (SS55-57)','Antarctica - 72°S to 76°S and 144°E to 162°E.',-76.0,-72.0,144.0,162.0,0);
INSERT INTO "area" VALUES('EPSG','3046','Antarctica - 72°S to 76°S, 162°E to 180°E (SS58-60)','Antarctica - 72°S to 76°S and 162°E to 180°E.',-76.0,-72.0,162.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','3047','Antarctica - 76°S to 80°S, 180°W to 156°W (ST01-04)','Antarctica - 76°S to 80°S and 180°W to 156°W.',-80.0,-76.0,-180.0,-156.0,0);
INSERT INTO "area" VALUES('EPSG','3048','Antarctica - 76°S to 80°S, 156°W to 132°W (ST05-08)','Antarctica - 76°S to 80°S and 156°W to 132°W.',-80.0,-76.0,-156.0,-132.0,0);
INSERT INTO "area" VALUES('EPSG','3049','Antarctica - 76°S to 80°S, 132°W to 108°W (ST09-12)','Antarctica - 76°S to 80°S and 132°W to 108°W.',-80.0,-76.0,-132.0,-108.0,0);
INSERT INTO "area" VALUES('EPSG','3050','Antarctica - 76°S to 80°S, 108°W to 84°W (ST13-16)','Antarctica - 76°S to 80°S and 108°W to 84°W.',-80.0,-76.0,-108.0,-84.0,0);
INSERT INTO "area" VALUES('EPSG','3051','Antarctica - 76°S to 80°S, 84°W to 60°W (ST17-20)','Antarctica - 76°S to 80°S and 84°W to 60°W.',-80.0,-76.0,-84.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','3052','Antarctica - 76°S to 80°S, 60°W to 36°W (ST21-24)','Antarctica - 76°S to 80°S and 60°W to 36°W.',-80.0,-76.0,-60.0,-36.0,0);
INSERT INTO "area" VALUES('EPSG','3053','Antarctica - 76°S to 80°S, 36°W to 12°W (ST25-28)','Antarctica - 76°S to 80°S and 36°W to 12°W.',-80.0,-76.0,-36.0,-12.0,0);
INSERT INTO "area" VALUES('EPSG','3054','Antarctica - 76°S to 80°S, 12°W to 12°E (ST29-32)','Antarctica - 76°S to 80°S and 12°W to 12°E.',-80.0,-76.0,-12.0,12.0,0);
INSERT INTO "area" VALUES('EPSG','3055','Antarctica - 76°S to 80°S, 12°E to 36°E (ST33-36)','Antarctica - 76°S to 80°S and 12°E to 36°E.',-80.0,-76.0,12.0,36.0,0);
INSERT INTO "area" VALUES('EPSG','3056','Antarctica - 76°S to 80°S, 36°E to 60°E (ST37-40)','Antarctica - 76°S to 80°S and 36°E to 60°E.',-80.0,-76.0,36.0,60.0,0);
INSERT INTO "area" VALUES('EPSG','3057','Antarctica - 76°S to 80°S, 60°E to 84°E (ST41-44)','Antarctica - 76°S to 80°S and 60°E to 84°E.',-80.0,-76.0,60.0,84.0,0);
INSERT INTO "area" VALUES('EPSG','3058','Antarctica - 76°S to 80°S, 84°E to 108°E (ST45-48)','Antarctica - 76°S to 80°S and 84°E to 108°E.',-80.0,-76.0,84.0,108.0,0);
INSERT INTO "area" VALUES('EPSG','3059','Antarctica - 76°S to 80°S, 108°E to 132°E (ST49-52)','Antarctica - 76°S to 80°S and 108°E to 132°E.',-80.0,-76.0,108.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','3060','Antarctica - 76°S to 80°S, 132°E to 156°E (ST53-56)','Antarctica - 76°S to 80°S and 132°E to 156°E.',-80.0,-76.0,132.0,156.0,0);
INSERT INTO "area" VALUES('EPSG','3061','Antarctica - 76°S to 80°S, 156°E to 180°E (ST57-60)','Antarctica - 76°S to 80°S and 156°E to 180°E.',-80.0,-76.0,156.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','3062','Antarctica - 80°S to 84°S, 180°W to 150°W (SU01-05)','Antarctica - 80°S to 84°S and 180°W to 150°W.',-84.0,-80.0,-180.0,-150.0,0);
INSERT INTO "area" VALUES('EPSG','3063','Antarctica - 80°S to 84°S, 150°W to 120°W (SU06-10)','Antarctica - 80°S to 84°S and 150°W to 120°W.',-84.0,-80.0,-150.0,-120.0,0);
INSERT INTO "area" VALUES('EPSG','3064','Antarctica - 80°S to 84°S, 120°W to 90°W (SU11-15)','Antarctica - 80°S to 84°S and 120°W to 90°W.',-84.0,-80.0,-120.0,-90.0,0);
INSERT INTO "area" VALUES('EPSG','3065','Antarctica - 80°S to 84°S, 90°W to 60°W (SU16-20)','Antarctica - 80°S to 84°S and 90°W to 60°W.',-84.0,-80.0,-90.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','3066','Antarctica - 80°S to 84°S, 60°W to 30°W (SU21-25)','Antarctica - 80°S to 84°S and 60°W to 30°W.',-84.0,-80.0,-60.0,-30.0,0);
INSERT INTO "area" VALUES('EPSG','3067','Antarctica - 80°S to 84°S, 30°W to 0°W (SU26-30)','Antarctica - 80°S to 84°S and 30°W to 0°W.',-84.0,-80.0,-30.0,0.0,0);
INSERT INTO "area" VALUES('EPSG','3068','Antarctica - 80°S to 84°S, 0°E to 30°E (SU31-35)','Antarctica - 80°S to 84°S and 0°E to 30°E.',-84.0,-80.0,0.0,30.0,0);
INSERT INTO "area" VALUES('EPSG','3069','Antarctica - 80°S to 84°S, 30°E to 60°E (SU36-40)','Antarctica - 80°S to 84°S and 30°E to 60°E.',-84.0,-80.0,30.0,60.0,0);
INSERT INTO "area" VALUES('EPSG','3070','Antarctica - 80°S to 84°S, 60°E to 90°E (SU41-45)','Antarctica - 80°S to 84°S and 60°E to 90°E.',-84.0,-80.0,60.0,90.0,0);
INSERT INTO "area" VALUES('EPSG','3071','Antarctica - 80°S to 84°S, 90°E to 120°E (SU46-50)','Antarctica - 80°S to 84°S and 90°E to 120°E.',-84.0,-80.0,90.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','3072','Antarctica - 80°S to 84°S, 120°E to 150°E (SU51-55)','Antarctica - 80°S to 84°S and 120°E to 150°E.',-84.0,-80.0,120.0,150.0,0);
INSERT INTO "area" VALUES('EPSG','3073','Antarctica - 80°S to 84°S, 150°E to 180° (SU56-60)','Antarctica - 80°S to 84°S and 150°E to 180°E.',-84.0,-80.0,150.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','3074','Antarctica - 84°S to 88°S, 180°W to 120°W (SV01-10)','Antarctica - 84°S to 88°S and 180°W to 120°W.',-88.0,-84.0,-180.0,-120.0,0);
INSERT INTO "area" VALUES('EPSG','3075','Antarctica - 84°S to 88°S, 120°W to 60°W (SV11-20)','Antarctica - 84°S to 88°S and 120°W to 60°W.',-88.0,-84.0,-120.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','3076','Antarctica - 84°S to 88°S, 60°W to 0°W (SV21-30)','Antarctica - 84°S to 88°S and 60°W to 0°W.',-88.0,-84.0,-60.0,0.0,0);
INSERT INTO "area" VALUES('EPSG','3077','Antarctica - 84°S to 88°S, 0°E to 60°E (SV31-40)','Antarctica - 84°S to 88°S and 0°E to 60°E.',-88.0,-84.0,0.0,60.0,0);
INSERT INTO "area" VALUES('EPSG','3078','Antarctica - 84°S to 88°S, 60°E to 120°E (SV41-50)','Antarctica - 84°S to 88°S and 60°E to 120°E.',-88.0,-84.0,60.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','3079','Antarctica - 84°S to 88°S, 120°E to 180°E (SV51-60)','Antarctica - 84°S to 88°S and 120°E to 180°E.',-88.0,-84.0,120.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','3080','Antarctica - 88°S to 90°S, 180°W to 180°E (SW01-60)','Antarctica - 88°S to 90°S and 180°W to 180°E.',-90.0,-88.0,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','3081','Antarctica - Transantarctic mountains north of 80°S','Antarctica - Transantarctic mountains north of 80°S.',-80.0,-68.6,149.83,174.01,0);
INSERT INTO "area" VALUES('EPSG','3082','Colombia region 1','Colombia - region I (north east). Onshore north of 9°48''N and east of 73°W.',9.8,12.52,-73.0,-71.06,0);
INSERT INTO "area" VALUES('EPSG','3083','Colombia region 2','Colombia - region II (north west). Onshore north of 9°24''N and west of 73°W.',9.39,11.59,-76.08,-73.0,0);
INSERT INTO "area" VALUES('EPSG','3084','Colombia region 3','Colombia - region III - onshore between 8°N and 9°24''N and west of 74°24''W.',8.0,9.4,-77.48,-74.39,0);
INSERT INTO "area" VALUES('EPSG','3085','Colombia region 4','Colombia - region IV - between 5°N and 9°24''N and between 74°24''W and 72°W.',5.0,9.4,-74.4,-71.99,0);
INSERT INTO "area" VALUES('EPSG','3086','Colombia region 5','Colombia - region V - onshore between 5°N and 8°N and west of 74°24''W.',5.0,8.01,-77.92,-74.39,0);
INSERT INTO "area" VALUES('EPSG','3087','Colombia region 6','Colombia - region VI - onshore between 3°N and 5°N and west of 74°24''W.',3.0,5.01,-77.68,-74.39,0);
INSERT INTO "area" VALUES('EPSG','3088','Colombia region 7','Colombia - region VII (south west). Onshore south of 3°N and west of 74°W.',-1.13,3.01,-79.1,-74.0,0);
INSERT INTO "area" VALUES('EPSG','3089','Colombia region 8','Colombia - region VIII (south east). South and east of a line from the intersection of the meridian of  74°W with the southern border, northwards to  3°N, 74°W, westwards to 3°''N, 74°24''W, northwards to 5°N, 74°24''W, eastwards to 5°N, 72°W, and then northwards to the intersection of the meridian of 72°W with the international border.',-4.23,7.1,-74.4,-66.87,0);
INSERT INTO "area" VALUES('EPSG','3090','Colombia - 78°35''W to 75°35''W','Colombia - onshore between 78°35''W and 75°35''W of Greenwich (4°30'' W and 1°30'' W of Bogota).',0.03,10.21,-78.59,-75.58,0);
INSERT INTO "area" VALUES('EPSG','3091','Colombia - west of 78°35''W','Colombia - mainland onshore west of 78°35''W of Greenwich (4°30'' W of Bogota).',1.23,2.48,-79.1,-78.58,0);
INSERT INTO "area" VALUES('EPSG','3092','Finland - west of 19.5°E onshore','Finland - onshore west of 19°30''E.',60.08,60.34,19.24,19.5,0);
INSERT INTO "area" VALUES('EPSG','3093','Finland - 19.5°E to 20.5°E onshore','Finland - onshore between 19°30''E and 20°30''E.',59.92,60.48,19.5,20.5,0);
INSERT INTO "area" VALUES('EPSG','3094','Finland - 20.5°E to 21.5°E onshore','Finland - onshore between 20°30''E and 21°30''E.',59.84,69.33,20.5,21.5,0);
INSERT INTO "area" VALUES('EPSG','3095','Finland - 21.5°E to 22.5°E onshore','Finland - onshore between 21°30''E and 22°30''E.',59.76,69.31,21.5,22.5,0);
INSERT INTO "area" VALUES('EPSG','3096','Finland - 22.5°E to 23.5°E onshore','Finland - onshore between 22°30''E and 23°30''E.',59.75,68.74,22.5,23.5,0);
INSERT INTO "area" VALUES('EPSG','3097','Finland - 23.5°E to 24.5°E onshore','Finland - onshore between 23°30''E and 24°30''E.',59.86,68.84,23.5,24.5,0);
INSERT INTO "area" VALUES('EPSG','3098','Finland - 24.5°E to 25.5°E onshore','Finland - onshore between 24°30''E and 25°30''E.',59.94,68.9,24.5,25.5,0);
INSERT INTO "area" VALUES('EPSG','3099','Finland - 25.5°E to 26.5°E onshore','Finland - onshore between 25°30''E and 26°30''E.',60.18,69.94,25.5,26.5,0);
INSERT INTO "area" VALUES('EPSG','3100','Finland - 26.5°E to 27.5°E onshore','Finland - onshore between 26°30''E and 27°30''E.',60.36,70.05,26.5,27.5,0);
INSERT INTO "area" VALUES('EPSG','3101','Finland - 27.5°E to 28.5°E onshore','Finland - onshore between 27°30''E and 28°30''E.',60.42,70.09,27.5,28.5,0);
INSERT INTO "area" VALUES('EPSG','3102','Finland - 28.5°E to 29.5°E','Finland - between 28°30''E and 29°30''E.',60.94,69.81,28.5,29.5,0);
INSERT INTO "area" VALUES('EPSG','3103','Finland - 29.5°E to 30.5°E','Finland - between 29°30''E and 30°30''E.',61.43,67.98,29.5,30.5,0);
INSERT INTO "area" VALUES('EPSG','3104','Finland - east of 30.5°E','Finland - east of 30°30''E.',62.08,64.27,30.5,31.59,0);
INSERT INTO "area" VALUES('EPSG','3105','French Guiana - coastal area','French Guiana - coastal area.',3.43,5.81,-54.45,-51.61,0);
INSERT INTO "area" VALUES('EPSG','3106','Saudi Arabia - east of 54°E','Saudi Arabia - east of 54°E.',19.66,22.77,54.0,55.67,0);
INSERT INTO "area" VALUES('EPSG','3107','Saudi Arabia - onshore west of 36°E','Saudi Arabia - onshore west of 36°E.',26.82,29.38,34.51,36.0,0);
INSERT INTO "area" VALUES('EPSG','3108','Micronesia - Yap Islands','Federated States of Micronesia - Yap Islands.',9.39,9.69,137.99,138.27,0);
INSERT INTO "area" VALUES('EPSG','3109','American Samoa - 2 main island groups','American Samoa - Tutuila, Aunu''u, Ofu, Olesega and Ta''u islands.',-14.43,-14.11,-170.88,-169.38,0);
INSERT INTO "area" VALUES('EPSG','3110','American Samoa - 2 main island groups and Rose Island','American Samoa - Tutuila, Aunu''u, Ofu, Olesega, Ta''u and Rose islands.',-14.59,-14.11,-170.88,-168.09,0);
INSERT INTO "area" VALUES('EPSG','3111','Europe - ED79 tfm','Austria; Finland; Netherlands; Norway; Spain; Sweden, Switzerland.',36.0,71.05,-8.95,31.6,1);
INSERT INTO "area" VALUES('EPSG','3112','South America - 84°W to 78°W, N hemisphere and PSAD56 by country','South America (Ecuador) between 84°W and 78°W, northern hemisphere, onshore.',0.0,1.45,-80.18,-78.0,0);
INSERT INTO "area" VALUES('EPSG','3113','Nigeria - OML 58','Nigeria - block OML 58.',5.05,5.36,6.53,6.84,0);
INSERT INTO "area" VALUES('EPSG','3114','North America - 96°W to 90°W and NAD83 by country','North America - between 96°W and 90°W - onshore and offshore. Canada - Manitoba; Nunavut; Ontario. United States (USA) - Arkansas; Illinois; Iowa; Kansas; Louisiana; Michigan; Minnesota; Mississippi; Missouri; Nebraska; Oklahoma; Tennessee; Texas; Wisconsin.',25.61,84.0,-96.0,-90.0,0);
INSERT INTO "area" VALUES('EPSG','3115','North America - 90°W to 84°W and NAD83 by country','North America - between 90°W and 84°W - onshore and offshore. Canada - Manitoba; Nunavut; Ontario. United States (USA) - Alabama; Arkansas; Florida; Georgia; Indiana; Illinois; Kentucky; Louisiana; Michigan; Minnesota; Mississippi; Missouri; North Carolina; Ohio; Tennessee; Wisconsin.',23.97,84.0,-90.0,-84.0,0);
INSERT INTO "area" VALUES('EPSG','3116','North America - 84°W to 78°W and NAD83 by country','North America - between 84°W and 78°W - onshore and offshore. Canada - Nunavut; Ontario; Quebec. United States (USA) - Florida; Georgia; Kentucky; Maryland; Michigan; New York; North Carolina; Ohio; Pennsylvania; South Carolina; Tennessee; Virginia; West Virginia.',23.81,84.0,-84.0,-78.0,0);
INSERT INTO "area" VALUES('EPSG','3117','North America - 78°W to 72°W and NAD83 by country','North America - between 78°W and 72°W - onshore and offshore. Canada - Nunavut; Ontario; Quebec. United States (USA) - Connecticut; Delaware; Maryland; Massachusetts; New Hampshire; New Jersey; New York; North Carolina; Pennsylvania; Virginia; Vermont.',28.28,84.0,-78.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','3118','Grenada - main island - onshore','Grenada - main island - onshore.',11.94,12.29,-61.84,-61.54,0);
INSERT INTO "area" VALUES('EPSG','3119','Greenland - onshore','Greenland - onshore.',59.74,83.67,-73.29,-11.81,0);
INSERT INTO "area" VALUES('EPSG','3120','French Polynesia - west of 150°W','French Polynesia - west of 150°W onshore and offshore.',-26.7,-12.5,-158.13,-150.0,0);
INSERT INTO "area" VALUES('EPSG','3121','French Polynesia - 150°W to 144°W','French Polynesia - between 150°W and 144°W onshore and offshore.',-31.2,-7.29,-150.0,-144.0,0);
INSERT INTO "area" VALUES('EPSG','3122','French Polynesia - 144°W to 138°W','French Polynesia - between 144°W and 138°W onshore and offshore.',-31.24,-4.52,-144.0,-138.0,0);
INSERT INTO "area" VALUES('EPSG','3123','French Polynesia - east of 138°W','French Polynesia - east of 138°W.',-26.58,-5.52,-138.0,-131.97,0);
INSERT INTO "area" VALUES('EPSG','3124','French Polynesia - Society Islands - Tahiti','French Polynesia - Society Islands - Tahiti.',-17.93,-17.44,-149.7,-149.09,0);
INSERT INTO "area" VALUES('EPSG','3125','French Polynesia - Society Islands - Moorea','French Polynesia - Society Islands - Moorea.',-17.63,-17.41,-150.0,-149.73,0);
INSERT INTO "area" VALUES('EPSG','3126','French Polynesia - Society Islands - Maupiti','French Polynesia - Society Islands - Maupiti.',-16.57,-16.34,-152.39,-152.14,0);
INSERT INTO "area" VALUES('EPSG','3127','French Polynesia - Marquesas Islands - Ua Huka','French Polynesia - Marquesas Islands - Ua Huka.',-9.0,-8.81,-139.66,-139.44,0);
INSERT INTO "area" VALUES('EPSG','3128','French Polynesia - Marquesas Islands - Ua Pou','French Polynesia - Marquesas Islands - Ua Pou.',-9.57,-9.27,-140.21,-139.95,0);
INSERT INTO "area" VALUES('EPSG','3129','French Polynesia - Marquesas Islands - Nuku Hiva, Ua Huka and Ua Pou','French Polynesia - Marquesas Islands - Nuku Hiva, Ua Huka and Ua Pou.',-9.57,-8.72,-140.31,-139.44,0);
INSERT INTO "area" VALUES('EPSG','3130','French Polynesia - Marquesas Islands - Hiva Oa and Tahuata','French Polynesia - Marquesas Islands - Hiva Oa and Tahuata.',-10.08,-9.64,-139.23,-138.75,0);
INSERT INTO "area" VALUES('EPSG','3131','French Polynesia - Marquesas Islands - Hiva Oa','French Polynesia - Marquesas Islands - Hiva Oa.',-9.89,-9.64,-139.23,-138.75,0);
INSERT INTO "area" VALUES('EPSG','3132','French Polynesia - Marquesas Islands - Tahuata','French Polynesia - Marquesas Islands - Tahuata.',-10.08,-9.86,-139.19,-138.98,0);
INSERT INTO "area" VALUES('EPSG','3133','French Polynesia - Marquesas Islands - Fatu Hiva','French Polynesia - Marquesas Islands - Fatu Hiva.',-10.6,-10.36,-138.75,-138.54,0);
INSERT INTO "area" VALUES('EPSG','3134','French Polynesia - Society Islands - main islands','French Polynesia - Society Islands - Bora Bora, Huahine, Maupiti, Moorea, Raiatea, Tahaa and Tahiti.',-17.93,-16.17,-152.39,-149.09,0);
INSERT INTO "area" VALUES('EPSG','3135','French Polynesia - Society Islands - Huahine','French Polynesia - Society Islands - Huahine.',-16.87,-16.63,-151.11,-150.89,0);
INSERT INTO "area" VALUES('EPSG','3136','French Polynesia - Society Islands - Raiatea','French Polynesia - Society Islands - Raiatea.',-16.96,-16.68,-151.55,-151.3,0);
INSERT INTO "area" VALUES('EPSG','3137','French Polynesia - Society Islands - Bora Bora','French Polynesia - Society Islands - Bora Bora.',-16.62,-16.39,-151.86,-151.61,0);
INSERT INTO "area" VALUES('EPSG','3138','French Polynesia - Society Islands - Tahaa','French Polynesia - Society Islands - Tahaa.',-16.72,-16.5,-151.63,-151.36,0);
INSERT INTO "area" VALUES('EPSG','3139','Australia - New South Wales','Australia - New South Wales.',-37.53,-28.15,140.99,153.69,0);
INSERT INTO "area" VALUES('EPSG','3140','Iran - South Pars block 11','Iran - South Pars field phase 11.',26.46,26.64,52.22,52.41,0);
INSERT INTO "area" VALUES('EPSG','3141','Iran - Tombak LNG plant','Iran - Tombak LNG plant.',27.63,27.81,52.09,52.26,0);
INSERT INTO "area" VALUES('EPSG','3142','Libya - Sirte NC192','Libya - Sirte Basin licence NC192.',27.5,28.07,21.25,21.59,0);
INSERT INTO "area" VALUES('EPSG','3143','Trinidad and Tobago - Trinidad - onshore','Trinidad and Tobago - Trinidad - onshore.',9.99,10.9,-61.98,-60.85,0);
INSERT INTO "area" VALUES('EPSG','3144','French Guiana - east of 54°W','French Guiana - east of 54°W, onshore and offshore.',2.17,8.88,-54.0,-49.45,0);
INSERT INTO "area" VALUES('EPSG','3145','French Guiana - west of 54°W','French Guiana - west of 54°W.',2.11,5.69,-54.61,-54.0,0);
INSERT INTO "area" VALUES('EPSG','3146','French Guiana - onshore','French Guiana - onshore.',2.11,5.81,-54.61,-51.61,0);
INSERT INTO "area" VALUES('EPSG','3147','Congo DR (Zaire) - Katanga','The Democratic Republic of the Congo (Zaire) - Katanga.',-13.46,-4.99,21.74,30.78,0);
INSERT INTO "area" VALUES('EPSG','3148','Congo DR (Zaire) - Kasai - SE','The Democratic Republic of the Congo (Zaire) - Kasai - south of 5°S and east of 21°30''E.',-7.31,-5.01,21.5,26.26,0);
INSERT INTO "area" VALUES('EPSG','3149','Congo DR (Zaire) - 6th parallel south','The Democratic Republic of the Congo (Zaire) - adjacent to 6th parallel south traverse.',-7.36,-3.29,12.17,29.64,0);
INSERT INTO "area" VALUES('EPSG','3150','Congo DR (Zaire) - 11°E to 13°E onshore','The Democratic Republic of the Congo (Zaire) - onshore west of 13°E.',-6.04,-4.67,12.17,13.01,0);
INSERT INTO "area" VALUES('EPSG','3151','Congo DR (Zaire) - 13°E to 15°E','The Democratic Republic of the Congo (Zaire) - between 13°E to 15°E.',-5.91,-4.28,13.0,15.01,0);
INSERT INTO "area" VALUES('EPSG','3152','Congo DR (Zaire) - 15°E to 17°E','The Democratic Republic of the Congo (Zaire) - between 15°E to 17°E.',-7.31,-1.13,14.99,17.01,0);
INSERT INTO "area" VALUES('EPSG','3153','Congo DR (Zaire) - 17°E to 19°E','The Democratic Republic of the Congo (Zaire) - between 17°E to 19°E.',-8.11,4.77,17.0,19.01,0);
INSERT INTO "area" VALUES('EPSG','3154','Congo DR (Zaire) - 19°E to 21°E','The Democratic Republic of the Congo (Zaire) - between 19°E to 21°E.',-8.0,5.16,18.99,21.01,0);
INSERT INTO "area" VALUES('EPSG','3155','Congo DR (Zaire) - 21°E to 23°E','The Democratic Republic of the Congo (Zaire) - between 21°E to 23°E.',-11.24,4.84,20.99,23.01,0);
INSERT INTO "area" VALUES('EPSG','3156','Congo DR (Zaire) - 23°E to 25°E','The Democratic Republic of the Congo (Zaire) - between 23°E to 25°E.',-11.47,5.12,22.99,25.01,0);
INSERT INTO "area" VALUES('EPSG','3157','Congo DR (Zaire) - 25°E to 27°E','The Democratic Republic of the Congo (Zaire) - between 25°E to 27°E.',-11.99,5.39,24.99,27.0,0);
INSERT INTO "area" VALUES('EPSG','3158','Congo DR (Zaire) - 27°E to 29°E','The Democratic Republic of the Congo (Zaire) - between 27°E to 29°E.',-13.39,5.21,26.99,29.01,0);
INSERT INTO "area" VALUES('EPSG','3159','Congo DR (Zaire) - east of 29°E','The Democratic Republic of the Congo (Zaire) - east of 29°E.',-13.46,4.69,29.0,31.31,0);
INSERT INTO "area" VALUES('EPSG','3160','Congo DR (Zaire) - 6th parallel south 15°E to 17°E','The Democratic Republic of the Congo (Zaire) - adjacent to 6th parallel south traverse between 15°E and 17°E.',-5.87,-3.29,15.0,17.0,0);
INSERT INTO "area" VALUES('EPSG','3161','Congo DR (Zaire) - 6th parallel south 17°E to 19°E','The Democratic Republic of the Congo (Zaire) - adjacent to 6th parallel traverse between 17°E and 19°E.',-5.38,-3.4,17.0,19.0,0);
INSERT INTO "area" VALUES('EPSG','3162','Congo DR (Zaire) - 6th parallel south 19°E to 21°E','The Democratic Republic of the Congo (Zaire) - adjacent to 6th parallel south traverse between 19°E and 21°E.',-7.29,-4.01,19.0,21.0,0);
INSERT INTO "area" VALUES('EPSG','3163','Congo DR (Zaire) - 6th parallel south 21°E to 23°E','The Democratic Republic of the Congo (Zaire) - adjacent to 6th parallel south traverse between 21°E and 23°E.',-7.31,-5.31,21.0,23.0,0);
INSERT INTO "area" VALUES('EPSG','3164','Congo DR (Zaire) - 6th parallel south 23°E to 25°E','The Democratic Republic of the Congo (Zaire) - adjacent to 6th parallel south traverse between 23°E and 25°E.',-6.99,-5.01,23.0,25.0,0);
INSERT INTO "area" VALUES('EPSG','3165','Congo DR (Zaire) - 6th parallel south 25°E to 27°E','The Democratic Republic of the Congo (Zaire) - adjacent to 6th parallel south traverse between 25°E and 27°E.',-7.26,-4.23,25.0,27.0,0);
INSERT INTO "area" VALUES('EPSG','3166','Congo DR (Zaire) - 6th parallel south 27°E to 29°E','The Democratic Republic of the Congo (Zaire) - adjacent to 6th parallel south traverse between 27°E and 29°E.',-7.36,-4.24,27.0,29.0,0);
INSERT INTO "area" VALUES('EPSG','3167','Congo DR (Zaire) - 6th parallel south 29°E to 31°E','The Democratic Republic of the Congo (Zaire) - adjacent to 6th parallel south traverse and east of 29°E.',-6.04,-4.34,29.0,29.64,0);
INSERT INTO "area" VALUES('EPSG','3168','Poland - west of 18°E','Poland - west of 18°E.',49.98,54.85,14.14,18.0,1);
INSERT INTO "area" VALUES('EPSG','3169','Poland - 18°E to 24°E','Poland - between 18°E and 24°E.',49.03,55.95,18.0,24.0,1);
INSERT INTO "area" VALUES('EPSG','3170','Poland - east of 24°E','Poland - east of 24°E.',50.4,50.9,24.0,24.16,1);
INSERT INTO "area" VALUES('EPSG','3171','Congo DR (Zaire) - Bas Congo','The Democratic Republic of the Congo (Zaire) - Lower Congo (Bas Congo)',-6.04,-4.28,12.17,16.28,0);
INSERT INTO "area" VALUES('EPSG','3172','Pacific Ocean','Pacific Ocean - American Samoa, Antarctica, Australia, Brunei Darussalam, Cambodia, Canada, Chile, China, China - Hong Kong, China - Macao, Cook Islands, Ecuador, Fiji, French Polynesia, Guam, Indonesia, Japan, Kiribati, Democratic People''s Republic of Korea (North Korea), Republic of Korea (South Korea), Malaysia, Marshall Islands, Federated States of Micronesia, Nauru, New Caledonia, New Zealand, Niue, Norfolk Island, Northern Mariana Islands, Palau, Panama, Papua New Guinea (PNG), Peru, Philippines, Pitcairn, Russian Federation, Samoa, Singapore, Solomon Islands, Taiwan, Thailand, Tokelau, Tonga, Tuvalu, United States (USA), United States Minor Outlying Islands, Vanuatu, Venezuela, Vietnam, Wallis and Futuna.',-60.0,66.67,98.69,-68.0,0);
INSERT INTO "area" VALUES('EPSG','3173','Europe - FSU - CS63 zone C0','Estonia, Latvia and Lithuania - onshore west of 23°27''E. Russia - Kaliningrad onshore.',54.17,59.27,19.57,23.45,0);
INSERT INTO "area" VALUES('EPSG','3174','Europe - FSU - CS63 zone C1','Estonia, Latvia and Lithuania - onshore between 23°27''E and 26°27''E.',53.89,59.72,23.45,26.45,0);
INSERT INTO "area" VALUES('EPSG','3175','Europe - FSU - CS63 zone C2','Estonia, Latvia and Lithuania - onshore east of 26°27''E.',55.15,59.61,26.45,28.24,0);
INSERT INTO "area" VALUES('EPSG','3176','Brazil - 54°W to 48°W and south of 15°S','Brazil - onshore between 54°W and 48°W and south of 15°S.',-33.78,-15.0,-54.0,-48.0,0);
INSERT INTO "area" VALUES('EPSG','3177','Brazil - 48°W to 42°W and south of 15°S','Brazil - onshore between 48°W and 42°W and south of 15°S.',-25.29,-15.0,-48.0,-42.0,0);
INSERT INTO "area" VALUES('EPSG','3178','Brazil - east of 36°W onshore','Brazil - onshore east of 36°W .',-10.1,-4.99,-36.0,-34.74,0);
INSERT INTO "area" VALUES('EPSG','3179','Africa - Angola (Cabinda) and DR Congo (Zaire) - coastal','Angola (Cabinda) - onshore and offshore; The Democratic Republic of the Congo (Zaire) - onshore coastal area and offshore.',-6.04,-4.38,10.53,13.1,0);
INSERT INTO "area" VALUES('EPSG','3180','Africa - Angola (Cabinda) and DR Congo (Zaire) - offshore','Angola (Cabinda) - offshore; The Democratic Republic of the Congo (Zaire) - offshore.',-6.04,-5.05,10.53,12.37,0);
INSERT INTO "area" VALUES('EPSG','3181','USA - Hawaii - Tern Island and Sorel Atoll','United States (USA) - Hawaii - Tern Island and Sorel Atoll.',23.69,23.93,-166.36,-166.03,0);
INSERT INTO "area" VALUES('EPSG','3182','St Helena - Ascension Island','St Helena, Ascension and Tristan da Cunha - Ascension Island - onshore.',-8.03,-7.83,-14.46,-14.24,0);
INSERT INTO "area" VALUES('EPSG','3183','St Helena - St Helena Island','St Helena, Ascension and Tristan da Cunha - St Helena Island - onshore.',-16.08,-15.85,-5.85,-5.58,0);
INSERT INTO "area" VALUES('EPSG','3184','St Helena - Tristan da Cunha','St Helena, Ascension and Tristan da Cunha - Tristan da Cunha island group including Tristan, Inaccessible, Nightingale, Middle and Stoltenhoff Islands.',-40.42,-37.0,-12.76,-9.8,0);
INSERT INTO "area" VALUES('EPSG','3185','Cayman Islands - Grand Cayman','Cayman Islands - Grand Cayman.',19.21,19.41,-81.46,-81.04,0);
INSERT INTO "area" VALUES('EPSG','3186','Cayman Islands - Little Cayman and Cayman Brac','Cayman Islands - Little Cayman and Cayman Brac.',19.63,19.78,-80.14,-79.69,0);
INSERT INTO "area" VALUES('EPSG','3187','South Georgia and the South Sandwich Islands - onshore','South Georgia and the South Sandwich Islands - onshore.',-59.53,-53.49,-42.14,-26.19,0);
INSERT INTO "area" VALUES('EPSG','3188','Chile - Easter Island onshore','Chile - Easter Island onshore.',-27.25,-27.01,-109.51,-109.16,0);
INSERT INTO "area" VALUES('EPSG','3189','British Indian Ocean Territory - Diego Garcia','British Indian Ocean Territory - Chagos Archipelago - Diego Garcia.',-7.49,-7.18,72.3,72.55,0);
INSERT INTO "area" VALUES('EPSG','3190','Wake - onshore','Wake atoll - onshore.',19.22,19.38,166.55,166.72,0);
INSERT INTO "area" VALUES('EPSG','3191','Pacific - Marshall Islands, Wake - onshore','Marshall Islands - onshore. Wake atoll onshore.',8.66,19.38,162.27,167.82,0);
INSERT INTO "area" VALUES('EPSG','3192','Micronesia - Kosrae (Kusaie)','Federated States of Micronesia - Kosrae (Kusaie).',5.21,5.43,162.85,163.1,0);
INSERT INTO "area" VALUES('EPSG','3193','Vanuatu - southern islands','Vanuatu - southern islands - Aneityum, Efate, Erromango and Tanna.',-20.31,-17.37,168.09,169.95,0);
INSERT INTO "area" VALUES('EPSG','3194','Vanuatu - northern islands','Vanuatu - northern islands - Aese, Ambrym, Aoba, Epi, Espiritu Santo, Maewo, Malo, Malkula, Paama, Pentecost, Shepherd and Tutuba.',-17.32,-14.57,166.47,168.71,0);
INSERT INTO "area" VALUES('EPSG','3195','Fiji - Viti Levu','Fiji - Viti Levu island.',-18.32,-17.25,177.19,178.75,0);
INSERT INTO "area" VALUES('EPSG','3196','Kiribati - Phoenix Islands','Kiribati - Phoenix Islands: Kanton, Orona, McKean Atoll, Birnie Atoll, Phoenix Seamounts.',-4.76,-2.68,-174.6,-170.66,0);
INSERT INTO "area" VALUES('EPSG','3197','Solomon Islands - Guadalcanal Island','Solomon Islands - Guadalcanal Island.',-9.98,-9.2,159.55,160.88,0);
INSERT INTO "area" VALUES('EPSG','3198','Solomon Islands - New Georgia - Ghizo (Gizo)','Solomon Islands - Western Islands - New Georgia, Ghizo (Gizo).',-8.86,-7.52,156.44,158.2,0);
INSERT INTO "area" VALUES('EPSG','3199','Spain - Canary Islands','Spain - Canary Islands onshore and offshore.',24.6,32.76,-21.93,-11.75,0);
INSERT INTO "area" VALUES('EPSG','3200','Japan - Iwo Jima','Japan - Iwo Jima island.',24.67,24.89,141.2,141.42,0);
INSERT INTO "area" VALUES('EPSG','3201','Johnston Island','United States Minor Outlying Islands - Johnston Island.',16.67,16.79,-169.59,-169.47,0);
INSERT INTO "area" VALUES('EPSG','3202','Midway Islands - Sand and Eastern Islands','United States Minor Outlying Islands - Midway Islands - Sand Island and Eastern Island.',28.13,28.28,-177.45,-177.31,0);
INSERT INTO "area" VALUES('EPSG','3203','Japan - Minamitori-shima (Marcus Island)','Japan - Minamitori-shima (Marcus Island).',24.26,24.32,153.95,154.01,1);
INSERT INTO "area" VALUES('EPSG','3204','Antarctica - Deception Island','Antarctica - South Shetland Islands - Deception Island.',-63.08,-62.82,-60.89,-60.35,0);
INSERT INTO "area" VALUES('EPSG','3205','Antarctica - Camp McMurdo area','Antarctica - McMurdo Sound, Camp McMurdo area.',-77.94,-77.17,165.73,167.43,0);
INSERT INTO "area" VALUES('EPSG','3206','North America - Bahamas and USA - Florida - onshore','North America - onshore - Bahamas and USA - Florida (east).',20.86,30.83,-82.33,-72.68,0);
INSERT INTO "area" VALUES('EPSG','3207','Cayman Islands - Cayman Brac','Cayman Islands - Cayman Brac.',19.66,19.78,-79.92,-79.69,0);
INSERT INTO "area" VALUES('EPSG','3208','Pitcairn - Pitcairn Island','Pitcairn - Pitcairn Island.',-25.14,-25.0,-130.16,-130.01,0);
INSERT INTO "area" VALUES('EPSG','3209','Mauritius - mainland','Mauritius - mainland onshore.',-20.57,-19.94,57.25,57.85,0);
INSERT INTO "area" VALUES('EPSG','3210','Serbia and Montenegro','Serbia and Montenegro - onshore and offshore.',41.82,46.23,18.44,23.05,1);
INSERT INTO "area" VALUES('EPSG','3211','Aaland Islands','Åland Islands - onshore and offshore.',59.84,60.48,19.24,21.19,0);
INSERT INTO "area" VALUES('EPSG','3212','Albania - onshore','Albania - onshore.',39.64,42.67,19.22,21.06,0);
INSERT INTO "area" VALUES('EPSG','3213','Algeria - onshore','Algeria - onshore.',18.97,37.14,-8.67,11.99,0);
INSERT INTO "area" VALUES('EPSG','3214','Anguilla - onshore','Anguilla - onshore.',18.11,18.33,-63.22,-62.92,0);
INSERT INTO "area" VALUES('EPSG','3215','Argentina - mainland onshore','Argentina - mainland onshore.',-52.43,-21.78,-73.59,-53.65,0);
INSERT INTO "area" VALUES('EPSG','3216','Aruba - onshore','Aruba - onshore.',12.36,12.68,-70.11,-69.82,0);
INSERT INTO "area" VALUES('EPSG','3217','Bangladesh - onshore','Bangladesh - onshore.',20.52,26.64,88.01,92.67,0);
INSERT INTO "area" VALUES('EPSG','3218','Barbados - onshore','Barbados - onshore.',13.0,13.39,-59.71,-59.37,0);
INSERT INTO "area" VALUES('EPSG','3219','Belize - onshore','Belize - onshore.',15.88,18.49,-89.22,-87.72,0);
INSERT INTO "area" VALUES('EPSG','3220','Benin - onshore','Benin - onshore.',6.17,12.4,0.77,3.86,0);
INSERT INTO "area" VALUES('EPSG','3221','Bermuda - onshore','Bermuda - onshore.',32.21,32.43,-64.89,-64.61,0);
INSERT INTO "area" VALUES('EPSG','3222','Bouvet Island - onshore','Bouvet Island - onshore.',-54.52,-54.33,3.29,3.54,0);
INSERT INTO "area" VALUES('EPSG','3223','Brazil - onshore','Brazil - onshore.',-33.78,5.28,-74.01,-34.74,0);
INSERT INTO "area" VALUES('EPSG','3224','Bulgaria - onshore','Bulgaria - onshore.',41.24,44.23,22.36,28.68,0);
INSERT INTO "area" VALUES('EPSG','3225','Cambodia - onshore','Cambodia - onshore.',10.39,14.71,102.34,107.64,0);
INSERT INTO "area" VALUES('EPSG','3226','Cameroon - onshore','Cameroon - onshore.',1.65,13.09,8.45,16.21,0);
INSERT INTO "area" VALUES('EPSG','3227','Chile - onshore north of 45°S','Chile - onshore north of 45°S.',-45.0,-17.5,-75.22,-67.0,0);
INSERT INTO "area" VALUES('EPSG','3228','China - onshore','China - onshore.',18.11,53.56,73.62,134.77,0);
INSERT INTO "area" VALUES('EPSG','3229','Colombia - mainland','Colombia - mainland onshore.',-4.23,12.52,-79.1,-66.87,0);
INSERT INTO "area" VALUES('EPSG','3230','Congo - onshore','Congo - onshore.',-5.06,3.72,11.11,18.65,0);
INSERT INTO "area" VALUES('EPSG','3231','Congo DR (Zaire) - onshore','The Democratic Republic of the Congo (Zaire) - onshore.',-13.46,5.39,12.17,31.31,0);
INSERT INTO "area" VALUES('EPSG','3232','Costa Rica - onshore','Costa Rica - onshore.',7.98,11.22,-85.97,-82.53,0);
INSERT INTO "area" VALUES('EPSG','3233','Cote d''Ivoire (Ivory Coast) - onshore','Côte d''Ivoire (Ivory Coast) - onshore.',4.29,10.74,-8.61,-2.48,0);
INSERT INTO "area" VALUES('EPSG','3234','Croatia - onshore','Croatia - onshore.',42.34,46.54,13.43,19.43,0);
INSERT INTO "area" VALUES('EPSG','3235','Cuba - onshore','Cuba - onshore.',19.77,23.25,-85.01,-74.07,0);
INSERT INTO "area" VALUES('EPSG','3236','Cyprus - onshore','Cyprus - onshore.',34.59,35.74,32.2,34.65,0);
INSERT INTO "area" VALUES('EPSG','3237','Denmark - onshore','Denmark - onshore.',54.51,57.8,8.0,15.24,0);
INSERT INTO "area" VALUES('EPSG','3238','Djibouti - onshore','Djibouti - onshore.',10.94,12.72,41.75,43.48,0);
INSERT INTO "area" VALUES('EPSG','3239','Dominica - onshore','Dominica - onshore.',15.14,15.69,-61.55,-61.2,0);
INSERT INTO "area" VALUES('EPSG','3240','Dominican Republic - onshore','Dominican Republic - onshore.',17.55,19.99,-72.01,-68.27,0);
INSERT INTO "area" VALUES('EPSG','3241','Ecuador - mainland onshore','Ecuador - mainland - onshore.',-5.01,1.45,-81.03,-75.21,0);
INSERT INTO "area" VALUES('EPSG','3242','Egypt - onshore','Egypt - onshore.',21.97,31.68,24.7,36.95,0);
INSERT INTO "area" VALUES('EPSG','3243','El Salvador - onshore','El Salvador - onshore.',13.1,14.44,-90.11,-87.69,0);
INSERT INTO "area" VALUES('EPSG','3244','Equatorial Guinea - onshore','Equatorial Guinea - onshore.',0.93,3.82,8.37,11.36,0);
INSERT INTO "area" VALUES('EPSG','3245','Eritrea - onshore','Eritrea - onshore.',12.36,18.01,36.44,43.18,0);
INSERT INTO "area" VALUES('EPSG','3246','Estonia - onshore','Estonia - onshore.',57.52,59.75,21.74,28.2,0);
INSERT INTO "area" VALUES('EPSG','3247','Falkland Islands - onshore','Falkland Islands (Malvinas) - onshore.',-52.51,-50.96,-61.54,-57.61,0);
INSERT INTO "area" VALUES('EPSG','3248','Faroe Islands - onshore','Faroe Islands - onshore.',61.33,62.41,-7.49,-6.33,0);
INSERT INTO "area" VALUES('EPSG','3249','Gabon - onshore','Gabon - onshore.',-3.98,2.32,8.65,14.52,0);
INSERT INTO "area" VALUES('EPSG','3250','Gambia - onshore','Gambia - onshore.',13.05,13.83,-16.88,-13.79,0);
INSERT INTO "area" VALUES('EPSG','3251','Georgia - onshore','Georgia - onshore.',41.04,43.59,39.99,46.72,0);
INSERT INTO "area" VALUES('EPSG','3252','Ghana - onshore','Ghana - onshore.',4.67,11.16,-3.25,1.23,0);
INSERT INTO "area" VALUES('EPSG','3253','Gibraltar - onshore','Gibraltar - onshore.',36.07,36.16,-5.42,-5.27,0);
INSERT INTO "area" VALUES('EPSG','3254','Greece - onshore','Greece - onshore.',34.88,41.75,19.57,28.3,0);
INSERT INTO "area" VALUES('EPSG','3255','Guam - onshore','Guam - onshore.',13.18,13.7,144.58,145.01,0);
INSERT INTO "area" VALUES('EPSG','3256','Guatemala - onshore','Guatemala - onshore.',13.69,17.83,-92.29,-88.19,0);
INSERT INTO "area" VALUES('EPSG','3257','Guinea - onshore','Guinea - onshore.',7.19,12.68,-15.13,-7.65,0);
INSERT INTO "area" VALUES('EPSG','3258','Guinea-Bissau - onshore','Guinea-Bissau - onshore.',10.87,12.69,-16.77,-13.64,0);
INSERT INTO "area" VALUES('EPSG','3259','Guyana - onshore','Guyana - onshore.',1.18,8.58,-61.39,-56.47,0);
INSERT INTO "area" VALUES('EPSG','3260','Haiti - onshore','Haiti - onshore.',17.97,20.15,-74.52,-71.62,0);
INSERT INTO "area" VALUES('EPSG','3261','Honduras - onshore','Honduras - onshore.',12.98,16.49,-89.36,-83.08,0);
INSERT INTO "area" VALUES('EPSG','3262','Iceland - onshore','Iceland - onshore.',63.34,66.59,-24.66,-13.38,0);
INSERT INTO "area" VALUES('EPSG','3263','Japan - onshore mainland','Japan - onshore mainland - Hokkaido, Honshu, Shikoku, Kyushu.',30.94,45.54,129.3,145.87,0);
INSERT INTO "area" VALUES('EPSG','3264','Kenya - onshore','Kenya - onshore.',-4.72,4.63,33.9,41.91,0);
INSERT INTO "area" VALUES('EPSG','3265','Korea, Democratic People''s Republic of (North Korea) - onshore','Democratic People''s Republic of Korea (North Korea) - onshore.',37.62,43.01,124.27,130.75,0);
INSERT INTO "area" VALUES('EPSG','3266','Korea, Republic of (South Korea) - onshore','Republic of Korea (South Korea) - onshore.',33.14,38.64,124.53,131.01,0);
INSERT INTO "area" VALUES('EPSG','3267','Kuwait - onshore','Kuwait - onshore.',28.53,30.09,46.54,48.48,0);
INSERT INTO "area" VALUES('EPSG','3268','Latvia - onshore','Latvia - onshore.',55.67,58.09,20.87,28.24,0);
INSERT INTO "area" VALUES('EPSG','3269','Lebanon - onshore','Lebanon - onshore.',33.06,34.65,35.04,36.63,0);
INSERT INTO "area" VALUES('EPSG','3270','Liberia - onshore','Liberia - onshore.',4.29,8.52,-11.52,-7.36,0);
INSERT INTO "area" VALUES('EPSG','3271','Libya - onshore','Libya - onshore.',19.5,33.23,9.31,25.21,0);
INSERT INTO "area" VALUES('EPSG','3272','Lithuania - onshore','Lithuania - onshore.',53.89,56.45,20.86,26.82,0);
INSERT INTO "area" VALUES('EPSG','3273','Madagascar - onshore','Madagascar - onshore.',-25.64,-11.89,43.18,50.56,0);
INSERT INTO "area" VALUES('EPSG','3274','Maldives - onshore','Maldives - onshore.',-0.69,7.08,72.81,73.69,0);
INSERT INTO "area" VALUES('EPSG','3275','Malta - onshore','Malta - onshore.',35.74,36.05,14.27,14.63,0);
INSERT INTO "area" VALUES('EPSG','3276','Martinique - onshore','Martinique - onshore.',14.35,14.93,-61.29,-60.76,0);
INSERT INTO "area" VALUES('EPSG','3277','Mauritania - onshore','Mauritania - onshore.',14.72,27.3,-17.08,-4.8,0);
INSERT INTO "area" VALUES('EPSG','3278','Mexico - onshore','Mexico - onshore.',14.51,32.72,-118.47,-86.68,0);
INSERT INTO "area" VALUES('EPSG','3279','Montserrat - onshore','Montserrat - onshore.',16.62,16.87,-62.29,-62.08,0);
INSERT INTO "area" VALUES('EPSG','3280','Morocco - onshore','Morocco - onshore.',27.66,35.97,-13.24,-1.01,0);
INSERT INTO "area" VALUES('EPSG','3281','Mozambique - onshore','Mozambique - onshore.',-26.87,-10.42,30.21,40.9,0);
INSERT INTO "area" VALUES('EPSG','3282','Myanmar (Burma) - onshore','Myanmar (Burma) - onshore.',9.78,28.55,92.2,101.17,0);
INSERT INTO "area" VALUES('EPSG','3283','Namibia - onshore','Namibia - onshore.',-28.97,-16.95,11.66,25.27,0);
INSERT INTO "area" VALUES('EPSG','3284','Netherlands - onshore','Netherlands - onshore.',50.78,53.6,3.33,7.3,1);
INSERT INTO "area" VALUES('EPSG','3285','New Zealand - onshore and nearshore','New Zealand - North Island, South Island, Stewart Island - onshore and nearshore.',-47.65,-33.89,165.87,179.27,0);
INSERT INTO "area" VALUES('EPSG','3286','Nicaragua - onshore','Nicaragua - onshore.',10.7,15.03,-87.74,-83.08,0);
INSERT INTO "area" VALUES('EPSG','3287','Nigeria - onshore','Nigeria - onshore.',4.22,13.9,2.69,14.65,0);
INSERT INTO "area" VALUES('EPSG','3288','Oman - onshore','Oman - onshore. Includes Musandam and the Kuria Muria (Al Hallaniyah) islands.',16.59,26.58,51.99,59.91,0);
INSERT INTO "area" VALUES('EPSG','3289','Pakistan - onshore','Pakistan - onshore.',23.64,37.07,60.86,77.83,0);
INSERT INTO "area" VALUES('EPSG','3290','Panama - onshore','Panama - onshore.',7.15,9.68,-83.04,-77.19,0);
INSERT INTO "area" VALUES('EPSG','3291','Papua New Guinea - onshore','Papua New Guinea - onshore.',-11.7,-1.3,140.85,156.02,0);
INSERT INTO "area" VALUES('EPSG','3292','Peru - onshore','Peru - onshore.',-18.35,-0.03,-81.41,-68.67,0);
INSERT INTO "area" VALUES('EPSG','3293','Poland - onshore','Poland - onshore.',49.0,54.89,14.14,24.15,0);
INSERT INTO "area" VALUES('EPSG','3294','Puerto Rico - onshore','Puerto Rico - onshore.',17.87,18.57,-67.97,-65.19,0);
INSERT INTO "area" VALUES('EPSG','3295','Romania - onshore','Romania - onshore.',43.62,48.27,20.26,29.74,0);
INSERT INTO "area" VALUES('EPSG','3296','Russia - onshore','Russian Federation - onshore.',41.19,81.91,19.58,-168.97,0);
INSERT INTO "area" VALUES('EPSG','3297','St Kitts and Nevis - onshore','St Kitts and Nevis - onshore.',17.06,17.46,-62.92,-62.5,0);
INSERT INTO "area" VALUES('EPSG','3298','St Lucia - onshore','St Lucia - onshore.',13.66,14.16,-61.13,-60.82,0);
INSERT INTO "area" VALUES('EPSG','3299','St Pierre and Miquelon - onshore','St Pierre and Miquelon - onshore.',46.69,47.19,-56.48,-56.07,0);
INSERT INTO "area" VALUES('EPSG','3300','St Vincent and the Grenadines - onshore','St Vincent and the northern Grenadine Islands - onshore.',12.54,13.44,-61.52,-61.07,0);
INSERT INTO "area" VALUES('EPSG','3301','Samoa - onshore','Samoa - onshore.',-14.11,-13.41,-172.84,-171.37,0);
INSERT INTO "area" VALUES('EPSG','3302','Sao Tome and Principe - onshore','Sao Tome and Principe - onshore.',-0.04,1.76,6.41,7.52,0);
INSERT INTO "area" VALUES('EPSG','3303','Saudi Arabia - onshore','Saudi Arabia - onshore.',15.61,32.16,34.51,55.67,0);
INSERT INTO "area" VALUES('EPSG','3304','Senegal - onshore','Senegal - onshore.',12.29,16.7,-17.59,-11.36,0);
INSERT INTO "area" VALUES('EPSG','3305','Serbia and Montenegro - onshore','Serbia and Montenegro - onshore.',41.82,46.23,18.44,23.05,1);
INSERT INTO "area" VALUES('EPSG','3306','Sierra Leone - onshore','Sierra Leone - onshore.',6.88,10.0,-13.35,-10.26,0);
INSERT INTO "area" VALUES('EPSG','3307','Slovenia - onshore','Slovenia - onshore.',45.42,46.88,13.38,16.61,0);
INSERT INTO "area" VALUES('EPSG','3308','Somalia - onshore','Somalia - onshore.',-1.71,12.03,40.99,51.47,0);
INSERT INTO "area" VALUES('EPSG','3309','South Africa - onshore','South Africa - mainland onshore.',-34.88,-22.13,16.45,32.95,0);
INSERT INTO "area" VALUES('EPSG','3310','Sri Lanka - onshore','Sri Lanka - onshore.',5.86,9.88,79.64,81.95,0);
INSERT INTO "area" VALUES('EPSG','3311','Africa - South Sudan and Sudan onshore','South Sudan. Sudan - onshore.',3.49,22.24,21.82,38.66,0);
INSERT INTO "area" VALUES('EPSG','3312','Suriname - onshore','Suriname - onshore.',1.83,6.06,-58.08,-53.95,0);
INSERT INTO "area" VALUES('EPSG','3313','Sweden - onshore','Sweden - onshore.',55.28,69.07,10.93,24.17,0);
INSERT INTO "area" VALUES('EPSG','3314','Syria - onshore','Syria - onshore.',32.31,37.3,35.61,42.38,0);
INSERT INTO "area" VALUES('EPSG','3315','Taiwan - onshore - mainland and Penghu','Taiwan, Republic of China - onshore - Taiwan Island, Penghu (Pescadores) Islands.',21.87,25.34,119.25,122.06,0);
INSERT INTO "area" VALUES('EPSG','3316','Tanzania - onshore','Tanzania - onshore.',-11.75,-0.99,29.34,40.48,0);
INSERT INTO "area" VALUES('EPSG','3317','Thailand - onshore','Thailand - onshore.',5.63,20.46,97.34,105.64,0);
INSERT INTO "area" VALUES('EPSG','3318','East Timor - onshore','Timor-Leste (East Timor) - onshore.',-9.5,-8.08,124.03,127.36,0);
INSERT INTO "area" VALUES('EPSG','3319','Togo - onshore','Togo - onshore.',6.05,11.14,-0.15,1.8,0);
INSERT INTO "area" VALUES('EPSG','3320','Tokelau - onshore','Tokelau - onshore.',-9.27,-9.12,-171.92,-171.79,0);
INSERT INTO "area" VALUES('EPSG','3321','Tonga - onshore','Tonga - onshore.',-21.32,-18.51,-175.42,-173.85,0);
INSERT INTO "area" VALUES('EPSG','3322','Turkey - onshore','Turkey - onshore.',35.81,42.15,25.62,44.83,0);
INSERT INTO "area" VALUES('EPSG','3323','Turks and Caicos Islands - onshore','Turks and Caicos Islands - onshore.',21.38,22.01,-72.09,-71.07,0);
INSERT INTO "area" VALUES('EPSG','3324','Ukraine - onshore','Ukraine - onshore.',44.32,52.38,22.15,40.18,0);
INSERT INTO "area" VALUES('EPSG','3325','UAE - onshore','United Arab Emirates (UAE) - onshore. Abu Dhabi, Dubai, Sharjah, Umm al Qaywayn, Al Fujairah, Ras al Khaymah.',22.63,26.1,51.56,56.44,0);
INSERT INTO "area" VALUES('EPSG','3326','Uruguay - onshore','Uruguay - onshore.',-35.0,-30.09,-58.49,-53.09,0);
INSERT INTO "area" VALUES('EPSG','3327','Venezuela - onshore','Venezuela - onshore.',0.64,12.25,-73.38,-59.8,0);
INSERT INTO "area" VALUES('EPSG','3328','Vietnam - onshore','Vietnam - onshore.',8.5,23.33,102.14,109.52,0);
INSERT INTO "area" VALUES('EPSG','3329','Virgin Islands, British - onshore','British Virgin Islands - onshore - Anegada, Jost Van Dyke, Tortola, and Virgin Gorda.',18.28,18.78,-64.88,-64.25,0);
INSERT INTO "area" VALUES('EPSG','3330','Virgin Islands, US - onshore','US Virgin Islands - onshore - St Croix, St John, and St Thomas.',17.62,18.44,-65.09,-64.51,0);
INSERT INTO "area" VALUES('EPSG','3331','Western Sahara - onshore','Western Sahara - onshore.',20.71,27.67,-17.16,-8.66,0);
INSERT INTO "area" VALUES('EPSG','3332','Yemen - onshore','Yemen - onshore.',12.09,19.0,41.8,54.53,0);
INSERT INTO "area" VALUES('EPSG','3333','Finland - onshore','Finland - onshore.',59.75,70.09,19.24,31.59,0);
INSERT INTO "area" VALUES('EPSG','3334','China - Hong Kong - onshore','China - Hong Kong - onshore.',22.19,22.56,113.82,114.39,0);
INSERT INTO "area" VALUES('EPSG','3335','China - Hong Kong - offshore','China - Hong Kong - offshore.',22.13,22.58,113.76,114.51,0);
INSERT INTO "area" VALUES('EPSG','3336','Iran - onshore','Iran - onshore.',25.02,39.78,44.03,63.34,0);
INSERT INTO "area" VALUES('EPSG','3337','Reunion - onshore','Reunion - onshore.',-21.42,-20.81,55.16,55.91,0);
INSERT INTO "area" VALUES('EPSG','3338','New Zealand - Stewart Island','New Zealand - Stewart Island.',-47.33,-46.63,167.29,168.34,0);
INSERT INTO "area" VALUES('EPSG','3339','Germany - onshore','Germany - onshore - states of Baden-Wurtemberg, Bayern, Berlin, Brandenburg, Bremen, Hamburg, Hessen, Mecklenburg-Vorpommern, Niedersachsen, Nordrhein-Westfalen, Rheinland-Pfalz, Saarland, Sachsen, Sachsen-Anhalt, Schleswig-Holstein, Thuringen.',47.27,55.09,5.86,15.04,0);
INSERT INTO "area" VALUES('EPSG','3340','Mayotte - onshore','Mayotte - onshore.',-13.05,-12.61,44.98,45.35,0);
INSERT INTO "area" VALUES('EPSG','3341','India - mainland','India - mainland onshore.',8.02,35.51,68.13,97.42,0);
INSERT INTO "area" VALUES('EPSG','3342','Jamaica - onshore','Jamaica - onshore.',17.64,18.58,-78.43,-76.17,0);
INSERT INTO "area" VALUES('EPSG','3343','Italy - including San Marino and Vatican','Italy - onshore and offshore; San Marino, Vatican City State.',34.76,47.1,5.93,18.99,0);
INSERT INTO "area" VALUES('EPSG','3344','New Zealand - South and Stewart Islands','New Zealand - South Island, Stewart Island.',-47.33,-40.44,166.37,174.46,0);
INSERT INTO "area" VALUES('EPSG','3345','Slovenia - Ljubljana east','Slovenia - eastern part of the Ljubljana region with the Kamnik-Domzale area.',45.85,46.32,14.45,15.01,0);
INSERT INTO "area" VALUES('EPSG','3346','Slovenia - Prekmurje','Slovenia - Prekmurje (the Transmuraland).',46.47,46.88,15.98,16.61,0);
INSERT INTO "area" VALUES('EPSG','3347','Slovenia - Novo Mesto','Slovenia - Novo Mesto with the Gorjanci.',45.66,45.87,15.06,15.47,0);
INSERT INTO "area" VALUES('EPSG','3348','Slovenia - Gorenjska - upper','Slovenia - upper Gorenjska (Upper Carniola) with the Baca Valley and part of the Cerkno Mountains.',46.09,46.53,13.7,14.18,0);
INSERT INTO "area" VALUES('EPSG','3349','Slovenia - Ljubliana west','Slovenia - western part of the Ljubljana region with part of Skofja Loka Hills and the Idrija-Cerklje region.',45.86,46.21,13.95,14.52,0);
INSERT INTO "area" VALUES('EPSG','3350','Slovenia - Notranjska','Slovenia - Notranjska (Inner Carniola) with parts of the Karst and the Brkini Hills.',45.47,45.88,14.08,14.59,0);
INSERT INTO "area" VALUES('EPSG','3351','Slovenia - Kocevje','Slovenia - Kocevje with the Kocevski Forest and Gotenica Mountain.',45.46,45.76,14.6,15.12,0);
INSERT INTO "area" VALUES('EPSG','3352','Slovenia - Koroska','Slovenia - Koroska Region (Slovene Carinthia).',46.46,46.66,14.83,15.51,0);
INSERT INTO "area" VALUES('EPSG','3353','Slovenia - Velenje','Slovenia - Velenje with part of Koroska Region (Slovene Carinthia).',46.28,46.51,14.9,15.26,0);
INSERT INTO "area" VALUES('EPSG','3354','Slovenia - Zasavje','Slovenia - Zasavje (the Sava Valley) with the broad region of Celje.',46.0,46.32,14.84,15.35,0);
INSERT INTO "area" VALUES('EPSG','3355','Brazil - south of 18°S and west of 54°W','Brazil - onshore south of 18°S and west of 54°W.',-31.91,-17.99,-58.16,-54.0,0);
INSERT INTO "area" VALUES('EPSG','3356','South America - Brazil - south of 18°S and west of 54°W + DF; N Paraguay','Brazil - south of 18°S and west of 54°W, plus Distrito Federal. Paraguay - north.',-31.91,-15.37,-62.57,-47.1,0);
INSERT INTO "area" VALUES('EPSG','3357','USA - GoM OCS','United States (USA) - offshore Gulf of Mexico outer continental shelf (GoM OCS) - protraction areas South Padre Island; North Padre Island; Mustang Island; Matagorda Island; Brazos; Galveston; High Island; Sabine Pass; West Cameron; East Cameron; Vermilion; South Marsh Island; Eugene Island; Ship Shoal; South Pelto; Bay Marchand; South Timbalier; Grand Isle; West Delta; South Pass; Main Pass; Breton Sound; Chandeleur; Corpus Christi; Port Isabel; East Breaks; Alaminos Canyon; Garden Banks; Keathley Canyon; Sigsbee Escarpment; Ewing Bank; Green Canyon; Walker Ridge; Amery Terrace; Mobile; Viosca Knoll; Mississippi Canyon; Atwater Valley; Lund; Lund South; Pensacola; Destin Dome; De Soto Canyon; Lloyd Ridge; Henderson; Florida Plain; Campeche Escarpment; Apalachicola; Florida Middle Ground; The Elbow; Vernon Basin; Howell Hook; Rankin; Gainesville; Tarpon Springs; St Petersburg; Charlotte Harbor; Pulley Ridge; Dry Tortugas; Tortugas Valley; Miami; Key West.',23.82,30.25,-97.22,-81.17,0);
INSERT INTO "area" VALUES('EPSG','3358','USA - GoM - east of 87.25°W','United States (USA) - offshore Gulf of Mexico (GoM) east of approximately 87°15''W - protraction areas Gainesville, Tarpon Springs, St Petersburg, Charlotte Harbor, Pulley Ridge, Dry Tortugas, Tortugas Valley, Miami, Key West, Apalachicola, Florida Middle Ground, The Elbow, Vernon Basin, Howell Hook, Rankin and Campeche Escarpment. Also for protraction areas Pensacola, Destin Dome, Desoto Canyon, Lloyd Ridge, Henderson and Florida Plain - east of 87°15''W.',23.82,30.25,-87.25,-81.17,0);
INSERT INTO "area" VALUES('EPSG','3359','USA - GoM - 95°W to 87.25°W','United States (USA) - offshore Gulf of Mexico (GoM) between approximately 95°W and 87°15''W - protraction areas High Island (including all additions and extensions), Sabine Pass, West Cameron (including west and south additions), East Cameron (including south addition), Vermillion (including south addition), South Marsh Island (including north and south additions), Eugene Island (including south addition), Ship Shoal (including south addition), South Timbalier (including south addition), Grand Isle (including south addition), West Delta (including south addition), South Pass (including south and east additions), Main Pass (including south and east addition), Breton Sound, Chandeleur (including east addition), Mobile, Viosca Knoll, Mississippi Canyon, Atwater Valley, Lund, Lund South, Ewing Bank, Green Canyon, Walker Ridge, Amery Terrace, Garden Banks, Keathley Canyon and Sigsbee Escarpment. Also for protraction areas Galveston (including south addition), East Breaks and Aliminos Canyon - east of 95°W; for protraction areas Pensacola, Destin Dome, Desoto Canyon, Lloyd Ridge, Henderson and Florida Plain - west of 87°15''W.',25.61,30.23,-95.0,-87.25,0);
INSERT INTO "area" VALUES('EPSG','3360','USA - GoM - west of 95°W','United States (USA) - offshore Gulf of Mexico (GoM) west of approximately 95°W - protraction areas Brazos (including south addition), Matagorda Island, Mustang Island (including east addition); North Padre Island (including east addition), South Padre Island (including east addition), Corpus Christi and Port Isabel. Also protraction areas Galveston (including south addition), East Breaks and Aliminos Canyon - west of 95°W.',25.97,28.97,-97.22,-95.0,0);
INSERT INTO "area" VALUES('EPSG','3361','Mexico - offshore GoM - Tampico area','Mexico - offshore Gulf of Mexico (GoM) - Tampico area.',21.51,22.75,-98.1,-96.89,0);
INSERT INTO "area" VALUES('EPSG','3362','Greenland - west coast','Greenland - west coast onshore.',59.74,79.0,-73.29,-42.52,0);
INSERT INTO "area" VALUES('EPSG','3363','Greenland - west coast - 63°N to 66°N','Greenland - west coast onshore - between 63°N and 66°N.',63.0,66.0,-53.7,-49.17,0);
INSERT INTO "area" VALUES('EPSG','3364','Greenland - west coast - 66°N to 69°N','Greenland - west coast onshore - between 66°N and 69°N.',66.0,69.0,-54.09,-49.4,0);
INSERT INTO "area" VALUES('EPSG','3365','Greenland - west coast - 69°N to 72°N','Greenland - west coast onshore - between 69°N and 72°N.',69.0,72.0,-56.06,-49.11,0);
INSERT INTO "area" VALUES('EPSG','3366','Greenland - west coast - 72°N to 75°N','Greenland - west coast onshore - between 72°N and 75°N.',72.0,75.0,-58.21,-52.02,0);
INSERT INTO "area" VALUES('EPSG','3367','Greenland - west coast - 75°N to 78°N','Greenland - west coast - between 75°N and 78°N.',75.0,78.0,-72.79,-56.31,0);
INSERT INTO "area" VALUES('EPSG','3368','Greenland - west coast - 78°N to 79°N','Greenland - west coast onshore - between 78°N and 79°N.',78.0,79.0,-73.29,-65.24,0);
INSERT INTO "area" VALUES('EPSG','3369','Greenland - east coast - 68°N to 69°N','Greenland - east coast onshore - between 68°N and 69°N.',68.66,69.0,-26.99,-25.14,0);
INSERT INTO "area" VALUES('EPSG','3370','Greenland - east coast - 69°N to 72°N','Greenland - east coast onshore - between 69°N and 72°N.',69.0,72.0,-29.69,-21.32,0);
INSERT INTO "area" VALUES('EPSG','3371','Greenland - east coast - 72°N to 75°N','Greenland - east coast onshore - between 72°N and 75°N.',72.0,74.58,-29.15,-19.89,0);
INSERT INTO "area" VALUES('EPSG','3372','USA - west of 174°E - AK, OCS','United States (USA) - west of 174°E. Alaska and offshore continental shelf (OCS).',49.01,56.28,167.65,174.01,0);
INSERT INTO "area" VALUES('EPSG','3373','USA - 174°E to 180°E - AK, OCS','United States (USA) - between 174°E and 180°E - Alaska and offshore continental shelf (OCS).',47.92,56.67,174.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','3374','USA - 180°W to 174°W - AK, OCS','United States (USA) - between 180°W and 174°W - Alaska and offshore continental shelf (OCS).',47.88,63.21,-180.0,-173.99,0);
INSERT INTO "area" VALUES('EPSG','3375','USA - 174°W to 168°W - AK, OCS','United States (USA) - between 174°W and 168°W - Alaska and offshore continental shelf (OCS).',48.66,73.05,-174.0,-167.99,0);
INSERT INTO "area" VALUES('EPSG','3376','Malaysia - West Malaysia - Johor','Malaysia - West Malaysia - Johor.',1.21,2.95,102.44,104.6,0);
INSERT INTO "area" VALUES('EPSG','3377','Malaysia - West Malaysia - Sembilan and Melaka','Malaysia - West Malaysia - Negeri Sembilan and Melaka.',2.03,3.28,101.7,102.71,0);
INSERT INTO "area" VALUES('EPSG','3378','Malaysia - West Malaysia - Pahang','Malaysia - West Malaysia - Pahang.',2.45,4.78,101.33,103.67,0);
INSERT INTO "area" VALUES('EPSG','3379','Malaysia - West Malaysia - Selangor','Malaysia - West Malaysia - Selangor.',2.54,3.87,100.76,101.97,0);
INSERT INTO "area" VALUES('EPSG','3380','Malaysia - West Malaysia - Terengganu','Malaysia - West Malaysia - Terengganu.',3.89,5.9,102.38,103.72,0);
INSERT INTO "area" VALUES('EPSG','3381','Malaysia - West Malaysia - Pulau Pinang','Malaysia - West Malaysia - Pulau Pinang - Pinang (Penang) Island and Seberang Perai (Province Wellesley).',5.12,5.59,100.12,100.56,0);
INSERT INTO "area" VALUES('EPSG','3382','Malaysia - West Malaysia - Kedah and Perlis','Malaysia - West Malaysia - Kedah and Perlis.',5.08,6.72,99.59,101.12,0);
INSERT INTO "area" VALUES('EPSG','3383','Malaysia - West Malaysia - Perak','Malaysia - West Malaysia - Perak.',3.66,5.92,100.07,102.0,0);
INSERT INTO "area" VALUES('EPSG','3384','Malaysia - West Malaysia - Kelantan','Malaysia - West Malaysia - Kelantan.',4.54,6.29,101.33,102.67,0);
INSERT INTO "area" VALUES('EPSG','3385','Finland - east of 31.5°E','Finland - east of 31°30''E.',62.83,63.0,31.5,31.59,0);
INSERT INTO "area" VALUES('EPSG','3386','Asia - Middle East - Iraq and Kuwait 42°E to 48°E','Iraq - between 42°E and 48°E. Kuwait - west of 48°E.',28.53,37.39,42.0,48.0,1);
INSERT INTO "area" VALUES('EPSG','3387','Iraq - west of 42°E','Iraq - west of 42°E.',31.14,36.75,38.79,42.0,0);
INSERT INTO "area" VALUES('EPSG','3388','Iraq - 42°E to 48°E','Iraq - between 42°E and 48°E.',29.06,37.39,42.0,48.0,0);
INSERT INTO "area" VALUES('EPSG','3389','Iraq - east of 48°E onshore','Iraq - onshore east of 48°E.',29.87,31.0,48.0,48.61,0);
INSERT INTO "area" VALUES('EPSG','3390','Asia - Middle East -SE Iraq and SW Iran','Iraq - onshore southeast; Iran - onshore northern Gulf coast and west bordering southeast Iraq.',29.06,33.5,44.3,51.06,0);
INSERT INTO "area" VALUES('EPSG','3391','World - between 80°S and 84°N','World between 80°S and 84°N.',-80.0,84.0,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','3392','Germany - Thuringen - west of 10.5°E','Germany - Thuringen - west of 10°30''E.',50.35,51.56,9.92,10.5,0);
INSERT INTO "area" VALUES('EPSG','3393','Germany - Thuringen - east of 10.5°E','Germany - Thuringen - east of 10°30''E.',50.2,51.64,10.5,12.56,0);
INSERT INTO "area" VALUES('EPSG','3394','Germany - Saxony - east of 13.5°E','Germany - Sachsen - east of 13°30''E.',50.62,51.58,13.5,15.04,0);
INSERT INTO "area" VALUES('EPSG','3395','Germany - Saxony - west of 13.5°E','Germany - Sachsen - west of 13°30''E.',50.2,51.66,11.89,13.51,0);
INSERT INTO "area" VALUES('EPSG','3396','Germany - Mecklenburg-Vorpommern and Sachsen-Anhalt','Germany - Mecklenburg-Vorpommern and Sachsen-Anhalt.',50.94,53.05,10.54,14.43,1);
INSERT INTO "area" VALUES('EPSG','3397','Iraq - Basra area','Iraq - Basra area.',29.87,31.09,46.46,48.61,0);
INSERT INTO "area" VALUES('EPSG','3398','Fiji - main islands','Fiji - onshore - Vanua Levu, Taveuni, Viti Levu and and immediately adjacent smaller islands of Yasawa and Kandavu groups.',-19.22,-16.1,176.81,-179.77,0);
INSERT INTO "area" VALUES('EPSG','3399','Fiji - main islands - west of 180°','Fiji - onshore west of 180° - Vanua Levu, Taveuni, Viti Levu and and immediately adjacent smaller islands of Yasawa and Kandavu groups.',-19.22,-16.1,176.81,180.0,0);
INSERT INTO "area" VALUES('EPSG','3400','Fiji - main islands - east of 180°','Fiji - onshore east of 180° - Vanua Levu, Taveuni.',-17.04,-16.1,-180.0,-179.77,0);
INSERT INTO "area" VALUES('EPSG','3401','Fiji - Vanua Levu and Taveuni','Fiji - Vanua Levu and Taveuni.',-17.07,-16.1,178.42,-179.77,0);
INSERT INTO "area" VALUES('EPSG','3402','Algeria - Hassi Mouina licence area','Algeria - Hassi Mouina licence area.',29.25,31.0,0.0,1.25,0);
INSERT INTO "area" VALUES('EPSG','3403','Russia - west of 19.5°E','Russian Federation - Kaliningrad - west of 19°30''E.',54.32,55.3,19.2,19.5,1);
INSERT INTO "area" VALUES('EPSG','3404','North America - 120°W to 114°W and NAD83 by country','North America - between 120°W and 114°W - onshore and offshore. Canada - Alberta; British Columbia; Northwest Territories; Nunavut. United States (USA) - California; Idaho; Nevada, Oregon; Washington.',30.88,83.5,-120.0,-114.0,0);
INSERT INTO "area" VALUES('EPSG','3405','North America - 114°W to 108°W and NAD83 by country','North America - between 114°W and 108°W - onshore and offshore. Canada - Alberta; Northwest Territories; Nunavut; Saskatchewan.  United States (USA) - Arizona; Colorado; Idaho; Montana; New Mexico; Utah; Wyoming.',31.33,84.0,-114.0,-108.0,0);
INSERT INTO "area" VALUES('EPSG','3406','North America - 108°W to 102°W and NAD83 by country','North America - between 108°W and 102°W - onshore and offshore. Canada - Northwest Territories; Nunavut; Saskatchewan. United States (USA) - Colorado; Montana; Nebraska; New Mexico; North Dakota; Oklahoma; South Dakota; Texas; Wyoming.',28.98,84.0,-108.0,-102.0,0);
INSERT INTO "area" VALUES('EPSG','3407','North America - 102°W to 96°W and NAD83 by country','North America - between 102°W and 96°W - onshore and offshore. Canada - Manitoba; Nunavut; Saskatchewan. United States (USA) - Iowa; Kansas; Minnesota; Nebraska; North Dakota; Oklahoma; South Dakota; Texas.',25.83,84.0,-102.0,-96.0,0);
INSERT INTO "area" VALUES('EPSG','3408','Sweden - Stockholm','Sweden - Stockholm commune.',59.22,59.43,17.75,18.2,0);
INSERT INTO "area" VALUES('EPSG','3409','Canada - 144°W to 138°W','Canada west of 138°W, onshore and offshore south of 84°N - British Columbia, Yukon.',52.05,72.53,-141.01,-138.0,0);
INSERT INTO "area" VALUES('EPSG','3410','Canada - 138°W to 132°W','Canada between 138°W and 132°W, onshore and offshore south of 84°N - British Columbia, Northwest Territories, Yukon.',48.06,79.42,-138.0,-132.0,0);
INSERT INTO "area" VALUES('EPSG','3411','Canada - 132°W to 126°W','Canada - between 132°W and 126°W, onshore and offshore south of 84°N - British Columbia, Northwest Territories, Yukon.',46.52,80.93,-132.0,-126.0,0);
INSERT INTO "area" VALUES('EPSG','3412','Canada - 126°W to 120°W','Canada between 126°W and 120°W, onshore and offshore south of 84°N - British Columbia, Northwest Territories, Yukon.',48.13,81.8,-126.0,-120.0,0);
INSERT INTO "area" VALUES('EPSG','3413','Canada - 102°W to 96°W','Canada between 102°W and 96°W, onshore and offshore south of 84°N - Manitoba, Nunavut, Saskatchewan.',48.99,84.0,-102.0,-96.0,0);
INSERT INTO "area" VALUES('EPSG','3414','Canada - 96°W to 90°W','Canada between 96°W and 90°W, onshore and offshore south of 84°N - Manitoba, Nunavut, Ontario.',48.03,84.0,-96.0,-90.0,0);
INSERT INTO "area" VALUES('EPSG','3415','Canada - 90°W to 84°W','Canada between 90°W and 84°W, onshore and offshore south of 84°N - Manitoba, Nunavut, Ontario.',46.11,84.0,-90.0,-84.0,0);
INSERT INTO "area" VALUES('EPSG','3416','Canada - 84°W to 78°W','Canada between 84°W and 78°W, onshore and offshore south of 84°N - Nunavut, Ontario and Quebec.',41.67,84.0,-84.0,-78.0,0);
INSERT INTO "area" VALUES('EPSG','3417','Canada - 78°W to 72°W','Canada between 78°W and 72°W, onshore and offshore south of 84°N - Nunavut, Ontario and Quebec.',43.63,84.0,-78.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','3418','Latin America - SIRGAS 2000 by country','Latin America - Central America and South America - onshore and offshore. Brazil - onshore and offshore.',-59.87,32.72,-122.19,-25.28,0);
INSERT INTO "area" VALUES('EPSG','3419','North America - 72°W to 66°W and NAD83 by country','North America - between 72°W and 66°W - onshore and offshore. Canada - Labrador; New Brunswick; Nova Scotia; Nunavut; Quebec. Puerto Rico. United States (USA) - Connecticut; Maine; Massachusetts; New Hampshire; New York (Long Island); Rhode Island; Vermont.',14.92,84.0,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','3420','North America - 66°W to 60°W and NAD83 by country','North America - between 66°W and 60°W - onshore and offshore. British Virgin Islands. Canada - New Brunswick; Labrador; Nunavut; Prince Edward Island; Quebec. Puerto Rico. US Virgin Islands. United States (USA) offshore Atlantic.',15.63,84.0,-66.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','3421','Latin America - 84°W to 78°West; N hemisphere and SIRGAS by country','Latin America - Central America and South America - between 84°W and 78°W, northern hemisphere, onshore and offshore.',0.0,19.54,-84.0,-78.0,0);
INSERT INTO "area" VALUES('EPSG','3422','Latin America - 78°W to 72°West; N hemisphere and SIRGAS by country','Latin America - Central America and South America - between 78°W and 72°W, northern hemisphere, onshore and offshore.',0.0,15.04,-78.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','3423','Mexico - west of 114°W','Mexico west of 114°W, onshore and offshore.',15.01,32.72,-122.19,-114.0,0);
INSERT INTO "area" VALUES('EPSG','3424','Mexico - 114°W to 108°W','Mexico between 114°W and 108°W, onshore and offshore.',15.09,32.27,-114.0,-108.0,0);
INSERT INTO "area" VALUES('EPSG','3425','Mexico - 108°W to 102°W','Mexico between 108°W and 102°W, onshore and offshore.',14.05,31.79,-108.0,-102.0,0);
INSERT INTO "area" VALUES('EPSG','3426','Mexico - 102°W to 96°W','Mexico between 102°W and 96°W, onshore and offshore.',12.3,29.81,-102.0,-96.0,0);
INSERT INTO "area" VALUES('EPSG','3427','Latin America - 96°W to 90°W; N hemisphere and SIRGAS 2000 by country','Latin America - Central and South America - between 96°W and 90°W, northern hemisphere, onshore and offshore.',0.0,26.0,-96.0,-90.0,0);
INSERT INTO "area" VALUES('EPSG','3428','Latin America - 90°W to 84°W; N hemisphere and SIRGAS 2000 by country','Latin America - Central America and South America - between 90°W and 84°W, northern hemisphere, onshore and offshore.',0.0,25.77,-90.0,-83.99,0);
INSERT INTO "area" VALUES('EPSG','3429','Spain - mainland and Balearic Islands onshore','Spain - mainland, Balearic Islands, Ceuta and Melila - onshore.',35.26,43.82,-9.37,4.39,0);
INSERT INTO "area" VALUES('EPSG','3430','New Caledonia - Belep, Grande Terre, Ile des Pins, Loyalty Islands','New Caledonia - Belep, Grande Terre, Ile des Pins, Loyalty Islands (Lifou, Mare, Ouvea).',-22.73,-19.5,163.54,168.19,0);
INSERT INTO "area" VALUES('EPSG','3431','New Caledonia - west of 162°E','New Caledonia - west of 162°E onshore and offshore.',-26.03,-15.34,156.25,162.01,0);
INSERT INTO "area" VALUES('EPSG','3432','New Caledonia - 162°E to 168°E','New Caledonia - between 162°E and 168°E onshore and offshore.',-26.45,-14.83,162.0,168.0,0);
INSERT INTO "area" VALUES('EPSG','3433','New Caledonia - east of 168°E','New Caledonia - east of 168°E onshore and offshore.',-25.95,-19.75,168.0,174.28,0);
INSERT INTO "area" VALUES('EPSG','3434','New Caledonia - Mare - west of 168°E','New Caledonia - Loyalty Islands - Mare - west of 168°E.',-21.71,-21.32,167.75,168.0,0);
INSERT INTO "area" VALUES('EPSG','3435','New Caledonia - Mare - east of 168°E','New Caledonia - Loyalty Islands - Mare - east of 168°E.',-21.71,-21.35,168.0,168.19,0);
INSERT INTO "area" VALUES('EPSG','3436','South America - 72°W to 66°W, N hemisphere and SIRGAS 2000 by country','South America between 72°W and 66°W and north of approximately 2°N, onshore and offshore.',0.0,15.64,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','3437','South America - 66°W to 60°W, N hemisphere and SIRGAS 2000 by country','South America between 66°W and 60°W, north of approximately 4°N, onshore and offshore.',0.64,16.75,-66.0,-59.99,0);
INSERT INTO "area" VALUES('EPSG','3438','South America - 60°W to 54°W, N hemisphere and SIRGAS 2000 by country','South America between 60°W and 54°W, north of approximately 2°N, onshore and offshore.',1.18,12.19,-60.0,-54.0,0);
INSERT INTO "area" VALUES('EPSG','3439','South America - 54°W to 48°W, N hemisphere and SIRGAS 2000 by country','South America between 54°W and 48°W, northern hemisphere, onshore and offshore except Brazil where offshore only.',0.0,9.24,-54.0,-47.99,0);
INSERT INTO "area" VALUES('EPSG','3440','South America - 78°W to 72°W, S hemisphere and SIRGAS 2000 by country','Brazil west of 72°W. In remainder of South America, between 78°W and 72°W, southern hemisphere, onshore and offshore.',-59.36,0.0,-78.0,-71.99,0);
INSERT INTO "area" VALUES('EPSG','3441','South America - 72°W to 66°W, S hemisphere and SIRGAS 2000 by country','Brazil - between 72°W and 66°W, northern and southern hemispheres. In remainder of South America - between 72°W and 66°W, southern hemisphere, onshore and offshore.',-59.87,2.15,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','3442','South America - 66°W to 60°W, S hemisphere and SIRGAS 2000 by country','Brazil - between 66°W and 60°W, northern and southern hemispheres. In remainder of South America - between 66°W and 60°W, southern hemisphere, onshore and offshore.',-58.39,5.28,-66.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','3443','South America - 60°W to 54°W, S hemisphere and SIRGAS 2000 by country','Brazil - between 60°W and 54°W, northern and southern hemispheres. In remainder of South America - between 60°W and 54°W, southern hemisphere, onshore and offshore.',-44.82,4.51,-60.0,-54.0,0);
INSERT INTO "area" VALUES('EPSG','3444','South America - 54°W to 48°W, S hemisphere and SIRGAS 2000 by country','Brazil - between 54°W and 48°W, northern and southern hemispheres, onshore and offshore. In remainder of South America - between 54°W and 48°W, southern hemisphere, onshore and offshore.',-54.18,7.04,-54.0,-47.99,0);
INSERT INTO "area" VALUES('EPSG','3445','Brazil - 48°W to 42°W','Brazil - between 48°W and 42°W, northern and southern hemispheres, onshore and offshore.',-33.5,5.13,-48.0,-42.0,0);
INSERT INTO "area" VALUES('EPSG','3446','Brazil - 42°W to 36°W','Brazil - between 42°W and 36°W, northern and southern hemispheres, onshore and offshore.',-26.35,0.74,-42.0,-36.0,0);
INSERT INTO "area" VALUES('EPSG','3447','Brazil - 36°W to 30°W','Brazil - between 36°W and 30°W, northern and southern hemispheres, onshore and offshore.',-23.8,4.19,-36.0,-29.99,0);
INSERT INTO "area" VALUES('EPSG','3448','South America - SIRGAS 1995 by country','South America - onshore and offshore. Ecuador (mainland and Galapagos) - onshore and offshore.',-59.87,16.75,-113.21,-26.0,0);
INSERT INTO "area" VALUES('EPSG','3449','Greenland - west of 72°W','Greenland - west of 72°W, onshore and offshore.',74.52,79.04,-75.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','3450','Greenland - 72°W to 66°W','Greenland - between 72°W and 66°W, onshore and offshore.',73.24,80.9,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','3451','Greenland - 66°W to 60°W','Greenland - between 66°W and 60°W, onshore and offshore.',68.92,82.22,-66.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','3452','Greenland - 60°W to 54°W','Greenland - between 60°W and 54°W, onshore and offshore south of 84°N.',58.91,84.0,-60.0,-54.0,0);
INSERT INTO "area" VALUES('EPSG','3453','Greenland - 54°W to 48°W','Greenland - between 54°W and 48°W, onshore and offshore south of 84°N.',56.9,84.0,-54.0,-48.0,0);
INSERT INTO "area" VALUES('EPSG','3454','Greenland - 48°W to 42°W','Greenland - between 48°W and 42°W, onshore and offshore south of 84°N.',56.38,84.0,-48.0,-42.0,0);
INSERT INTO "area" VALUES('EPSG','3455','Greenland - 42°W to 36°W','Greenland - between 42°W and 36°W, onshore and offshore south of 84°N.',56.56,84.0,-42.0,-36.0,0);
INSERT INTO "area" VALUES('EPSG','3456','Greenland - 36°W to 30°W','Greenland - between 36°W and 30°W, onshore and offshore south of 84°N.',60.16,84.0,-36.0,-30.0,0);
INSERT INTO "area" VALUES('EPSG','3457','Greenland - 30°W to 24°W','Greenland - between 30°W and 24°W, onshore and offshore south of 84°N.',64.96,84.0,-30.0,-24.0,0);
INSERT INTO "area" VALUES('EPSG','3458','Greenland - 24°W to 18°W','Greenland - between 24°W and 18°W, onshore and offshore south of 84°N.',67.7,84.0,-24.0,-18.0,0);
INSERT INTO "area" VALUES('EPSG','3459','Greenland - 18°W to 12°W','Greenland - between 18°W and 12°W, onshore and offshore south of 84°N.',68.67,84.0,-18.0,-12.0,0);
INSERT INTO "area" VALUES('EPSG','3460','Greenland - 12°W to 6°W','Greenland - 12°W to 6°W, onshore and offshore south of 84°N.',72.43,84.0,-12.0,-6.0,0);
INSERT INTO "area" VALUES('EPSG','3461','Mexico - offshore GoM - Campeche area N','Mexico - offshore Gulf of Mexico (GoM) - Bay of Campeche northeast.',20.87,23.01,-94.33,-88.67,0);
INSERT INTO "area" VALUES('EPSG','3462','Mexico - offshore GoM - Campeche area S','Mexico - offshore Gulf of Mexico (GoM) - Bay of Campeche southeast.',17.85,20.89,-94.79,-89.75,0);
INSERT INTO "area" VALUES('EPSG','3463','World - 86°S to 86°N','World between 86°S and 86°N.',-86.0,86.0,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','3464','World - N hemisphere - 12°E to 18°E - by country and WGS 72BE','Between 12°E and 18°E, northern hemisphere between equator and 84°N, onshore and offshore. Chad - west of 18°E.',0.0,84.0,12.0,18.0,0);
INSERT INTO "area" VALUES('EPSG','3465','World - N hemisphere - 18°E to 24°E - by country and WGS 72BE','Between 12°E and 18°E, northern hemisphere between equator and 84°N, onshore and offshore. Chad - east of 18°E.',0.0,84.0,18.0,24.0,0);
INSERT INTO "area" VALUES('EPSG','3466','China - Ordos - 108°E to 108.5°E and 37.75°N to 38.25°N','China - Ordos basin.',35.0,39.0,107.0,110.01,0);
INSERT INTO "area" VALUES('EPSG','3467','North America - Great Lakes basin','Canada and United States (USA) - Great Lakes basin.',40.99,50.74,-93.17,-74.47,0);
INSERT INTO "area" VALUES('EPSG','3468','North America - Great Lakes basin and St Lawrence Seaway','Canada and United States (USA) - Great Lakes basin and St Lawrence Seaway.',40.99,52.22,-93.17,-54.75,0);
INSERT INTO "area" VALUES('EPSG','3469','China - offshore - Yellow Sea','China - offshore - Huang Hai (Yellow Sea).',31.23,37.4,119.23,125.06,0);
INSERT INTO "area" VALUES('EPSG','3470','China - offshore - Pearl River basin','China - offshore South China Sea - Pearl River basin.',18.31,22.89,110.13,116.76,0);
INSERT INTO "area" VALUES('EPSG','3471','Denmark - onshore west of 12°E','Denmark - onshore west of 12°E - Zealand, Jutland, Fuen and Lolland.',54.51,57.8,8.0,12.0,0);
INSERT INTO "area" VALUES('EPSG','3472','Denmark - onshore east of 12°E','Denmark - onshore east of 12°E - Zealand and Falster, Bornholm.',54.51,56.18,12.0,15.24,0);
INSERT INTO "area" VALUES('EPSG','3473','World - south of 40°S','Southern hemisphere - south of 40°S including Antarctica.',-90.0,-40.0,-180.0,180.0,1);
INSERT INTO "area" VALUES('EPSG','3474','World - south of 0°N','Southern hemisphere.',-90.0,0.0,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','3475','World - north of 0°N','Northern hemisphere.',0.0,90.0,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','3476','World - north of 30°N','Northern hemisphere - north of 30°N, including Arctic.',30.0,90.0,-180.0,180.0,1);
INSERT INTO "area" VALUES('EPSG','3477','Libya - Cyrenaica','Libya - Cyrenaica area 42, blocks 2 and 4.',32.0,32.8,22.49,23.0,0);
INSERT INTO "area" VALUES('EPSG','3478','Jamaica - west of 78°W','Jamaica - west of 78°W onshore and offshore.',14.16,19.36,-80.6,-77.99,0);
INSERT INTO "area" VALUES('EPSG','3479','Jamaica - east of 78°W','Jamaica - east of 78°W onshore and offshore.',14.08,19.2,-78.0,-74.51,0);
INSERT INTO "area" VALUES('EPSG','3480','World - north of 45°N','Northern hemisphere - north of 45°N, including Arctic.',45.0,90.0,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','3481','Canada - NWT','Canada - Northwest Territories onshore.',59.98,78.81,-136.46,-102.0,0);
INSERT INTO "area" VALUES('EPSG','3482','USA - west of 174°E - AK','United States (USA) - west of 174°E - Alaska (AK).',49.0,56.3,168.0,174.0,1);
INSERT INTO "area" VALUES('EPSG','3483','USA - 174°E to 180°E - AK','United States (USA) - between 174°E and 180°E - Alaska (AK).',48.0,59.8,174.0,180.0,1);
INSERT INTO "area" VALUES('EPSG','3484','USA - 180°W to 174°W - AK','United States (USA) - between 180°W and 174°W - Alaska (AK).',48.0,63.3,-180.0,-174.0,1);
INSERT INTO "area" VALUES('EPSG','3485','USA - 174°W to 168°W - AK','United States (USA) - between 174°W and 168°W - Alaska (AK).',48.7,73.0,-174.0,-168.0,1);
INSERT INTO "area" VALUES('EPSG','3486','USA - 168°W to 162°W - AK','United States (USA) - between 168°W and 162°W - Alaska (AK).',49.6,74.3,-168.0,-162.0,1);
INSERT INTO "area" VALUES('EPSG','3487','USA - 162°W to 156°W - AK','United States (USA) - between 162°W and 156°W - Alaska (AK).',51.1,74.7,-162.0,-156.0,1);
INSERT INTO "area" VALUES('EPSG','3488','USA - 162°W to 156°W  onshore - HI','United States (USA) - between 162°W and 156°W onshore - Hawaii.',19.51,22.29,-160.3,-155.99,0);
INSERT INTO "area" VALUES('EPSG','3489','USA - 162°W to 156°W - AK, HI','United States (USA) - between 162°W and 156°W onshore and offshore - Alaska, Hawaii.',15.57,74.71,-162.0,-155.99,0);
INSERT INTO "area" VALUES('EPSG','3490','USA - 156°W to 150°W - AK','United States (USA) - between 156°W and 150°W - Alaska (AK).',52.1,74.7,-156.0,-150.0,1);
INSERT INTO "area" VALUES('EPSG','3491','USA - 156°W to 150°W onshore - HI','United States (USA) - between 156°W and 150°W onshore - Hawaii.',18.87,20.86,-156.0,-154.74,0);
INSERT INTO "area" VALUES('EPSG','3492','USA - 156°W to 150°W - AK, HI','United States (USA) - between 156°W and 150°W onshore and offshore - Alaska, Hawaii.',15.56,74.71,-156.0,-149.99,0);
INSERT INTO "area" VALUES('EPSG','3493','USA - 150°W to 144°W - AK','United States (USA) - between 150°W and 144°W - Alaska (AK).',54.0,74.2,-150.0,-144.0,1);
INSERT INTO "area" VALUES('EPSG','3494','USA - 144°W to 138°W','United States (USA) - between 144°W and 138°W onshore and offshore - Alaska.',53.47,73.59,-144.0,-137.99,0);
INSERT INTO "area" VALUES('EPSG','3495','USA - 138°W to 132°W','United States (USA) - between 138°W and 132°W onshore and offshore - Alaska.',53.6,73.04,-138.0,-131.99,0);
INSERT INTO "area" VALUES('EPSG','3496','USA - 132°W to 126°W','United States (USA) - between 132°W and 126°W onshore and offshore - Alaska.',35.38,56.84,-132.0,-126.0,0);
INSERT INTO "area" VALUES('EPSG','3497','USA - 126°W to 120°W','United States (USA) - between 126°W and 120°W onshore and offshore - California; Oregon; Washington.',30.54,49.09,-126.0,-119.99,0);
INSERT INTO "area" VALUES('EPSG','3498','USA - 120°W to 114°W','United States (USA) - between 120°W and 114°W onshore and offshore - California, Idaho, Nevada, Oregon, Washington.',30.88,49.01,-120.0,-114.0,0);
INSERT INTO "area" VALUES('EPSG','3499','USA - 114°W to 108°W','United States (USA) - between 114°W and 108°W - Arizona; Colorado; Idaho; Montana; New Mexico; Utah; Wyoming.',31.33,49.01,-114.0,-108.0,0);
INSERT INTO "area" VALUES('EPSG','3500','USA - 108°W to 102°W','United States (USA) - between 108°W and 102°W - Colorado; Montana; Nebraska; New Mexico; North Dakota; Oklahoma; South Dakota; Texas; Wyoming.',28.98,49.01,-108.0,-102.0,0);
INSERT INTO "area" VALUES('EPSG','3501','USA - 102°W to 96°W','United States (USA) - between 102°W and 96°W onshore and offshore - Iowa; Kansas; Minnesota; Nebraska; North Dakota; Oklahoma; South Dakota; Texas.',25.83,49.01,-102.0,-96.0,0);
INSERT INTO "area" VALUES('EPSG','3502','USA - 96°W to 90°W','United States (USA) - between 96°W and 90°W onshore and offshore - Arkansas; Illinois; Iowa; Kansas; Louisiana; Michigan; Minnesota; Mississippi; Missouri; Nebraska; Oklahoma; Tennessee; Texas; Wisconsin.',25.61,49.38,-96.01,-90.0,0);
INSERT INTO "area" VALUES('EPSG','3503','USA - 90°W to 84°W','United States (USA) - between 90°W and 84°W onshore and offshore - Alabama; Arkansas; Florida; Georgia; Indiana; Illinois; Kentucky; Louisiana; Michigan; Minnesota; Mississippi; Missouri; North Carolina; Ohio; Tennessee; Wisconsin.',23.97,48.32,-90.0,-84.0,0);
INSERT INTO "area" VALUES('EPSG','3504','USA - 84°W to 78°W','United States (USA) - between 84°W and 78°W onshore and offshore - Florida; Georgia; Kentucky; Maryland; Michigan; New York; North Carolina; Ohio; Pennsylvania; South Carolina; Tennessee; Virginia; West Virginia.',23.81,46.13,-84.0,-78.0,0);
INSERT INTO "area" VALUES('EPSG','3505','USA - 78°W to 72°W','United States (USA) - between 78°W and 72°W onshore and offshore - Connecticut; Delaware; Maryland; Massachusetts; New Hampshire; New Jersey; New York; North Carolina; Pennsylvania; Virginia; Vermont.',28.28,45.03,-78.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','3506','USA - 72°W to 66°W','United States (USA) - between 72°W and 66°W onshore and offshore - Connecticut; Maine; Massachusetts; New Hampshire; New York (Long Island); Rhode Island; Vermont.',33.61,47.47,-72.0,-65.99,0);
INSERT INTO "area" VALUES('EPSG','3507','China - Tarim - 77.5°E to 88°E and 37°N to 42°N','China - south and west Tarim basin.',37.0,41.99,77.45,88.0,0);
INSERT INTO "area" VALUES('EPSG','3508','New Zealand - offshore Pacific Ocean, Southern Ocean','Southwestern Pacific Ocean and Southern Ocean areas surrounding New Zealand.',-60.0,-25.0,155.0,-170.0,0);
INSERT INTO "area" VALUES('EPSG','3509','UAE - Abu Dhabi - offshore','United Arab Emirates (UAE) - Abu Dhabi offshore.',24.0,25.64,51.5,54.85,0);
INSERT INTO "area" VALUES('EPSG','3510','Indonesia - 96°E to 99°E onshore','Indonesia - onshore between 96°E and 99°E.',-1.81,5.42,96.0,99.0,0);
INSERT INTO "area" VALUES('EPSG','3511','Indonesia - 99°E to 102°E onshore','Indonesia - onshore between 99°E and 102°E.',-3.57,3.71,99.0,102.0,0);
INSERT INTO "area" VALUES('EPSG','3512','Indonesia - 102°E to 105°E onshore','Indonesia - onshore between 102°E and 105°E.',-5.99,1.68,102.0,105.0,0);
INSERT INTO "area" VALUES('EPSG','3513','Indonesia - 105°E to 108°E onshore','Indonesia - onshore between 105°E and 108°E.',-7.79,4.11,105.0,108.0,0);
INSERT INTO "area" VALUES('EPSG','3514','Indonesia - 108°E to 111°E onshore','Indonesia - onshore between 108°E and 111°E.',-8.31,4.25,108.0,111.0,0);
INSERT INTO "area" VALUES('EPSG','3515','Indonesia - 111°E to 114°E onshore','Indonesia - onshore between 111°E and 114°E.',-8.67,1.59,111.0,114.0,0);
INSERT INTO "area" VALUES('EPSG','3516','Indonesia - 114°E to 117°E onshore','Indonesia - onshore between 114°E and 117°E.',-9.15,4.37,114.0,117.01,0);
INSERT INTO "area" VALUES('EPSG','3517','Indonesia - 117°E to 120°E onshore','Indonesia - onshore between 117°E and 120°E.',-10.15,4.36,117.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','3518','Indonesia - 120°E to 123°E onshore','Indonesia - onshore between 120°E and 123°E.',-10.98,1.4,120.0,123.0,0);
INSERT INTO "area" VALUES('EPSG','3519','Indonesia - 123°E to 126°E onshore','Indonesia - onshore between 123°E and 126°E.',-10.92,3.84,123.0,126.0,0);
INSERT INTO "area" VALUES('EPSG','3520','Indonesia - 126°E to 129°E onshore','Indonesia - onshore between 126°E and 129°E.',-8.32,4.59,126.0,129.0,0);
INSERT INTO "area" VALUES('EPSG','3521','Indonesia - 129°E to 132°E onshore','Indonesia - onshore between 129°E and 132°E.',-8.41,0.1,129.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','3522','Indonesia - 132°E to 135°E onshore','Indonesia - onshore between 132°E and 135°E.',-7.3,-0.29,132.0,135.0,0);
INSERT INTO "area" VALUES('EPSG','3523','Indonesia - 135°E to 138°E onshore','Indonesia - onshore between 135°E and 138°E.',-8.49,-0.58,135.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','3524','Canada - 72°W to 66°W','Canada between 72°W and 66°W onshore and offshore - New Brunswick, Labrador, Nova Scotia, Nunavut, Quebec.',40.8,84.0,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','3525','Canada - 66°W to 60°W','Canada between 66°W and 60°W onshore and offshore - New Brunswick, Labrador, Nova Scotia, Nunavut, Prince Edward Island, Quebec.',40.04,84.0,-66.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','3526','Canada - 108°W to 102°W','Canada between 108°W and 102°W onshore and offshore - Northwest Territories, Nunavut, Saskatchewan.',48.99,84.0,-108.0,-102.0,0);
INSERT INTO "area" VALUES('EPSG','3527','Canada - 114°W to 108°W','Canada between 114°W and 108°W onshore and offshore - Alberta, Northwest Territories, Nunavut, Saskatchewan.',48.99,84.0,-114.0,-108.0,0);
INSERT INTO "area" VALUES('EPSG','3528','Canada - 120°W to 114°W','Canada between 120°W and 114°W onshore and offshore - Alberta, British Columbia, Northwest Territories, Nunavut.',48.99,83.5,-120.0,-114.0,0);
INSERT INTO "area" VALUES('EPSG','3529','South Georgia - onshore','South Georgia and the South Sandwich Islands - South Georgia onshore.',-54.95,-53.93,-38.08,-35.74,0);
INSERT INTO "area" VALUES('EPSG','3530','UAE - Dubai - offshore','United Arab Emirates (UAE) - Dubai offshore - Falah, Fateh and Rashid oilfields.',24.94,25.8,54.06,55.3,0);
INSERT INTO "area" VALUES('EPSG','3531','UAE - Dubai municipality','United Arab Emirates (UAE) - Dubai municipality.',24.85,25.34,54.84,55.55,0);
INSERT INTO "area" VALUES('EPSG','3532','Channel Islands - Jersey','Channel Islands - Jersey.',48.93,49.34,-2.3,-1.98,1);
INSERT INTO "area" VALUES('EPSG','3533','Channel Islands - Guernsey','Channel Islands - Guernsey.',49.4,49.75,-2.75,-2.13,1);
INSERT INTO "area" VALUES('EPSG','3534','Serbia and Kosovo','Serbia including Vojvodina and Kosovo.',41.85,46.19,18.81,23.01,0);
INSERT INTO "area" VALUES('EPSG','3535','Montenegro','Montenegro - onshore and offshore.',41.27,43.56,18.02,20.38,0);
INSERT INTO "area" VALUES('EPSG','3536','Montenegro - onshore','Montenegro - onshore.',41.79,43.56,18.45,20.38,0);
INSERT INTO "area" VALUES('EPSG','3537','Portugal - mainland - offshore','Portugal - mainland - offshore.',34.91,41.88,-13.87,-7.24,0);
INSERT INTO "area" VALUES('EPSG','3538','Croatia - east of 18°E','Croatia - east of 18°E, onshore and offshore.',41.62,45.92,18.0,19.43,0);
INSERT INTO "area" VALUES('EPSG','3539','Croatia - west of 18°E','Croatia - west of 18°E, onshore and offshore.',41.63,46.54,13.0,18.0,0);
INSERT INTO "area" VALUES('EPSG','3540','Canada - Alberta - west of 118.5°W','Canada - Alberta - west of 118°30'' W.',52.88,60.0,-120.0,-118.5,0);
INSERT INTO "area" VALUES('EPSG','3541','Canada - Alberta - 118.5°W to 115.5°W','Canada - Alberta - between 118°30''W and 115°30'' W.',50.77,60.0,-118.5,-115.5,0);
INSERT INTO "area" VALUES('EPSG','3542','Canada - Alberta - 115.5°W to 112.5°W','Canada - Alberta - between 115°30''W and 112°30''W.',48.99,60.0,-115.5,-112.5,0);
INSERT INTO "area" VALUES('EPSG','3543','Canada - Alberta - east of 112.5°W','Canada - Alberta - east of 112°30''W.',48.99,60.0,-112.5,-109.98,0);
INSERT INTO "area" VALUES('EPSG','3544','World - 85°S to 85°N','World between 85.06°S and 85.06°N.',-85.06,85.06,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','3545','France - mainland south of 43°N and Corsica','France onshore - mainland south of 43°N and Corsica.',41.31,43.07,-1.06,9.63,0);
INSERT INTO "area" VALUES('EPSG','3546','France - mainland south of 44°N','France - mainland onshore south of 44°N.',42.33,44.0,-1.79,7.65,0);
INSERT INTO "area" VALUES('EPSG','3547','France - mainland - 43°N to 45°N','France - mainland onshore between 43°N and 45°N.',43.0,45.0,-1.79,7.71,0);
INSERT INTO "area" VALUES('EPSG','3548','France - mainland - 44°N to 46°N','France - mainland onshore between 44°N and 46°N.',44.0,46.0,-1.46,7.71,0);
INSERT INTO "area" VALUES('EPSG','3549','France - mainland - 45°N to 47°N','France - mainland onshore between 45°N and 47°N.',45.0,47.0,-2.21,7.16,0);
INSERT INTO "area" VALUES('EPSG','3550','France - mainland - 46°N to 48°N','France - mainland onshore between 46°N and 48°N.',46.0,48.0,-4.77,7.63,0);
INSERT INTO "area" VALUES('EPSG','3551','France - mainland - 47°N to 49°N','France - mainland onshore between 47°N and 49°N.',47.0,49.0,-4.87,8.23,0);
INSERT INTO "area" VALUES('EPSG','3552','France - mainland - 48°N to 50°N','France - mainland onshore between 48°N and 50°N.',48.0,50.0,-4.87,8.23,0);
INSERT INTO "area" VALUES('EPSG','3553','France - mainland north of 49°N','France - mainland onshore north of 49°N.',49.0,51.14,-2.03,8.08,0);
INSERT INTO "area" VALUES('EPSG','3554','New Zealand - Snares and Auckland Islands','New Zealand - Snares Island, Auckland Island - onshore.',-51.13,-47.8,165.55,166.93,0);
INSERT INTO "area" VALUES('EPSG','3555','New Zealand - Campbell Island','New Zealand - Campbell Island.',-52.83,-52.26,168.65,169.6,0);
INSERT INTO "area" VALUES('EPSG','3556','New Zealand - Antipodes and Bounty Islands','New Zealand - Antipodes Island, Bounty Islands.',-49.92,-47.54,178.4,179.37,0);
INSERT INTO "area" VALUES('EPSG','3557','New Zealand - Raoul and Kermadec Islands','New Zealand - Raoul Island, Kermadec Islands.',-31.56,-29.03,-179.07,-177.62,0);
INSERT INTO "area" VALUES('EPSG','3558','Antarctica - Ross Sea Region','Antarctica - Ross Sea Region - nominally between 160°E and 150°W but includes buffer on eastern hemisphere margin to include Transantarctic Mountains',-90.0,-59.99,144.99,-144.99,0);
INSERT INTO "area" VALUES('EPSG','3559','Australia - offshore','Australia - offshore including EEZ.',-47.2,-8.88,109.23,163.2,0);
INSERT INTO "area" VALUES('EPSG','3560','Slovenia - Dolenjska - central','Slovenia - central Dolenjska (Lower Carniola).',45.81,46.01,14.97,15.43,0);
INSERT INTO "area" VALUES('EPSG','3561','China - offshore - Bei Bu','China - offshore - Bei Bu Wan (Gulf of Tonkin).',17.81,21.69,107.15,110.17,0);
INSERT INTO "area" VALUES('EPSG','3562','Taiwan - 120°E to 122°E','Taiwan, Republic of China - between 120°E and 122°E, onshore and offshore - Taiwan Island.',20.41,26.72,119.99,122.06,0);
INSERT INTO "area" VALUES('EPSG','3563','Taiwan - 118°E to 120°E','Taiwan, Republic of China - between 118°E and 120°E, onshore and offshore - Penghu (Pescadores) Islands.',18.63,24.65,118.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','3564','Slovenia - west of 14°30''E onshore','Slovenia - onshore west of 14°30''E.',45.44,46.53,13.38,14.58,0);
INSERT INTO "area" VALUES('EPSG','3565','Slovenia - NE','Slovenia - east of 14°30''E and north of 46°03''N.',46.14,46.88,14.54,16.61,0);
INSERT INTO "area" VALUES('EPSG','3566','Slovenia - SE','Slovenia - east of 14°30''E and south of 46°09''N.',45.42,46.22,14.55,15.73,0);
INSERT INTO "area" VALUES('EPSG','3567','Slovenia - southeastern','Slovenia - southeastern.',45.42,45.77,14.53,15.36,0);
INSERT INTO "area" VALUES('EPSG','3568','Slovenia - Dolenjska','Slovenia - Dolenjska (Lower Carniola).',45.7,46.12,14.47,15.73,0);
INSERT INTO "area" VALUES('EPSG','3569','Slovenia - Stajerska','Slovenia - Stajerska (Slovene Styria).',46.1,46.76,14.74,16.27,0);
INSERT INTO "area" VALUES('EPSG','3570','Slovenia - Pomurje','Slovenia - Pomurje (the Mura Region).',46.47,46.88,15.96,16.61,0);
INSERT INTO "area" VALUES('EPSG','3571','Slovenia - Gorenjska and N Primorsko','Slovenia - Gorenjska (Upper Carniola) and northern Primorska.',46.05,46.53,13.38,14.82,0);
INSERT INTO "area" VALUES('EPSG','3572','Slovenia - Primorska and Notranjska onshore','Slovenia - onshore Primorska and Notranjska (Inner Carniola).',45.44,46.08,13.47,14.58,0);
INSERT INTO "area" VALUES('EPSG','3573','Slovenia - central','Slovenia - central.',45.91,46.31,14.21,15.28,0);
INSERT INTO "area" VALUES('EPSG','3574','Europe - onshore - eastern - S-42(58)','Onshore: Bulgaria, Czechia, Germany (former DDR), Hungary, Poland and Slovakia. Onshore and offshore: Albania and Romania.',39.63,54.89,9.92,31.41,0);
INSERT INTO "area" VALUES('EPSG','3575','Germany - East Germany - west of 12°E','Germany - states of former East Germany - west of 12°E.',50.2,54.23,9.92,12.0,0);
INSERT INTO "area" VALUES('EPSG','3576','Europe - 12°E to 18°E onshore and S-42(83) by country','Germany (former DDR) - onshore east of 12°E. Czechia, Hungary and Slovakia - west of 18°E.',45.78,54.74,12.0,18.01,0);
INSERT INTO "area" VALUES('EPSG','3577','Europe - 18°E to 24°E onshore and S-42(58) by country','Albania - onshore east of 18°E. Czechia, Hungary and Slovakia - east of 18°E. Poland - onshore between 18°E and 24°E. Bulgaria and Romania - onshore west of 24°E.',39.64,54.89,18.0,24.0,0);
INSERT INTO "area" VALUES('EPSG','3578','Europe - 18°E to 24°E onshore and S-42(83) by country','Czechia, Hungary and Slovakia - east of 18°E.',45.74,50.06,18.0,22.9,0);
INSERT INTO "area" VALUES('EPSG','3579','Europe - 24°E to 30°E onshore and S-42(58) by country','Bulgaria, Poland and Romania - onshore east of 24°E.',41.24,50.93,24.0,29.74,0);
INSERT INTO "area" VALUES('EPSG','3580','Europe - 13.5°E to 16.5°E onshore and S-42(58) by country','Czechia - between 13°30''E and 16°30''E. Germany - states of former East Germany onshore - east of 13°30''E - Brandenburg; Mecklenburg-Vorpommern; Sachsen. Hungary and Poland - onshore west of 16°30''E.',46.54,54.72,13.5,16.5,0);
INSERT INTO "area" VALUES('EPSG','3581','Europe - 16.5°E to 19.5°E onshore and S-42(58) by country','Albania - onshore west of 19°30''E. Czechia - east of 16°30''E. Hungary and Poland - onshore between 16°30''E and 19°30''E. Slovakia - west of 19°30''E.',40.14,54.89,16.5,19.5,0);
INSERT INTO "area" VALUES('EPSG','3582','Europe - 16.5°E to 19.5°E onshore and S-42(83) by country','Czechia - east of 16°30''E. Hungary - between 16°30''E and 19°30''E. Slovakia - west of 19°30''E.',45.74,50.45,16.5,19.5,0);
INSERT INTO "area" VALUES('EPSG','3583','Europe - 19.5°E to 22.5°E onshore and S-42(58) by country','Albania - east of 19°30''E. Bulgaria and Romania - west of 22°30''E. Hungary, Poland and Slovakia - between 19°30''E and 22°30''E.',39.64,54.51,19.5,22.5,0);
INSERT INTO "area" VALUES('EPSG','3584','Europe - 19.5°E to 22.5°E onshore and S-42(83) by country','Hungary and Slovakia - between 19°30''E and 22°30''E.',46.1,49.59,19.5,22.5,0);
INSERT INTO "area" VALUES('EPSG','3585','Europe - 22.5°E to 25.5°E onshore and S-42(58) by country','Bulgaria and Romania - between 22°30''E and 25°30''E. Hungary, Poland and Slovakia - east of 22°30''E.',41.24,54.41,22.5,25.5,0);
INSERT INTO "area" VALUES('EPSG','3586','Europe - 22.5°E to 25.5°E onshore and S-42(83) by country','Hungary and Slovakia - east of 22°30''E.',47.76,49.1,22.5,22.9,0);
INSERT INTO "area" VALUES('EPSG','3587','Europe - 25.5°E to 28.5°E onshore and S-42(58) by country','Bulgaria and Romania - onshore between 25°30''E and 28°30''E.',41.28,48.27,25.5,28.5,0);
INSERT INTO "area" VALUES('EPSG','3588','Europe - 28.5°E to 31.5°E onshore and S-42(58) by country','Bulgaria and Romania - onshore east of 28°30''E.',43.34,45.44,28.5,29.74,0);
INSERT INTO "area" VALUES('EPSG','3589','Pakistan - Gambat','Pakistan - Gambat.',25.88,27.67,68.24,69.3,0);
INSERT INTO "area" VALUES('EPSG','3590','Nigeria - 4°N to 5°N, 6°E to 8°E','Nigeria - 4°N to 5°N and 6°E to 8°E.',3.99,5.01,5.99,8.01,0);
INSERT INTO "area" VALUES('EPSG','3591','Taiwan - onshore - Penghu','Taiwan, Republic of China - onshore - Penghu (Pescadores) Islands.',23.12,23.82,119.25,119.78,0);
INSERT INTO "area" VALUES('EPSG','3592','Antarctica - Darwin Glacier region','Antarctica - Darwin Glacier region.',-81.0,-76.0,145.0,169.0,0);
INSERT INTO "area" VALUES('EPSG','3593','New Zealand - offshore','New Zealand - offshore.',-55.95,-25.88,160.6,-171.2,0);
INSERT INTO "area" VALUES('EPSG','3594','Europe - EVRF2007','Europe - onshore - Andorra; Austria; Belgium; Bosnia and Herzegovina; Bulgaria; Croatia; Czechia; Denmark; Estonia; Finland; France - mainland; Germany; Gibraltar, Hungary; Italy - mainland and Sicily; Latvia; Liechtenstein; Lithuania; Luxembourg; Netherlands; Norway; Poland; Portugal - mainland; Romania; San Marino; Slovakia; Slovenia; Spain - mainland; Sweden; Switzerland; United Kingdom (UK) - Great Britain mainland; Vatican City State.',35.95,71.21,-9.56,31.59,0);
INSERT INTO "area" VALUES('EPSG','3595','Finland - west of 19.5°E onshore nominal','Finland - nominally onshore west of 19°30''E but may be used in adjacent areas to east if a municipality chooses to use one zone over its whole extent.',60.08,60.34,19.24,19.5,0);
INSERT INTO "area" VALUES('EPSG','3596','Finland - 19.5°E to 20.5°E onshore nominal','Finland - nominally onshore between 19°30''E and 20°30''E but may be used in adjacent areas if a municipality chooses to use one zone over its whole extent.',59.92,60.48,19.5,20.5,0);
INSERT INTO "area" VALUES('EPSG','3597','Finland - 20.5°E to 21.5°E onshore nominal','Finland - nominally onshore between 20°30''E and 21°30''E but may be used in adjacent areas if a municipality chooses to use one zone over its whole extent.',59.84,69.33,20.5,21.5,0);
INSERT INTO "area" VALUES('EPSG','3598','Finland - 21.5°E to 22.5°E onshore nominal','Finland - nominally onshore between 21°30''E and 22°30''E but may be used in adjacent areas if a municipality chooses to use one zone over its whole extent.',59.76,69.31,21.5,22.5,0);
INSERT INTO "area" VALUES('EPSG','3599','Finland - 22.5°E to 23.5°E onshore nominal','Finland - nominally onshore between 22°30''E and 23°30''E but may be used in adjacent areas if a municipality chooses to use one zone over its whole extent.',59.75,68.74,22.5,23.5,0);
INSERT INTO "area" VALUES('EPSG','3600','Finland - 23.5°E to 24.5°E onshore nominal','Finland - nominally onshore between 23°30''E and 24°30''E but may be used in adjacent areas if a municipality chooses to use one zone over its whole extent.',59.86,68.84,23.5,24.5,0);
INSERT INTO "area" VALUES('EPSG','3601','Finland - 24.5°E to 25.5°E onshore nominal','Finland - nominally onshore between 24°30''E and 25°30''E but may be used in adjacent areas if a municipality chooses to use one zone over its whole extent.',59.94,68.9,24.5,25.5,0);
INSERT INTO "area" VALUES('EPSG','3602','Finland - 25.5°E to 26.5°E onshore nominal','Finland - nominally onshore between 25°30''E and 26°30''E but may be used in adjacent areas if a municipality chooses to use one zone over its whole extent.',60.18,69.94,25.5,26.5,0);
INSERT INTO "area" VALUES('EPSG','3603','Finland - 26.5°E to 27.5°E onshore nominal','Finland - nominally onshore between 26°30''E and 27°30''E but may be used in adjacent areas if a municipality chooses to use one zone over its whole extent.',60.36,70.05,26.5,27.5,0);
INSERT INTO "area" VALUES('EPSG','3604','Finland - 27.5°E to 28.5°E onshore nominal','Finland - nominally onshore between 27°30''E and 28°30''E but may be used in adjacent areas if a municipality chooses to use one zone over its whole extent.',60.42,70.09,27.5,28.5,0);
INSERT INTO "area" VALUES('EPSG','3605','Finland - 28.5°E to 29.5°E nominal','Finland - nominally between 28°30''E and 29°30''E but may be used in adjacent areas if a municipality chooses to use one zone over its whole extent.',60.94,69.81,28.5,29.5,0);
INSERT INTO "area" VALUES('EPSG','3606','Finland - 29.5°E to 30.5°E nominal','Finland - nominally between 29°30''E and 30°30''E but may be used in adjacent areas if a municipality chooses to use one zone over its whole extent.',61.43,67.98,29.5,30.5,0);
INSERT INTO "area" VALUES('EPSG','3607','Finland - east of 30.5°E nominal','Finland - nominally east of 30°30''E but may be used in adjacent areas to west if a municipality chooses to use one zone over its whole extent.',62.08,64.27,30.5,31.59,0);
INSERT INTO "area" VALUES('EPSG','3608','Sweden - Stockholm county','Sweden - Stockholm county. Municipalities of Botkyrka, Danderyd, Ekerö, Haninge, Huddinge, Järfälla, Lidingö, Nacka, Nynäshamn, Salem, Sigtuna, Sollentuna, Solna, Stockholm and Sundbyberg.',58.69,60.27,17.25,19.61,0);
INSERT INTO "area" VALUES('EPSG','3609','Congo DR (Zaire) - Katanga west of 25.5°E','The Democratic Republic of the Congo (Zaire) - Katanga west of 25°30''E.',-11.72,-6.32,21.74,25.5,0);
INSERT INTO "area" VALUES('EPSG','3610','Congo DR (Zaire) - Katanga 24.5°E to 27.5°E','The Democratic Republic of the Congo (Zaire) - Katanga between 24°30''E and 27°30''E.',-12.08,-4.99,24.5,27.5,0);
INSERT INTO "area" VALUES('EPSG','3611','Congo DR (Zaire) - Katanga 26.5°E to 29.5°E','The Democratic Republic of the Congo (Zaire) - Katanga between 26°30''E and 29°30''E.',-13.44,-4.99,26.5,29.5,0);
INSERT INTO "area" VALUES('EPSG','3612','Congo DR (Zaire) - Katanga east of 28.5°E','The Democratic Republic of the Congo (Zaire) - Katanga east of 28°30''E.',-13.46,-4.99,28.5,30.78,0);
INSERT INTO "area" VALUES('EPSG','3613','Congo DR (Zaire) - south','The Democratic Republic of the Congo (Zaire) - south of a line through Bandundu, Seke and Pweto - onshore and offshore.',-13.46,-3.41,11.79,29.81,0);
INSERT INTO "area" VALUES('EPSG','3614','Congo DR (Zaire) - Katanga - Lubumbashi area','The Democratic Republic of the Congo (Zaire) - Katanga - Likasi-Lubumbashi area.',-12.01,-11.13,26.38,27.75,0);
INSERT INTO "area" VALUES('EPSG','3615','Moldova - west of 30°E','Moldova - west of 30°E.',45.44,48.47,26.63,30.0,0);
INSERT INTO "area" VALUES('EPSG','3616','Moldova - east of 30°E','Moldova - east of 30°E.',46.37,46.47,30.0,30.13,0);
INSERT INTO "area" VALUES('EPSG','3617','Congo DR (Zaire) - south and 15°E to 17°E','The Democratic Republic of the Congo (Zaire) - south of a line through Bandundu, Seke and Pweto and between 15°E and 17°E.',-7.31,-3.41,15.0,17.0,0);
INSERT INTO "area" VALUES('EPSG','3618','Congo DR (Zaire) - south and 17°E and 19°E','The Democratic Republic of the Congo (Zaire) - south of a line through Bandundu, Seke and Pweto and between 17°E and 19°E.',-8.11,-3.43,17.0,19.0,0);
INSERT INTO "area" VALUES('EPSG','3619','Brazil - Distrito Federal','Brazil - Distrito Federal.',-15.94,-15.37,-48.1,-47.1,0);
INSERT INTO "area" VALUES('EPSG','3620','Congo DR (Zaire) - south and 19°E to 21°E','The Democratic Republic of the Congo (Zaire) - south of a line through Bandundu, Seke and Pweto and between 19°E and 21°E.',-8.0,-3.77,19.0,21.0,0);
INSERT INTO "area" VALUES('EPSG','3621','Congo DR (Zaire) - south and 21°E to 23°E','The Democratic Republic of the Congo (Zaire) - south of a line through Bandundu, Seke and Pweto and between 21°E and 23°E.',-11.24,-4.18,21.0,23.01,0);
INSERT INTO "area" VALUES('EPSG','3622','Congo DR (Zaire) - south and 23°E to 25°E','The Democratic Republic of the Congo (Zaire) - south of a line through Bandundu, Seke and Pweto and between 23°E and 25°E.',-11.47,-4.58,23.0,25.0,0);
INSERT INTO "area" VALUES('EPSG','3623','Congo DR (Zaire) - south and 25°E to 27°E','The Democratic Republic of the Congo (Zaire) - south of a line through Bandundu, Seke and Pweto and between 25°E and 27°E.',-11.99,-4.99,25.0,27.0,0);
INSERT INTO "area" VALUES('EPSG','3624','Congo DR (Zaire) - south and 27°E to 29°E','The Democratic Republic of the Congo (Zaire) - south of a line through Bandundu, Seke and Pweto and between 27°E and 29°E.',-13.39,-6.43,27.0,29.0,0);
INSERT INTO "area" VALUES('EPSG','3625','Iraq - onshore','Iraq - onshore.',29.06,37.39,38.79,48.61,0);
INSERT INTO "area" VALUES('EPSG','3626','Congo DR (Zaire) - south and 12°E to 18°E','The Democratic Republic of the Congo (Zaire) - onshore and offshore south of a line through Bandundu, Seke and Pweto and between 12°E and 18°E.',-8.11,-3.41,12.0,18.01,0);
INSERT INTO "area" VALUES('EPSG','3627','Congo DR (Zaire) - south and 18°E to 24°E','The Democratic Republic of the Congo (Zaire) - south of a line through Bandundu, Seke and Pweto and between 18°E and 24°E.',-11.24,-3.57,18.0,24.0,0);
INSERT INTO "area" VALUES('EPSG','3628','Congo DR (Zaire) - south and 24°E to 30°E','The Democratic Republic of the Congo (Zaire) - south of a line through Bandundu, Seke and Pweto and east of 24°E.',-13.46,-4.79,24.0,29.81,0);
INSERT INTO "area" VALUES('EPSG','3629','Spain - Canary Islands - west of 18°W','Spain - Canary Islands - west of 18°W, onshore and offshore.',24.6,31.19,-21.93,-18.0,0);
INSERT INTO "area" VALUES('EPSG','3630','Spain - Canary Islands - east of 18°W','Spain - Canary Islands - east of 18°W, onshore and offshore.',25.25,32.76,-18.0,-11.75,0);
INSERT INTO "area" VALUES('EPSG','3631','Denmark - onshore Jutland west of 10°E','Denmark - Jutland onshore west of 10°E.',54.8,57.64,8.0,10.0,0);
INSERT INTO "area" VALUES('EPSG','3632','Denmark - onshore Jutland east of 9°E and Funen','Denmark - onshore - Jutland east of 9°E and Funen.',54.67,57.8,9.0,11.29,0);
INSERT INTO "area" VALUES('EPSG','3633','Mexico - 96°W to 90°W','Mexico between 96°W and 90°W, onshore and offshore.',12.1,26.0,-96.0,-90.0,0);
INSERT INTO "area" VALUES('EPSG','3634','Caribbean - Puerto Rico and US Virgin Islands - onshore','Puerto Rico and US Virgin Islands - onshore.',17.62,18.57,-67.97,-64.51,0);
INSERT INTO "area" VALUES('EPSG','3635','Mexico - east of 90°W','Mexico east of 90°W, onshore and offshore.',17.81,25.77,-90.0,-84.64,0);
INSERT INTO "area" VALUES('EPSG','3636','Norway - onshore - west of 6ºE','Norway - onshore - west of 6ºE.',58.32,62.49,4.68,6.0,0);
INSERT INTO "area" VALUES('EPSG','3637','USA - 102°W to 96°W and GoM OCS','United States (USA) - between 102°W and 96°W. Iowa; Kansas; Minnesota; Nebraska; North Dakota; Oklahoma; South Dakota; Texas; Gulf of Mexico outer continental shelf (GoM OCS) west of approximately 96°W - protraction areas Corpus Christi; Port Isabel.',25.83,49.01,-102.0,-95.87,0);
INSERT INTO "area" VALUES('EPSG','3638','South America - 84°W to 78°W, S hemisphere and SIRGAS95 by country','Ecuador (mainland whole country including areas in northern hemisphere and east of 78°W), onshore and offshore. In remainder of South America, between 84°W and 78°W, southern hemisphere, onshore and offshore.',-56.45,1.45,-84.0,-75.21,0);
INSERT INTO "area" VALUES('EPSG','3639','Norway - onshore - 6ºE to 7ºE','Norway - onshore - between 6ºE and 7ºE.',57.93,63.02,6.0,7.0,0);
INSERT INTO "area" VALUES('EPSG','3640','USA - 96°W to 90°W and GoM OCS','United States (USA) - between 96°W and 90°W - Arkansas; Illinois; Iowa; Kansas; Louisiana; Michigan; Minnesota; Mississippi; Missouri; Nebraska; Oklahoma; Tennessee; Texas; Wisconsin; Gulf of Mexico outer continental shelf (GoM OCS) between approximately 96°W and 90°W - protraction areas East Breaks; Alaminos Canyon; Garden Banks; Keathley Canyon; Sigsbee Escarpment; Ewing Bank; Green Canyon; Walker Ridge; Amery Terrace.',25.61,49.38,-96.01,-89.86,0);
INSERT INTO "area" VALUES('EPSG','3641','USA - 90°W to 84°W and GoM OCS','United States (USA) - between 90°W and 84°W onshore and offshore - Alabama; Arkansas; Florida; Georgia; Indiana; Illinois; Kentucky; Louisiana; Michigan; Minnesota; Mississippi; Missouri; North Carolina; Ohio; Tennessee; Wisconsin; Gulf of Mexico outer continental shelf (GoM OCS) between approximately 90°W and 84°W - protraction areas Mobile; Viosca Knoll; Mississippi Canyon; Atwater Valley; Lund; Lund South; Pensacola; Destin Dome; De Soto Canyon; Lloyd Ridge; Henderson; Florida Plain; Campeche Escarpment; Apalachicola; Florida Middle Ground; The Elbow; Vernon Basin; Howell Hook; Rankin.',23.95,48.32,-90.01,-83.91,0);
INSERT INTO "area" VALUES('EPSG','3642','USA - 84°W to 78°W and GoM OCS','United States (USA) - between 84°W and 78°W onshore and offshore - Florida; Georgia; Maryland; Michigan; New York; North Carolina; Ohio; Pennsylvania; South Carolina; Tennessee; Virginia; West Virginia; Gulf of Mexico outer continental shelf (GoM OCS) east of approximately 84°W - protraction areas Gainesville; Tarpon Springs; St Petersburg; Charlotte Harbor; Pulley Ridge; Dry Tortugas; Tortugas Valley; Miami; Key West.',23.81,46.13,-84.09,-77.99,0);
INSERT INTO "area" VALUES('EPSG','3643','Germany - Schleswig-Holstein','Germany - Schleswig-Holstein',53.35,55.06,7.8,11.35,1);
INSERT INTO "area" VALUES('EPSG','3644','Germany - Schleswig-Holstein - east of 10.5°E','Germany - Schleswig-Holstein - east of 10°30''E.',53.36,54.59,10.49,11.4,0);
INSERT INTO "area" VALUES('EPSG','3645','Sao Tome and Principe - onshore - Sao Tome','Sao Tome and Principe - onshore - Sao Tome.',-0.04,0.46,6.41,6.82,0);
INSERT INTO "area" VALUES('EPSG','3646','Sao Tome and Principe - onshore - Principe','Sao Tome and Principe - onshore - Principe.',1.48,1.76,7.27,7.52,0);
INSERT INTO "area" VALUES('EPSG','3647','Norway - onshore - 7ºE to 8ºE','Norway - onshore - between 7ºE and 8ºE.',57.93,63.52,7.0,8.0,0);
INSERT INTO "area" VALUES('EPSG','3648','Norway - onshore - 8ºE to 9ºE','Norway - onshore - between 8ºE and 9ºE.',58.03,63.87,8.0,9.0,0);
INSERT INTO "area" VALUES('EPSG','3649','Norway - onshore - 9ºE to 10ºE','Norway - onshore - between 9ºE and 10ºE.',58.52,64.16,9.0,10.0,0);
INSERT INTO "area" VALUES('EPSG','3650','Norway - onshore - 10ºE to 11ºE','Norway - onshore - between 10ºE and 11ºE.',58.9,65.04,10.0,11.0,0);
INSERT INTO "area" VALUES('EPSG','3651','Norway - onshore - 11ºE to 12ºE','Norway - onshore - between 11ºE and 12ºE.',58.88,65.76,11.0,12.0,0);
INSERT INTO "area" VALUES('EPSG','3652','USA - Michigan - SPCS - W','United States (USA) - Michigan - counties of Baraga; Dickinson; Gogebic; Houghton; Iron; Keweenaw; Marquette; Menominee; Ontonagon.',45.09,48.32,-90.42,-83.44,0);
INSERT INTO "area" VALUES('EPSG','3653','Norway - onshore - 12ºE to 13ºE','Norway - onshore - between 12ºE and 13ºE.',59.88,68.15,12.0,13.0,0);
INSERT INTO "area" VALUES('EPSG','3654','Norway - onshore - 13ºE to 14ºE','Norway - onshore - between 13ºE and 14ºE.',64.01,68.37,13.0,14.0,0);
INSERT INTO "area" VALUES('EPSG','3655','Norway - onshore - 14ºE to 15ºE','Norway - onshore - between 14ºE and 15ºE.',64.03,69.05,14.0,15.0,0);
INSERT INTO "area" VALUES('EPSG','3656','Norway - onshore - 15ºE to 16ºE','Norway - onshore - between 15ºE and 16ºE.',66.14,69.35,15.0,16.0,0);
INSERT INTO "area" VALUES('EPSG','3657','Norway - onshore - 16ºE to 17ºE','Norway - onshore - between 16ºE and 17ºE.',66.88,69.45,16.0,17.0,0);
INSERT INTO "area" VALUES('EPSG','3658','Norway - onshore - 17ºE to 18ºE','Norway - onshore - between 17ºE and 18ºE.',67.94,69.68,17.0,18.0,0);
INSERT INTO "area" VALUES('EPSG','3659','Germany - Schleswig-Holstein - west of 10.5°E','Germany - Schleswig-Holstein - west of 10°30''E including Heligoland.',53.37,55.09,7.8,10.5,0);
INSERT INTO "area" VALUES('EPSG','3660','Norway - onshore - 18ºE to 19ºE','Norway - onshore - between 18ºE and 19ºE.',68.04,70.27,18.0,19.0,0);
INSERT INTO "area" VALUES('EPSG','3661','Norway - onshore - 19ºE to 20ºE','Norway - onshore - between 19ºE and 20ºE.',68.33,70.34,19.0,20.0,0);
INSERT INTO "area" VALUES('EPSG','3662','Norway - onshore - 20ºE to 21ºE','Norway - onshore - between 20ºE and 21ºE.',68.37,70.29,20.0,21.0,0);
INSERT INTO "area" VALUES('EPSG','3663','Norway - onshore - 21ºE to 22ºE','Norway - onshore - between 21ºE and 22ºE.',69.03,70.71,21.0,22.0,0);
INSERT INTO "area" VALUES('EPSG','3664','USA - CONUS and Alaska - onshore','United States (USA) -  CONUS and Alaska - onshore - Alabama; Alaska mainland; Arizona; Arkansas; California; Colorado; Connecticut; Delaware; Florida; Georgia; Idaho; Illinois; Indiana; Iowa; Kansas; Kentucky; Louisiana; Maine; Maryland; Massachusetts; Michigan; Minnesota; Mississippi; Missouri; Montana; Nebraska; Nevada; New Hampshire; New Jersey; New Mexico; New York; North Carolina; North Dakota; Ohio; Oklahoma; Oregon; Pennsylvania; Rhode Island; South Carolina; South Dakota; Tennessee; Texas; Utah; Vermont; Virginia; Washington; West Virginia; Wisconsin; Wyoming.',24.41,71.4,-168.26,-66.91,0);
INSERT INTO "area" VALUES('EPSG','3665','Norway - onshore - 22ºE to 23ºE','Norway - onshore - between 22ºE and 23ºE.',68.69,70.81,22.0,23.0,0);
INSERT INTO "area" VALUES('EPSG','3666','Indonesia - Java and Java Sea','Indonesia - Java and Bali onshore, offshore southern Java Sea, Madura Strait and western Bali Sea.',-8.91,-4.07,105.06,117.01,0);
INSERT INTO "area" VALUES('EPSG','3667','Norway - onshore - 23ºE to 24ºE','Norway - onshore - between 23ºE and 24ºE.',68.62,71.08,23.0,24.0,0);
INSERT INTO "area" VALUES('EPSG','3668','Norway - onshore - 24ºE to 25ºE','Norway - onshore - between 24ºE and 25ºE.',68.58,71.16,24.0,25.0,0);
INSERT INTO "area" VALUES('EPSG','3669','Norway - onshore - 25ºE to 26ºE','Norway - onshore - between 25ºE and 26ºE.',68.59,71.21,25.0,26.0,0);
INSERT INTO "area" VALUES('EPSG','3670','Portugal - Azores and Madeira','Portugal - Azores and Madeira island groups and surrounding EEZ - Flores, Corvo; Graciosa, Terceira, Sao Jorge, Pico, Faial; Sao Miguel, Santa Maria; Madeira, Porto Santo, Desertas; Selvagens.',29.24,43.07,-35.58,-12.48,0);
INSERT INTO "area" VALUES('EPSG','3671','Norway - onshore - 26ºE to 27ºE','Norway - onshore - between 26ºE and 27ºE.',69.71,71.17,26.0,27.0,0);
INSERT INTO "area" VALUES('EPSG','3672','Norway - onshore - 27ºE to 28ºE','Norway - onshore - between 27ºE and 28ºE.',69.9,71.17,27.0,28.0,0);
INSERT INTO "area" VALUES('EPSG','3673','Norway - onshore - 28ºE to 29ºE','Norway - onshore - between 28ºE and 29ºE.',69.03,71.13,28.0,29.0,0);
INSERT INTO "area" VALUES('EPSG','3674','Norway - onshore - 29ºE to 30ºE','Norway - onshore - between 29ºE and 30ºE.',69.02,70.93,29.0,30.0,0);
INSERT INTO "area" VALUES('EPSG','3675','Paraguay - north of 22°S','Paraguay - north of 22°S.',-22.0,-19.29,-62.57,-57.81,0);
INSERT INTO "area" VALUES('EPSG','3676','Norway - onshore - east of 30ºE','Norway - onshore - east of 30ºE.',69.46,70.77,30.0,31.22,0);
INSERT INTO "area" VALUES('EPSG','3677','Portugal - Azores 30°W to 24°W','Portugal - between 30°W and 24°W - central and eastern Azores - Graciosa, Terceira, Sao Jorge, Pico, Faial; Sao Miguel and Santa Maria islands and surrounding EEZ.',33.52,42.96,-30.0,-24.0,0);
INSERT INTO "area" VALUES('EPSG','3678','Portugal - Madeira and EEZ E of 18°W','Portugal - Madeira, Porto Santo, Desertas and Selvagens islands and surrounding EEZ east of 18°W.',29.24,36.46,-18.0,-12.48,0);
INSERT INTO "area" VALUES('EPSG','3679','Portugal - Madeira island onshore','Portugal - Madeira island onshore.',32.58,32.93,-17.31,-16.66,0);
INSERT INTO "area" VALUES('EPSG','3680','Portugal - Porto Santo island onshore','Portugal - Porto Santo island (Madeira archipelago) onshore.',32.96,33.15,-16.44,-16.23,0);
INSERT INTO "area" VALUES('EPSG','3681','Portugal - Azores C - Graciosa onshore','Portugal - central Azores - Graciosa island onshore.',38.97,39.14,-28.13,-27.88,0);
INSERT INTO "area" VALUES('EPSG','3682','Portugal - Azores - west of 30°W','Portugal - west of 30°W - western Azores - Flores and Corvo islands and surrounding EEZ.',35.25,43.07,-35.58,-30.0,0);
INSERT INTO "area" VALUES('EPSG','3683','Portugal - Azores E - Santa Maria onshore','Portugal - eastern Azores - Santa Maria island onshore.',36.87,37.08,-25.26,-24.96,0);
INSERT INTO "area" VALUES('EPSG','3684','Portugal - Azores W - Flores onshore','Portugal - western Azores - Flores island onshore.',39.3,39.58,-31.34,-31.07,0);
INSERT INTO "area" VALUES('EPSG','3685','Portugal - Azores W - Corvo onshore','Portugal - western Azores - Corvo island onshore.',39.63,39.77,-31.18,-31.02,0);
INSERT INTO "area" VALUES('EPSG','3686','Colombia - mainland and offshore Caribbean','Colombia - mainland and offshore Caribbean.',-4.23,13.68,-79.1,-66.87,0);
INSERT INTO "area" VALUES('EPSG','3687','Australia - SA and WA 126°E to 132°E','Australia - South Australia west of 132°E, Western Australia east of 126°E, offshore federal waters between 126°E and 129°E.',-37.05,-9.37,125.99,132.01,0);
INSERT INTO "area" VALUES('EPSG','3688','Australia - SA 132°E to 138°E','Australia - South Australia between 132°E and 138°E.',-36.14,-25.99,132.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','3689','Australia - SA and Qld 138°E to 144°E','Australia - South Australia east of 138°E, Queensland west of 144°E.',-38.13,-9.86,138.0,144.01,0);
INSERT INTO "area" VALUES('EPSG','3690','Australia - Qld 144°E to 150°E','Australia - Queensland between 144°E and 150°E.',-29.01,-14.01,144.0,150.0,0);
INSERT INTO "area" VALUES('EPSG','3691','Australia - Qld east of 150°E','Australia - Queensland east of 150°E.',-29.19,-22.0,150.0,153.61,0);
INSERT INTO "area" VALUES('EPSG','3692','Brazil - Reconcavo and Jacuipe','Brazil - offshore - Reconcavo and Jacuipe basins.',-13.57,-11.18,-39.09,-35.31,0);
INSERT INTO "area" VALUES('EPSG','3693','Brazil - Tucano and Jatoba','Brazil - Tucano North, Tucano Central, Tucano South and Jatoba basins.',-12.27,-8.39,-39.14,-37.09,0);
INSERT INTO "area" VALUES('EPSG','3694','France - onshore - mainland and Corsica','France - onshore - mainland and Corsica.',41.31,51.14,-4.87,9.63,0);
INSERT INTO "area" VALUES('EPSG','3695','Iraq - 31.4°N to 33°N, 43.9°E to 46.1°E (map 16)','Iraq - between UTM 3470000mN and 3650000mN (approximately 31°21''N and 32°58''N) and between UTM 400000mE and 600000mE (approximately 43°56''E and 46°04''E).',31.36,32.99,43.92,46.08,0);
INSERT INTO "area" VALUES('EPSG','3696','Brazil - Sergipe and Alagoas','Brazil - offshore - Sergipe and Alagoas basins.',-13.58,-8.73,-37.34,-32.01,0);
INSERT INTO "area" VALUES('EPSG','3697','Brazil - Paraiba-Pernambuco','Brazil - offshore - Paraiba-Pernambuco basin.',-10.17,-4.6,-35.1,-29.13,0);
INSERT INTO "area" VALUES('EPSG','3698','Brazil - Potiguar, Ceara and Barreirinhas','Brazil - offshore - Potiguar, Ceara and Barreirinhas basins.',-6.5,4.26,-44.79,-26.0,0);
INSERT INTO "area" VALUES('EPSG','3699','Brazil - Cumuruxatiba, Jequitinhonha and Camamu-Almada','Brazil - offshore - Cumuruxatiba, Jequitinhonha and Camamu-Almada basins.',-17.7,-13.01,-39.22,-34.6,0);
INSERT INTO "area" VALUES('EPSG','3700','Brazil - Santos and Pelotas','Brazil - offshore - Santos and Pelotas basins.',-35.71,-22.66,-53.38,-40.2,0);
INSERT INTO "area" VALUES('EPSG','3701','Iraq - 34.6°N to 36.2°N, west of 42.8°E (map 5)','Iraq - between UTM 3830000mN and 4010000mN (approximately 34°35''N and 36°13''N) and west of UTM 300000mE (approximately 42°48''E).',34.55,36.22,41.09,42.82,0);
INSERT INTO "area" VALUES('EPSG','3702','Iraq - SE','Iraq - onshore southeast.',29.06,32.51,43.98,48.61,0);
INSERT INTO "area" VALUES('EPSG','3703','Germany - Lower Saxony west of 7.5°E','Germany - Niedersachsen onshore west of 7°30''E.',52.23,53.81,6.58,7.5,0);
INSERT INTO "area" VALUES('EPSG','3704','Iraq - 31.4°N to 33°N, east of 46.1°E (map 17)','Iraq - between UTM 3470000mN and 3650000mN (approximately 31°21''N and 32°58''N) and east of UTM 600000mE (approximately 46°04''E).',31.33,32.99,46.05,47.87,0);
INSERT INTO "area" VALUES('EPSG','3705','Germany - Lower Saxony east of 10.5°E','Germany - Niedersachsen east of 10°30''E.',51.55,53.38,10.5,11.59,0);
INSERT INTO "area" VALUES('EPSG','3706','Iraq - 29.7 to 31.4°N, 42°E to 43.9°E (map 19)','Iraq - between UTM 3290000mN and 3470000mN (approximately 29°47''N and 31°21''N) and between 42°E and UTM 400000mE (approximately 43°56''E).',29.75,31.37,42.0,43.97,0);
INSERT INTO "area" VALUES('EPSG','3707','Germany - Lower Saxony 7.5°E to 10.5°E','Germany - Niedersachsen between 7°30''E and 10°30''E.',51.28,53.95,7.5,10.51,0);
INSERT INTO "area" VALUES('EPSG','3708','Iraq - 29.7°N to 31.4°N, 43.9°E to 46.1°E (map 20)','Iraq - between UTM 3290000mN and 3470000mN (approximately 29°47''N and 31°21''N) and between UTM 400000mE and 600000mE (approximately 43°56''E and 46°04''E).',29.73,31.37,43.94,46.06,0);
INSERT INTO "area" VALUES('EPSG','3709','Iraq - 31.4°N to 33°N, 42°E to 43.9°E (map 15)','Iraq - between UTM 3470000mN and 3650000mN (approximately 31°21''N and 32°58''N) and between 42°E and UTM 400000mE (approximately 43°56''E).',31.32,32.99,42.0,43.95,0);
INSERT INTO "area" VALUES('EPSG','3710','Iraq - 29.7°N to 31.4°N, 46.1°E to 48°E (map 21)','Iraq - between UTM 3290000mN and 3470000mN (approximately 29°47''N and 31°21''N) and between UTM 600000mE (approximately 46°04''E) and 48°E.',29.72,31.37,46.03,48.0,0);
INSERT INTO "area" VALUES('EPSG','3711','Iraq - south of 29.7°N, west of 46.1°E (map 24)','Iraq - south of UTM 3290000mN (approximately 29°47''N) and west of UTM 600000mE (approximately 46°04''E).',29.09,29.75,43.99,46.04,0);
INSERT INTO "area" VALUES('EPSG','3712','Iraq - south of 29.7°N, east of 46.1°E (map 25)','Iraq - south of UTM 3290000mN (approximately 29°47''N) and east of UTM 600000mE (approximately 46°04''E).',29.06,29.74,46.02,47.02,0);
INSERT INTO "area" VALUES('EPSG','3713','Asia - Korea N and S - west of 126°E','Democratic People''s Republic of Korea (North Korea) and Republic of Korea (South Korea) - onshore west of 126°E.',33.99,40.9,124.27,126.0,0);
INSERT INTO "area" VALUES('EPSG','3714','Iraq - north of 36.2°N, west of 42°E (map 1)','Iraq - north of UTM 4010000mN (approximately 36°13''N and west of 42°E.',36.19,36.75,41.27,42.0,0);
INSERT INTO "area" VALUES('EPSG','3715','Iraq - 34.6°N to 36.2°N, 42.8°E to 45°E (map 6)','Iraq - between UTM 3830000mN and 4010000mN (approximately 34°35''N and 36°13''N) and between UTM 300000mE (approximately 42°48''E) and 45°E.',34.59,36.24,42.77,45.0,0);
INSERT INTO "area" VALUES('EPSG','3716','Asia - Korea N and S - 126°E to 128°E','Democratic People''s Republic of Korea (North Korea) and Republic of Korea (South Korea) - onshore between 126°E and 128°E.',33.14,41.8,126.0,128.0,0);
INSERT INTO "area" VALUES('EPSG','3717','Iraq - north of 36.2°N, 42°E to 43.9°E (map 2)','Iraq - north of UTM 4010000mN (approximately 36°13''N) and between 42°E and UTM 400000mE (approximately 43°56''E).',36.19,37.39,42.0,43.89,0);
INSERT INTO "area" VALUES('EPSG','3718','Iraq - 34.6°N to 36.2°N, east of 45°E (map 7)','Iraq - between UTM 3830000mN and 4010000mN (approximately 34°35''N and 36°13''N) and east of 45°E.',34.6,36.24,45.0,46.35,0);
INSERT INTO "area" VALUES('EPSG','3719','Iraq - north of 36.2°N, east of 43.9°E (map 3)','Iraq - north of UTM 4010000mN (approximately 36°13''N) and east of UTM 400000mE (approximatrely 43°56''E).',36.22,37.33,43.87,45.33,0);
INSERT INTO "area" VALUES('EPSG','3720','Korea, Republic of (South Korea) - 130°E to 132°E onshore','Republic of Korea (South Korea) - onshore between 130°E and 132°E.',37.39,37.62,130.71,131.01,0);
INSERT INTO "area" VALUES('EPSG','3721','Korea, Republic of (South Korea) - 126°E to 128°E Jeju','Republic of Korea (South Korea) - between 126°E and 128°E - Jeju island onshore.',33.14,33.61,126.09,127.01,0);
INSERT INTO "area" VALUES('EPSG','3722','Iraq - 33°N to 34.6°N, west of 40.1°E (map 8)','Iraq - north of UTM 3650000mN (approximately 32°58''N) and west of UTM zone 37 600000mE (approximately 40°04''E).',32.98,33.99,38.79,40.09,0);
INSERT INTO "area" VALUES('EPSG','3723','Iraq - 33°N to 34.6°N, 40.1°E to 42°E (map 9)','Iraq - between UTM 3650000mN and 3830000mN (approximately 32°58''N and 34°35''N) and between UTM zone 37 600000mE (approximately 40°04''E) and 42°E.',32.95,34.6,40.07,42.0,0);
INSERT INTO "area" VALUES('EPSG','3724','Iraq - 33°N to 34.6°N, 42°E to 43.9°E (map 10)','Iraq - between UTM 3650000mN and 3830000mN (approximately 32°58''N and 34°35''N) and between 42°E and UTM 400000mE (approximately 43°56''E).',32.95,34.61,42.0,43.93,0);
INSERT INTO "area" VALUES('EPSG','3725','Iraq - 33°N to 34.6°N, 43.9°E to 46.1°E (map 11)','Iraq - between UTM 3650000mN and 3830000mN (approximately 32°58''N and 34°35''N) and between UTM 400000mE and 600000mE (approximately 43°56''E and 46°04''E).',32.98,34.62,43.9,46.2,0);
INSERT INTO "area" VALUES('EPSG','3726','Asia - Korea N and S - 128°E to 130°E','Democratic People''s Republic of Korea (North Korea) and Republic of Korea (South Korea) - onshore between 128°E and 130°E.',34.49,43.01,128.0,130.0,0);
INSERT INTO "area" VALUES('EPSG','3727','Asia - Korea N and S - east of 130°E','Democratic People''s Republic of Korea (North Korea) and Republic of Korea (South Korea) - onshore east of 130°E.',37.39,42.98,130.0,131.01,0);
INSERT INTO "area" VALUES('EPSG','3728','Iraq - 31.4°N to 33°N, 40.1°E to 42°E (map 14)','Iraq - between UTM 3470000mN and 3650000mN (approximately 31°21''N and 32°58''N) and between UTM zone 37 600000mE (approximately 40°04''E) and 42°E.',31.32,32.99,40.05,42.0,0);
INSERT INTO "area" VALUES('EPSG','3729','Iraq - 31.4°N to 33°N, west of 40.1°E (map 13)','Iraq - sorth of UTM 3650000mN (approximately 32°58''N) and west of UTM zone 37 600000mE (approximately 40°04''E).',32.0,32.99,38.92,40.08,0);
INSERT INTO "area" VALUES('EPSG','3730','Korea, Republic of (South Korea) - 126°E to 128°E mainland','Republic of Korea (South Korea) - between 126°E and 128°E - mainland and nearshore.',33.96,38.33,126.0,128.0,0);
INSERT INTO "area" VALUES('EPSG','3731','Georgia - offshore','Georgia - offshore.',41.54,43.33,38.97,41.71,0);
INSERT INTO "area" VALUES('EPSG','3732','Spain - Catalonia onshore','Spain - Catalonia onshore.',40.49,42.86,0.16,3.39,0);
INSERT INTO "area" VALUES('EPSG','3733','Bolivia - east of 60°W','Bolivia - east of 60°W.',-20.17,-16.27,-60.0,-57.52,0);
INSERT INTO "area" VALUES('EPSG','3734','Bhutan - Bumthang district','Bhutan - Bumthang district.',27.33,28.09,90.46,91.02,0);
INSERT INTO "area" VALUES('EPSG','3735','Thailand - onshore east of 102°E','Thailand - onshore east of 102°E.',6.02,18.44,102.0,105.64,0);
INSERT INTO "area" VALUES('EPSG','3736','Italy - mainland and Sicily','Italy - mainland (including San Marino and Vatican City State) and Sicily.',36.59,47.1,6.62,18.58,0);
INSERT INTO "area" VALUES('EPSG','3737','Bhutan - Chhukha district','Bhutan - Chhukha district.',26.71,27.32,89.26,89.83,0);
INSERT INTO "area" VALUES('EPSG','3738','Bhutan - Dagana district','Bhutan - Dagana district.',26.7,27.29,89.63,90.08,0);
INSERT INTO "area" VALUES('EPSG','3739','Korea, Republic of (South Korea) - mainland','Republic of Korea (South Korea) - mainland onshore.',33.96,38.64,125.75,129.65,0);
INSERT INTO "area" VALUES('EPSG','3740','Bhutan - Gasa district','Bhutan - Gasa district.',27.72,28.33,89.44,90.47,0);
INSERT INTO "area" VALUES('EPSG','3741','Thailand - onshore and Gulf of Thailand','Thailand - onshore plus offshore Gulf of Thailand.',5.63,20.46,97.34,105.64,0);
INSERT INTO "area" VALUES('EPSG','3742','Bhutan - Ha district','Bhutan - Ha district.',27.02,27.62,88.9,89.39,0);
INSERT INTO "area" VALUES('EPSG','3743','Bhutan - Lhuentse district','Bhutan - Lhuentse district.',27.39,28.09,90.77,91.49,0);
INSERT INTO "area" VALUES('EPSG','3744','Europe - Ireland (Republic and Ulster) - on- and offshore','Ireland - onshore. United Kingdom (UK) - Northern Ireland (Ulster) - onshore and offshore.',51.33,55.4,-10.6,-5.33,1);
INSERT INTO "area" VALUES('EPSG','3745','Bhutan - Mongar district','Bhutan - Mongar district.',26.93,27.61,90.95,91.5,0);
INSERT INTO "area" VALUES('EPSG','3746','Bhutan - Paro district','Bhutan - Paro district.',27.18,27.79,89.12,89.56,0);
INSERT INTO "area" VALUES('EPSG','3747','Bhutan - Pemagatshel district','Bhutan - Pemagatshel district.',26.78,27.18,91.0,91.56,0);
INSERT INTO "area" VALUES('EPSG','3748','Latin America - 120°W to 114°W','Latin America between 120°W and 114°W, northern hemisphere, onshore and offshore.',15.01,32.72,-120.0,-114.0,0);
INSERT INTO "area" VALUES('EPSG','3749','Bhutan - Punakha district','Bhutan - Punakha district.',27.46,27.87,89.63,90.08,0);
INSERT INTO "area" VALUES('EPSG','3750','Bhutan - Samdrup Jongkhar district','Bhutan - Samdrup Jongkhar district.',26.79,27.25,91.39,92.13,0);
INSERT INTO "area" VALUES('EPSG','3751','Bhutan - Samtse district','Bhutan - Samtse district.',26.8,27.28,88.74,89.38,0);
INSERT INTO "area" VALUES('EPSG','3752','Bhutan - Sarpang district','Bhutan - Sarpang district.',26.73,27.23,90.01,90.78,0);
INSERT INTO "area" VALUES('EPSG','3753','Bhutan - Thimphu district','Bhutan - Thimphu district.',27.14,28.01,89.22,89.77,0);
INSERT INTO "area" VALUES('EPSG','3754','Bhutan - Trashigang district','Bhutan - Trashigang district.',27.01,27.49,91.37,92.13,0);
INSERT INTO "area" VALUES('EPSG','3755','Bhutan - Trongsa district','Bhutan - Trongsa district.',27.13,27.79,90.26,90.76,0);
INSERT INTO "area" VALUES('EPSG','3756','Latin America - 114°W to 108°W','Latin America between 114°W and 108°W, northern hemisphere, onshore and offshore.',15.09,32.27,-114.0,-108.0,0);
INSERT INTO "area" VALUES('EPSG','3757','Bhutan - Tsirang district','Bhutan - Tsirang district.',26.81,27.2,90.0,90.35,0);
INSERT INTO "area" VALUES('EPSG','3758','Bhutan - Wangdue Phodrang district','Bhutan - Wangdue Phodrang district.',27.11,28.08,89.71,90.54,0);
INSERT INTO "area" VALUES('EPSG','3759','Latin America - 108°W to 102°W','Latin America between 108°W and 102°W,  northern hemisphere, onshore and offshore.',14.05,31.79,-108.0,-102.0,0);
INSERT INTO "area" VALUES('EPSG','3760','Bhutan - Yangtse district','Bhutan - Yangtse district.',27.37,28.0,91.34,91.77,0);
INSERT INTO "area" VALUES('EPSG','3761','Bhutan - Zhemgang district','Bhutan - Zhemgang district.',26.77,27.39,90.53,91.19,0);
INSERT INTO "area" VALUES('EPSG','3762','New Zealand - North Island - One Tree vcrs','New Zealand - North Island - One Tree Point vertical CRS area.',-36.41,-34.36,172.61,174.83,0);
INSERT INTO "area" VALUES('EPSG','3763','Latin America - 102°W to 96°W','Latin America between 102°W and 96°W, northern hemisphere, onshore and offshore.',12.3,29.81,-102.01,-96.0,0);
INSERT INTO "area" VALUES('EPSG','3764','New Zealand - North Island - Auckland vcrs','New Zealand - North Island - Auckland vertical CRS area.',-37.67,-36.12,174.0,176.17,0);
INSERT INTO "area" VALUES('EPSG','3765','French Guiana - coastal area west of 54°W','French Guiana - coastal area west of 54°W.',4.84,5.69,-54.45,-54.0,0);
INSERT INTO "area" VALUES('EPSG','3766','French Guiana - coastal area east of 54°W','French Guiana - coastal area east of 54°W.',3.43,5.81,-54.0,-51.61,0);
INSERT INTO "area" VALUES('EPSG','3767','Ireland - onshore','Ireland - onshore.',51.39,55.43,-10.56,-5.93,0);
INSERT INTO "area" VALUES('EPSG','3768','New Zealand - North Island - Moturiki vcrs','New Zealand - North Island - Moturiki vertical CRS area.',-40.59,-37.52,174.57,177.26,0);
INSERT INTO "area" VALUES('EPSG','3769','New Zealand - North Island - Taranaki vcrs','New Zealand - North Island - Taranaki vertical CRS area.',-39.92,-38.41,173.68,174.95,0);
INSERT INTO "area" VALUES('EPSG','3770','Vietnam - DBSCL 02 and 03','Vietnam - Mekong delta blocks DBSCL 02 and 03.',9.34,11.03,104.25,107.11,0);
INSERT INTO "area" VALUES('EPSG','3771','New Zealand - North Island - Gisborne vcrs','New Zealand - North Island - Gisborne vertical CRS area.',-39.04,-37.49,176.41,178.63,0);
INSERT INTO "area" VALUES('EPSG','3772','New Zealand - North Island - Hawkes Bay mc Napier vcrs','New Zealand - North Island - Hawkes Bay meridional circuit and Napier vertical crs area.',-40.57,-38.87,175.8,178.07,0);
INSERT INTO "area" VALUES('EPSG','3773','New Zealand - North Island - Wellington vcrs','New Zealand - North Island - Wellington vertical CRS area.',-41.67,-40.12,174.52,176.56,0);
INSERT INTO "area" VALUES('EPSG','3774','New Zealand - North Island - Wellington mc','New Zealand - North Island - Wellington meridional circuit area.',-41.5,-40.91,174.52,175.36,0);
INSERT INTO "area" VALUES('EPSG','3775','New Zealand - North Island - Wairarapa mc','New Zealand - North Island - Wairarapa meridional circuit area.',-41.67,-40.29,175.01,176.55,0);
INSERT INTO "area" VALUES('EPSG','3776','New Zealand - North Island - Wanganui mc','New Zealand - North Island - Wanganui meridional circuit area.',-40.97,-39.46,174.4,176.27,0);
INSERT INTO "area" VALUES('EPSG','3777','New Zealand - North Island - Taranaki mc','New Zealand - North Island - Taranaki meridional circuit area.',-39.78,-38.4,173.68,175.44,0);
INSERT INTO "area" VALUES('EPSG','3778','New Zealand - North Island - Tuhirangi mc','New Zealand - North Island - Tuhirangi meridional circuit area.',-39.55,-38.87,174.88,176.33,0);
INSERT INTO "area" VALUES('EPSG','3779','New Zealand - North Island - Bay of Plenty mc','New Zealand - North Island - Bay of Plenty meridional circuit area.',-39.13,-37.22,175.75,177.23,0);
INSERT INTO "area" VALUES('EPSG','3780','New Zealand - North Island - Poverty Bay mc','New Zealand - North Island - Poverty Bay meridional circuit area.',-39.04,-37.49,176.73,178.63,0);
INSERT INTO "area" VALUES('EPSG','3781','New Zealand - North Island - Mount Eden mc','New Zealand - North Island - Mount Eden meridional circuit area.',-39.01,-34.1,171.99,176.12,0);
INSERT INTO "area" VALUES('EPSG','3782','New Zealand - South Island - Collingwood mc','New Zealand - South Island - Collingwood meridional circuit area.',-41.22,-40.44,172.16,173.13,0);
INSERT INTO "area" VALUES('EPSG','3783','New Zealand - South Island - Karamea mc','New Zealand - South Island - Karamea meridional circuit area.',-41.49,-40.75,171.96,172.7,0);
INSERT INTO "area" VALUES('EPSG','3784','New Zealand - South Island - Nelson mc','New Zealand - South Island - Nelson meridional circuit area.',-42.18,-40.66,172.4,174.08,0);
INSERT INTO "area" VALUES('EPSG','3785','New Zealand - South Island - Marlborough mc','New Zealand - South Island - Marlborough meridional circuit area.',-42.65,-40.85,172.95,174.46,0);
INSERT INTO "area" VALUES('EPSG','3786','New Zealand - South Island - Buller mc','New Zealand - South Island - Buller meridional circuit area.',-42.19,-41.42,171.27,172.41,0);
INSERT INTO "area" VALUES('EPSG','3787','New Zealand - South Island - Grey mc','New Zealand - South Island - Grey meridional circuit area.',-42.74,-41.5,171.15,172.75,0);
INSERT INTO "area" VALUES('EPSG','3788','New Zealand - South Island - Amuri mc','New Zealand - South Island - Amuri meridional circuit area.',-42.95,-42.09,171.88,173.55,0);
INSERT INTO "area" VALUES('EPSG','3789','New Zealand - South Island - Hokitika mc','New Zealand - South Island - Hokitika meridional circuit area.',-43.23,-42.41,170.39,171.89,0);
INSERT INTO "area" VALUES('EPSG','3790','New Zealand - South Island - Mount Pleasant mc','New Zealand - South Island - Mount Pleasant meridional circuit area.',-43.96,-42.69,171.11,173.38,0);
INSERT INTO "area" VALUES('EPSG','3791','New Zealand - South Island - Okarito mc','New Zealand - South Island - Okarito meridional circuit area.',-43.85,-43.0,169.21,170.89,0);
INSERT INTO "area" VALUES('EPSG','3792','New Zealand - South Island - Gawler mc','New Zealand - South Island - Gawler meridional circuit area.',-44.25,-43.13,170.68,172.26,0);
INSERT INTO "area" VALUES('EPSG','3793','New Zealand - South Island - Timaru mc','New Zealand - South Island - Timaru meridional circuit area.',-44.98,-43.35,169.82,171.55,0);
INSERT INTO "area" VALUES('EPSG','3794','New Zealand - South Island - Jacksons Bay mc','New Zealand - South Island - Jacksons Bay meridional circuit area.',-44.4,-43.67,168.02,170.01,0);
INSERT INTO "area" VALUES('EPSG','3795','New Zealand - South Island - Lindis Peak mc','New Zealand - South Island - Lindis Peak meridional circuit area.',-45.4,-43.71,168.62,170.24,0);
INSERT INTO "area" VALUES('EPSG','3796','New Zealand - South Island - Observation Point mc','New Zealand - South Island - Observation Point meridional circuit area.',-45.82,-44.61,169.77,171.24,0);
INSERT INTO "area" VALUES('EPSG','3797','New Zealand - South Island - Mount Nicholas mc','New Zealand - South Island - Mount Nicholas meridional circuit area.',-45.58,-44.29,167.72,169.11,0);
INSERT INTO "area" VALUES('EPSG','3798','New Zealand - South Island - North Taieri mc','New Zealand - South Island - North Taieri meridional circuit area.',-46.73,-45.23,168.64,170.87,0);
INSERT INTO "area" VALUES('EPSG','3799','New Zealand - South Island - Mount York mc','New Zealand - South Island - Mount York meridional circuit area.',-46.33,-44.53,166.37,168.21,0);
INSERT INTO "area" VALUES('EPSG','3800','New Zealand - South and Stewart Islands - Bluff mc','New Zealand - Stewart Island; South Island - Bluff meridional circuit area.',-47.33,-45.33,167.29,168.97,0);
INSERT INTO "area" VALUES('EPSG','3801','New Zealand - South Island - Bluff vcrs','New Zealand - South Island - Bluff vertical CRS area.',-46.71,-46.26,168.01,168.86,0);
INSERT INTO "area" VALUES('EPSG','3802','New Zealand - South Island - Nelson vcrs','New Zealand - South Island - north of approximately 42°20''S - Nelson vertical CRS area.',-42.44,-40.44,171.82,174.46,0);
INSERT INTO "area" VALUES('EPSG','3803','New Zealand - South Island - Dunedin vcrs','New Zealand - South Island - between approximately 44°S and 46°S - Dunedin vertical CRS area.',-46.4,-43.82,167.73,171.28,0);
INSERT INTO "area" VALUES('EPSG','3804','New Zealand - South Island - Lyttleton vcrs','New Zealand - South Island - between approximately 41°20''S and 45°S - Lyttleton vertical CRS area.',-44.92,-41.6,168.95,173.77,0);
INSERT INTO "area" VALUES('EPSG','3805','Bonaire, St Eustatius and Saba','Bonaire, St Eustatius and Saba - onshore and offshore.',11.66,17.96,-69.09,-62.76,0);
INSERT INTO "area" VALUES('EPSG','3806','New Zealand - South Island - Dunedin-Bluff vcrs','New Zealand - South Island - Dunedin-Bluff vertical CRS area.',-46.73,-44.52,166.37,169.95,0);
INSERT INTO "area" VALUES('EPSG','3807','Curacao','Curaçao - onshore and offshore.',11.66,15.35,-69.55,-68.54,0);
INSERT INTO "area" VALUES('EPSG','3808','Brazil - 36°W to 30°W offshore','Brazil - offshore between 36°W and 30°W, southern hemisphere.',-20.11,0.0,-36.0,-30.0,0);
INSERT INTO "area" VALUES('EPSG','3809','St Maarten','Sint Maarten - onshore and offshore.',17.81,18.07,-63.3,-62.92,0);
INSERT INTO "area" VALUES('EPSG','3810','Caribbean - St Maarten, St Eustatius and Saba - onshore','Caribbean - St Maarten, St Eustatius and Saba - onshore.',17.41,18.07,-63.31,-62.88,0);
INSERT INTO "area" VALUES('EPSG','3811','Chile - 72°W to 66°W','Chile - 72°W to 66°W, onshore and offshore.',-59.87,-17.5,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','3812','Nigeria - offshore deep water - east of 6°E','Nigeria - offshore deep water - east of 6°E.',2.61,3.68,6.0,7.82,0);
INSERT INTO "area" VALUES('EPSG','3813','Nigeria - offshore blocks OPL 209, 219 and 220','Nigeria - offshore blocks OPL 209, 219 and 220.',3.25,5.54,4.01,6.96,0);
INSERT INTO "area" VALUES('EPSG','3814','Nigeria - offshore blocks OML 99-102 and OPL 222 and 223','Nigeria - offshore blocks OML 99-102 and OPL 222 and 223.',3.25,4.51,7.16,8.25,0);
INSERT INTO "area" VALUES('EPSG','3815','Nigeria - offshore blocks OPL 209-213 and 316','Nigeria - offshore blocks OPL 209-213 and 316.',4.22,6.31,3.83,5.17,0);
INSERT INTO "area" VALUES('EPSG','3816','Nigeria - offshore blocks OPL 217-223','Nigeria - offshore blocks OPL 217-223.',3.24,3.86,5.58,8.0,0);
INSERT INTO "area" VALUES('EPSG','3817','Nigeria - offshore blocks OPL 210, 213, 217 and 218','Nigeria - offshore blocks OPL 210, 213, 217 and 218.',3.24,5.54,4.41,6.29,0);
INSERT INTO "area" VALUES('EPSG','3818','New Zealand - North Island - Tararu vcrs','New Zealand - North Island - Tararu vertical CRS area.',-37.21,-36.78,175.44,175.99,0);
INSERT INTO "area" VALUES('EPSG','3819','Nigeria - offshore blocks OPL 215 and 221','Nigeria - offshore blocks OPL 215 and 221.',3.25,4.23,5.02,7.31,0);
INSERT INTO "area" VALUES('EPSG','3820','Bonaire - St Eustatius and Saba','Bonaire, St Eustatius and Saba - St Eustatius and Saba - onshore and offshore.',16.68,17.96,-64.02,-62.76,0);
INSERT INTO "area" VALUES('EPSG','3821','Bonaire','Bonaire, St Eustatius and Saba - Bonaire - onshore and offshore.',11.66,15.3,-69.09,-67.98,0);
INSERT INTO "area" VALUES('EPSG','3822','Bonaire - onshore','Bonaire, St Eustatius and Saba - Bonaire - onshore.',11.97,12.36,-68.47,-68.14,0);
INSERT INTO "area" VALUES('EPSG','3823','Curacao - onshore','Curaçao - onshore.',11.99,12.44,-69.22,-68.69,0);
INSERT INTO "area" VALUES('EPSG','3824','Nigeria - Gongola Basin','Nigeria - onshore - Gongola Basin',8.78,11.63,9.41,12.13,0);
INSERT INTO "area" VALUES('EPSG','3825','Caribbean - French Antilles west of 60°W','French Antilles onshore and offshore west of 60°W - Guadeloupe (including Grande Terre, Basse Terre, Marie Galante, Les Saintes, Iles de la Petite Terre, La Desirade, St Barthélemy, and northern St Martin) and Martinique.',14.08,18.32,-63.66,-60.0,0);
INSERT INTO "area" VALUES('EPSG','3826','Uruguay - west of 54°W','Uruguay - west of 54°W, onshore and offshore.',-36.63,-30.09,-58.49,-54.0,0);
INSERT INTO "area" VALUES('EPSG','3827','Bolivia - west of 66°W','Bolivia - west of 66°W.',-22.91,-9.77,-69.66,-66.0,0);
INSERT INTO "area" VALUES('EPSG','3828','Uruguay - east of 54°W','Uruguay - east of 54°W, onshore and offshore.',-37.77,-31.9,-54.0,-50.01,0);
INSERT INTO "area" VALUES('EPSG','3829','Chile - 78°W to 72°W','Chile - 78°W to 72°W, onshore and offshore.',-59.36,-18.35,-78.0,-71.99,0);
INSERT INTO "area" VALUES('EPSG','3830','South America - 84°W to 78°W, N hemisphere and SAD69 by country','South America between 84°W and 78°W, northern hemisphere, onshore.',0.0,2.7,-80.18,-78.0,0);
INSERT INTO "area" VALUES('EPSG','3831','South America - 84°W to 78°W, S hemisphere and SAD69 by country','South America between 84°W and 78°W, southern hemisphere, onshore.',-10.53,0.0,-81.41,-78.0,0);
INSERT INTO "area" VALUES('EPSG','3832','South America - 78°W to 72°W, N hemisphere and SAD69 by country','South America between 78°W and 72°W, northern hemisphere, onshore.',0.0,12.31,-78.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','3833','South America - 78°W to 72°W, S hemisphere and SAD69 by country','Brazil - west of 72°W. In rest of South America between 78°W and 72°W, southern hemisphere onshore north of 45°S.',-45.0,0.0,-78.0,-71.99,0);
INSERT INTO "area" VALUES('EPSG','3834','South America - 72°W to 66°W, N hemisphere onshore','South America between 72°W and 66°W, northern hemisphere, onshore, but excluding the area between approximately 0°N, 70°W to 2°N, 70°W to 2°N, 66°W.',0.0,12.52,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','3835','South America - 72°W to 66°W, S hemisphere onshore','Brazil - between 72°W and 66°W, northern and southern hemispheres. In rest of South America between 72°W and 66°W, southern hemisphere onshore north of 45°S.',-45.0,2.15,-72.0,-65.99,0);
INSERT INTO "area" VALUES('EPSG','3836','Peru - east of 72°W','Peru - east of 72°W, onshore and offshore.',-20.44,-2.14,-72.0,-68.67,0);
INSERT INTO "area" VALUES('EPSG','3837','Peru - 84°W to 78°W','Peru - between 84°W and 78°W, onshore and offshore.',-17.33,-3.11,-84.0,-78.0,0);
INSERT INTO "area" VALUES('EPSG','3838','Peru - 78°W to 72°W','Peru - between 78°W and 72°W, onshore and offshore.',-21.05,-0.03,-78.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','3839','South America - 66°W to 60°W, N hemisphere and SAD69 by country','South America between 66°W and 60°W, northern hemisphere, onshore, but excluding most of the area south of 4°N.',0.64,11.23,-66.0,-59.99,0);
INSERT INTO "area" VALUES('EPSG','3840','South America - 66°W to 60°W, S hemisphere and SAD69 by country','Brazil - between 66°W and 60°W, northern and southern hemispheres. In rest of South America between 66°W and 60°W, southern hemisphere onshore.',-45.0,5.28,-66.0,-59.99,0);
INSERT INTO "area" VALUES('EPSG','3841','South America - 60°W to 54°W, N hemisphere and SAD69 by country','South America between 60°W and 54°W, northern hemisphere onshore, but excluding most of the area south of approximately 2°N.',1.18,8.6,-60.0,-54.0,0);
INSERT INTO "area" VALUES('EPSG','3842','Brazil - east of 30°W','Brazil - east of 30°W, northern and southern hemispheres, onshore and offshore.',-23.86,4.26,-30.0,-25.28,0);
INSERT INTO "area" VALUES('EPSG','3843','Argentina - mainland onshore and offshore TdF','Argentina - mainland onshore and Atlantic offshore Tierra del Fuego.',-54.93,-21.78,-73.59,-53.65,0);
INSERT INTO "area" VALUES('EPSG','3844','Nicaragua - onshore north of 12°48''N','Nicaragua - onshore north of 12°48''N.',12.8,15.03,-87.74,-83.08,0);
INSERT INTO "area" VALUES('EPSG','3845','Brazil - SAD69','Brazil - onshore southeast of a line beginning at the intersection of the 54°W meridian with the northern national boundary then running southwards to 5°S, 54°W, southwestwards to 10°S, 60°W, and southwards to the national boundary. Offshore within 370km of the mainland.',-35.71,7.04,-60.57,-29.03,1);
INSERT INTO "area" VALUES('EPSG','3846','Greenland - southwest coast south of 63°N','Greenland - onshore southwest coastal area  south of 63°N.',59.74,63.0,-50.72,-42.52,0);
INSERT INTO "area" VALUES('EPSG','3847','Nicaragua - onshore south of 12°48''N','Nicaragua - onshore south of 12°48''N.',10.7,12.8,-87.63,-83.42,0);
INSERT INTO "area" VALUES('EPSG','3848','Honduras - onshore north of 14°38''30"N','Honduras - onshore north of 14°38''30"N.',14.64,16.49,-89.23,-83.08,0);
INSERT INTO "area" VALUES('EPSG','3849','Costa Rica - onshore and offshore east of 86°30''W','Costa Rica - onshore and offshore east of 86°30''W.',2.21,11.77,-86.5,-81.43,0);
INSERT INTO "area" VALUES('EPSG','3850','Honduras - onshore south of 14°38''30"N','Honduras - onshore south of 14°38''30"N.',12.98,14.65,-89.36,-84.4,0);
INSERT INTO "area" VALUES('EPSG','3851','Brazil - 36°W to 30°W SAD69','Brazil - between 36°W and 30°W, northern and southern hemispheres, onshore and offshore within 370km of the mainland.',-20.1,-0.49,-36.0,-30.0,1);
INSERT INTO "area" VALUES('EPSG','3852','USA - 120°W to 114°W onshore','United States (USA) - between 120°W and 114°W - onshore - Arizona; California; Idaho; Montana;  Nevada; Oregon; Utah; Washington.',32.26,49.01,-120.0,-114.0,0);
INSERT INTO "area" VALUES('EPSG','3853','Antarctica - McMurdo Sound region','Antarctica - McMurdo Sound region.',-81.0,-76.0,153.0,173.0,0);
INSERT INTO "area" VALUES('EPSG','3854','Antarctica - Borchgrevink Coast region','Antarctica - Borchgrevink Coast region.',-76.0,-73.0,157.0,173.0,0);
INSERT INTO "area" VALUES('EPSG','3855','Antarctica - Pennell Coast region','Antarctica - Pennell Coast region.',-73.0,-69.5,160.0,172.0,0);
INSERT INTO "area" VALUES('EPSG','3856','Antarctica - Ross Ice Shelf Region','Antarctica - Ross Ice Shelf Region.',-90.0,-76.0,150.0,-150.0,0);
INSERT INTO "area" VALUES('EPSG','3857','USA - 126°W to 120°W onshore','United States (USA) - between 126°W and 120°W - onshore - California; Oregon; Washington.',33.85,49.05,-124.79,-119.99,0);
INSERT INTO "area" VALUES('EPSG','3858','Venezuela - east of 66°W','Venezuela - east of 66°W, onshore and offshore.',0.64,16.75,-66.0,-58.95,0);
INSERT INTO "area" VALUES('EPSG','3859','Venezuela - 72°W and 66°W','Venezuela - between 72°W and 66°W, onshore and offshore.',0.73,15.64,-72.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','3860','USA - 102°W to 96°W onshore','United States (USA) - between 102°W and 96°W - onshore - Iowa; Kansas; Minnesota; Nebraska; North Dakota; Oklahoma; South Dakota; Texas.',25.83,49.01,-102.0,-95.99,0);
INSERT INTO "area" VALUES('EPSG','3861','USA - 96°W to 90°W onshore','United States (USA) - between 96°W and 90°W - onshore - Arkansas; Illinois; Iowa; Kansas; Louisiana; Michigan; Minnesota; Mississippi; Missouri; Nebraska; Oklahoma; Tennessee; Texas; Wisconsin.',28.42,49.38,-96.0,-89.99,0);
INSERT INTO "area" VALUES('EPSG','3862','USA - 90°W to 84°W onshore','United States (USA) - between 90°W and 84°W - onshore - Alabama; Arkansas; Florida; Georgia; Indiana; Illinois; Kentucky; Louisiana; Michigan; Minnesota; Mississippi; Missouri; North Carolina; Ohio; Tennessee; Wisconsin.',28.85,48.32,-90.0,-83.99,0);
INSERT INTO "area" VALUES('EPSG','3863','USA - 84°W to 78°W onshore','United States (USA) - between 84°W and 78°W - onshore - Florida; Georgia; Maryland; Michigan; New York; North Carolina; Ohio; Pennsylvania; South Carolina; Tennessee; Virginia; West Virginia.',24.41,46.13,-84.01,-78.0,0);
INSERT INTO "area" VALUES('EPSG','3864','North America - 126°W to 120°W and NAD83 by country','North America - between 126°W and 120°W - onshore and offshore. Canada - British Columbia; Northwest Territories; Yukon. United States (USA) - California; Oregon; Washington.',30.54,81.8,-126.0,-119.99,0);
INSERT INTO "area" VALUES('EPSG','3865','Canada - Labrador - 66°W to 63°W','Canada - Labrador - 66°W to 63°W.',51.58,60.52,-66.0,-63.0,0);
INSERT INTO "area" VALUES('EPSG','3866','North America - 132°W to 126°W and NAD83 by country','North America - between 132°W and 126°W - onshore and offshore. Canada - British Columbia; Northwest Territories; Yukon. United States (USA) - Alaska.',35.38,80.93,-132.0,-126.0,0);
INSERT INTO "area" VALUES('EPSG','3867','North America - 138°W to 132°W and NAD83 by country','North America - between 138°W and 132°W - onshore and offshore. Canada - British Columbia; Northwest Territiories; Yukon. United States (USA) - Alaska.',48.06,79.42,-138.0,-132.0,0);
INSERT INTO "area" VALUES('EPSG','3868','USA - 78°W to 72°W onshore','United States (USA) - between 78°W and 72°W - onshore - Connecticut; Delaware; Maryland; Massachusetts; New Hampshire; New Jersey; New York; North Carolina; Pennsylvania; Virginia; Vermont.',33.84,45.03,-78.0,-72.0,0);
INSERT INTO "area" VALUES('EPSG','3869','Costa Rica - onshore north of 9°32''N','Costa Rica - onshore north of 9°32''N.',9.53,11.22,-85.97,-82.53,0);
INSERT INTO "area" VALUES('EPSG','3870','Costa Rica - onshore south of 9°56''N','Costa Rica - onshore south of 9°56''N',7.98,9.94,-85.74,-82.53,0);
INSERT INTO "area" VALUES('EPSG','3871','USA - 72°W to 66°W onshore','United States (USA) - between 72°W and 66°W - onshore - Connecticut; Maine; Massachusetts; New Hampshire; New York (Long Island); Rhode Island; Vermont.',40.96,47.47,-72.0,-66.91,0);
INSERT INTO "area" VALUES('EPSG','3872','North America - 144°W to 138°W and NAD83 by country','North America - between 144°W and 138°W - onshore and offshore. Canada - British Columbia; Yukon. United States (USA) - Alaska.',52.05,73.59,-144.0,-137.99,0);
INSERT INTO "area" VALUES('EPSG','3873','Spain - Canary Islands onshore','Spain - Canary Islands onshore.',27.58,29.3,-18.22,-13.37,0);
INSERT INTO "area" VALUES('EPSG','3874','Brazil - Corrego Alegre 1961','Brazil - onshore - between 18°S and 27°30''S, also east of 54°W between 15°S and 18°S.',-27.5,-14.99,-58.16,-38.82,0);
INSERT INTO "area" VALUES('EPSG','3875','Canada - Labrador - 63°W to 60°W','Canada - Labrador between 63°W and 60°W.',52.0,58.92,-63.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','3876','Central America - Guatemala to Costa Rica','Costa Rica; El Salvador; Guatemala; Honduras; Nicaragua.',7.98,17.83,-92.29,-82.53,0);
INSERT INTO "area" VALUES('EPSG','3877','Brazil - 42°W to 36°W and south of 15°S onshore','Brazil - between 42°W and 36°W and south of 15°S, onshore.',-22.96,-14.99,-42.0,-38.82,0);
INSERT INTO "area" VALUES('EPSG','3878','Brazil - 54°W to 48°W and SAD69','Brazil - onshore and offshore northern and southern hemispheres between 54°W and 48°W.',-35.71,7.04,-54.01,-47.99,0);
INSERT INTO "area" VALUES('EPSG','3879','Germany - onshore east of 12°E','Germany - onshore east of 12°E.',47.46,54.74,12.0,15.04,0);
INSERT INTO "area" VALUES('EPSG','3880','Canada - Labrador - west of 66°W','Canada - Labrador - west of 66°W.',52.05,55.34,-67.81,-66.0,0);
INSERT INTO "area" VALUES('EPSG','3881','Brazil - 60°W to 54°W','Brazil - between 60°W and 54°W, northern and southern hemispheres.',-31.91,4.51,-60.0,-53.99,0);
INSERT INTO "area" VALUES('EPSG','3882','Papua New Guinea - west of 144°E','Papua New Guinea - west of 144°E, onshore and offshore.',-11.15,2.31,139.2,144.0,0);
INSERT INTO "area" VALUES('EPSG','3883','USA - Hawaii - main islands','United States (USA) - Hawaii - main islands onshore and offshore.',15.56,25.58,-163.74,-151.27,0);
INSERT INTO "area" VALUES('EPSG','3884','Brazil - SAD69 onshore south of 4°30''S','Brazil - onshore southeast of a line beginning at the intersection of the coast with the 4°30''S parallel, then westwards to 4°30''S, 54°W, then southwards to 5°S, 54°W, southwestwards to 10°S, 60°W, and southwards to the national boundary.',-33.78,-4.5,-60.57,-34.74,1);
INSERT INTO "area" VALUES('EPSG','3885','Papua New Guinea - 144°E to 150°E','Papua New Guinea - between 144°E and 150°E, onshore and offshore.',-13.88,2.58,144.0,150.01,0);
INSERT INTO "area" VALUES('EPSG','3886','Finland - onshore west of 19.5°E','Finland - onshore west of 19°30''E.',60.0,60.42,19.3,19.5,1);
INSERT INTO "area" VALUES('EPSG','3887','Brazil - onshore south of 14°S and east of 53°W','Brazil - onshore southeast of a line beginning at the intersection of the 53°W meridian with the northern national boundary then running southwards to 14°S, then westwards to the national boundary.',-33.78,4.43,-60.58,-34.74,0);
INSERT INTO "area" VALUES('EPSG','3888','Papua New Guinea - 150°E to 156°E','Papua New Guinea - between 150°E and 156°E, onshore and offshore.',-14.75,1.98,150.0,156.0,0);
INSERT INTO "area" VALUES('EPSG','3889','Europe - Fehmarnbelt outer','Fehmarnbelt area of Denmark and Germany.',54.33,54.83,10.66,12.01,0);
INSERT INTO "area" VALUES('EPSG','3890','Europe - Fehmarnbelt inner','Fehmarnbelt area of Denmark and Germany.',54.42,54.76,11.17,11.51,0);
INSERT INTO "area" VALUES('EPSG','3891','Canada - 60°W to 54°W and NAD27','Canada between 60°W and 54°W, onshore and offshore - Newfoundland and Labrador; Quebec.',40.57,68.93,-60.0,-54.0,0);
INSERT INTO "area" VALUES('EPSG','3892','Germany - offshore North Sea west of 4.5°E','Germany - offshore North Sea west of 4°30''E.',55.24,55.92,3.34,4.5,0);
INSERT INTO "area" VALUES('EPSG','3893','UK - Wytch Farm','United Kingdom (UK) - Wytch Farm area - onshore and offshore.',50.53,50.8,-2.2,-1.68,0);
INSERT INTO "area" VALUES('EPSG','3894','New Zealand - Chatham Island onshore','New Zealand - Chatham Island - onshore.',-44.18,-43.67,-176.92,-176.2,0);
INSERT INTO "area" VALUES('EPSG','3895','Ukraine - west of 24°E','Ukraine - west of 24°E.',47.95,51.66,22.15,24.0,0);
INSERT INTO "area" VALUES('EPSG','3896','Brazil - equatorial margin','Brazil - offshore - equatorial margin.',-5.74,7.04,-51.64,-32.43,0);
INSERT INTO "area" VALUES('EPSG','3897','France - offshore Mediterranean','France - offshore Mediterranean.',41.15,43.74,3.04,10.38,0);
INSERT INTO "area" VALUES('EPSG','3898','Ukraine - 24°E to 30°E','Ukraine - between 24°E and 30°E, onshore and offshore.',45.1,51.96,24.0,30.0,0);
INSERT INTO "area" VALUES('EPSG','3899','Europe - South Permian basin','Europe - South Permian basin.',50.5,56.0,-1.67,22.0,0);
INSERT INTO "area" VALUES('EPSG','3900','Europe - onshore - eastern - S-42(83)','Onshore Bulgaria, Czechia, Germany (former DDR), Hungary and Slovakia.',41.24,54.74,9.92,28.68,0);
INSERT INTO "area" VALUES('EPSG','3901','Germany - onshore west of 6°E','Germany - onshore west of 6°E.',50.97,51.83,5.87,6.0,0);
INSERT INTO "area" VALUES('EPSG','3902','Reunion','Reunion - onshore and offshore.',-24.72,-18.28,51.83,58.24,0);
INSERT INTO "area" VALUES('EPSG','3903','Ukraine - 30°E to 36°E','Ukraine - between 30°E and 36°E, onshore and offshore.',43.18,52.38,30.0,36.0,0);
INSERT INTO "area" VALUES('EPSG','3904','Germany - onshore between 6°E and 12°E','Germany - onshore between 6°E and 12°E.',47.27,55.09,6.0,12.0,0);
INSERT INTO "area" VALUES('EPSG','3905','Ukraine - east of 36°E','Ukraine - east of 36°E, onshore and offshore.',43.43,50.44,36.0,40.18,0);
INSERT INTO "area" VALUES('EPSG','3906','Ukraine - west of 22.5°E','Ukraine - west of 22°30''E.',48.24,48.98,22.15,22.5,0);
INSERT INTO "area" VALUES('EPSG','3907','Ukraine - 22.5°E to 25.5°E','Ukraine - between 22°30''E and 25°30''E.',47.71,51.96,22.5,25.5,0);
INSERT INTO "area" VALUES('EPSG','3908','Ukraine - 25.5°E to 28.5°E','Ukraine - between 25°30''E and 28°30''E.',45.26,51.94,25.5,28.5,0);
INSERT INTO "area" VALUES('EPSG','3909','Ukraine - 28.5°E to 31.5°E','Ukraine - between 28°30''E and 31°30''E, onshore and offshore.',43.42,52.12,28.5,31.5,0);
INSERT INTO "area" VALUES('EPSG','3910','Ukraine - 31.5°E to 34.5°E','Ukraine - between 31°30''E and 34°30''E, onshore and offshore.',43.18,52.38,31.5,34.5,0);
INSERT INTO "area" VALUES('EPSG','3911','Reunion - east of 54ºE','Reunion - onshore and offshore - east of 54ºE.',-24.72,-18.28,54.0,58.24,0);
INSERT INTO "area" VALUES('EPSG','3912','Ukraine - 34.5°E to 37.5°E','Ukraine - between 34°30''E and 37°30''E, onshore and offshore.',43.24,51.25,34.5,37.5,0);
INSERT INTO "area" VALUES('EPSG','3913','Ukraine - east of 37.5°E','Ukraine - east of 37°30''E.',46.77,50.39,37.5,40.18,0);
INSERT INTO "area" VALUES('EPSG','3914','World - N hemisphere - 3°E to 9°E - by country','France - offshore Mediterranean including area east of 9°E. Nigeria - offshore including area west of 3°E.',1.92,43.74,2.66,10.38,0);
INSERT INTO "area" VALUES('EPSG','3915','Reunion - west of 54ºE','Reunion - offshore - west of 54ºE.',-24.37,-18.52,51.83,54.0,0);
INSERT INTO "area" VALUES('EPSG','3916','French Southern Territories - Amsterdam onshore','French Southern Territories - Amsterdam Island onshore.',-37.93,-37.74,77.45,77.67,0);
INSERT INTO "area" VALUES('EPSG','3917','Algeria - Ahnet licence area','Algeria - Ahnet licence area.',26.06,27.51,1.26,2.92,0);
INSERT INTO "area" VALUES('EPSG','3918','French Southern Territories - Kerguelen','French Southern Territories - Kerguelen onshore and offshore.',-53.24,-45.11,62.96,75.66,0);
INSERT INTO "area" VALUES('EPSG','3919','French Southern Territories - Crozet','French Southern Territories - Crozet onshore and offshore.',-49.82,-42.61,45.37,57.16,0);
INSERT INTO "area" VALUES('EPSG','3920','French Southern Territories - Crozet onshore','French Southern Territories - Crozet onshore.',-46.53,-45.87,50.09,52.36,0);
INSERT INTO "area" VALUES('EPSG','3921','French Southern Territories - Amsterdam & St Paul','French Southern Territories - Amsterdam & St Paul islands onshore and offshore.',-42.08,-34.47,73.24,81.83,0);
INSERT INTO "area" VALUES('EPSG','3922','French Southern Territories - St Paul onshore','French Southern Territories - St Paul Island onshore.',-38.79,-38.63,77.44,77.63,0);
INSERT INTO "area" VALUES('EPSG','3923','French Southern Territories - Tromelin','French Southern Territories - Tromelin onshore and offshore.',-18.69,-12.59,52.45,57.18,0);
INSERT INTO "area" VALUES('EPSG','3924','French Southern Territories - Tromelin onshore','French Southern Territories - Tromelin onshore.',-15.96,-15.82,54.46,54.6,0);
INSERT INTO "area" VALUES('EPSG','3925','French Southern Territories - Glorieuses','French Southern Territories - Glorieuses onshore and offshore.',-12.8,-10.65,45.76,48.49,0);
INSERT INTO "area" VALUES('EPSG','3926','French Southern Territories - Glorieuses onshore','French Southern Territories - Glorieuses onshore.',-11.63,-11.5,47.22,47.36,0);
INSERT INTO "area" VALUES('EPSG','3927','French Southern Territories - Juan de Nova','French Southern Territories - Juan de Nova onshore and offshore.',-19.21,-15.35,40.94,43.46,0);
INSERT INTO "area" VALUES('EPSG','3928','Sudan - onshore','Sudan - onshore.',8.64,22.24,21.82,38.66,0);
INSERT INTO "area" VALUES('EPSG','3929','Mozambique - west of 36°E','Mozambique - west of 36°E, onshore and offshore.',-27.58,-11.41,30.21,36.0,0);
INSERT INTO "area" VALUES('EPSG','3930','French Southern Territories - Juan de Nova onshore','French Southern Territories - Juan de Nova onshore.',-17.13,-17.0,42.67,42.82,0);
INSERT INTO "area" VALUES('EPSG','3931','Mozambique - 36°E to 42°E','Mozambique - between 36°E and 42°E, onshore and offshore.',-27.71,-10.09,36.0,42.0,0);
INSERT INTO "area" VALUES('EPSG','3932','French Southern Territories - Bassas da India','French Southern Territories - Bassas da India onshore and offshore.',-23.21,-19.07,37.55,41.59,0);
INSERT INTO "area" VALUES('EPSG','3933','French Southern Territories - Bassas da India onshore','French Southern Territories - Bassas da India onshore.',-21.58,-21.37,39.57,39.82,0);
INSERT INTO "area" VALUES('EPSG','3934','French Southern Territories - Europa','French Southern Territories - Europa onshore and offshore.',-25.7,-20.91,37.98,41.82,0);
INSERT INTO "area" VALUES('EPSG','3935','Mozambique - east of 42°E','Mozambique - offshore east of 42°E.',-15.83,-10.09,42.0,43.03,0);
INSERT INTO "area" VALUES('EPSG','3936','French Southern Territories - Europa onshore','French Southern Territories - Europa onshore.',-22.46,-22.27,40.26,40.46,0);
INSERT INTO "area" VALUES('EPSG','3937','Congo DR (Zaire) - 11°E to 13°E','The Democratic Republic of the Congo (Zaire) - west of 13°E onshore and offshore.',-6.04,-4.67,11.79,13.0,0);
INSERT INTO "area" VALUES('EPSG','3938','Mauritania - 18°W to 12°W','Mauritania - 18°W to 12°W, onshore and offshore.',14.72,23.46,-18.0,-12.0,0);
INSERT INTO "area" VALUES('EPSG','3939','Mauritania - 12°W to 6°W','Mauritania - between 12°W and 6°W, onshore and offshore.',14.73,27.31,-12.0,-6.0,1);
INSERT INTO "area" VALUES('EPSG','3940','Mauritania - east of 6°W','Mauritania - east of 6°W, onshore and offshore.',14.73,27.31,-6.0,0.0,1);
INSERT INTO "area" VALUES('EPSG','3941','Libya - east of 24°E','Libya - east of 24°E, onshore and offshore.',19.99,33.6,24.0,26.21,0);
INSERT INTO "area" VALUES('EPSG','3942','South Sudan','South Sudan.',3.49,12.22,24.14,35.94,0);
INSERT INTO "area" VALUES('EPSG','3943','Bahrain - onshore','Bahrain - onshore.',25.53,26.34,50.39,50.85,0);
INSERT INTO "area" VALUES('EPSG','3944','China - 102°E to 108°E','China - onshore and offshore between 102°E and 108°E.',17.75,42.47,102.0,108.0,0);
INSERT INTO "area" VALUES('EPSG','3945','China - 108°E to 114°E','China - onshore and offshore between 108°E and 114°E.',16.7,45.11,108.0,114.0,0);
INSERT INTO "area" VALUES('EPSG','3946','China - 114°E to 120°E','China - onshore and offshore between 114°E and 120°E.',19.02,51.52,114.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','3947','China - 120°E to 126°E','China - onshore and offshore between 120°E and 126°E.',24.64,53.56,120.0,126.0,0);
INSERT INTO "area" VALUES('EPSG','3948','China - 126°E to 132°E','China - onshore and offshore between 126°E and 132°E.',29.7,52.79,126.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','3949','Libya - west of 12°E','Libya - west of 12°E, onshore and offshore.',23.51,33.92,9.31,12.0,0);
INSERT INTO "area" VALUES('EPSG','3950','Libya - 12°E to 18°E','Libya - between 12°E and 18°E, onshore and offshore.',22.51,35.23,12.0,18.0,0);
INSERT INTO "area" VALUES('EPSG','3951','Libya - 18°E to 24°E','Libya - between 18°E and 24°E, onshore and offshore.',19.5,35.03,17.99,24.01,0);
INSERT INTO "area" VALUES('EPSG','3952','Algeria - 6°W to 0°W','Algeria - between 6°W and 0°W (of Greenwich), onshore and offshore.',21.82,37.01,-6.0,0.0,0);
INSERT INTO "area" VALUES('EPSG','3953','Algeria - 0°E to 6°E','Algeria - between 0°E and 6°E (of Greenwich), onshore and offshore.',18.97,38.77,0.0,6.01,0);
INSERT INTO "area" VALUES('EPSG','3954','Algeria - east of 6°E','Algeria - east of 6°E (of Greenwich), onshore and offshore.',19.6,38.8,6.0,11.99,0);
INSERT INTO "area" VALUES('EPSG','3955','Malaysia - West Malaysia','Malaysia - West Malaysia onshore and offshore.',1.13,7.81,98.02,105.82,0);
INSERT INTO "area" VALUES('EPSG','3956','Iraq - east of 48°E','Iraq - east of 48°E, onshore and offshore.',29.6,31.0,48.0,48.75,0);
INSERT INTO "area" VALUES('EPSG','3957','Japan - onshore','Japan including outlying islands - onshore.',20.37,45.54,122.83,154.05,0);
INSERT INTO "area" VALUES('EPSG','3958','Philippines - zone I onshore','Philippines - onshore west of 118°E.',7.75,9.32,116.89,118.0,0);
INSERT INTO "area" VALUES('EPSG','3959','Japan - 120°E to 126°E','Japan - west of 126°E, onshore and offshore.',21.1,29.71,122.38,126.0,0);
INSERT INTO "area" VALUES('EPSG','3960','Japan - 126°E to 132°E','Japan - between 126°E and 132°E, onshore and offshore.',21.12,38.63,126.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','3961','Japan - 132°E to 138°E','Japan - between 132°E and 138°E, onshore and offshore.',17.09,43.55,132.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','3962','Japan - 138°E to 144°E','Japan - between 138°E and 144°E, onshore and offshore.',17.63,46.05,138.0,144.0,0);
INSERT INTO "area" VALUES('EPSG','3963','Japan - 144°E to 150°E','Japan - east of 144°E, onshore and offshore.',23.03,45.65,144.0,147.86,0);
INSERT INTO "area" VALUES('EPSG','3964','Philippines - zone II onshore','Philippines - onshore approximately between 118°E and 120°E - Palawan; Calamian Islands.',8.82,11.58,118.0,120.07,0);
INSERT INTO "area" VALUES('EPSG','3965','Philippines - zone III onshore','Philippines - onshore approximately between 120°E and 122°E. Luzon (west of 122°E); Mindoro.',4.99,19.45,119.7,122.21,0);
INSERT INTO "area" VALUES('EPSG','3966','Philippines - zone IV onshore','Philippines - onshore approximately between 122°E and 124°E - southeast Luzon (east of 122°E); Tablas; Masbate; Panay; Cebu; Negros; northwest Mindanao (west of 124°E).',6.35,18.58,121.74,124.29,0);
INSERT INTO "area" VALUES('EPSG','3967','Philippines - zone V onshore','Philippines - onshore approximately between 124°E and 126°E - east Mindanao (east of 124°E); Bohol; Samar.',5.5,14.15,123.73,126.65,0);
INSERT INTO "area" VALUES('EPSG','3968','Saudi Arabia - onshore Gulf coast','Saudi Arabia - onshore Arabian Gulf coastal area.',24.63,28.57,47.95,50.81,0);
INSERT INTO "area" VALUES('EPSG','3969','Philippines - onshore','Philippines - onshore.',4.99,19.45,116.89,126.65,0);
INSERT INTO "area" VALUES('EPSG','3970','New Zealand - nearshore west of 168°E','New Zealand - nearshore west of 168°E.',-47.65,-42.59,165.87,168.0,0);
INSERT INTO "area" VALUES('EPSG','3971','New Zealand - nearshore 168°E to 174°E','New Zealand - nearshore between 168°E and 174°E.',-47.64,-33.89,168.0,174.0,0);
INSERT INTO "area" VALUES('EPSG','3972','New Zealand - nearshore east of 174°E','New Zealand - nearshore east of 174°E.',-44.13,-34.24,174.0,179.27,0);
INSERT INTO "area" VALUES('EPSG','3973','New Zealand - onshore','New Zealand - North Island, South Island, Stewart Island - onshore.',-47.33,-34.1,166.37,178.63,0);
INSERT INTO "area" VALUES('EPSG','3974','Cocos (Keeling) Islands','Cocos (Keeling) Islands - onshore and offshore.',-15.56,-8.47,93.41,100.34,0);
INSERT INTO "area" VALUES('EPSG','3975','Indonesia - east of 138°E onshore','Indonesia - onshore east of 138°E.',-9.19,-1.49,138.0,141.01,0);
INSERT INTO "area" VALUES('EPSG','3976','Indonesia - west of 96°E onshore','Indonesia - onshore west of 96°E.',2.55,5.97,95.16,96.0,0);
INSERT INTO "area" VALUES('EPSG','3977','Malaysia - East Malaysia','Malaysia - East Malaysia (Sabah; Sarawak), onshore and offshore.',0.85,7.67,109.31,119.61,0);
INSERT INTO "area" VALUES('EPSG','3978','Indonesia - 96°E to 102°E, N hemisphere onshore','Indonesia - onshore north of equator and between 96°E and 102°E.',0.0,5.42,96.0,102.0,0);
INSERT INTO "area" VALUES('EPSG','3979','Indonesia - 102°E to 108°E, N hemisphere onshore','Indonesia - onshore north of equator and between 102°E and 108°E.',0.0,4.11,102.0,108.0,0);
INSERT INTO "area" VALUES('EPSG','3980','Indonesia - 108°E to 114°E, N hemisphere onshore','Indonesia - onshore north of equator and between 108°E and 114°E.',0.0,4.25,108.0,114.0,0);
INSERT INTO "area" VALUES('EPSG','3981','Indonesia - 114°E to 120°E, N hemisphere onshore','Indonesia - onshore north of equator and between 114°E and 120°E.',0.0,4.37,114.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','3982','Taiwan - onshore - mainland','Taiwan, Republic of China - onshore - Taiwan Island.',21.87,25.34,119.99,122.06,0);
INSERT INTO "area" VALUES('EPSG','3983','Indonesia - 120°E to 126°E, N hemisphere onshore','Indonesia - onshore north of equator and between 120°E and 126°E.',0.0,3.84,120.0,125.71,0);
INSERT INTO "area" VALUES('EPSG','3984','Indonesia - 126°E to 132°E, N hemisphere onshore','Indonesia - onshore north of equator and between 126°E and 132°E.',0.0,4.59,126.55,131.0,0);
INSERT INTO "area" VALUES('EPSG','3985','Indonesia - 96°E to 102°E, S hemisphere onshore','Indonesia - onshore south of equator and between 96°E and 102°E.',-3.57,0.0,98.24,102.0,0);
INSERT INTO "area" VALUES('EPSG','3986','Indonesia - 102°E to 108°E, S hemisphere onshore','Indonesia - onshore south of equator and between 102°E and 108°E.',-7.79,0.0,102.0,108.0,0);
INSERT INTO "area" VALUES('EPSG','3987','Indonesia - 108°E to 114°E, S hemisphere onshore','Indonesia - onshore south of equator and between 108°E and 114°E.',-8.67,0.0,108.0,114.0,0);
INSERT INTO "area" VALUES('EPSG','3988','Indonesia - 114°E to 120°E, S hemisphere onshore','Indonesia - onshore south of equator and between 114°E and 120°E.',-10.15,0.0,114.0,120.0,0);
INSERT INTO "area" VALUES('EPSG','3989','Indonesia - 120°E to 126°E, S hemisphere onshore','Indonesia - onshore south of equator and between 120°E and 126°E.',-10.98,0.0,120.0,126.0,0);
INSERT INTO "area" VALUES('EPSG','3990','Indonesia - 126°E to 132°E, S hemisphere onshore','Indonesia - onshore south of equator and between 126°E and 132°E.',-8.41,0.0,126.0,132.0,0);
INSERT INTO "area" VALUES('EPSG','3991','Indonesia - 132°E to 138°E, S hemisphere onshore','Indonesia - onshore south of equator and between 132°E and 138°E.',-8.49,-0.29,132.0,138.0,0);
INSERT INTO "area" VALUES('EPSG','3992','New Zealand - offshore 180°W to 174°W','New Zealand - offshore between 180°W and 174°W.',-52.97,-25.88,-180.0,-174.0,0);
INSERT INTO "area" VALUES('EPSG','3993','Germany - onshore 7.5°E to 10.5°E','Germany - onshore between 7°30''E and 10°30''E.',47.27,55.09,7.5,10.51,0);
INSERT INTO "area" VALUES('EPSG','3994','Madagascar','Madagascar - onshore and offshore.',-28.92,-10.28,40.31,53.39,0);
INSERT INTO "area" VALUES('EPSG','3995','Japan - onshore mainland and adjacent islands','Japan - onshore mainland and adjacent islands.',30.18,45.54,128.31,145.87,0);
INSERT INTO "area" VALUES('EPSG','3996','Germany - onshore 10.5°E to 13.5°E','Germany - onshore between 10°30''E and 13°30''E.',47.39,54.74,10.5,13.51,0);
INSERT INTO "area" VALUES('EPSG','3997','Germany - East Germany - 10.5°E to 13.5°E onshore','Germany - states of former East Germany - onshore between 10°30''E and 13°30''E.',50.2,54.74,10.5,13.51,0);
INSERT INTO "area" VALUES('EPSG','3998','Germany - onshore east of 13.5°E','Germany - onshore east of 13°30''E.',48.51,54.72,13.5,15.04,0);
INSERT INTO "area" VALUES('EPSG','3999','Fiji','Fiji - onshore and offshore.',-25.09,-9.78,172.76,-176.27,0);
INSERT INTO "area" VALUES('EPSG','4000','Germany - onshore 10.5°E to 12°E','Germany - onshore between 10°30''E and 12°E.',47.39,54.59,10.5,12.0,0);
INSERT INTO "area" VALUES('EPSG','4001','Germany - onshore 12°E to 13.5°E','Germany - onshore between 12°E and 13°30''E.',47.46,54.74,12.0,13.51,0);
INSERT INTO "area" VALUES('EPSG','4002','Yemen - east of 54°E','Yemen - east of 54°E, onshore and offshore.',8.95,14.95,54.0,57.96,0);
INSERT INTO "area" VALUES('EPSG','4003','Germany - East Germany - east of 13.5°E onshore','Germany - states of former East Germany - onshore east of 13°30''E.',50.62,54.72,13.5,15.04,0);
INSERT INTO "area" VALUES('EPSG','4004','Australia - Northern Territory mainland','Australia - Northern Territory mainland onshore.',-26.01,-10.92,128.99,138.0,0);
INSERT INTO "area" VALUES('EPSG','4005','Indonesia - Kalimantan W - coastal','Indonesia - west Kalimantan - onshore coastal area.',0.06,2.13,108.79,109.78,0);
INSERT INTO "area" VALUES('EPSG','4006','Yemen - west of 42°E','Yemen - west of 42°E, onshore and offshore.',14.73,16.36,41.08,42.0,0);
INSERT INTO "area" VALUES('EPSG','4007','Asia - Cambodia and Vietnam - onshore & Cuu Long basin','Cambodia - onshore; Vietnam - onshore and offshore Cuu Long basin.',7.99,23.33,102.14,110.0,0);
INSERT INTO "area" VALUES('EPSG','4008','Oman - mainland east of 54°E','Oman - mainland onshore east of 54°E.',16.89,26.42,54.0,59.91,0);
INSERT INTO "area" VALUES('EPSG','4009','Oman - mainland','Oman - mainland onshore.',16.59,26.42,51.99,59.91,0);
INSERT INTO "area" VALUES('EPSG','4010','Solomon Islands','Solomon Islands - onshore and offshore.',-16.13,-4.14,154.58,173.58,0);
INSERT INTO "area" VALUES('EPSG','4011','Tuvalu - onshore','Tuvalu - onshore.',-8.62,-6.03,176.24,179.29,0);
INSERT INTO "area" VALUES('EPSG','4012','Congo DR (Zaire) - Bas Congo east of 15°E','The Democratic Republic of the Congo (Zaire) - Bas Congo east of 15°E.',-5.87,-4.42,14.99,16.28,0);
INSERT INTO "area" VALUES('EPSG','4013','Papua New Guinea - PFTB','Papua New Guinea - Papuan fold and thrust belt.',-8.28,-5.59,142.24,144.75,0);
INSERT INTO "area" VALUES('EPSG','4014','Australia - Western Australia mainland','Australia - Western Australia mainland.',-35.19,-13.67,112.85,129.01,0);
INSERT INTO "area" VALUES('EPSG','4015','Vietnam - mainland','Vietnam - mainland onshore.',8.5,23.33,102.14,109.52,0);
INSERT INTO "area" VALUES('EPSG','4016','South America -  onshore north of 45°S','South America - onshore north of 45°S excluding Amazonia.',-45.0,12.52,-81.41,-34.74,0);
INSERT INTO "area" VALUES('EPSG','4017','Australia - SE Australia (ACT NSW)','Australia - Australian Capital Territory and New South Wales onshore.',-37.53,-28.15,140.99,153.69,0);
INSERT INTO "area" VALUES('EPSG','4018','Congo DR (Zaire) - south and 29°E to 31°E','The Democratic Republic of the Congo (Zaire) - south of a line through Bandundu, Seke and Pweto and east of 29°E.',-13.46,-12.15,29.0,29.81,0);
INSERT INTO "area" VALUES('EPSG','4019','Arctic - 87°N to 75°N, 156°W to 66°W','Arctic - 87°N to 75°N, approximately 156°W to approximately 66°W. May be extended westwards or eastwards within the latitude limits.',75.0,87.01,-156.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','4020','Indonesia - onshore','Indonesia - onshore.',-10.98,5.97,95.16,141.01,0);
INSERT INTO "area" VALUES('EPSG','4021','Australia - Queensland mainland','Australia - Queensland mainland onshore.',-29.19,-10.65,137.99,153.61,0);
INSERT INTO "area" VALUES('EPSG','4022','UAE - Abu Dhabi and Dubai - onshore east of 54°E','United Arab Emirates (UAE) - Abu Dhabi onshore east of 54°E; Dubai onshore.',22.63,25.34,53.99,56.03,0);
INSERT INTO "area" VALUES('EPSG','4023','Brazil - west of 72°W','Brazil - west of 72°W.',-10.01,-4.59,-74.01,-71.99,0);
INSERT INTO "area" VALUES('EPSG','4024','Brazil - 72°W to 66°W','Brazil - between 72°W and 66°W, northern and southern hemispheres.',-11.14,2.15,-72.0,-65.99,0);
INSERT INTO "area" VALUES('EPSG','4025','Angola - offshore north of 8°S','Angola - offshore north of 8°S - including blocks 0, 1, 2, 14, 15, 17, 18 north of 8°S and 32; onshore Soyo area.',-8.01,-5.05,10.41,12.84,0);
INSERT INTO "area" VALUES('EPSG','4026','Brazil - 66°W to 60°W','Brazil - between 66°W and 60°W, northern and southern hemispheres.',-16.28,5.28,-66.0,-59.99,0);
INSERT INTO "area" VALUES('EPSG','4027','Arctic - 87°N to 75°N, 84°W to 6°E','Arctic - 87°N to 75°N, approximately 84°W to approximately 6°E. May be extended westwards or eastwards within the latitude limits.',75.0,87.01,-84.0,6.01,0);
INSERT INTO "area" VALUES('EPSG','4028','Arctic - 87°N to 75°N, 12°W to 78°E','Arctic - 87°N to 75°N, approximately 12°W to approximately 78°E. May be extended westwards or eastwards within the latitude limits.',75.0,87.01,-12.0,78.01,0);
INSERT INTO "area" VALUES('EPSG','4029','Arctic - 87°N to 75°N, 60°E to 150°E','Arctic - 87°N to 75°N, approximately 60°E to approximately 150°E. May be extended westwards or eastwards within the latitude limits.',75.0,87.01,60.0,150.01,0);
INSERT INTO "area" VALUES('EPSG','4030','Arctic - 84°30''N to 79°30''N, 135°W to 95°W','Arctic - between 84°30''N and 79°30''N, approximately 135°W to approximately 95°W. May be extended eastwards within the latitude limits.',79.5,84.51,-135.0,-95.0,0);
INSERT INTO "area" VALUES('EPSG','4031','Arctic - 87°N to 75°N, 132°E to 138°W','Arctic - 87°N to 75°N, approximately 132°E to approximately 138°W. May be extended westwards or eastwards within the latitude limits.',75.0,87.01,132.0,-138.0,0);
INSERT INTO "area" VALUES('EPSG','4032','Arctic - 79°N to 67°N, 156°W to 66°W','Arctic - 79°N to 67°N, approximately 156°W to approximately 66°W. May be extended westwards or eastwards within the latitude limits.',67.0,79.01,-156.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','4033','Arctic - 79°N to 67°N, 84°W to 6°E','Arctic - 79°N to 67°N, approximately 84°W to approximately 6°E. May be extended westwards or eastwards within the latitude limits.',67.0,79.01,-84.0,6.01,0);
INSERT INTO "area" VALUES('EPSG','4034','Arctic - 79°N to 67°N, 12°W to 78°E','Arctic - 79°N to 67°N, approximately 12°W to approximately 78°E. May be extended westwards or eastwards within the latitude limits.',67.0,79.01,-12.0,78.01,0);
INSERT INTO "area" VALUES('EPSG','4035','Italy - Emilia-Romagna','Italy - Emilia-Romagna region.',43.73,45.14,9.19,12.76,0);
INSERT INTO "area" VALUES('EPSG','4036','Arctic - 84°30''N to 79°30''N, 95°W to 55°W','Arctic - between 84°30''N and 79°30''N, approximately 95°W to approximately 55°W. May be extended westwards within the latitude limits.',79.5,84.51,-95.0,-55.0,0);
INSERT INTO "area" VALUES('EPSG','4037','Arctic - 79°N to 67°N, 60°E to 150°E','Arctic - 79°N to 67°N, approximately 60°E to approximately 150°E. May be extended westwards or eastwards within the latitude limits.',67.0,79.01,60.0,150.01,0);
INSERT INTO "area" VALUES('EPSG','4038','Arctic - 79°N to 67°N, 132°E to 138°W','Arctic - 79°N to 67°N, approximately 132°E to approximately 138°W. May be extended westwards or eastwards within the latitude limits.',67.0,79.01,132.0,-138.0,0);
INSERT INTO "area" VALUES('EPSG','4039','Arctic - 84°30''N to 79°30''N, 72°W to 32°W','Arctic - between 84°30''N and 79°30''N, approximately 72°W to approximately 32°W. May be extended eastwards within the latitude limits.',79.5,84.51,-72.0,-32.0,0);
INSERT INTO "area" VALUES('EPSG','4040','Arctic - 71°N to 59°N, 156°W to 66°W','Arctic - 71°N to 59°N, approximately 156°W to approximately 66°W. May be extended westwards or eastwards within the latitude limits.',59.0,71.0,-156.0,-66.0,0);
INSERT INTO "area" VALUES('EPSG','4041','Arctic - 71°N to 59°N, 84°W to 6°E','Arctic - 71°N to 59°N, approximately 84°W to approximately 6°E. May be extended westwards or eastwards within the latitude limits.',59.0,71.0,-84.0,6.0,0);
INSERT INTO "area" VALUES('EPSG','4042','Arctic - 71°N to 59°N, 12°W to 78°E','Arctic - 71°N to 59°N, approximately 12°W to approximately 78°E. May be extended westwards or eastwards within the latitude limits.',59.0,71.0,-12.0,78.01,0);
INSERT INTO "area" VALUES('EPSG','4043','Arctic - 71°N to 59°N, 60°E to 150°E','Arctic - 71°N to 59°N, approximately 60°E to approximately 150°E. May be extended westwards or eastwards within the latitude limits.',59.0,71.0,60.0,150.01,0);
INSERT INTO "area" VALUES('EPSG','4044','Arctic - 87°50''N to 82°50''N, 180°W to 120°W','Arctic - between 87°50''N and 82°50''N, approximately 180°W to approximately 120°W. May be extended westwards or eastwards within the latitude limits.',82.83,87.84,-180.0,-120.0,0);
INSERT INTO "area" VALUES('EPSG','4045','Arctic - 71°N to 59°N, 132°E to 138°W','Arctic - 71°N to 59°N, approximately 132°E to approximately 138°W. May be extended westwards or eastwards within the latitude limits.',59.0,71.0,132.0,-138.0,0);
INSERT INTO "area" VALUES('EPSG','4046','Arctic - 84°30''N to 79°30''N, 32°W to 8°E','Arctic - between 84°30''N and 79°30''N, approximately 32°W to approximately 8°E. May be extended westwards within the latitude limits.',79.5,84.51,-32.0,8.01,0);
INSERT INTO "area" VALUES('EPSG','4047','Arctic - 87°50''N to 82°50''N, 120°W to 60°W','Arctic - between 87°50''N and 82°50''N, approximately 120°W to approximately 60°W. May be extended westwards or eastwards within the latitude limits.',82.83,87.84,-120.0,-60.0,0);
INSERT INTO "area" VALUES('EPSG','4048','Arctic - 87°50''N to 82°50''N, 60°W to 0°E','Arctic - between 87°50''N and 82°50''N, approximately 60°W to approximately 0°E. May be extended westwards or eastwards within the latitude limits.',82.83,87.84,-60.0,0.0,0);
INSERT INTO "area" VALUES('EPSG','4049','Arctic - 87°50''N to 82°50''N, 0°E to 60°E','Arctic - between 87°50''N and 82°50''N, approximately 0°E to approximately 60°E. May be extended westwards or eastwards within the latitude limits.',82.83,87.84,0.0,60.01,0);
INSERT INTO "area" VALUES('EPSG','4050','Arctic - 87°50''N to 82°50''N, 60°E to 120°E','Arctic - between 87°50''N and 82°50''N, approximately 60°E to approximately 120°E. May be extended westwards or eastwards within the latitude limits.',82.83,87.84,60.0,120.01,0);
INSERT INTO "area" VALUES('EPSG','4051','Arctic - 87°50''N to 82°50''N, 120°E to 180°E','Arctic - between 87°50''N and 82°50''N, approximately 120°E to approximately 180°E. May be extended westwards or eastwards within the latitude limits.',82.83,87.83,120.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','4052','Arctic - 84°30''N to 79°30''N, 174°W to 135°W','Arctic - between 84°30''N and 79°30''N, approximately 174°W to approximately 135°W. May be extended westwards or eastwards within the latitude limits.',79.5,84.51,-174.0,-134.99,0);
INSERT INTO "area" VALUES('EPSG','4053','Arctic - 84°30''N to 79°30''N, 4°W to 36°E','Arctic - between 84°30''N and 79°30''N, approximately 4°W to approximately 36°E.',79.5,84.51,-4.0,36.01,0);
INSERT INTO "area" VALUES('EPSG','4054','Arctic - 84°30''N to 79°30''N, 33°E to 73°E','Arctic - between 84°30''N and 79°30''N, approximately 33°E to approximately 73°E. May be extended westwards or eastwards within the latitude limits.',79.5,84.51,33.0,73.01,0);
INSERT INTO "area" VALUES('EPSG','4055','Arctic - 84°30''N to 79°30''N, 73°E to 113°E','Arctic - between 84°30''N and 79°30''N, approximately 73°E to approximately 113°E. May be extended westwards or eastwards within the latitude limits.',79.5,84.51,73.0,113.01,0);
INSERT INTO "area" VALUES('EPSG','4056','Arctic - 84°30''N to 79°30''N, 113°E to 153°E','Arctic - between 84°30''N and 79°30''N, approximately 113°E to approximately 153°E. May be extended westwards or eastwards within the latitude limits.',79.5,84.51,113.0,153.01,0);
INSERT INTO "area" VALUES('EPSG','4057','Arctic - 84°30''N to 79°30''N, 146°E to 174°W','Arctic - between 84°30''N and 79°30''N, approximately 146°E to approximately 174°W. May be extended westwards or eastwards within the latitude limits.',79.5,84.51,146.0,-173.99,0);
INSERT INTO "area" VALUES('EPSG','4058','Arctic - 81°10''N to 76°10''N, 4°W to 38°E','Arctic (Norway (Svalbard) onshore and offshore) - between 81°10''N and 76°10''N.',76.16,81.17,-3.7,38.45,0);
INSERT INTO "area" VALUES('EPSG','4059','Arctic - 81°10''N to 76°10''N, 35°E to 67°E','Arctic (Russia onshore and offshore) - between 81°10''N and 76°10''N, approximately 35°E to approximately 67°E. May be extended eastwards within the latitude limits.',76.16,81.17,34.71,67.01,0);
INSERT INTO "area" VALUES('EPSG','4060','Arctic - 81°10''N to 76°10''N, 67°E to 98°E','Arctic (Russia onshore and offshore) - between 81°10''N and 76°10''N, approximately 67°E to approximately 98°E. May be extended westwards or eastwards within the latitude limits.',76.16,81.17,67.0,98.01,0);
INSERT INTO "area" VALUES('EPSG','4061','Arctic - 81°10''N to 76°10''N, 98°E to 129°E','Arctic (Russia onshore and offshore) - between 81°10''N and 76°10''N, approximately 98°E to approximately 129°E. May be extended westwards or eastwards within the latitude limits.',76.16,81.17,98.0,129.01,0);
INSERT INTO "area" VALUES('EPSG','4062','Arctic - 81°10''N to 76°10''N, 129°E to 160°E','Arctic (Russia onshore and offshore) - between 81°10''N and 76°10''N, approximately 129°E to approximately 160°E. May be extended westwards or eastwards within the latitude limits.',76.16,81.17,129.0,160.01,0);
INSERT INTO "area" VALUES('EPSG','4063','Arctic - 81°10''N to 76°10''N, 160°E to 169°W','Arctic - between 81°10''N and 76°10''N, approximately 160°E to approximately 169°W. May be extended westwards or eastwards within the latitude limits.',76.16,81.17,160.0,-168.99,0);
INSERT INTO "area" VALUES('EPSG','4064','Arctic - 81°10''N to 76°10''N, 169°W to 138°W','Arctic - between 81°10''N and 76°10''N, approximately 169°W to approximately 138°W. May be extended westwards or eastwards within the latitude limits.',76.16,81.17,-169.0,-138.0,0);
INSERT INTO "area" VALUES('EPSG','4065','Arctic - 81°10''N to 76°10''N, 144°W to 114°W','Arctic - between 81°10''N and 76°10''N, approximately 144°W to approximately 114°W. May be extended eastwards within the latitude limits.',76.16,81.17,-144.0,-114.0,0);
INSERT INTO "area" VALUES('EPSG','4066','Norway - onshore - 6°E to 12°E','Norway - onshore - between 6°E and 12°E.',57.93,65.76,6.0,12.0,0);
INSERT INTO "area" VALUES('EPSG','4067','Norway - onshore - 12°E to 18°E','Norway - onshore - between 12°E and 18°E.',59.88,69.68,12.0,18.01,0);
INSERT INTO "area" VALUES('EPSG','4068','Norway - onshore - 18°E to 24°E','Norway - onshore - between 18°E and 24°E.',68.04,71.08,18.0,24.01,0);
INSERT INTO "area" VALUES('EPSG','4069','Norway - onshore - 24°E to 30°E','Norway - onshore - between 24°E and 30°E.',68.58,71.21,24.0,30.0,0);
INSERT INTO "area" VALUES('EPSG','4070','Arctic - 81°10''N to 76°10''N, 114°W to 84°W','Arctic - between 81°10''N and 76°10''N, approximately 114°W to approximately 84°W. May be extended westwards or eastwards within the latitude limits.',76.16,81.17,-114.0,-84.0,0);
INSERT INTO "area" VALUES('EPSG','4071','Arctic - 81°10''N to 76°10''N, 84°W to 54°W','Arctic - between 81°10''N and 76°10''N, approximately 84°W to approximately 54°W. May be extended westwards or eastwards within the latitude limits.',76.16,81.17,-84.0,-54.0,0);
INSERT INTO "area" VALUES('EPSG','4072','Arctic - 81°10''N to 76°10''N, Canada east of 84°W','Arctic - between 81°10''N and 76°10''N, Canada east of approximately 84°W. May be extended westwards within the latitude limits.',76.16,81.17,-84.0,-64.78,0);
INSERT INTO "area" VALUES('EPSG','4073','Arctic - 81°10''N to 76°10''N, Greenland west of 54°W','Arctic - between 81°10''N and 76°10''N, Greenland west of approximately 54°W. May be extended eastwards within the latitude limits.',76.16,81.17,-75.0,-54.0,0);
INSERT INTO "area" VALUES('EPSG','4074','Arctic - 81°10''N to 76°10''N, 54°W to 24°W','Arctic - between 81°10''N and 76°10''N, approximately 54°W to approximately 24°W. May be extended westwards or eastwards within the latitude limits.',76.16,81.17,-54.0,-24.0,0);
INSERT INTO "area" VALUES('EPSG','4075','Arctic - 81°10''N to 76°10''N, 24°W to 3°E','Arctic - between 81°10''N and 76°10''N, approximately 24°W to approximately 2°E. May be extended westwards within the latitude limits.',76.16,81.17,-24.0,1.9,0);
INSERT INTO "area" VALUES('EPSG','4076','Arctic - 77°50''N to 72°50''N, 169°W to 141°W','Arctic - between 77°50''N and 72°50''N, approximately 169°W to approximately 141°W. May be extended westwards or eastwards within the latitude limits.',72.83,77.84,-169.0,-141.0,0);
INSERT INTO "area" VALUES('EPSG','4077','Arctic - 77°50''N to 72°50''N, 141°W to 116°W','Arctic - between 77°50''N and 72°50''N, approximately 141°W to approximately 116°W. May be extended westwards or eastwards within the latitude limits.',72.83,77.84,-141.0,-116.0,0);
INSERT INTO "area" VALUES('EPSG','4078','Arctic - 77°50''N to 72°50''N, 116°W to 91°W','Arctic - between 77°50''N and 72°50''N, approximately 116°W to approximately 91°W. May be extended westwards or eastwards within the latitude limits.',72.83,77.84,-116.0,-91.0,0);
INSERT INTO "area" VALUES('EPSG','4079','Arctic - 77°50''N to 72°50''N, 91°W to 67°W','Arctic - between 77°50''N and 72°50''N, approximately 91°W to approximately 67°W. May be extended westwards within the latitude limits.',72.83,77.84,-91.0,-67.0,0);
INSERT INTO "area" VALUES('EPSG','4080','Arctic - 77°50''N to 72°50''N, 76°W to 51°W','Arctic - between 77°50''N and 72°50''N, approximately 76°W to approximately 51°W. May be extended eastwards within the latitude limits.',72.83,77.84,-76.0,-51.0,0);
INSERT INTO "area" VALUES('EPSG','4081','Arctic - 77°50''N to 72°50''N, 51°W to 26°W','Arctic - between 77°50''N and 72°50''N, approximately 51°W to approximately 26°W. May be extended westwards or eastwards within the latitude limits.',72.83,77.84,-51.0,-26.0,0);
INSERT INTO "area" VALUES('EPSG','4082','Arctic - 77°50''N to 72°50''N, 26°W to 2°W','Arctic - between 77°50''N and 72°50''N, approximately 26°W to approximately 2°W. May be extended westwards within the latitude limits.',72.83,77.84,-26.0,-2.0,0);
INSERT INTO "area" VALUES('EPSG','4083','Arctic - 77°50''N to 72°50''N, 2°W to 22°E','Arctic - between 77°50''N and 72°50''N, approximately 2°W to approximately 22°E. May be extended westwards or eastwards within the latitude limits.',72.83,77.84,-2.0,22.01,0);
INSERT INTO "area" VALUES('EPSG','4084','Arctic - 77°50''N to 72°50''N, 22°E to 46°E','Arctic - between 77°50''N and 72°50''N, approximately 22°E to approximately 46°E. May be extended westwards or eastwards within the latitude limits.',72.83,77.84,22.0,46.01,0);
INSERT INTO "area" VALUES('EPSG','4085','Arctic - 77°50''N to 72°50''N, 46°E to 70°E','Arctic - between 77°50''N and 72°50''N, approximately 46°E to approximately 70°E. May be extended westwards or eastwards within the latitude limits.',72.83,77.84,46.0,70.01,0);
INSERT INTO "area" VALUES('EPSG','4086','Arctic - 77°50''N to 72°50''N, 70°E to 94°E','Arctic - between 77°50''N and 72°50''N, approximately 70°E to approximately 94°E. May be extended westwards or eastwards within the latitude limits.',72.83,77.84,70.0,94.01,0);
INSERT INTO "area" VALUES('EPSG','4087','Arctic - 77°50''N to 72°50''N, 94°E to 118°E','Arctic - between 77°50''N and 72°50''N, approximately 94°E to approximately 118°E. May be extended westwards or eastwards within the latitude limits.',72.83,77.84,94.0,118.01,0);
INSERT INTO "area" VALUES('EPSG','4088','Arctic - 77°50''N to 72°50''N, 118°E to 142°E','Arctic - between 77°50''N and 72°50''N, approximately 118°E to approximately 142°E. May be extended westwards or eastwards within the latitude limits.',72.83,77.84,118.0,142.01,0);
INSERT INTO "area" VALUES('EPSG','4089','Arctic - 77°50''N to 72°50''N, 142°E to 166°E','Arctic - between 77°50''N and 72°50''N, approximately 142°E to approximately 166°E. May be extended westwards or eastwards within the latitude limits.',72.83,77.84,142.0,166.01,0);
INSERT INTO "area" VALUES('EPSG','4090','Arctic - 77°50''N to 72°50''N, 166°E to 169°W','Arctic - between 77°50''N and 72°50''N, approximately 166°E to approximately 169°W. May be extended westwards or eastwards within the latitude limits.',72.83,77.84,166.0,-168.99,0);
INSERT INTO "area" VALUES('EPSG','4091','Arctic - 74°30''N to 69°30''N, 4°E to 24°E','Arctic - between 74°30''N and 69°30''N, approximately 4°E to approximately 24°E. May be extended westwards or eastwards within the latitude limits.',69.5,74.51,4.0,24.01,0);
INSERT INTO "area" VALUES('EPSG','4092','Arctic - 74°30''N to 69°30''N, 24°E to 44°E','Arctic - between 74°30''N and 69°30''N, approximately 24°E to approximately 44°E. May be extended westwards or eastwards within the latitude limits.',69.5,74.51,24.0,44.01,0);
INSERT INTO "area" VALUES('EPSG','4093','Arctic - 74°30''N to 69°30''N, 44°E to 64°E','Arctic - between 74°30''N and 69°30''N, approximately 44°E to approximately 64°E. May be extended westwards or eastwards within the latitude limits.',69.5,74.51,44.0,64.01,0);
INSERT INTO "area" VALUES('EPSG','4094','Arctic - 74°30''N to 69°30''N, 64°E to 85°E','Arctic - between 74°30''N and 69°30''N, approximately 64°E to approximately 85°E. May be extended westwards or eastwards within the latitude limits.',69.5,74.51,64.0,85.01,0);
INSERT INTO "area" VALUES('EPSG','4095','Arctic - 74°30''N to 69°30''N, 85°E to 106°E','Arctic - between 74°30''N and 69°30''N, approximately 85°E to approximately 106°E. May be extended westwards or eastwards within the latitude limits.',69.5,74.51,85.0,106.01,0);
INSERT INTO "area" VALUES('EPSG','4096','Arctic - 74°30''N to 69°30''N, 106°E to 127°E','Arctic - between 74°30''N and 69°30''N, approximately 106°E to approximately 127°E. May be extended westwards or eastwards within the latitude limits.',69.5,74.51,106.0,127.01,0);
INSERT INTO "area" VALUES('EPSG','4097','Arctic - 74°30''N to 69°30''N, 127°E to 148°E','Arctic - between 74°30''N and 69°30''N, approximately 127°E to approximately 148°E. May be extended westwards or eastwards within the latitude limits.',69.5,74.51,127.0,148.0,0);
INSERT INTO "area" VALUES('EPSG','4098','Arctic - 74°30''N to 69°30''N, 148°E to 169°E','Arctic - between 74°30''N and 69°30''N, approximately 148°E to approximately 169°E. May be extended westwards or eastwards within the latitude limits.',69.5,74.51,148.0,169.01,0);
INSERT INTO "area" VALUES('EPSG','4099','Arctic - 74°30''N to 69°30''N, 169°E to 169°W','Arctic - between 74°30''N and 69°30''N, approximately 169°E to approximately 169°W. May be extended westwards or eastwards within the latitude limits.',69.5,74.51,169.0,-169.0,0);
INSERT INTO "area" VALUES('EPSG','4100','Arctic - 74°30''N to 69°30''N, 173°W to 153°W','Arctic - between 74°30''N and 69°30''N, approximately 173°W to approximately 153°W. May be extended eastwards within the latitude limits.',69.5,74.51,-173.0,-153.0,0);
INSERT INTO "area" VALUES('EPSG','4101','Arctic - 74°30''N to 69°30''N, 157°W to 137°W','Arctic - between 74°30''N and 69°30''N, approximately 157°W to approximately 137°W. May be extended westwards within the latitude limits.',69.5,74.51,-157.0,-137.0,0);
INSERT INTO "area" VALUES('EPSG','4102','Arctic - 74°30''N to 69°30''N, 141°W to 121°W','Arctic - between 74°30''N and 69°30''N, approximately 141°W to approximately 121°W. May be extended eastwards within the latitude limits.',69.5,74.51,-141.0,-121.0,0);
INSERT INTO "area" VALUES('EPSG','4103','Arctic - 74°30''N to 69°30''N, 121°W to 101°W','Arctic - between 74°30''N and 69°30''N, approximately 121°W to approximately 101°W. May be extended westwards or eastwards within the latitude limits.',69.5,74.51,-121.0,-101.0,0);
INSERT INTO "area" VALUES('EPSG','4104','Arctic - 74°30''N to 69°30''N, 101°W to 81°W','Arctic - between 74°30''N and 69°30''N, approximately 101°W to approximately 81°W. May be extended westwards or eastwards within the latitude limits.',69.5,74.51,-101.0,-81.0,0);
INSERT INTO "area" VALUES('EPSG','4105','Arctic - 74°30''N to 69°30''N, 81°W to 61°W','Arctic - between 74°30''N and 69°30''N, approximately 81°W to approximately 61°W. May be extended westwards within the latitude limits.',69.5,74.51,-81.0,-61.0,0);
INSERT INTO "area" VALUES('EPSG','4106','Arctic - 74°30''N to 69°30''N, 72°W to 52°W','Arctic - between 74°30''N and 69°30''N, approximately 72°W to approximately 52°W. May be extended eastwards within the latitude limits.',69.48,74.51,-71.89,-51.99,0);
INSERT INTO "area" VALUES('EPSG','4107','Arctic - 74°30''N to 69°30''N, 52°W to 32°W','Arctic - between 74°30''N and 69°30''N, approximately 52°W to approximately 32°W. May be extended westwards or eastwards within the latitude limits.',69.5,74.51,-52.0,-32.0,0);
INSERT INTO "area" VALUES('EPSG','4108','Arctic - 74°30''N to 69°30''N, 32°W to 12°W','Arctic - between 74°30''N and 69°30''N, approximately 32°W to approximately 12°W. May be extended westwards or eastwards within the latitude limits.',69.5,74.51,-32.0,-12.0,0);
INSERT INTO "area" VALUES('EPSG','4109','Arctic - 74°30''N to 69°30''N, 15°W to 5°E','Arctic - between 74°30''N and 69°30''N, approximately 15°W to approximately 5°E. May be extended westwards or eastwards within the latitude limits.',69.5,74.51,-15.0,5.01,0);
INSERT INTO "area" VALUES('EPSG','4110','Arctic - 71°10''N to 66°10''N, 174°W to 156°W','Arctic - between 71°10''N and 66°10''N, approximately 174°W to approximately 156°W. May be extended eastwards within the latitude limits.',66.16,71.17,-174.0,-156.0,0);
INSERT INTO "area" VALUES('EPSG','4111','Arctic - 71°10''N to 66°10''N, 156°W to 138°W','Arctic - between 71°10''N and 66°10''N, approximately 156°W to approximately 138°W. May be extended westwards within the latitude limits.',66.16,71.17,-156.0,-138.0,0);
INSERT INTO "area" VALUES('EPSG','4112','Arctic - 71°10''N to 66°10''N, 141°W to 122°W','Arctic - between 71°10''N and 66°10''N, approximately 141°W to approximately 122°W. May be extended eastwards within the latitude limits.',66.16,71.17,-141.0,-122.0,0);
INSERT INTO "area" VALUES('EPSG','4113','Arctic - 71°10''N to 66°10''N, 122°W to 103°W','Arctic - between 71°10''N and 66°10''N, approximately 122°W to approximately 103°W. May be extended westwards or eastwards within the latitude limits.',66.16,71.17,-122.0,-103.0,0);
INSERT INTO "area" VALUES('EPSG','4114','Arctic - 71°10''N to 66°10''N, 103°W to 84°W','Arctic - between 71°10''N and 66°10''N, approximately 103°W to approximately 84°W. May be extended westwards or eastwards within the latitude limits.',66.16,71.17,-103.0,-84.0,0);
INSERT INTO "area" VALUES('EPSG','4115','Arctic - 71°10''N to 66°10''N, 84°W to 65°W','Arctic - between 71°10''N and 66°10''N, approximately 84°W to approximately 65°W. May be extended westwards or eastwards within the latitude limits.',66.16,71.17,-84.0,-65.0,0);
INSERT INTO "area" VALUES('EPSG','4116','Arctic - 71°10''N to 66°10''N, 65°W to 47°W','Arctic - between 71°10''N and 66°10''N, approximately 65°W to approximately 47°W. May be extended westwards or eastwards within the latitude limits.',66.16,71.17,-65.0,-47.0,0);
INSERT INTO "area" VALUES('EPSG','4117','Arctic - 71°10''N to 66°10''N, 47°W to 29°W','Arctic - between 71°10''N and 66°10''N, approximately 47°W to approximately 29°W. May be extended westwards or eastwards within the latitude limits.',66.16,71.17,-47.0,-29.0,0);
INSERT INTO "area" VALUES('EPSG','4118','Arctic - 71°10''N to 66°10''N, 29°W to 11°W','Arctic - between 71°10''N and 66°10''N, approximately 29°W to approximately 11°W. May be extended westwards within the latitude limits.',66.16,71.17,-29.0,-11.0,0);
INSERT INTO "area" VALUES('EPSG','4119','Arctic - 67°50''N to 62°50''N, 59°W to 42°W','Arctic - between 67°50''N and 62°50''N, approximately 59°W to approximately 42°W. May be extended eastwards within the latitude limits.',62.83,67.84,-59.0,-42.0,0);
INSERT INTO "area" VALUES('EPSG','4120','Arctic - 67°50''N to 62°50''N, 42°W to 25°W','Arctic - between 67°50''N and 62°50''N, approximately 42°W to approximately 25°W. May be extended westwards within the latitude limits.',62.83,67.84,-42.0,-25.0,0);
INSERT INTO "area" VALUES('EPSG','4121','Cayman Islands - Little Cayman','Cayman Islands - Little Cayman.',19.63,19.74,-80.14,-79.93,0);
INSERT INTO "area" VALUES('EPSG','4122','Colombia - Arauca city','Colombia - Arauca city.',7.05,7.1,-70.78,-70.71,0);
INSERT INTO "area" VALUES('EPSG','4123','Arctic - 64°30''N to 59°30''N, 59°W to 44°W','Arctic - between 64°30''N and 59°30''N, approximately 59°W to approximately 44°W. May be extended eastwards within the latitude limits.',59.5,64.51,-59.0,-44.0,0);
INSERT INTO "area" VALUES('EPSG','4124','Arctic - 64°30''N to 59°30''N, 44°W to 29°W','Arctic - between 64°30''N and 59°30''N, approximately 44°W to approximately 29°W. May be extended westwards within the latitude limits.',59.5,64.51,-44.0,-29.0,0);
INSERT INTO "area" VALUES('EPSG','4125','Portugal - Madeira and Desertas islands onshore','Portugal - Madeira and Desertas islands - onshore.',32.35,32.93,-17.31,-16.4,0);
INSERT INTO "area" VALUES('EPSG','4126','Portugal - Azores E onshore - Santa Maria and Formigas','Portugal - eastern Azores onshore - Santa Maria, Formigas.',36.87,37.34,-25.26,-24.72,0);
INSERT INTO "area" VALUES('EPSG','4127','Nigeria - OML 124','Nigeria - onshore - block OML 124 (formerly OPL 118).',5.56,5.74,6.72,6.97,0);
INSERT INTO "area" VALUES('EPSG','4128','Colombia - Santa Marta city','Colombia - Santa Marta city.',11.16,11.3,-74.24,-74.13,0);
INSERT INTO "area" VALUES('EPSG','4129','Brazil - 48°W to 42°W and north of 0°N','Brazil - offshore between 48°W and 42°W, northern hemisphere.',0.0,5.13,-48.0,-41.99,0);
INSERT INTO "area" VALUES('EPSG','4130','Colombia - Sucre city','Colombia - Sucre city.',8.79,8.83,-74.74,-74.69,0);
INSERT INTO "area" VALUES('EPSG','4131','Colombia - Tunja city','Colombia - Tunja city.',5.5,5.61,-73.39,-73.3,0);
INSERT INTO "area" VALUES('EPSG','4132','Colombia - Armenia city','Colombia - Armenia city.',4.5,4.55,-75.73,-75.65,0);
INSERT INTO "area" VALUES('EPSG','4133','Brazil - 42°W to 36°W and north of 0°N','Brazil - offshore between 42°W and 36°W, northern hemisphere.',0.0,0.74,-42.0,-38.22,0);
INSERT INTO "area" VALUES('EPSG','4134','Colombia - Barranquilla city','Colombia - Barranquilla city.',10.85,11.06,-74.87,-74.75,0);
INSERT INTO "area" VALUES('EPSG','4135','Colombia - Bogota city','Colombia - Bogota DC city.',4.45,4.85,-74.27,-73.98,0);
INSERT INTO "area" VALUES('EPSG','4136','Colombia - Bucaramanga city','Colombia - Bucaramanga city.',7.03,7.17,-73.19,-73.06,0);
INSERT INTO "area" VALUES('EPSG','4137','Colombia - Cali city','Colombia - Cali city.',3.32,3.56,-76.61,-76.42,0);
INSERT INTO "area" VALUES('EPSG','4138','Colombia - Cartagena city','Colombia - Cartagena city.',10.27,10.47,-75.57,-75.42,0);
INSERT INTO "area" VALUES('EPSG','4139','Colombia - Cucuta city','Colombia - Cucuta city.',7.81,7.97,-72.56,-72.46,0);
INSERT INTO "area" VALUES('EPSG','4140','Colombia - Florencia city','Colombia - Florencia city.',1.57,1.65,-75.63,-75.59,0);
INSERT INTO "area" VALUES('EPSG','4141','Colombia - Ibague city','Colombia - Ibague city.',4.39,4.47,-75.27,-75.11,0);
INSERT INTO "area" VALUES('EPSG','4142','Colombia - Inirida city','Colombia - Inirida city.',3.8,3.9,-67.94,-67.88,0);
INSERT INTO "area" VALUES('EPSG','4143','Colombia - Leticia city','Colombia - Leticia city.',-4.23,-4.17,-69.98,-69.92,0);
INSERT INTO "area" VALUES('EPSG','4144','Colombia - Manizales city','Colombia - Manizales city.',5.02,5.11,-75.54,-75.44,0);
INSERT INTO "area" VALUES('EPSG','4145','Colombia - Medellin city','Colombia - Medellin city.',6.12,6.37,-75.66,-75.5,0);
INSERT INTO "area" VALUES('EPSG','4146','Colombia - Mitu city','Colombia - Mitu city.',1.23,1.29,-70.25,-70.21,0);
INSERT INTO "area" VALUES('EPSG','4147','Colombia - Mocoa city','Colombia - Mocoa city.',1.12,1.18,-76.66,-76.63,0);
INSERT INTO "area" VALUES('EPSG','4148','Colombia - Monteria city','Colombia - Monteria city.',8.7,8.81,-75.94,-75.82,0);
INSERT INTO "area" VALUES('EPSG','4149','Colombia - Neiva city','Colombia - Neiva city.',2.87,2.99,-75.32,-75.23,0);
INSERT INTO "area" VALUES('EPSG','4150','Colombia - Pasto city','Colombia - Pasto city.',1.16,1.26,-77.32,-77.23,0);
INSERT INTO "area" VALUES('EPSG','4151','Colombia - Pereira city','Colombia - Pereira city.',4.78,4.87,-75.77,-75.64,0);
INSERT INTO "area" VALUES('EPSG','4152','Colombia - Popayan city','Colombia - Popayan city.',2.41,2.49,-76.65,-76.55,0);
INSERT INTO "area" VALUES('EPSG','4153','Colombia - Puerto Carreno city','Colombia - Puerto Carreno city.',5.98,6.3,-67.7,-67.41,0);
INSERT INTO "area" VALUES('EPSG','4154','Colombia - Quibdo city','Colombia - Quibdo city.',5.66,5.72,-76.67,-76.63,0);
INSERT INTO "area" VALUES('EPSG','4155','Colombia - Riohacha city','Colombia - Riohacha city.',11.42,11.58,-72.96,-72.84,0);
INSERT INTO "area" VALUES('EPSG','4156','Colombia - San Andres city','Colombia - San Andres city.',12.43,12.65,-81.82,-81.6,0);
INSERT INTO "area" VALUES('EPSG','4157','Colombia - San Jose del Guaviare city','Colombia - San Jose del Guaviare city.',2.54,2.61,-72.66,-72.6,0);
INSERT INTO "area" VALUES('EPSG','4158','Colombia - Valledupar city','Colombia - Valledupar city.',10.39,10.51,-73.3,-73.19,0);
INSERT INTO "area" VALUES('EPSG','4159','Colombia - Villavicencio city','Colombia - Villavicencio city.',4.07,4.21,-73.69,-73.56,0);
INSERT INTO "area" VALUES('EPSG','4160','Colombia - Yopal city','Colombia - Yopal city.',5.3,5.37,-72.43,-72.35,0);
INSERT INTO "area" VALUES('EPSG','4161','North America - Mexico and USA - onshore','Mexico - onshore. United States (USA) -  CONUS and Alaska - onshore - Alabama; Alaska; Arizona; Arkansas; California; Colorado; Connecticut; Delaware; Florida; Georgia; Idaho; Illinois; Indiana; Iowa; Kansas; Kentucky; Louisiana; Maine; Maryland; Massachusetts; Michigan; Minnesota; Mississippi; Missouri; Montana; Nebraska; Nevada; New Hampshire; New Jersey; New Mexico; New York; North Carolina; North Dakota; Ohio; Oklahoma; Oregon; Pennsylvania; Rhode Island; South Carolina; South Dakota; Tennessee; Texas; Utah; Vermont; Virginia; Washington; West Virginia; Wisconsin; Wyoming.',14.51,71.4,172.42,-66.91,0);
INSERT INTO "area" VALUES('EPSG','4162','Pacific - US interests Pacific plate','American Samoa, Marshall Islands, United States (USA) - Hawaii, United States minor outlying islands; onshore and offshore.',-17.56,31.8,157.47,-151.27,0);
INSERT INTO "area" VALUES('EPSG','4163','Japan excluding northern main province','Japan - onshore and offshore, excluding northern prefectures of ''main province'' (see remarks).',17.09,46.05,122.38,157.65,0);
INSERT INTO "area" VALUES('EPSG','4164','USA - Iowa - Spencer','United States (USA) - Iowa - counties of Clay; Dickinson; Emmet; Kossuth; Lyon; O''Brien; Osceola; Palo Alto; Sioux.',42.9,43.51,-96.6,-93.97,0);
INSERT INTO "area" VALUES('EPSG','4165','Japan - onshore mainland excluding eastern main province','Japan - onshore mainland - Hokkaido, Honshu (western part only, see remarks), Shikoku, Kyushu.',30.94,45.54,129.3,145.87,0);
INSERT INTO "area" VALUES('EPSG','4166','Japan - onshore - Honshu, Shikoku, Kyushu','Japan - onshore mainland - Honshu, Shikoku, Kyushu.',30.94,41.58,129.3,142.14,0);
INSERT INTO "area" VALUES('EPSG','4167','Pacific - US interests Mariana plate','Guam, Northern Mariana Islands and Palau; onshore and offshore.',1.64,23.9,129.48,149.55,0);
INSERT INTO "area" VALUES('EPSG','4168','Japan - onshore - Hokkaido','Japan - onshore mainland - Hokkaido.',41.34,45.54,139.7,145.87,0);
INSERT INTO "area" VALUES('EPSG','4169','Christmas Island - onshore','Christmas Island - onshore.',-10.63,-10.36,105.48,105.77,0);
INSERT INTO "area" VALUES('EPSG','4170','Japan - northern Honshu','Japan - northern Honshu prefectures affected by 2011 Tohoku earthquake: Aomori, Iwate, Miyagi, Akita, Yamaguta, Fukushima, Ibaraki, Tochigi, Gumma, Saitama, Chiba, Tokyo, Kanagawa, Niigata, Toyama, Ishikawa, Fukui, Yamanashi, Nagano, Gifu.',34.84,41.58,135.42,142.14,0);
INSERT INTO "area" VALUES('EPSG','4171','Northern Mariana Islands - Rota, Saipan and Tinian','Northern Mariana Islands - onshore - Rota, Saipan and Tinian.',14.06,15.35,145.06,145.89,0);
INSERT INTO "area" VALUES('EPSG','4172','Falkland Islands -  offshore 63°W to 57°W','Falkland Islands (Malvinas) - offshore - between 63°W and 57°W.',-56.25,-47.68,-63.01,-56.99,0);
INSERT INTO "area" VALUES('EPSG','4173','Heard Island and McDonald Islands - west of 66°E','Heard Island and McDonald Islands - offshore west of 66°E.',-57.5,-53.43,62.92,66.0,0);
INSERT INTO "area" VALUES('EPSG','4174','Australia','Australia - onshore and offshore. Includes Lord Howe Island, Macquarie Islands, Ashmore and Cartier Islands.',-60.56,-8.88,105.8,164.7,0);
INSERT INTO "area" VALUES('EPSG','4175','Australasia - Australia and Norfolk Island - 162°E to 168°E','Australia - offshore east of 162°E.  Norfolk Island - onshore and offshore west of 168°E.',-59.39,-25.94,162.0,168.0,0);
INSERT INTO "area" VALUES('EPSG','4176','Australasia - Australia and Christmas Island - 108°E to 114°E','Australia - onshore and offshore west of 114°E. Christmas Island - offshore east of 108°E.',-37.84,-10.72,108.0,114.01,0);
INSERT INTO "area" VALUES('EPSG','4177','Australia - GDA','Australia including Lord Howe Island, Macquarie Islands, Ashmore and Cartier Islands, Christmas Island, Cocos (Keeling) Islands, Norfolk Island. All onshore and offshore.',-60.56,-8.47,93.41,173.35,0);
INSERT INTO "area" VALUES('EPSG','4178','Australia - 114°E to 120°E','Australia - onshore and offshore between 114°E and 120°E.',-38.53,-12.06,114.0,120.01,0);
INSERT INTO "area" VALUES('EPSG','4179','Norfolk Island - east of 168°E','Norfolk Island - offshore east of 168°E.',-32.48,-25.61,168.0,173.35,0);
INSERT INTO "area" VALUES('EPSG','4180','USA - Oregon - Baker City','United States (USA) - Oregon - Baker City area.',44.6,45.19,-118.15,-117.37,0);
INSERT INTO "area" VALUES('EPSG','4181','Heard Island and McDonald Islands - 66°E to 72°E','Heard Island and McDonald Islands - offshore 66°E to 72°E.',-58.96,-51.18,66.0,72.01,0);
INSERT INTO "area" VALUES('EPSG','4182','USA - Oregon - Bend-Burns','United States (USA) - Oregon - Bend-Burns area.',43.34,44.28,-120.95,-118.8,0);
INSERT INTO "area" VALUES('EPSG','4183','Seychelles - Seychelles Bank','Seychelles - Mahe, Silhouette, North, Aride Island, Praslin, La Digue and Frigate islands including adjacent smaller granitic islands on the Seychelles Bank, Bird Island and Denis Island.',-4.86,-3.66,55.15,56.01,0);
INSERT INTO "area" VALUES('EPSG','4184','Heard Island and McDonald Islands - 72°E to 78°E','Heard Island and McDonald Islands - onshore and offshore 72°E to 78°E.',-59.02,-49.5,72.0,78.01,0);
INSERT INTO "area" VALUES('EPSG','4185','Heard Island and McDonald Islands - east of 78°E','Heard Island and McDonald Islands - offshore east of 78°E.',-58.47,-50.65,78.0,83.57,0);
INSERT INTO "area" VALUES('EPSG','4186','Italy - 12°E to 18°E','Italy - onshore and offshore - between 12°E and 18°E including San Marino and Vatican City State.',34.79,47.1,12.0,18.0,0);
INSERT INTO "area" VALUES('EPSG','4187','Italy - east of 18°E','Italy - onshore and offshore - east of 18°E.',34.76,41.64,17.99,18.99,0);
INSERT INTO "area" VALUES('EPSG','4188','Spain and Gibraltar - onshore','Gibraltar - onshore; Spain - mainland onshore.',35.95,43.82,-9.37,3.39,0);
INSERT INTO "area" VALUES('EPSG','4189','Cocos (Keeling) Islands - west of 96°E','Cocos (Keeling) Islands - offshore west of 96°E.',-15.46,-8.57,93.41,96.01,0);
INSERT INTO "area" VALUES('EPSG','4190','Cocos (Keeling) Islands - east of 96°E','Cocos (Keeling) Islands - onshore and offshore east of 96°E.',-15.56,-8.47,96.0,100.34,0);
INSERT INTO "area" VALUES('EPSG','4191','Australasia - Australia and Christmas Island - west of 108°E','Australia - offshore west of 108°E. Christmas Island - onshore and offshore west of 108°E.',-34.68,-8.87,102.14,108.01,0);
INSERT INTO "area" VALUES('EPSG','4192','USA - Oregon - Bend-Klamath Falls','United States (USA) - Oregon - Bend-Klamath Falls area.',41.88,43.89,-122.45,-120.77,0);
INSERT INTO "area" VALUES('EPSG','4193','Vietnam - west of 103°30''E onshore','Vietnam - onshore west of 103°30''E.',9.23,22.8,102.14,103.51,0);
INSERT INTO "area" VALUES('EPSG','4194','Japan onshore excluding northern main province','Japan - onshore, excluding northern prefectures of ''main province'' (see remarks).',20.37,45.54,122.83,154.05,0);
INSERT INTO "area" VALUES('EPSG','4195','USA - Oregon - Bend-Redmond-Prineville','United States (USA) - Oregon - Bend-Redmond-Prineville area.',43.76,44.98,-121.88,-119.79,0);
INSERT INTO "area" VALUES('EPSG','4196','Australia and Macquarie - 156°E to 162°E','Australia including Lord Howe Island and Macquarie Islands - onshore and offshore between 156°E and 162°E.',-60.56,-14.08,156.0,162.01,0);
INSERT INTO "area" VALUES('EPSG','4197','USA - Oregon - Eugene','United States (USA) - Oregon - Eugene area.',43.74,44.71,-123.8,-122.18,0);
INSERT INTO "area" VALUES('EPSG','4198','USA - Oregon - Grants Pass-Ashland','United States (USA) - Oregon - Grants Pass-Ashland area.',41.88,42.85,-123.95,-122.37,0);
INSERT INTO "area" VALUES('EPSG','4199','USA - Oregon - Canyonville-Grants Pass','United States (USA) - Oregon - Canyonville-Grants Pass area.',42.49,43.24,-123.83,-122.43,0);
INSERT INTO "area" VALUES('EPSG','4200','USA - Oregon - Columbia River East','United States (USA) - Oregon - Columbia River area between approximately 122°03''W and 118°53''W.',45.49,46.08,-122.05,-118.89,0);
INSERT INTO "area" VALUES('EPSG','4201','USA - Oregon - Gresham-Warm Springs','United States (USA) - Oregon - Gresham-Warm Springs area.',45.02,45.55,-122.43,-121.68,0);
INSERT INTO "area" VALUES('EPSG','4202','USA - Oregon - Columbia River West','United States (USA) - Oregon - Columbia River area west of approximately 121°30''W.',45.17,46.56,-124.33,-121.47,0);
INSERT INTO "area" VALUES('EPSG','4203','USA - Oregon - Cottage Grove-Canyonville','United States (USA) - Oregon - Cottage Grove-Canyonville area.',42.82,43.88,-123.96,-122.4,0);
INSERT INTO "area" VALUES('EPSG','4204','USA - Oregon - Dufur-Madras','United States (USA) - Oregon - Dufur-Madras area.',44.63,45.55,-121.95,-120.46,0);
INSERT INTO "area" VALUES('EPSG','4205','[enter here applicable extent]','[enter here applicable extent]',89.99,90.0,179.99,180.0,0);
INSERT INTO "area" VALUES('EPSG','4206','USA - Oregon - La Grande','United States (USA) - Oregon - La Grande area.',45.13,45.8,-118.17,-117.14,0);
INSERT INTO "area" VALUES('EPSG','4207','USA - Oregon - Ontario','United States (USA) - Oregon - Ontario area.',43.41,44.65,-117.9,-116.7,0);
INSERT INTO "area" VALUES('EPSG','4208','USA - Oregon - Oregon Coast','United States (USA) - Oregon - coastal area.',41.89,46.4,-124.84,-123.35,0);
INSERT INTO "area" VALUES('EPSG','4209','USA - Oregon - Pendleton','United States (USA) - Oregon - Pendleton area.',45.46,46.02,-119.36,-118.17,0);
INSERT INTO "area" VALUES('EPSG','4210','USA - Oregon - Pendleton-La Grande','United States (USA) - Oregon - Pendleton-La Grande area.',45.13,45.64,-118.64,-118.09,0);
INSERT INTO "area" VALUES('EPSG','4211','USA - Oregon - Portland','United States (USA) - Oregon - Portland area.',45.23,46.01,-123.53,-122.11,0);
INSERT INTO "area" VALUES('EPSG','4212','USA - Oregon - Salem','United States (USA) - Oregon - Salem area.',44.32,45.3,-123.73,-121.89,0);
INSERT INTO "area" VALUES('EPSG','4213','USA - Oregon - Sweet Home-Sisters','United States (USA) - Oregon - Sweet Home-Santiam Pass-Sisters area.',44.1,44.66,-122.51,-121.69,0);
INSERT INTO "area" VALUES('EPSG','4214','Papua New Guinea - mainland onshore','Papua New Guinea - mainland onshore.',-10.76,-2.53,140.85,150.96,0);
INSERT INTO "area" VALUES('EPSG','4215','Vietnam - 103.5°E to 106.5°E onshore','Vietnam - between 103°30''E and 106°30''E, onshore.',8.5,23.33,103.5,106.51,0);
INSERT INTO "area" VALUES('EPSG','4216','Papua New Guinea - North Fly','Papua New Guinea - North Fly area (between 5°04''S and 6°36''S and west of 141°32''E).',-6.6,-5.05,140.89,141.54,0);
INSERT INTO "area" VALUES('EPSG','4217','Vietnam - east of 106.5°E onshore','Vietnam - onshore east of 106°30''E.',8.58,22.94,106.5,109.52,0);
INSERT INTO "area" VALUES('EPSG','4218','Vietnam - Quang Ninh; Da Nang, Quang Nam; Ba Ria-Vung Tau, Dong Nai, Lam Dong','Vietnam - Quang Ninh province; Da Nang municipality and Quang Nam province; Ba Ria-Vung Tau, Dong Nai and Lam Dong provinces.',8.57,21.67,106.43,108.76,0);
INSERT INTO "area" VALUES('EPSG','4219','USA - Iowa - Mason City','United States (USA) - Iowa - counties of Cerro Gordo; Chickasaw; Floyd; Hancock; Howard; Mitchell; Winnebago; Winneshiek; Worth.',42.9,43.51,-93.98,-91.6,0);
INSERT INTO "area" VALUES('EPSG','4220','Equatorial Guinea - Bioko','Equatorial Guinea - Bioko onshore.',3.14,3.82,8.37,9.02,0);
INSERT INTO "area" VALUES('EPSG','4221','Chile - onshore 36°S to 43.5°S','Chile - onshore between 36°S and 43°30''S.',-43.5,-35.99,-74.48,-70.39,0);
INSERT INTO "area" VALUES('EPSG','4222','Chile - onshore 26°S to 36°S','Chile - onshore between 26°S and 36°S.',-36.0,-26.0,-72.87,-68.28,0);
INSERT INTO "area" VALUES('EPSG','4223','Asia - Malaysia (west including SCS) and Singapore','Malaysia - West Malaysia onshore and offshore east coast; Singapore - onshore and offshore.',1.13,7.81,99.59,105.82,0);
INSERT INTO "area" VALUES('EPSG','4224','Chile - onshore 32°S to 36°S','Chile - onshore between 32°S and 36°S.',-36.0,-31.99,-72.87,-69.77,0);
INSERT INTO "area" VALUES('EPSG','4225','UAE - Abu Dhabi - onshore','United Arab Emirates (UAE) - Abu Dhabi onshore.',22.63,24.95,51.56,56.03,0);
INSERT INTO "area" VALUES('EPSG','4226','UAE - Abu Dhabi','United Arab Emirates (UAE) - Abu Dhabi onshore and offshore.',22.63,25.64,51.5,56.03,0);
INSERT INTO "area" VALUES('EPSG','4227','UAE - Abu Dhabi - onshore east of 54°E','United Arab Emirates (UAE) - Abu Dhabi onshore east of 54°E.',22.63,24.95,53.99,56.03,0);
INSERT INTO "area" VALUES('EPSG','4228','USA - California - San Francisco Bay Area','United States (USA) - California - San Francisco bay area – counties of Alameda, Contra Costa, Marin, Napa, San Francisco, San Mateo, Santa Clara, Santa Cruz, Solano and Sonoma.',36.85,38.87,-123.56,-121.2,0);
INSERT INTO "area" VALUES('EPSG','4229','UAE - Abu Dhabi island','United Arab Emirates (UAE) - Abu Dhabi island.',24.24,24.64,54.2,54.71,0);
INSERT INTO "area" VALUES('EPSG','4230','USA - Iowa - Elkader','United States (USA) - Iowa - counties of Allamakee; Clayton; Delaware.',42.29,43.51,-91.62,-90.89,0);
INSERT INTO "area" VALUES('EPSG','4231','Chile - onshore north of 26°S','Chile - onshore north of 26°S.',-26.0,-17.5,-70.79,-67.0,0);
INSERT INTO "area" VALUES('EPSG','4232','Chile - onshore north of 32°S','Chile - onshore north of 32°S.',-32.0,-17.5,-71.77,-67.0,0);
INSERT INTO "area" VALUES('EPSG','4233','USA - Iowa - Sioux City-Iowa Falls','United States (USA) - Iowa - counties of Buena Vista; Calhoun; Cherokee; Franklin; Hamilton; Hardin; Humboldt; Ida; Plymouth; Pocahontas; Sac; Webster; Woodbury; Wright.',42.2,42.92,-96.65,-93.0,0);
INSERT INTO "area" VALUES('EPSG','4234','USA - Iowa - Waterloo','United States (USA) - Iowa - counties of Black Hawk; Bremer; Buchanan; Butler; Fayette; Grundy.',42.2,43.09,-93.03,-91.59,0);
INSERT INTO "area" VALUES('EPSG','4235','USA - Iowa - Council Bluffs','United States (USA) - Iowa - counties of Crawford; Fremont; Harrison; Mills; Monona; Pottawattamie; Shelby.',40.58,42.22,-96.37,-95.04,0);
INSERT INTO "area" VALUES('EPSG','4236','USA - Iowa - Carroll-Atlantic','United States (USA) - Iowa - counties of Adair; Audubon; Carroll; Cass; Greene; Guthrie.',41.15,42.22,-95.16,-94.16,0);
INSERT INTO "area" VALUES('EPSG','4237','USA - Iowa - Ames-Des Moines','United States (USA) - Iowa - counties of Boone; Dallas; Madison; Polk; Story; Warren.',41.15,42.22,-94.29,-93.23,0);
INSERT INTO "area" VALUES('EPSG','4238','Asia - Middle East - Iraq and SW Iran','Iraq - onshore; Iran - onshore northern Gulf coast and west bordering southeast Iraq.',29.06,37.39,38.79,51.06,0);
INSERT INTO "area" VALUES('EPSG','4239','USA - Iowa - Newton','United States (USA) - Iowa - counties of Jasper; Mahaska; Marion; Marshall; Poweshiek; Tama.',41.16,42.3,-93.35,-92.29,0);
INSERT INTO "area" VALUES('EPSG','4240','USA - Iowa - Cedar Rapids','United States (USA) - Iowa - counties of Benton; Cedar; Iowa; Johnson; Jones; Linn.',41.42,42.3,-92.31,-90.89,0);
INSERT INTO "area" VALUES('EPSG','4241','USA - Iowa - Dubuque-Davenport','United States (USA) - Iowa - counties of Clinton; Dubuque; Jackson; Scott.',41.44,42.68,-91.14,-90.14,0);
INSERT INTO "area" VALUES('EPSG','4242','USA - Iowa - Red Oak-Ottumwa','United States (USA) - Iowa - counties of Adams; Appanoose; Clarke; Davis; Decatur; Lucas; Monroe; Montgomery; Page; Ringgold; Taylor; Union; Wapello; Wayne.',40.57,41.17,-95.39,-92.17,0);
INSERT INTO "area" VALUES('EPSG','4243','USA - Iowa - Fairfield','United States (USA) - Iowa - counties of Jefferson; Keokuk; Van Buren; Washington.',40.59,41.52,-92.42,-91.48,0);
INSERT INTO "area" VALUES('EPSG','4244','USA - Iowa - Burlington','United States (USA) - Iowa - counties of Des Moines; Henry; Lee; Louisa; Muscatine.',40.37,41.6,-91.72,-90.78,0);
INSERT INTO "area" VALUES('EPSG','4245','French Southern Territories - Crozet west of 48°E','French Southern Territories - Crozet offshore west of 48°E.',-49.38,-43.12,45.37,48.01,0);
INSERT INTO "area" VALUES('EPSG','4246','French Southern and Antarctic Territories','French Southern Territories - onshore and offshore: Amsterdam and St Paul, Crozet, Europa and Kerguelen. Antarctica - Adelie Land coastal area.',-67.13,-20.91,37.98,142.0,0);
INSERT INTO "area" VALUES('EPSG','4247','French Southern Territories - Crozet 48°E to 54°E','French Southern Territories - Crozet onshore and offshore between 48°E to 54°E.',-49.82,-42.61,48.0,54.01,0);
INSERT INTO "area" VALUES('EPSG','4248','French Southern Territories - Crozet east of 54°E','French Southern Territories - Crozet offshore east of 54°E.',-49.61,-43.3,54.0,57.16,0);
INSERT INTO "area" VALUES('EPSG','4249','French Southern Territories - 60°E to 66°E','French Southern Territories - Kerguelen offshore west of 66°E.',-53.03,-45.73,62.96,66.0,0);
INSERT INTO "area" VALUES('EPSG','4250','French Southern Territories - 66°E to 72°E','French Southern Territories - Kerguelen onshore and offshore between 66°E and 72°E.',-53.24,-45.11,66.0,72.01,0);
INSERT INTO "area" VALUES('EPSG','4251','French Southern Territories - 72°E to 78°E','French Southern Territories - Kerguelen offshore east of 72°E and Amsterdam & St Paul onshore and offshore west of 78°E.',-51.19,-34.47,72.0,78.01,0);
INSERT INTO "area" VALUES('EPSG','4252','French Southern Territories - east of 78°E','French Southern Territories - Amsterdam & St Paul offshore east of 78°E.',-42.04,-34.5,78.0,81.83,0);
INSERT INTO "area" VALUES('EPSG','4253','USA - Indiana - Lake and Newton','United States (USA) - Indiana - counties of Lake and Newton.',40.73,41.77,-87.53,-87.21,0);
INSERT INTO "area" VALUES('EPSG','4254','USA - Indiana - Jasper and Porter','United States (USA) - Indiana - counties of Jasper and Porter.',40.73,41.77,-87.28,-86.92,0);
INSERT INTO "area" VALUES('EPSG','4255','USA - Indiana - LaPorte, Pulaski, Starke','United States (USA) - Indiana - counties of LaPorte, Pulaski and Starke.',40.9,41.77,-86.94,-86.46,0);
INSERT INTO "area" VALUES('EPSG','4256','USA - Indiana - Benton','United States (USA) - Indiana - Benton county.',40.47,40.74,-87.53,-87.09,0);
INSERT INTO "area" VALUES('EPSG','4257','USA - Indiana - Tippecanoe and White','United States (USA) - Indiana - counties of Tippecanoe and White.',40.21,40.92,-87.1,-86.58,0);
INSERT INTO "area" VALUES('EPSG','4258','USA - Indiana - Carroll','United States (USA) - Indiana - Carroll county.',40.43,40.74,-86.78,-86.37,0);
INSERT INTO "area" VALUES('EPSG','4259','USA - Indiana - Fountain and Warren','United States (USA) - Indiana - counties of Fountain and Warren.',39.95,40.48,-87.54,-87.09,0);
INSERT INTO "area" VALUES('EPSG','4260','USA - Indiana - Clinton','United States (USA) - Indiana - Clinton county.',40.17,40.44,-86.7,-86.24,0);
INSERT INTO "area" VALUES('EPSG','4261','USA - Indiana - Parke and Vermillion','United States (USA) - Indiana - counties of Parke and Vermillion.',39.6,40.15,-87.54,-87.0,0);
INSERT INTO "area" VALUES('EPSG','4262','USA - Indiana - Montgomery and Putnam','United States (USA) - Indiana - counties of Montgomery and Putnam.',39.47,40.22,-87.1,-86.64,0);
INSERT INTO "area" VALUES('EPSG','4263','USA - Indiana - Boone and Hendricks','United States (USA) - Indiana - counties of Boone and Hendricks.',39.6,40.19,-86.7,-86.24,0);
INSERT INTO "area" VALUES('EPSG','4264','USA - Indiana - Vigo','United States (USA) - Indiana - Vigo county.',39.25,39.61,-87.62,-87.19,0);
INSERT INTO "area" VALUES('EPSG','4265','USA - Indiana - Clay','United States (USA) - Indiana - Clay county.',39.16,39.61,-87.25,-86.93,0);
INSERT INTO "area" VALUES('EPSG','4266','USA - Indiana - Owen','United States (USA) - Indiana - Owen county.',39.16,39.48,-87.06,-86.63,0);
INSERT INTO "area" VALUES('EPSG','4267','USA - Indiana - Monroe and Morgan','United States (USA) - Indiana - counties of Monroe and Morgan.',38.99,39.64,-86.69,-86.24,0);
INSERT INTO "area" VALUES('EPSG','4268','USA - Indiana - Sullivan','United States (USA) - Indiana - Sullivan county.',38.9,39.26,-87.65,-87.24,0);
INSERT INTO "area" VALUES('EPSG','4269','USA - Indiana - Daviess and Greene','United States (USA) - Indiana - counties of Daviess and Greene.',38.49,39.18,-87.28,-86.68,0);
INSERT INTO "area" VALUES('EPSG','4270','USA - Indiana - Knox','United States (USA) - Indiana - Knox county.',38.41,38.91,-87.75,-87.09,0);
INSERT INTO "area" VALUES('EPSG','4271','USA - Indiana - Dubois and Martin','United States (USA) - Indiana - counties of Dubois and Martin.',38.2,38.91,-87.08,-86.67,0);
INSERT INTO "area" VALUES('EPSG','4272','USA - Indiana - Crawford, Lawrence, Orange','United States (USA) - Indiana - counties of Crawford, Lawrence and Orange.',38.1,39.0,-86.69,-86.24,0);
INSERT INTO "area" VALUES('EPSG','4273','USA - Indiana - Gibson','United States (USA) - Indiana - Gibson county.',38.16,38.54,-87.98,-87.31,0);
INSERT INTO "area" VALUES('EPSG','4274','USA - Indiana - Pike and Warrick','United States (USA) - Indiana - counties of Pike and Warrick.',37.87,38.56,-87.48,-87.01,0);
INSERT INTO "area" VALUES('EPSG','4275','USA - Indiana - Posey','United States (USA) - Indiana - Posey county.',37.77,38.24,-88.06,-87.68,0);
INSERT INTO "area" VALUES('EPSG','4276','USA - Indiana - Vanderburgh','United States (USA) - Indiana - Vanderburgh county.',37.82,38.17,-87.71,-87.44,0);
INSERT INTO "area" VALUES('EPSG','4277','USA - Indiana - Spencer','United States (USA) - Indiana - Spencer county.',37.78,38.21,-87.27,-86.76,0);
INSERT INTO "area" VALUES('EPSG','4278','USA - Indiana - Perry','United States (USA) - Indiana - Perry county.',37.84,38.27,-86.82,-86.43,0);
INSERT INTO "area" VALUES('EPSG','4279','USA - Indiana - Fulton, Marshall, St Joseph','United States (USA) - Indiana - counties of Fulton, Marshall and St Joseph.',40.9,41.77,-86.53,-85.94,0);
INSERT INTO "area" VALUES('EPSG','4280','USA - Indiana - Elkhart, Kosciusko, Wabash','United States (USA) - Indiana - counties of Elkhart, Kosciusko and Wabash.',40.65,41.77,-86.08,-85.63,0);
INSERT INTO "area" VALUES('EPSG','4281','USA - Indiana - LaGrange and Noble','United States (USA) - Indiana - counties of LaGrange and Noble.',41.26,41.77,-85.66,-85.19,0);
INSERT INTO "area" VALUES('EPSG','4282','USA - Indiana - Steuben','United States (USA) - Indiana - Steuben county.',41.52,41.77,-85.2,-84.8,0);
INSERT INTO "area" VALUES('EPSG','4283','USA - Indiana - DeKalb','United States (USA) - Indiana - DeKalb county.',41.26,41.54,-85.2,-84.8,0);
INSERT INTO "area" VALUES('EPSG','4284','USA - Indiana - Huntington and Whitley','United States (USA) - Indiana - counties of Huntington and Whitley.',40.65,41.3,-85.69,-85.3,0);
INSERT INTO "area" VALUES('EPSG','4285','USA - Indiana - Allen','United States (USA) - Indiana - Allen county.',40.91,41.28,-85.34,-84.8,0);
INSERT INTO "area" VALUES('EPSG','4286','USA - Indiana - Cass','United States (USA) - Indiana - Cass county.',40.56,40.92,-86.59,-86.16,0);
INSERT INTO "area" VALUES('EPSG','4287','USA - Indiana - Howard and Miami','United States (USA) - Indiana - counties of Howard and Miami.',40.37,41.0,-86.38,-85.86,0);
INSERT INTO "area" VALUES('EPSG','4288','USA - Indiana - Wells','United States (USA) - Indiana - Wells county.',40.56,40.92,-85.45,-85.06,0);
INSERT INTO "area" VALUES('EPSG','4289','USA - Indiana - Adams','United States (USA) - Indiana - Adams county.',40.56,40.93,-85.08,-84.8,0);
INSERT INTO "area" VALUES('EPSG','4290','USA - Indiana - Grant','United States (USA) - Indiana - Grant county.',40.37,40.66,-85.87,-85.44,0);
INSERT INTO "area" VALUES('EPSG','4291','USA - Indiana - Blackford and Delaware','United States (USA) - Indiana - counties of Blackford and Delaware.',40.07,40.57,-85.58,-85.2,0);
INSERT INTO "area" VALUES('EPSG','4292','USA - Indiana - Jay','United States (USA) - Indiana - Jay county.',40.3,40.58,-85.22,-84.8,0);
INSERT INTO "area" VALUES('EPSG','4293','USA - Indiana - Hamilton and Tipton','United States (USA) - Indiana - counties of Hamilton and Tipton.',39.92,40.41,-86.25,-85.86,0);
INSERT INTO "area" VALUES('EPSG','4294','USA - Indiana - Hancock and Madison','United States (USA) - Indiana - counties of Hancock and Madison.',39.69,40.38,-85.96,-85.57,0);
INSERT INTO "area" VALUES('EPSG','4295','USA - Indiana - Randolph and Wayne','United States (USA) - Indiana - counties of Randolph and Wayne.',39.71,40.32,-85.23,-84.8,0);
INSERT INTO "area" VALUES('EPSG','4296','USA - Indiana - Henry','United States (USA) - Indiana - Henry county.',39.78,40.08,-85.6,-85.2,0);
INSERT INTO "area" VALUES('EPSG','4297','USA - Indiana - Johnson and Marion','United States (USA) - Indiana - counties of Johnson and Marion.',39.34,39.93,-86.33,-85.93,0);
INSERT INTO "area" VALUES('EPSG','4298','USA - Indiana - Shelby','United States (USA) - Indiana - Shelby county.',39.34,39.7,-85.96,-85.62,0);
INSERT INTO "area" VALUES('EPSG','4299','USA - Indiana - Decatur and Rush','United States (USA) - Indiana - counties of Decatur and Rush.',39.13,39.79,-85.69,-85.29,0);
INSERT INTO "area" VALUES('EPSG','4300','USA - Indiana - Fayette, Franklin, Union','United States (USA) - Indiana - counties of Fayette, Franklin and Union.',39.26,39.79,-85.31,-84.81,0);
INSERT INTO "area" VALUES('EPSG','4301','USA - Indiana - Brown','United States (USA) - Indiana - Brown county.',39.04,39.35,-86.39,-86.07,0);
INSERT INTO "area" VALUES('EPSG','4302','USA - Indiana - Bartholomew','United States (USA) - Indiana - Bartholomew county.',39.03,39.36,-86.09,-85.68,0);
INSERT INTO "area" VALUES('EPSG','4303','USA - Indiana - Jackson','United States (USA) - Indiana - Jackson county.',38.72,39.08,-86.32,-85.79,0);
INSERT INTO "area" VALUES('EPSG','4304','USA - Indiana - Jennings','United States (USA) - Indiana - Jennings county.',38.8,39.2,-85.8,-85.43,0);
INSERT INTO "area" VALUES('EPSG','4305','USA - Indiana - Ripley','United States (USA) - Indiana - Ripley county.',38.91,39.32,-85.45,-85.06,0);
INSERT INTO "area" VALUES('EPSG','4306','USA - Indiana - Dearborn, Ohio, Switzerland','United States (USA) - Indiana - counties of Dearborn, Ohio and Switzerland.',38.68,39.31,-85.21,-84.78,0);
INSERT INTO "area" VALUES('EPSG','4307','USA - Indiana - Harrison and Washington','United States (USA) - Indiana - counties of Harrison and Washington.',37.95,38.79,-86.33,-85.84,0);
INSERT INTO "area" VALUES('EPSG','4308','USA - Indiana - Clark, Floyd, Scott','United States (USA) - Indiana - counties of Clark, Floyd and Scott.',38.17,38.84,-86.04,-85.41,0);
INSERT INTO "area" VALUES('EPSG','4309','USA - Indiana - Jefferson','United States (USA) - Indiana - Jefferson county.',38.58,38.92,-85.69,-85.2,0);
INSERT INTO "area" VALUES('EPSG','4310','USA - Montana - St Mary valley','United States (USA) - Montana - St Mary''s Valley area.',48.55,49.01,-113.97,-113.0,0);
INSERT INTO "area" VALUES('EPSG','4311','USA - Montana - Blackfeet reservation','United States (USA) - Montana - Blackfeet Indian Reservation.',48.0,49.01,-113.84,-112.0,0);
INSERT INTO "area" VALUES('EPSG','4312','USA - Montana - Milk River','United States (USA) - Montana - Milk River area.',47.78,49.01,-112.5,-108.74,0);
INSERT INTO "area" VALUES('EPSG','4313','USA - Montana - Fort Belknap','United States (USA) - Montana - Fort Belknap Indian Reservation area.',47.78,49.01,-110.84,-106.99,0);
INSERT INTO "area" VALUES('EPSG','4314','USA - Montana - Fort Peck higher areas','United States (USA) - Montana - Fort Peck Indian Reservation - higher areas, notably in west and north.',48.01,48.88,-107.57,-104.78,0);
INSERT INTO "area" VALUES('EPSG','4315','USA - Montana - Fort Peck lower areas','United States (USA) - Montana - Fort Peck Indian Reservation - lower areas, notably in south and east.',47.75,49.01,-107.76,-104.04,0);
INSERT INTO "area" VALUES('EPSG','4316','USA - Montana - Crow reservation','United States (USA) - Montana - Crow Indian Reservation.',44.99,46.09,-108.84,-106.66,0);
INSERT INTO "area" VALUES('EPSG','4317','USA - Montana - Three Forks','United States (USA) - Montana - Three Forks area.',45.36,46.59,-112.34,-110.75,0);
INSERT INTO "area" VALUES('EPSG','4318','USA - Montana - Billings','United States (USA) - Montana - Billings area.',44.99,47.41,-109.42,-107.99,0);
INSERT INTO "area" VALUES('EPSG','4319','USA - Wyoming - Wind River reservation','United States (USA) - Wyoming - Wind River Indian Reservation.',42.69,43.86,-109.5,-107.94,0);
INSERT INTO "area" VALUES('EPSG','4320','USA - Wisconsin - Ashland','United States (USA) - Wisconsin - Ashland county.',45.98,47.09,-90.93,-90.3,0);
INSERT INTO "area" VALUES('EPSG','4321','USA - Wisconsin - Bayfield','United States (USA) - Wisconsin - Bayfield county.',46.15,47.01,-91.56,-90.75,0);
INSERT INTO "area" VALUES('EPSG','4322','Oman - west of 54°E','Oman - onshore and offshore west of 54°E.',14.94,19.67,51.99,54.01,0);
INSERT INTO "area" VALUES('EPSG','4323','Oman - 54°E to 60°E','Oman - onshore and offshore between 54°E and 60°E.',14.33,26.74,54.0,60.01,0);
INSERT INTO "area" VALUES('EPSG','4324','Oman - east of 60°E','Oman - offshore east of 60°E.',16.37,24.09,60.0,63.38,0);
INSERT INTO "area" VALUES('EPSG','4325','USA - Wisconsin - Burnett','United States (USA) - Wisconsin - Burnett county.',45.63,46.16,-92.89,-92.03,0);
INSERT INTO "area" VALUES('EPSG','4326','USA - Wisconsin - Douglas','United States (USA) - Wisconsin - Douglas county.',46.15,46.76,-92.3,-91.55,0);
INSERT INTO "area" VALUES('EPSG','4327','USA - Wisconsin - Florence','United States (USA) - Wisconsin - Florence county.',45.71,46.03,-88.69,-88.05,0);
INSERT INTO "area" VALUES('EPSG','4328','USA - Wisconsin - Forest','United States (USA) - Wisconsin - Forest county.',45.37,46.08,-89.05,-88.42,0);
INSERT INTO "area" VALUES('EPSG','4329','USA - Wisconsin - Iron','United States (USA) - Wisconsin - Iron county.',45.98,46.6,-90.56,-89.92,0);
INSERT INTO "area" VALUES('EPSG','4330','USA - Wisconsin - Oneida','United States (USA) - Wisconsin - Oneida county.',45.46,45.91,-90.05,-89.04,0);
INSERT INTO "area" VALUES('EPSG','4331','USA - Wisconsin - Barron','United States (USA) - Wisconsin - Barron county.',45.2,45.65,-92.16,-91.53,0);
INSERT INTO "area" VALUES('EPSG','4332','USA - Wisconsin - Price','United States (USA) - Wisconsin - Price county.',45.37,45.99,-90.68,-90.04,0);
INSERT INTO "area" VALUES('EPSG','4333','USA - Wisconsin - Sawyer','United States (USA) - Wisconsin - Sawyer county.',45.63,46.16,-91.56,-90.67,0);
INSERT INTO "area" VALUES('EPSG','4334','USA - Wisconsin - Vilas','United States (USA) - Wisconsin - Vilas county.',45.85,46.3,-90.05,-88.93,0);
INSERT INTO "area" VALUES('EPSG','4335','USA - Wisconsin - Washburn','United States (USA) - Wisconsin - Washburn county.',45.63,46.16,-92.06,-91.54,0);
INSERT INTO "area" VALUES('EPSG','4336','USA - Wisconsin - Brown','United States (USA) - Wisconsin - Brown county.',44.24,44.68,-88.26,-87.76,0);
INSERT INTO "area" VALUES('EPSG','4337','USA - Wisconsin - Buffalo','United States (USA) - Wisconsin - Buffalo county.',44.02,44.6,-92.09,-91.52,0);
INSERT INTO "area" VALUES('EPSG','4338','USA - Wisconsin - Chippewa','United States (USA) - Wisconsin - Chippewa county.',44.85,45.3,-91.67,-90.92,0);
INSERT INTO "area" VALUES('EPSG','4339','USA - Wisconsin - Clark','United States (USA) - Wisconsin - Clark county.',44.42,45.04,-90.93,-90.31,0);
INSERT INTO "area" VALUES('EPSG','4340','USA - Wisconsin - Door','United States (USA) - Wisconsin - Door county.',44.67,45.43,-87.74,-86.8,0);
INSERT INTO "area" VALUES('EPSG','4341','USA - Wisconsin - Dunn','United States (USA) - Wisconsin - Dunn county.',44.68,45.21,-92.16,-91.64,0);
INSERT INTO "area" VALUES('EPSG','4342','USA - Wisconsin - Eau Claire','United States (USA) - Wisconsin - Eau Claire county.',44.59,44.86,-91.66,-90.92,0);
INSERT INTO "area" VALUES('EPSG','4343','USA - Wisconsin - Jackson','United States (USA) - Wisconsin - Jackson county.',44.07,44.6,-91.17,-90.31,0);
INSERT INTO "area" VALUES('EPSG','4344','USA - Wisconsin - Langlade','United States (USA) - Wisconsin - Langlade county.',45.02,45.48,-89.43,-88.63,0);
INSERT INTO "area" VALUES('EPSG','4345','USA - Wisconsin - Lincoln','United States (USA) - Wisconsin - Lincoln county.',45.11,45.56,-90.05,-89.42,0);
INSERT INTO "area" VALUES('EPSG','4346','USA - Wisconsin - Marathon','United States (USA) - Wisconsin - Marathon county.',44.68,45.13,-90.32,-89.22,0);
INSERT INTO "area" VALUES('EPSG','4347','USA - Wisconsin - Marinette','United States (USA) - Wisconsin - Marinette county.',44.96,45.8,-88.43,-87.48,0);
INSERT INTO "area" VALUES('EPSG','4348','USA - Wisconsin - Menominee','United States (USA) - Wisconsin - Menominee county.',44.85,45.12,-88.99,-88.48,0);
INSERT INTO "area" VALUES('EPSG','4349','USA - Wisconsin - Oconto','United States (USA) - Wisconsin - Oconto county.',44.67,45.38,-88.69,-87.76,0);
INSERT INTO "area" VALUES('EPSG','4350','USA - Wisconsin - Pepin and Pierce','United States (USA) - Wisconsin - counties of Pepin and Pierce.',44.4,44.87,-92.81,-91.65,0);
INSERT INTO "area" VALUES('EPSG','4351','USA - Wisconsin - Polk','United States (USA) - Wisconsin - Polk county.',45.2,45.73,-92.89,-92.15,0);
INSERT INTO "area" VALUES('EPSG','4352','USA - Wisconsin - Portage','United States (USA) - Wisconsin - Portage county.',44.24,44.69,-89.85,-89.22,0);
INSERT INTO "area" VALUES('EPSG','4353','USA - Wisconsin - Rusk','United States (USA) - Wisconsin - Rusk county.',45.29,45.64,-91.55,-90.67,0);
INSERT INTO "area" VALUES('EPSG','4354','USA - Wisconsin - Shawano','United States (USA) - Wisconsin - Shawano county.',44.58,45.03,-89.23,-88.24,0);
INSERT INTO "area" VALUES('EPSG','4355','USA - Wisconsin - St. Croix','United States (USA) - Wisconsin - St. Croix county.',44.85,45.22,-92.81,-92.13,0);
INSERT INTO "area" VALUES('EPSG','4356','USA - Wisconsin - Taylor','United States (USA) - Wisconsin - Taylor county.',45.03,45.39,-90.93,-90.04,0);
INSERT INTO "area" VALUES('EPSG','4357','USA - Wisconsin - Trempealeau','United States (USA) - Wisconsin - Trempealeau county.',43.98,44.6,-91.62,-91.15,0);
INSERT INTO "area" VALUES('EPSG','4358','USA - Wisconsin - Waupaca','United States (USA) - Wisconsin - Waupaca county.',44.24,44.69,-89.23,-88.6,0);
INSERT INTO "area" VALUES('EPSG','4359','USA - Wisconsin - Wood','United States (USA) - Wisconsin - Wood county.',44.24,44.69,-90.32,-89.72,0);
INSERT INTO "area" VALUES('EPSG','4360','USA - Wisconsin - Adams and Juneau','United States (USA) - Wisconsin - counties of Adams and Juneau.',43.64,44.25,-90.32,-89.59,0);
INSERT INTO "area" VALUES('EPSG','4361','USA - Wisconsin - Calumet, Fond du Lac, Outagamie and Winnebago','United States (USA) - Wisconsin - counties of Calumet, Fond du Lac, Outagamie and Winnebago.',43.54,44.6,-88.89,-88.04,0);
INSERT INTO "area" VALUES('EPSG','4362','USA - Wisconsin - Columbia','United States (USA) - Wisconsin - Columbia county.',43.28,43.65,-89.79,-89.0,0);
INSERT INTO "area" VALUES('EPSG','4363','USA - Wisconsin - Crawford','United States (USA) - Wisconsin - Crawford county.',42.98,43.43,-91.22,-90.66,0);
INSERT INTO "area" VALUES('EPSG','4364','USA - Wisconsin - Dane','United States (USA) - Wisconsin - Dane county.',42.84,43.3,-89.84,-89.0,0);
INSERT INTO "area" VALUES('EPSG','4365','USA - Wisconsin - Dodge and Jefferson','United States (USA) - Wisconsin - counties of Dodge and Jefferson.',42.84,43.64,-89.02,-88.4,0);
INSERT INTO "area" VALUES('EPSG','4366','USA - Wisconsin - Grant','United States (USA) - Wisconsin - Grant county.',42.5,43.22,-91.16,-90.42,0);
INSERT INTO "area" VALUES('EPSG','4367','USA - Wisconsin - Green and Lafayette','United States (USA) - Wisconsin - counties of Green and Lafayette.',42.5,42.86,-90.43,-89.36,0);
INSERT INTO "area" VALUES('EPSG','4368','USA - Wisconsin - Green Lake and Marquette','United States (USA) - Wisconsin - counties of Green Lake and Marquette.',43.63,43.99,-89.6,-88.88,0);
INSERT INTO "area" VALUES('EPSG','4369','USA - Wisconsin - Iowa','United States (USA) - Wisconsin - Iowa county.',42.81,43.21,-90.43,-89.83,0);
INSERT INTO "area" VALUES('EPSG','4370','USA - Wisconsin - Kenosha, Milwaukee, Ozaukee and Racine','United States (USA) - Wisconsin - counties of Kenosha, Milwaukee, Ozaukee and Racine.',42.49,43.55,-88.31,-87.75,0);
INSERT INTO "area" VALUES('EPSG','4371','USA - Wisconsin - Kewaunee, Manitowoc and Sheboygan','United States (USA) - Wisconsin - counties of Kewaunee, Manitowoc and Sheboygan.',43.54,44.68,-88.17,-87.37,0);
INSERT INTO "area" VALUES('EPSG','4372','USA - Wisconsin - La Crosse','United States (USA) - Wisconsin - La Crosse county.',43.72,44.1,-91.43,-90.91,0);
INSERT INTO "area" VALUES('EPSG','4373','USA - Wisconsin - Monroe','United States (USA) - Wisconsin - Monroe county.',43.72,44.17,-90.98,-90.31,0);
INSERT INTO "area" VALUES('EPSG','4374','USA - Wisconsin - Richland','United States (USA) - Wisconsin - Richland county.',43.16,43.56,-90.68,-90.19,0);
INSERT INTO "area" VALUES('EPSG','4375','USA - Wisconsin - Rock','United States (USA) - Wisconsin - Rock county.',42.49,42.85,-89.37,-88.77,0);
INSERT INTO "area" VALUES('EPSG','4376','USA - Wisconsin - Sauk','United States (USA) - Wisconsin - Sauk county.',43.14,43.65,-90.32,-89.59,0);
INSERT INTO "area" VALUES('EPSG','4377','USA - Wisconsin - Vernon','United States (USA) - Wisconsin - Vernon county.',43.42,43.74,-91.28,-90.31,0);
INSERT INTO "area" VALUES('EPSG','4378','USA - Wisconsin - Walworth','United States (USA) - Wisconsin - Walworth county.',42.49,42.85,-88.78,-88.3,0);
INSERT INTO "area" VALUES('EPSG','4379','USA - Wisconsin - Washington','United States (USA) - Wisconsin - Washington county.',43.19,43.55,-88.42,-88.03,0);
INSERT INTO "area" VALUES('EPSG','4380','USA - Wisconsin - Waukesha','United States (USA) - Wisconsin - Waukesha county.',42.84,43.2,-88.55,-88.06,0);
INSERT INTO "area" VALUES('EPSG','4381','USA - Wisconsin - Waushara','United States (USA) - Wisconsin - Waushara county.',43.98,44.25,-89.6,-88.88,0);
INSERT INTO "area" VALUES('EPSG','4382','Algeria - Ain Tsila','Algeria - Ain Tsila field.',27.4,28.1,7.66,8.27,0);
INSERT INTO "area" VALUES('EPSG','4383','Papua New Guinea - onshore south of 5°S and west of 144°E','Papua New Guinea - onshore south of 5°S and west of 144°E.',-9.35,-5.0,140.85,144.01,0);
INSERT INTO "area" VALUES('EPSG','4384','Papua New Guinea - 0°N to 12°S and 140°E to 158°E','Papua New Guinea - between 0°N and 12°S and 140°E and 158°E - onshore and offshore.',-12.0,0.01,140.0,158.01,0);
INSERT INTO "area" VALUES('EPSG','4385','Kyrgyzstan - west of 70°01''E','Kyrgyzstan - west of 70°01''E.',39.51,40.22,69.24,70.02,0);
INSERT INTO "area" VALUES('EPSG','4386','Kyrgyzstan - 70°01''E to 73°01''E','Kyrgyzstan - between 70°01''E and 73°01''E.',39.19,42.83,70.01,73.02,0);
INSERT INTO "area" VALUES('EPSG','4387','Kyrgyzstan - 73°01''E to 76°01''E','Kyrgyzstan - between 73°01''E and 76°01''E.',39.35,43.22,73.01,76.02,0);
INSERT INTO "area" VALUES('EPSG','4388','Kyrgyzstan - 76°01''E to 79°01''E','Kyrgyzstan - between 76°01''E and 79°01''E.',40.35,43.0,76.01,79.02,0);
INSERT INTO "area" VALUES('EPSG','4389','Kyrgyzstan - east of 79°01''E','Kyrgyzstan - east of 79°01''E.',41.66,42.8,79.01,80.29,0);
INSERT INTO "area" VALUES('EPSG','4390','UK - Britain and UKCS 49°46''N to 61°01''N, 7°33''W to 3°33''E','United Kingdom (UK) - offshore to boundary of UKCS within 49°46''N to 61°01''N and 7°33''W to 3°33''E; onshore Great Britain (England, Wales and Scotland). Isle of Man onshore.',49.75,61.14,-9.2,2.88,0);
INSERT INTO "area" VALUES('EPSG','4391','UK - offshore 49°46''N to 61°01''N, 7°33''W to 3°33''E','United Kingdom (UK) – offshore between 2km from shore and boundary of UKCS within 49°46''N to 61°01''N and 7°33''W to 3°33''E.',49.75,61.14,-9.2,2.88,0);
INSERT INTO "area" VALUES('EPSG','4392','India - northeast','India - Arunachal Pradesh, Assam, Manipur, Meghalaya, Mizoram, Nagaland and Tripura.',21.94,29.47,89.69,97.42,0);
INSERT INTO "area" VALUES('EPSG','4393','To be specified','Description of the extent of the CRS.',-90.0,90.0,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','4394','India - Andhra Pradesh and Telangana','India - Andhra Pradesh; Telangana; Yanam area of Pudacherry territory.',12.61,19.92,76.75,84.81,0);
INSERT INTO "area" VALUES('EPSG','4395','India - Arunachal Pradesh','India - Arunachal Pradesh.',26.65,29.47,91.55,97.42,0);
INSERT INTO "area" VALUES('EPSG','4396','India - Assam','India - Assam.',24.13,27.98,89.69,96.03,0);
INSERT INTO "area" VALUES('EPSG','4397','India - Bihar','India - Bihar.',24.28,27.86,83.31,88.3,0);
INSERT INTO "area" VALUES('EPSG','4398','India - Chhattisgarh','India - Chhattisgarh.',17.78,24.11,80.23,84.39,0);
INSERT INTO "area" VALUES('EPSG','4399','India - Goa','India - Goa.',14.86,15.8,73.61,74.35,0);
INSERT INTO "area" VALUES('EPSG','4400','India - Gujarat','India - Gujarat and union territories of Daman, Diu, Dadra and Nagar Haveli.',20.05,24.71,68.13,74.48,0);
INSERT INTO "area" VALUES('EPSG','4401','India - Haryana','India - Haryana including Chandigarh.',27.65,30.94,74.46,77.6,0);
INSERT INTO "area" VALUES('EPSG','4402','India - Himachal Pradesh','India - Himachal Pradesh.',30.38,33.26,75.57,79.0,0);
INSERT INTO "area" VALUES('EPSG','4403','India - Jammu and Kashmir','India - Jammu and Kashmir.',32.27,35.51,73.76,79.57,0);
INSERT INTO "area" VALUES('EPSG','4404','India - Jharkhand','India - Jharkhand.',21.96,25.35,83.32,87.98,0);
INSERT INTO "area" VALUES('EPSG','4405','India - Karnataka','India - Karnataka.',11.57,18.46,74.0,78.58,0);
INSERT INTO "area" VALUES('EPSG','4406','India - Kerala','India - Kerala; Mayyazhi (Mahe) area of Pudacherry territory.',8.25,12.8,74.81,77.4,0);
INSERT INTO "area" VALUES('EPSG','4407','India - Madhya Pradesh','India - Madhya Pradesh.',21.07,26.88,74.03,82.81,0);
INSERT INTO "area" VALUES('EPSG','4408','India - Maharashtra','India - Maharashtra.',15.6,22.04,72.6,80.9,0);
INSERT INTO "area" VALUES('EPSG','4409','India - Manipur','India - Manipur.',23.84,25.7,92.97,94.76,0);
INSERT INTO "area" VALUES('EPSG','4410','India - Meghalaya','India - Meghalaya.',25.03,26.12,89.82,92.81,0);
INSERT INTO "area" VALUES('EPSG','4411','India - Mizoram','India - Mizoram.',21.94,24.53,92.25,93.45,0);
INSERT INTO "area" VALUES('EPSG','4412','India - Nagaland','India - Nagaland.',25.2,27.05,93.33,95.25,0);
INSERT INTO "area" VALUES('EPSG','4413','India - Odisha','India - Odisha (Orissa).',17.8,22.57,81.38,87.5,0);
INSERT INTO "area" VALUES('EPSG','4414','India - Punjab','India - Punjab including Chandigarh.',29.54,32.58,73.87,76.94,0);
INSERT INTO "area" VALUES('EPSG','4415','India - Rajasthan','India - Rajasthan.',23.06,30.2,69.48,78.27,0);
INSERT INTO "area" VALUES('EPSG','4416','India - Sikkim','India - Sikkim.',27.08,28.14,88.01,88.92,0);
INSERT INTO "area" VALUES('EPSG','4417','India - Tamil Nadu','India - Tamil Nadu; Pudacherry and Karaikal areas of Pudacherry territory.',8.02,13.59,76.22,80.4,0);
INSERT INTO "area" VALUES('EPSG','4418','India - Tripura','India - Tripura.',22.94,24.54,91.15,92.34,0);
INSERT INTO "area" VALUES('EPSG','4419','India - Uttar Pradesh','India - Uttar Pradesh.',23.87,30.42,77.08,84.64,0);
INSERT INTO "area" VALUES('EPSG','4420','India - Uttarakhand','India - Uttarakhand (Uttaranchal).',28.71,31.48,77.56,81.02,0);
INSERT INTO "area" VALUES('EPSG','4421','India - West Bengal','India - West Bengal.',21.49,27.23,85.82,89.88,0);
INSERT INTO "area" VALUES('EPSG','4422','India - Delhi','India - Delhi national capital territory.',28.4,28.89,76.83,77.34,0);
INSERT INTO "area" VALUES('EPSG','4423','India - Andaman and Nicobar Islands','India - Andaman and Nicobar Islands.',6.7,13.73,92.15,94.33,0);
INSERT INTO "area" VALUES('EPSG','4424','India - Lakshadweep','India - Lakshadweep (Laccadive, Minicoy, and Aminidivi Islands).',8.21,11.76,72.04,73.76,0);
INSERT INTO "area" VALUES('EPSG','4425','Papua New Guinea - onshore - Central province and Gulf province east of 144°E','Papua New Guinea - onshore - Gulf province east of 144°24''E, Central province and National Capital District.',-10.42,-6.67,144.4,149.67,0);
INSERT INTO "area" VALUES('EPSG','4426','Bulgaria - east of 30°E','Bulgaria - offshore east of 30°E.',42.56,43.67,30.0,31.35,0);
INSERT INTO "area" VALUES('EPSG','4427','Bulgaria - 24°E to 30°E','Bulgaria - onshore east of 24°E, offshore west of 30°E.',41.24,44.15,24.0,30.01,0);
INSERT INTO "area" VALUES('EPSG','4428','Bulgaria - west of 24°E','Bulgaria - west of 24°E.',41.32,44.23,22.36,24.0,0);
INSERT INTO "area" VALUES('EPSG','4429','Ukraine - 25°E to 28°E','Ukraine - between 25°E and 28°E.',47.72,51.96,25.0,28.01,0);
INSERT INTO "area" VALUES('EPSG','4430','Ukraine - 28°E to 31°E onshore','Ukraine - between 28°E and 31°E, onshore.',45.18,52.09,28.0,31.01,0);
INSERT INTO "area" VALUES('EPSG','4431','Ukraine - 31°E to 34°E onshore','Ukraine - between 31°E and 34°E, onshore.',44.32,52.38,31.0,34.01,0);
INSERT INTO "area" VALUES('EPSG','4432','Ukraine - 34°E to 37°E onshore','Ukraine - between 34°E and 37°E, onshore.',44.33,52.25,34.0,37.01,0);
INSERT INTO "area" VALUES('EPSG','4433','Ukraine - 37°E to 40°E onshore','Ukraine - between 37°E and 40°E, onshore.',46.8,50.44,37.0,40.01,0);
INSERT INTO "area" VALUES('EPSG','4434','Ukraine - east of 40°E','Ukraine - east of 40°E.',48.8,49.62,40.0,40.18,0);
INSERT INTO "area" VALUES('EPSG','4435','Ukraine - west of 25°E','Ukraine - west of 25°E.',47.71,51.92,22.15,25.01,0);
INSERT INTO "area" VALUES('EPSG','4436','Australia - Western Australia - Kalgoorlie','Australia - Western Australia - Kalgoorlie area.',-32.25,-28.75,121.0,121.84,0);
INSERT INTO "area" VALUES('EPSG','4437','Australia - Western Australia - Busselton','Australia - Western Australia - Busselton area onshore below 250m AHD.',-33.75,-33.4,115.18,115.87,0);
INSERT INTO "area" VALUES('EPSG','4438','Australia - Western Australia - Barrow','Australia - Western Australia - Barrow Island and Onslow area onshore.',-22.2,-20.21,114.9,115.59,0);
INSERT INTO "area" VALUES('EPSG','4439','Australia - Western Australia - Albany','Australia - Western Australia - Albany area onshore below 190m AHD.',-35.21,-34.75,117.55,118.22,0);
INSERT INTO "area" VALUES('EPSG','4440','Australia - Western Australia - Jurien Bay','Australia - Western Australia - Jurien Bay area onshore below 200m AHD.',-30.74,-29.08,114.83,115.34,0);
INSERT INTO "area" VALUES('EPSG','4441','Australia - Western Australia - Broome','Australia - Western Australia - Broome area onshore below 130m AHD.',-18.09,-16.75,122.08,122.62,0);
INSERT INTO "area" VALUES('EPSG','4442','Australia - Western Australia - Carnarvon','Australia - Western Australia - Carnarvon area onshore.',-25.5,-23.0,113.33,114.0,0);
INSERT INTO "area" VALUES('EPSG','4443','Australia - Western Australia - Collie','Australia - Western Australia - Collie area between 50m and 310m AHD.',-34.67,-33.25,115.73,116.4,0);
INSERT INTO "area" VALUES('EPSG','4444','Australia - Western Australia - Kalbarri','Australia - Western Australia - Kalbarri area onshore.',-28.5,-27.16,113.9,114.75,0);
INSERT INTO "area" VALUES('EPSG','4445','Australia - Western Australia - Esperance','Australia - Western Australia - Esperance area onshore.',-34.5,-33.33,121.56,122.2,0);
INSERT INTO "area" VALUES('EPSG','4446','Albania - north of 41°18''N and east of 19°09''E','Albania - north of 41°18''N and east of 19°09''E, onshore and offshore.',41.3,42.67,19.14,20.63,0);
INSERT INTO "area" VALUES('EPSG','4447','DR Congo (Zaire) - offshore','The Democratic Republic of the Congo (Zaire) - offshore.',-6.04,-5.79,11.79,12.37,0);
INSERT INTO "area" VALUES('EPSG','4448','Australia - Western Australia - Exmouth','Australia - Western Australia - Exmouth area onshore below 160m AHD.',-22.42,-21.75,113.75,114.25,0);
INSERT INTO "area" VALUES('EPSG','4449','Australia - Western Australia - Geraldton','Australia - Western Australia - Geraldton area onshore below 195m AHD.',-29.1,-28.48,114.51,115.0,0);
INSERT INTO "area" VALUES('EPSG','4450','USA - Arizona - Pima county west','United States (USA) - Arizona - Pima county - west of the township line between ranges R2W and R3W, Gila and Salt River Meridian (west of approximately 112°31''W).',31.8,32.51,-113.33,-112.51,0);
INSERT INTO "area" VALUES('EPSG','4451','Australia - Western Australia - Karratha','Australia - Western Australia - Karratha area onshore.',-20.92,-20.25,116.58,117.25,0);
INSERT INTO "area" VALUES('EPSG','4452','Australia - Western Australia - Kununurra','Australia - Western Australia - Kununurra area onshore below 200m AHD.',-16.75,-14.75,128.5,129.0,0);
INSERT INTO "area" VALUES('EPSG','4453','Australia - Western Australia - Lancelin','Australia - Western Australia - Lancelin area onshore below 200m AHD.',-31.49,-30.71,115.15,115.62,0);
INSERT INTO "area" VALUES('EPSG','4454','Greenland - 58°N to 85°N','Greenland - onshore and offshore between 58°N and 85°N and west of 7°W.',58.0,85.01,-75.0,-6.99,0);
INSERT INTO "area" VALUES('EPSG','4455','Europe - Upper Austria, Salzburg and Bohemia','Austria - Upper Austria and Salzburg provinces. Czechia - Bohemia.',46.93,51.06,12.07,16.83,0);
INSERT INTO "area" VALUES('EPSG','4456','Europe - Lower Austria and Moravia','Austria - Lower Austria. Czechia - Moravia and Czech Silesia.',47.42,50.45,14.41,18.86,0);
INSERT INTO "area" VALUES('EPSG','4457','Australia - Western Australia - Margaret River','Australia - Western Australia - Margaret River area onshore below 200m AHD.',-34.42,-33.51,114.96,115.24,0);
INSERT INTO "area" VALUES('EPSG','4458','USA - Oregon - Riley-Lakeview','United States (USA) - Oregon - Riley-Lakeview area.',41.88,43.45,-120.97,-119.15,0);
INSERT INTO "area" VALUES('EPSG','4459','USA - Oregon - Burns-Harper','United States (USA) - Oregon - Burns-Harper area.',43.49,44.19,-118.61,-117.49,0);
INSERT INTO "area" VALUES('EPSG','4460','USA - Arizona - Pima county central','United States (USA) - Arizona - Pima county - between the township line between ranges R2W and R3W and the township line between ranges R7E and R8E, Gila and Salt River Meridian (between approximately 112°31''W and 111°34''W).',31.5,32.51,-112.52,-111.56,0);
INSERT INTO "area" VALUES('EPSG','4461','Greenland - 59°N to 84°N','Greenland - onshore and offshore between 59°N and 84°N and west of 10°W.',59.0,84.01,-75.0,-10.0,0);
INSERT INTO "area" VALUES('EPSG','4462','Australia - Western Australia - Perth','Australia - Western Australia - Perth area onshore below 165m AHD.',-33.42,-31.33,115.44,116.09,0);
INSERT INTO "area" VALUES('EPSG','4463','USA - Oregon - Siskiyou Pass','United States (USA) - Oregon - Siskiyou Pass area.',41.95,42.46,-122.71,-121.96,0);
INSERT INTO "area" VALUES('EPSG','4464','USA - onshore - AZ MI MT ND OR SC','United States (USA) - onshore - Arizona; Michigan; Montana; North Dakota; Oregon; South Carolina.',31.33,49.01,-124.6,-78.52,0);
INSERT INTO "area" VALUES('EPSG','4465','USA - Oregon - Canyon City-Burns','United States (USA) - Oregon - Canyon City-Burns area.',43.52,44.36,-119.22,-118.52,0);
INSERT INTO "area" VALUES('EPSG','4466','Australia - Western Australia - Port Hedland','Australia - Western Australia - Port Hedland area onshore.',-20.79,-20.1,118.25,118.97,0);
INSERT INTO "area" VALUES('EPSG','4467','Trinidad and Tobago - offshore west of 60°W','Trinidad and Tobago - offshore west of 60°W.',9.83,12.34,-62.09,-59.99,0);
INSERT INTO "area" VALUES('EPSG','4468','Trinidad and Tobago - offshore east of 60°W','Trinidad and Tobago - offshore east of 60°W.',9.95,12.19,-60.0,-57.28,0);
INSERT INTO "area" VALUES('EPSG','4469','Angola - onshore','Angola - onshore including Cabinda.',-18.02,-4.38,11.67,24.09,0);
INSERT INTO "area" VALUES('EPSG','4470','USA - Oregon - Ukiah-Fox','United States (USA) - Oregon - Ukiah-Fox area.',44.52,45.21,-119.35,-118.64,0);
INSERT INTO "area" VALUES('EPSG','4471','USA - Oregon - Coast Range North','United States (USA) - Oregon - Coast Range North area.',45.4,45.98,-123.81,-123.01,0);
INSERT INTO "area" VALUES('EPSG','4472','USA - Arizona - Pima county east','United States (USA) - Arizona - Pima county - east of the township line between ranges R7E and R8E, Gila and Salt River Meridian (east of approximately 111°34''W).',31.43,32.52,-111.57,-110.44,0);
INSERT INTO "area" VALUES('EPSG','4473','USA - Arizona - Pima county Mt. Lemmon','United States (USA) - Arizona - Pima county - Catalina Highway corridor between Mt. Lemmon and Willow Canyon.',32.33,32.49,-110.87,-110.61,0);
INSERT INTO "area" VALUES('EPSG','4474','USA - Oregon - Dayville-Prairie City','United States (USA) - Oregon - Dayville-Prairie City area.',44.24,44.94,-119.89,-118.61,0);
INSERT INTO "area" VALUES('EPSG','4475','USA - Oregon - Denio-Burns','United States (USA) - Oregon - Denio-Burns area.',41.88,43.54,-119.41,-117.67,0);
INSERT INTO "area" VALUES('EPSG','4476','USA - Oregon - Halfway','United States (USA) - Oregon - Halfway area.',44.61,45.28,-117.61,-116.63,0);
INSERT INTO "area" VALUES('EPSG','4477','USA - Oregon - Medford-Diamond Lake','United States (USA) - Oregon - Medford-Diamond Lake area.',42.53,43.34,-122.73,-121.71,0);
INSERT INTO "area" VALUES('EPSG','4478','USA - Oregon - Mitchell','United States (USA) - Oregon - Mitchell area.',44.38,44.78,-120.56,-119.82,0);
INSERT INTO "area" VALUES('EPSG','4479','USA - Oregon - North Central','United States (USA) - Oregon - North Central area.',44.89,45.95,-121.79,-119.03,0);
INSERT INTO "area" VALUES('EPSG','4480','USA - Oregon - Wallowa','United States (USA) - Oregon - Wallowa area.',45.27,46.05,-118.16,-116.42,0);
INSERT INTO "area" VALUES('EPSG','4481','USA - Oregon - Ochoco Summit','United States (USA) - Oregon - Ochoco Summit area.',44.21,44.61,-121.01,-120.31,0);
INSERT INTO "area" VALUES('EPSG','4482','USA - Oregon - Owyhee','United States (USA) - Oregon - Owyhee area.',41.88,43.54,-118.14,-116.85,0);
INSERT INTO "area" VALUES('EPSG','4483','USA - Oregon - Pilot Rock-Ukiah','United States (USA) - Oregon - Pilot Rock-Ukiah area.',44.99,46.04,-119.65,-118.11,0);
INSERT INTO "area" VALUES('EPSG','4484','USA - Oregon - Prairie City-Brogan','United States (USA) - Oregon - Prairie City-Brogan area.',44.16,45.02,-118.77,-117.48,0);
INSERT INTO "area" VALUES('EPSG','4485','USA - Nevada - Las Vegas','United States (USA) - Nevada - Las Vegas area below approximately 3000 feet.',35.88,36.43,-115.5,-114.71,0);
INSERT INTO "area" VALUES('EPSG','4486','USA - Oregon - Warner Highway','United States (USA) - Oregon - Warner Highway area.',41.95,42.43,-120.42,-119.3,0);
INSERT INTO "area" VALUES('EPSG','4487','USA - Nevada - Las Vegas high elevation','United States (USA) - Nevada - Las Vegas area above approximately 2850 feet.',35.88,36.43,-115.5,-114.71,0);
INSERT INTO "area" VALUES('EPSG','4488','USA - Oregon - Willamette Pass','United States (USA) - Oregon - Willamette Pass area.',42.99,44.18,-122.26,-121.48,0);
INSERT INTO "area" VALUES('EPSG','4489','Antarctica - Adelie Land coastal area west of 138°E','Antarctica - Adelie Land - coastal area between 136°E and 138°E.',-66.73,-65.61,136.0,138.01,0);
INSERT INTO "area" VALUES('EPSG','4490','Germany - Hamburg','Germany - Hamburg, including Neuwerk, Nigehörn, Scharhörn and surrounding maritime area.',53.36,53.99,8.33,10.41,0);
INSERT INTO "area" VALUES('EPSG','4491','Australia - Queensland - Weipa','Australia - Queensland - Weipa area between 141°30''E and 142°30''E.',-13.5,-11.49,141.5,142.51,0);
INSERT INTO "area" VALUES('EPSG','4492','Antarctica - Adelie Land coastal area east of 138°E','Antarctica - Adelie Land - coastal area between 138°E and 142°E.',-67.13,-66.1,138.0,142.0,0);
INSERT INTO "area" VALUES('EPSG','4493','Australia Christmas and Cocos - onshore','Australia - Australian Capital Territory, New South Wales, Northern Territory, Queensland, South Australia, Tasmania, Western Australia and Victoria - onshore. Christmas Island - onshore. Cocos and Keeling Islands - onshore.',-43.7,-9.86,96.76,153.69,0);
INSERT INTO "area" VALUES('EPSG','4494','USA - Kansas - Hays','United States (USA) - Kansas - counties of Ellis; Graham; Norton; Phillips; Rooks; Trego.',38.69,40.01,-100.19,-99.03,0);
INSERT INTO "area" VALUES('EPSG','4495','USA - Kansas - Goodland','United States (USA) - Kansas - counties of Cheyenne; Sherman; Wallace.',38.69,40.01,-102.06,-101.38,0);
INSERT INTO "area" VALUES('EPSG','4496','USA - Kansas - Colby','United States (USA) - Kansas - counties of Logan; Rawlins; Thomas.',38.69,40.01,-101.49,-100.71,0);
INSERT INTO "area" VALUES('EPSG','4497','USA - Kansas - Oberlin','United States (USA) - Kansas - counties of Decatur; Gove; Sheridan.',38.69,40.01,-100.82,-100.14,0);
INSERT INTO "area" VALUES('EPSG','4498','USA - Kansas - Great Bend','United States (USA) - Kansas - counties of Barton; Osborne; Russell; Smith.',38.26,40.01,-99.07,-98.47,0);
INSERT INTO "area" VALUES('EPSG','4499','USA - Kansas - Beloit','United States (USA) - Kansas - counties of Ellsworth; Jewell; Lincoln; Mitchell; Rice.',38.15,40.01,-98.51,-97.92,0);
INSERT INTO "area" VALUES('EPSG','4500','USA - Kansas - Salina','United States (USA) - Kansas - counties of Clay; Cloud; Dickinson; Marion; McPherson; Ottawa; Republic; Saline; Washington.',38.08,40.01,-97.94,-96.8,0);
INSERT INTO "area" VALUES('EPSG','4501','USA - Kansas - Manhattan','United States (USA) - Kansas - counties of Geary; Pottawatomie; Riley; Wabaunsee.',38.73,39.57,-96.97,-95.94,0);
INSERT INTO "area" VALUES('EPSG','4502','USA - Kansas - Emporia','United States (USA) - Kansas - counties of Chase; Lyon; Morris.',38.08,38.88,-96.94,-95.94,0);
INSERT INTO "area" VALUES('EPSG','4503','USA - Kansas - Atchison','United States (USA) - Kansas - counties of Atchison; Brown; Doniphan; Jackson; Marshall; Nemaha.',39.21,40.01,-96.81,-94.85,0);
INSERT INTO "area" VALUES('EPSG','4504','USA - Kansas - Kansas City','United States (USA) - Kansas - counties of Douglas; Jefferson; Johnson; Leavenworth; Shawnee; Wyandotte.',38.73,39.43,-96.04,-94.58,0);
INSERT INTO "area" VALUES('EPSG','4505','USA - Kansas - Ulysses','United States (USA) - Kansas - counties of Grant; Greeley; Hamilton; Kearny; Morton; Stanton; Stevens; Wichita.',36.99,38.71,-102.05,-101.06,0);
INSERT INTO "area" VALUES('EPSG','4506','USA - Kansas - Garden City','United States (USA) - Kansas - counties of Finney; Gray; Haskell; Lane; Meade; Scott; Seward.',36.99,38.71,-101.13,-100.08,0);
INSERT INTO "area" VALUES('EPSG','4507','USA - Kansas - Dodge City','United States (USA) - Kansas - counties of Clark; Ford; Hodgeman; Ness.',36.99,38.7,-100.25,-99.54,0);
INSERT INTO "area" VALUES('EPSG','4508','USA - Kansas - Larned','United States (USA) - Kansas - counties of Comanche; Edwards; Kiowa; Pawnee; Rush.',36.99,38.7,-99.59,-98.91,0);
INSERT INTO "area" VALUES('EPSG','4509','USA - Kansas - Pratt','United States (USA) - Kansas - counties of Barber; Pratt; Stafford.',36.99,38.27,-99.03,-98.34,0);
INSERT INTO "area" VALUES('EPSG','4510','USA - Kansas - Wichita','United States (USA) - Kansas - counties of Butler; Harvey; Kingman; Reno; Sedgwick.',37.38,38.18,-98.48,-96.52,0);
INSERT INTO "area" VALUES('EPSG','4511','USA - Kansas - Arkansas City','United States (USA) - Kansas - counties of Cowley; Harper; Sumner.',36.99,37.48,-98.35,-96.52,0);
INSERT INTO "area" VALUES('EPSG','4512','USA - Kansas - Coffeyville','United States (USA) - Kansas - counties of Chautauqua; Coffey; Elk; Greenwood; Montgomery; Osage; Wilson; Woodson.',36.99,38.88,-96.53,-95.5,0);
INSERT INTO "area" VALUES('EPSG','4513','USA - Kansas - Pittsburg','United States (USA) - Kansas - counties of Allen; Anderson; Bourbon; Cherokee; Crawford; Franklin; Labette; Linn; Miami; Neosho.',36.99,38.74,-95.53,-94.6,0);
INSERT INTO "area" VALUES('EPSG','4514','Pacific - Guam and NMI west of 144°E','Guam and Northern Mariana Islands; offshore west of 144°E.',10.95,23.9,141.19,144.01,0);
INSERT INTO "area" VALUES('EPSG','4515','USA - FBN','American Samoa - Tutuila, Aunu''u, Ofu, Olesega, Ta''u and Rose islands - onshore. Guam - onshore. Northern Mariana Islands - onshore. Puerto Rico - onshore. United States (USA) – CONUS - Alabama; Arizona; Arkansas; California; Colorado; Connecticut; Delaware; Florida; Georgia; Idaho; Illinois; Indiana; Iowa; Kansas; Kentucky; Louisiana; Maine; Maryland; Massachusetts; Michigan; Minnesota; Mississippi; Missouri; Montana; Nebraska; Nevada; New Hampshire; New Jersey; New Mexico; New York; North Carolina; North Dakota; Ohio; Oklahoma; Oregon; Pennsylvania; Rhode Island; South Carolina; South Dakota; Tennessee; Texas; Utah; Vermont; Virginia; Washington; West Virginia; Wisconsin; Wyoming - onshore plus Gulf of Mexico offshore continental shelf (GoM OCS). US Virgin Islands - onshore.',-14.59,49.38,144.58,-64.51,0);
INSERT INTO "area" VALUES('EPSG','4516','USA - CONUS and GoM','United States (USA) - CONUS onshore - Alabama; Arizona; Arkansas; California; Colorado; Connecticut; Delaware; Florida; Georgia; Idaho; Illinois; Indiana; Iowa; Kansas; Kentucky; Louisiana; Maine; Maryland; Massachusetts; Michigan; Minnesota; Mississippi; Missouri; Montana; Nebraska; Nevada; New Hampshire; New Jersey; New Mexico; New York; North Carolina; North Dakota; Ohio; Oklahoma; Oregon; Pennsylvania; Rhode Island; South Carolina; South Dakota; Tennessee; Texas; Utah; Vermont; Virginia; Washington; West Virginia; Wisconsin; Wyoming. US Gulf of Mexico offshore continental shelf (GoM OCS).',23.82,49.38,-124.79,-66.91,0);
INSERT INTO "area" VALUES('EPSG','4517','Canada - NAD27','Canada - onshore - Alberta; British Columbia; Manitoba; New Brunswick; Newfoundland and Labrador; Northwest Territories; Nova Scotia; Nunavut; Ontario; Prince Edward Island; Quebec; Saskatchewan; Yukon; offshore east coast.',40.04,83.17,-141.01,-47.74,0);
INSERT INTO "area" VALUES('EPSG','4518','Pacific - Guam and NMI east of 144°E','Guam and Northern Mariana Islands; onshore and offshore east of 144°E.',11.05,23.9,144.0,149.55,0);
INSERT INTO "area" VALUES('EPSG','4519','Algeria - 32°N to 34°39''N','Algeria - 35.6 grads to 38.5 grads North (32°N to 34°39''N).',31.99,34.66,-2.95,9.09,0);
INSERT INTO "area" VALUES('EPSG','4520','World centred on 90°W','World centred on the Americas.',-90.0,90.0,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','4521','Northern Mariana Islands - onshore','Northern Mariana Islands - onshore.',14.06,20.61,144.83,146.12,0);
INSERT INTO "area" VALUES('EPSG','4522','Finland - mainland south of 66°N','Finland - onshore mainland south of approximately 66°N.',59.75,66.73,20.95,31.59,0);
INSERT INTO "area" VALUES('EPSG','4523','World centred on 150°E','World centred on Asia-Pacific.',-90.0,90.0,-180.0,180.0,0);
INSERT INTO "area" VALUES('EPSG','4524','Saudi Arabia - west of 36°E','Saudi Arabia - onshore and offshore - west of 36°E.',24.92,29.38,34.44,36.01,0);
INSERT INTO "area" VALUES('EPSG','4525','Pacific - Guam and NMI - onshore','Guam - onshore. Northern Mariana Islands - onshore.',13.18,20.61,144.58,146.12,0);
INSERT INTO "area" VALUES('EPSG','4526','Saudi Arabia - 36°E to 42°E','Saudi Arabia - onshore and offshore - between 36°E and 42°E.',16.29,32.16,36.0,42.0,0);
INSERT INTO "area" VALUES('EPSG','4527','Saudi Arabia - 42°E to 48°E','Saudi Arabia - onshore and offshore - between of 42°E and 48°E.',15.61,31.15,41.99,48.0,0);
INSERT INTO "area" VALUES('EPSG','4528','Saudi Arabia - 48°E to 54°E','Saudi Arabia - onshore and offshore - between 48°E and 54°E.',17.43,28.94,48.0,54.01,0);
INSERT INTO "area" VALUES('EPSG','4530','Latin America - Central America and South America','Latin America - Central America and South America, onshore and offshore.',-59.87,32.72,-122.19,-25.28,0);
INSERT INTO "area" VALUES('EPSG','4531','Costa Rica - offshore Caribbean','Costa Rica - offshore - Caribbean sea.',9.6,11.77,-83.6,-81.43,0);
INSERT INTO "area" VALUES('EPSG','4532','Costa Rica - offshore Pacific','Costa Rica - offshore Pacific ocean and onshore Coco Island.',2.15,11.11,-90.45,-82.92,0);
INSERT INTO "area" VALUES('EPSG','4533','Canada - British Columbia - CRD','Canada - British Columbia - Vancouver Island - Capital Regional District.',48.25,49.06,-124.52,-123.0,0);
INSERT INTO "area" VALUES('EPSG','4534','Canada - British Columbia - north Vancouver Is','Canada - British Columbia - north Vancouver Island.',48.48,50.93,-128.5,-123.49,0);
INSERT INTO "area" VALUES('EPSG','4535','Canada - British Columbia - mainland','Canada - British Columbia - mainland and Graham Island.',48.99,60.01,-139.04,-114.08,0);
INSERT INTO "area" VALUES('EPSG','4536','Canada - Ontario - Toronto','Canada - Ontario - Toronto.',43.58,43.86,-79.64,-79.11,0);
INSERT INTO "area" VALUES('EPSG','4537','Canada - Ontario ex. Toronto','Canada - Ontario excluding Toronto.',41.67,56.9,-95.16,-74.35,0);
INSERT INTO "area" VALUES('EPSG','4538','Vietnam - Son La','Vietnam - Son La province.',20.57,22.04,103.21,105.03,0);
INSERT INTO "area" VALUES('EPSG','4539','Angola - east of 18°E','Angola - east of 18°E.',-18.02,-6.91,17.99,24.09,0);
INSERT INTO "area" VALUES('EPSG','4540','Africa - South Africa, Lesotho and Eswatini.','Eswatini (Swaziland); Lesotho; South Africa - onshore and offshore.',-50.32,-22.13,13.33,42.85,0);
INSERT INTO "area" VALUES('EPSG','4541','Vietnam - Dien Bien and Lai Chau','Vietnam - Dien Bien and Lai Chau provinces.',20.89,22.82,102.14,103.99,0);
INSERT INTO "area" VALUES('EPSG','4542','Kosovo','Kosovo.',41.85,43.25,19.97,21.8,0);
INSERT INTO "area" VALUES('EPSG','4543','Serbia','Serbia including Vojvodinja.',42.23,46.19,18.81,23.01,0);
INSERT INTO "area" VALUES('EPSG','4544','North America - Canada, US (Conus+AK), PRVI','North America - onshore and offshore: Canada - Alberta; British Columbia; Manitoba; New Brunswick; Newfoundland and Labrador; Northwest Territories; Nova Scotia; Nunavut; Ontario; Prince Edward Island; Quebec; Saskatchewan; Yukon. Puerto Rico. United States (USA) - Alabama; Alaska; Arizona; Arkansas; California; Colorado; Connecticut; Delaware; Florida; Georgia; Idaho; Illinois; Indiana; Iowa; Kansas; Kentucky; Louisiana; Maine; Maryland; Massachusetts; Michigan; Minnesota; Mississippi; Missouri; Montana; Nebraska; Nevada; New Hampshire; New Jersey; New Mexico; New York; North Carolina; North Dakota; Ohio; Oklahoma; Oregon; Pennsylvania; Rhode Island; South Carolina; South Dakota; Tennessee; Texas; Utah; Vermont; Virginia; Washington; West Virginia; Wisconsin; Wyoming. US Virgin Islands.',14.92,86.46,167.65,-47.74,0);
INSERT INTO "area" VALUES('EPSG','4545','Vietnam - Ca Mau and Kien Giang','Vietnam - Ca Mau and Kien Giang provinces.',8.33,10.55,103.4,105.54,0);
INSERT INTO "area" VALUES('EPSG','4546','Vietnam - An Giang, Lao Cai, Nghe An, Phu Tho, Yen Bai','Vietnam - An Giang, Lao Cai, Nghe An, Phu Tho and Yen Bai provinces.',10.18,22.85,103.53,105.86,0);
INSERT INTO "area" VALUES('EPSG','4547','Vietnam - 104°20''E to 106°10''E by province - Hanoi','Vietnam - Ha Noi city, Ha Nam, Ha Tay, Ninh Binh, Thanh Hoa and Vinh Phuc provinces; Can Tho city, Bac Lieu, Dong Thap and Hau Giang provinces.',8.97,21.58,104.37,106.19,0);
INSERT INTO "area" VALUES('EPSG','4548','Vietnam - 104°20''E to 106°40''E by province','Vietnam - Bac Ninh, Ha Giang, Ha Tinh, Hai Duong, Hung Yen, Nam Dinh, Soc Trang, Tay Ninh, Thai Binh, Tra Vinh and Vinh Long provinces.',9.19,23.4,104.33,106.69,0);
INSERT INTO "area" VALUES('EPSG','4549','Vietnam - 105°15''E to 107°50''E by province - HCMC','Vietnam - Hai Phong and Ho Chi Minh cities; Ben Tre, Binh Duong, Cao Bang, Long An and Tien Giang provinces.',9.75,23.12,105.26,107.8,0);
INSERT INTO "area" VALUES('EPSG','4550','Vietnam - Hoa Binh, Quang Binh and Tuyen Quang','Vietnam - Hoa Binh, Quang Binh and Tuyen Quang provinces.',16.92,22.7,104.83,107.03,0);
INSERT INTO "area" VALUES('EPSG','4551','Angola - west of 12°E','Angola - west of 12°E, onshore and offshore.',-17.28,-5.03,8.2,12.01,0);
INSERT INTO "area" VALUES('EPSG','4552','Vietnam - Binh Phuoc and Quang Tri','Vietnam - Binh Phuoc and Quang Tri provinces.',11.3,17.22,106.41,107.43,0);
INSERT INTO "area" VALUES('EPSG','4553','Vietnam - Bac Kan and Thai Nguyen','Vietnam - Bac Kan and Thai Nguyen provinces.',21.32,22.75,105.43,106.25,0);
INSERT INTO "area" VALUES('EPSG','4554','Vietnam - Bac Giang and Thua Thien-Hue','Vietnam - Bac Giang and Thua Thien-Hue provinces.',15.99,21.63,105.88,108.24,0);
INSERT INTO "area" VALUES('EPSG','4555','Angola - 12°E to 18°E','Angola - between 12°E and 18°E, onshore and offshore.',-17.44,-4.38,12.0,18.0,0);
INSERT INTO "area" VALUES('EPSG','4556','Vietnam - Lang Son','Vietnam - Lang Son province.',21.32,22.47,106.09,107.37,0);
INSERT INTO "area" VALUES('EPSG','4557','Vietnam - Kon Tum','Vietnam - Kon Tum province.',13.92,15.42,107.33,108.55,0);
INSERT INTO "area" VALUES('EPSG','4558','Vietnam - Quang Ngai','Vietnam - Quang Ngai province.',14.53,15.49,108.23,109.2,0);
INSERT INTO "area" VALUES('EPSG','4559','Vietnam - Binh Dinh, Khanh Hoa, Ninh Thuan','Vietnam - Binh Dinh, Khanh Hoa and Ninh Thuan provinces.',11.25,14.71,108.55,109.53,0);
INSERT INTO "area" VALUES('EPSG','4560','Vietnam - Binh Thuan, Dak Lak, Dak Nong, Gia Lai, Phu Yen','Vietnam - Binh Thuan, Dak Lak, Dak Nong, Gia Lai and Phu Yen provinces.',10.43,14.61,107.2,109.52,0);
INSERT INTO "area" VALUES('EPSG','4566','Europe - offshore North Sea - Germany and Netherlands east of 5°E','Germany - offshore North Sea. Netherlands - offshore east of 5E.',53.49,55.92,3.34,8.88,0);
INSERT INTO "area" VALUES('EPSG','4567','South Africa - mainland - onshore and offshore','South Africa - mainland - onshore and offshore.',-38.17,-22.13,13.33,36.54,0);
INSERT INTO "area" VALUES('EPSG','4568','South Africa - Prince Edward islands - onshore and offshore','South Africa - Marion Island and Prince Edward Island - onshore and offshore.',-50.32,-43.26,32.71,42.85,0);
