--- This file has been generated by scripts/build_db_create_ignf_from_xml.py from the http://librairies.ign.fr/geoportail/resources/IGNF.xml definition file. DO NOT EDIT !

INSERT INTO "metadata" VALUES('IGNF.SOURCE', 'http://librairies.ign.fr/geoportail/resources/IGNF.xml');
INSERT INTO "metadata" VALUES('IGNF.VERSION', '3.0.3');
INSERT INTO "metadata" VALUES('IGNF.DATE', '2019-01-04');
INSERT INTO "ellipsoid" VALUES('IGNF','ELG032','SPHERE PICARD',NULL,'PROJ', 'EARTH', 6371598,'EPSG','9001',0,NULL,0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA052','BORA_SAU 2001',NULL,NULL,'EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5530001','CADASTRE 1953-1954 (ATOLL RAIVAVAE)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5680001','CADASTRE 1980 (ATOLL APATAKI)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG7010001','CADASTRE 1997',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG0100001','CAP BIENVENUE - PERROUD 1955',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG0110001','CAP JULES - PERROUD 1955',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5060001','CLIPPERTON (MARINE 1967)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG0130001','CROZET-POSSESSION 1963',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG4070101','CSG 1967 (IGN 1995)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA018','DANGER 1950 (SAINT-PIERRE-ET-MIQUELON)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5050001','EFATE-IGN 1957',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA034','EPF 1952 (ILE DES PETRELS)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG3790001','EUROPA (MHM 1954)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA122','EVRF2000 (UELN-95/98)(EUROPEAN VERTICAL REFERENCE FRAME)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA125','EVRF2007 (EUROPEAN VERTICAL REFERENCE FRAME 2007)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5690001','FG 1949 (ATOLL APATAKI)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG3800001','GLORIEUSES (MHG 1977)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG4260001','GUADELOUPE - FORT MARIGOT',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA051','HUAHINE_SAU 2001',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA026','IGN 1962 (KERGUELEN)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5630001','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA028','IGN 1966 (TAHITI)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5870001','IGN 1978 (ATOLL MURUROA) TUAMOTU',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA027','IGN 1984 (ILE UVEA OU WALLIS)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA014','IGN 1987 (MARTINIQUE)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA006','IGN 1988 (GUADELOUPE)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA008','IGN 1988 LS (GUADELOUPE / LES SAINTES)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA007','IGN 1988 MG (GUADELOUPE / MARIE-GALANTE)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA012','IGN 1988 SB (GUADELOUPE / SAINT-BARTHELEMY)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA009','IGN 1988 SM (GUADELOUPE / SAINT-MARTIN)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA033','IGN 1989 (REUNION)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA037','IGN 1992 LD (GUADELOUPE / LA DESIRADE)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA053','IGN 2008 LD (GUADELOUPE / LA DESIRADE)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG0300001','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5970001','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG0140001','ILE AMSTERDAM 1963',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG0150001','ILE SAINT-PAUL 1969',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG3810001','JUAN DE NOVA (MHM 1953)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG0060001','KERGUELEN - K0 (IGN 1962)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5590001','MANGAREVA 1951',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA047','MAUPITI_SAU 2001',NULL,NULL,'EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5880001','MGT 1947 (ATOLL RANGIROA OU RAIROA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5700001','MGT 1948 (ATOLL APATAKI)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5780001','MGT 1949 (ATOLL HAO)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5730001','MGT 1950 (ATOLL FANGATAUFA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5850001','MGT 1951 (ATOLL MURUROA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5570001','MGT 1955 (TUBUAI)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5550001','MHEFO 1955 (ATOLL RAPA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5600001','MHEFO 1955 (FATU HUKU)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5640001','MHEFO 1955 (MOHOTANI)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5860001','MHOI 1962 (ATOLL MURUROA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5800001','MHPF 1958 (ATOLL HAO)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5840001','MHPF 1959 (ATOLL MURUROA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5890001','MHPF 1959 (ATOLL RANGIROA OU RAIROA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5920001','MHPF 1960 (ATOLL TIKEHAU)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5610001','MHPF 1960 (HIVA OA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5660001','MHPF 1963 (ATOLL AMANU)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5740001','MHPF 1964 (ATOLL FANGATAUFA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5750001','MHPF 1965-1 (ATOLL FANGATAUFA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5760001','MHPF 1965-2 (ATOLL FANGATAUFA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5900001','MHPF 1966-1968 (ATOLL RANGIROA OU RAIROA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5770001','MHPF 1966 (ATOLL FANGATAUFA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5540001','MHPF 1966 (ATOLL RAIVAVAE)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5790001','MHPF 1967 (ATOLLS HAO ET AMANU)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5620001','MHPF 1967 (HIVA OA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG0270001','MHPF 1967 (MANGAREVA - AGAKAUITAI - AUKENA - MEKIRO) GAMBIER',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5910001','MHPF 1969 (ATOLLS TAKAROA ET TAKAPOTO)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5580001','MHPF 1969 (TUBUAI) ILES AUSTRALES',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG0290001','MHPF70 (KAUEHI) TUAMOTU',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA029','MOOREA 1981 (MOOREA_SAU 2001)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG0340001','MOP 1983 (MAUPITI)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5720001','MOP84 (FANGATAUFA 1984)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5960001','MOP86 (APATAKI - RAPA - HAO) TUAMOTU',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG0870001','MOP88 (TIKEHAU) TUAMOTU',NULL,NULL,'EPSG','7043','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG0280001','MOP90 (TETIAROA) ILES DE LA SOCIETE',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5980001','MOP92 (ANAA) TUAMOTU',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA001','NGF-BOURDALOUE',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA003','NGF-IGN 1969',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA011','NGF-IGN 1978',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA002','NGF-LALLEMAND',NULL,NULL,'EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5650001','NGT 1949 (ATOLL AMANU)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA054','NGWF FUTUNA',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA041','NGWF WALLIS (MOP 1996)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA016','NIVELLEMENT GENERAL DE GUYANE (NGG) 1977',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA010','NIVELLEMENT GENERAL DE LA CORSE (NGC)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA036','NIVELLEMENT GENERAL DE LIFOU (IGN 1991 LF)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA035','NIVELLEMENT GENERAL DE MARE (IGN 1991 MR)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA019','NIVELLEMENT GENERAL DE NOUVELLE-CALEDONIE (NGNC)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA109','NORMAL NULL (NIVELLEMENT GENERAL DU LUXEMBOURG NG-L)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG7080001','NOUMEA 74 (TRIANGULATION DE NOUMEA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5040001','NOUVELLE CALEDONIE - GOMEN TERME NORD',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG0120001','PORT-MARTIN - PERROUD 1955',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA049','RAIATEA_SAU 2001',NULL,NULL,'EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG3170201','REUNION - PITON DES NEIGES (IGN 1992)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG3170301','REUNION - PITON DES NEIGES (IGN 2008)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG9150001','RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG7020001','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG7060001','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG0360001','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG0890001','RGWF96 (RESEAU GEODESIQUE DE WALLIS ET FUTUNA 1996)',NULL,NULL,'EPSG','7019','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG0310001','SAT84 (RURUTU) ILES AUSTRALES',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5560001','SEQ 1980 (ATOLL RAPA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5710001','SHM 1947-1950 (ATOLL FAKARAVA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5820001','SHM 1947-1950 (ATOLL HIKUERU)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5830001','SHM 1947-1950 (ATOLL MAKEMO)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5930001','SHM 1947-1950 (ATOLL TIKEHAU)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5670001','SHM 1947 (ATOLL ANAA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5810001','SHM 1949 (ATOLL HARAIKI)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5940001','SHM 1969 (ATOLL TUREIA)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA038','SHOM 1953 (MAYOTTE)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA042','SHOM 1977 (ILES GLORIEUSES - CANAL DE MOZAMBIQUE)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA020','SHOM 1978 (ILE DES PINS)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG7100001','ST 84 ILE DES PINS',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG7090001','ST 87 OUVEA',NULL,NULL,'EPSG','7030','EPSG','8901','EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('IGNF','REA050','TAHAA_SAU 2001',NULL,NULL,'EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG5250001','TANNA BLOC SUD',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG3820001','TROMELIN (SGM 1956)',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_datum" VALUES('IGNF','REG0160001','WALLIS-UVEA MOP1976',NULL,NULL,'EPSG','7022','EPSG','8901','EPSG','1262',0);
INSERT INTO "area" VALUES('IGNF','1','AMANU (ARCHIPEL DES TUAMOTU)','AMANU (ARCHIPEL DES TUAMOTU)',-18,-17.58,-141,-140.58,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','AMANU63','Amanu MHPF 1963 cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5660001','IGNF','1',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','AMANU49','Amanu NGT 1949 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5650001','IGNF','1',NULL,0);
INSERT INTO "area" VALUES('IGNF','2','ANAA (ARCHIPEL DES TUAMOTU)','ANAA (ARCHIPEL DES TUAMOTU)',-17.5,-17.32,-145.6,-145.37,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ANAA92','Anaa (MOP92) cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5980001','IGNF','2',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ANAA47','Anaa SHM 1947 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5670001','IGNF','2',NULL,0);
INSERT INTO "area" VALUES('IGNF','3','APATAKI (ARCHIPEL DES TUAMOTU)','APATAKI (ARCHIPEL DES TUAMOTU)',-15.63,-15.29,-146.46,-146.18,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','APAT80','Apataki Cadastre 1980 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5680001','IGNF','3',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','CADA80','Apataki Cadastre 1980 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5680001','IGNF','3',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','APAT49','Apataki FG 1949 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5690001','IGNF','3',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','APAT48','Apataki MGT 1948 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5700001','IGNF','3',NULL,0);
INSERT INTO "area" VALUES('IGNF','4','FRANCE METROPOLITAINE (CORSE COMPRISE)','FRANCE METROPOLITAINE (CORSE COMPRISE)',41,52,-5.5,10,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ATIG','ATIG cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6901','IGNF','4',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ATI','ATIG cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6901','IGNF','4',NULL,0);
INSERT INTO "area" VALUES('IGNF','5','ILE DE MAYOTTE','ILE DE MAYOTTE',-13.05,-12.5,44.95,45.4,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','CAD97','Cadastre 1997 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG7010001','IGNF','5',NULL,0);
INSERT INTO "area" VALUES('IGNF','6','CAP BIENVENUE (TERRE ADELIE)','CAP BIENVENUE (TERRE ADELIE)',-67,-66.5,140.33,140.67,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','CAPBP55','Cap Bienvenue - Perroud 1955 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0100001','IGNF','6',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','BIEN55','Cap Bienvenue - Perroud 1955 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0100001','IGNF','6',NULL,0);
INSERT INTO "area" VALUES('IGNF','7','CAP JULES (TERRE ADELIE)','CAP JULES (TERRE ADELIE)',-67,-66.5,140.75,141,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','CAPJP55','Cap Jules - Perroud 1955 cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0110001','IGNF','7',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','JULES55','Cap Jules - Perroud 1955 cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0110001','IGNF','7',NULL,0);
INSERT INTO "area" VALUES('IGNF','8','ILE CLIPPERTON','ILE CLIPPERTON',10.17,10.5,-109.5,-109,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','CLIP67','Clipperton (Marine 1967) cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5060001','IGNF','8',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MAYO50','Combani cartesiennes',NULL,NULL,'geocentric','EPSG','6500','EPSG','6632','IGNF','5',NULL,0);
INSERT INTO "area" VALUES('IGNF','9','ILES CROZET (ARCHIPEL)','ILES CROZET (ARCHIPEL)',-46.75,-45.75,50,52.5,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','CROZ63','Crozet-Possession 1963 cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0130001','IGNF','9',NULL,0);
INSERT INTO "area" VALUES('IGNF','10','GUYANE FRANCAISE','GUYANE FRANCAISE',2.05,5.95,-54.95,-51.05,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','CSG67','CSG 1967 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6623','IGNF','10',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','C67I95','CSG67 (IGN 1995) CARTESIENNES GEOCENTRIQUES',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG4070101','IGNF','10',NULL,0);
INSERT INTO "area" VALUES('IGNF','11','EUROPE DE L''OUEST ED50','EUROPE DE L''OUEST ED50',34,72,-10,32,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ED50','ED50 CARTESIENNES GEOCENTRIQUES',NULL,NULL,'geocentric','EPSG','6500','EPSG','6230','IGNF','11',NULL,0);
INSERT INTO "area" VALUES('IGNF','12','EFATE (ARCHIPEL DU VANUATU)','EFATE (ARCHIPEL DU VANUATU)',-18,-17.25,168,168.67,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','EFATE57','Efate - IGN 1957 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5050001','IGNF','12',NULL,0);
INSERT INTO "area" VALUES('IGNF','13','EIAO, HIVA OA, MOHOTANI (ARCHIPEL DES MARQUISES)','EIAO, HIVA OA, MOHOTANI (ARCHIPEL DES MARQUISES)',-10.05,-7.89,-140.74,-138.78,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MARQUI72','Eiao Hiva Oa Motohani cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5970001','IGNF','13',NULL,0);
INSERT INTO "area" VALUES('IGNF','14','EUROPE (ETRS89)','EUROPE (ETRS89)',27.5,71.5,-25,45.5,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ETRS89','ETRS89 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6258','IGNF','14',NULL,0);
INSERT INTO "area" VALUES('IGNF','15','ILE EUROPA','ILE EUROPA',-22.33,-22,40.25,40.5,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','EUROPA54','Europa MHM 1954 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG3790001','IGNF','15',NULL,0);
INSERT INTO "area" VALUES('IGNF','16','FAKARAVA (ARCHIPEL DES TUAMOTU)','FAKARAVA (ARCHIPEL DES TUAMOTU)',-16.58,-16,-146,-145.25,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','FAKA50','Fakarava SHM 1947-1950 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5710001','IGNF','16',NULL,0);
INSERT INTO "area" VALUES('IGNF','17','FANGATAUFA (ARCHIPEL DES TUAMOTU)','FANGATAUFA (ARCHIPEL DES TUAMOTU)',-22.33,-22.15,-138.83,-138.58,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','FANGA50','Fangataufa MGT 1950 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5730001','IGNF','17',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','FANGA64','Fangataufa MHPF 1964 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5740001','IGNF','17',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','FANGA651','Fangataufa MHPF 1965-1 cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5750001','IGNF','17',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','FANGA652','Fangataufa MHPF 1965-2 cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5760001','IGNF','17',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','FANGA66','Fangataufa MHPF 1966 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5770001','IGNF','17',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','FANGA84','Fangataufa MOP 1984 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5720001','IGNF','17',NULL,0);
INSERT INTO "area" VALUES('IGNF','18','FATU HUKU (ARCHIPEL DES MARQUISES)','FATU HUKU (ARCHIPEL DES MARQUISES)',-9.44,-9.43,-138.94,-138.92,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','FATU55','Fatu Huku MHEFO 1955 cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5600001','IGNF','18',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MHEFO55F','Fatu Huku MHEFO 1955 cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5600001','IGNF','18',NULL,0);
INSERT INTO "area" VALUES('IGNF','19','MANGAREVA, AGAKAUITAI, AUKENA, MEKIRO (ILES GAMBIER)','MANGAREVA, AGAKAUITAI, AUKENA, MEKIRO (ILES GAMBIER)',-23.18,-23.07,-135.04,-134.89,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MHPF67','Gambier MHPF 1967 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0270001','IGNF','19',NULL,0);
INSERT INTO "area" VALUES('IGNF','20','ILES GLORIEUSES','ILES GLORIEUSES',-11.62,-11.43,47.25,47.47,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','GLOR77MHG','Glorieuses (MHG 1977) cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG3800001','IGNF','20',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','GLOR77CAR','Glorieuses (MHG 1977) cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG3800001','IGNF','20',NULL,0);
INSERT INTO "area" VALUES('IGNF','21','GRANDE TERRE (NOUVELLE-CALEDONIE)','GRANDE TERRE (NOUVELLE-CALEDONIE)',-22.75,-19.5,163.5,167.67,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','GTN51','GOMEN TERME NORD 1951 CARTESIENNES',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5040001','IGNF','21',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','NC51','GOMEN TERME NORD 1951 CARTESIENNES',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5040001','IGNF','21',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','IGN72','Grande Terre - Ile des Pins IGN 72 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','EPSG','6634','IGNF','21',NULL,0);
INSERT INTO "area" VALUES('IGNF','22','ILES DE SAINT-MARTIN ET SAINT-BARTHELEMY (GUADELOUPE)','ILES DE SAINT-MARTIN ET SAINT-BARTHELEMY (GUADELOUPE)',17.82,18.18,-63.18,-62.25,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','GUADFM','Guadeloupe Fort Marigot cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG4260001','IGNF','22',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','GUADFM49','Guadeloupe Fort Marigot cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG4260001','IGNF','22',NULL,0);
INSERT INTO "area" VALUES('IGNF','23','GRANDE-TERRE, BASSE-TERRE, MARIE-GALANTE, LA DESIRADE, LES SAINTES (GUADELOUPE)','GRANDE-TERRE, BASSE-TERRE, MARIE-GALANTE, LA DESIRADE, LES SAINTES (GUADELOUPE)',15.82,16.6,-61.83,-60.77,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','GUADANN','Guadeloupe Sainte-Anne cartesiennes',NULL,NULL,'geocentric','EPSG','6500','EPSG','6622','IGNF','23',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','GUAD48','Guadeloupe Sainte-Anne cartesiennes',NULL,NULL,'geocentric','EPSG','6500','EPSG','6622','IGNF','23',NULL,0);
INSERT INTO "area" VALUES('IGNF','24','HAO ET AMANU (ARCHIPEL DES TUAMOTU)','HAO ET AMANU (ARCHIPEL DES TUAMOTU)',-18.5,-17.58,-141.17,-140.58,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','HAOAM67','Hao Amanu MHPF 1967 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5790001','IGNF','24',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','HAO67','Hao Amanu MHPF 1967 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5790001','IGNF','24',NULL,0);
INSERT INTO "area" VALUES('IGNF','25','HAO (ARCHIPEL DES TUAMOTU)','HAO (ARCHIPEL DES TUAMOTU)',-18.5,-18,-141.17,-140.58,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','HAO49','Hao MGT 1949 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5780001','IGNF','25',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','HAO58','Hao MHPF 1958 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5800001','IGNF','25',NULL,0);
INSERT INTO "area" VALUES('IGNF','26','HARAIKI (ARCHIPEL DES TUAMOTU)','HARAIKI (ARCHIPEL DES TUAMOTU)',-17.58,-17.42,-143.58,-143.33,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','HARA49','Haraiki SHM 1949 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5810001','IGNF','26',NULL,0);
INSERT INTO "area" VALUES('IGNF','27','HIKUERU (ARCHIPEL DES TUAMOTU)','HIKUERU (ARCHIPEL DES TUAMOTU)',-17.83,-17.42,-142.83,-142.42,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','HIKU50','Hikureu SHM 1947-1950 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5820001','IGNF','27',NULL,0);
INSERT INTO "area" VALUES('IGNF','28','HIVA OA (ARCHIPEL DES MARQUISES)','HIVA OA (ARCHIPEL DES MARQUISES)',-9.87,-9.6,-139.25,-138.58,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','HIVA60','Hiva Oa MHPF 1960 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5610001','IGNF','28',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','HIVA67','Hiva Oa MHPF 1967 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5620001','IGNF','28',NULL,0);
INSERT INTO "area" VALUES('IGNF','29','HIVA OA, TAHUATA, MOHOTANI (ARCHIPEL DES MARQUISES)','HIVA OA, TAHUATA, MOHOTANI (ARCHIPEL DES MARQUISES)',-9.88,-9.65,-139.2,-138.75,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ATUO63','Hiva Oa Tahuata Motohani IGN 1963 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5630001','IGNF','29',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','IGN63','Hiva Oa Tahuata Motohani IGN 1963 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5630001','IGNF','29',NULL,0);
INSERT INTO "area" VALUES('IGNF','30','ILE AMSTERDAM','ILE AMSTERDAM',-37.92,-37.75,77.45,77.63,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','AMST63','Ile Amsterdam 1963 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0140001','IGNF','30',NULL,0);
INSERT INTO "area" VALUES('IGNF','31','ILE DES PINS (NOUVELLE-CALEDONIE)','ILE DES PINS (NOUVELLE-CALEDONIE)',-22.8,-22.44,167.29,167.62,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ST84','Ile des Pins ST84 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG7100001','IGNF','31',NULL,0);
INSERT INTO "area" VALUES('IGNF','32','ILE JUAN DE NOVA','ILE JUAN DE NOVA',-17.17,-17,42.67,42.83,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','NOVA53','Juan de Nova MHM 1953 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG3810001','IGNF','32',NULL,0);
INSERT INTO "area" VALUES('IGNF','33','KAUHEI (ARCHIPEL DES TUAMOTU)','KAUHEI (ARCHIPEL DES TUAMOTU)',-16,-15.67,-145.33,-145,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','KAUE70','Kauehi MHPF70 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0290001','IGNF','33',NULL,0);
INSERT INTO "area" VALUES('IGNF','34','KERGUELEN','KERGUELEN',-50.5,-48,67,71,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','KERG62K0','Kerguelen - K0 IGN 1962 cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0060001','IGNF','34',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','KERG62CAR','Kerguelen - K0 IGN 1962 cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0060001','IGNF','34',NULL,0);
INSERT INTO "area" VALUES('IGNF','35','LIFOU (ILES LOYAUTE)','LIFOU (ILES LOYAUTE)',-21.22,-20.65,166.96,167.51,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','LIFOU56','Lifou IGN 1956 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6633','IGNF','35',NULL,0);
INSERT INTO "area" VALUES('IGNF','36','MAKEMO (ARCHIPEL DES TUAMOTU)','MAKEMO (ARCHIPEL DES TUAMOTU)',-16.83,-16.33,-144,-143.33,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MAKE50','Makemo SHM 1947-1950 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5830001','IGNF','36',NULL,0);
INSERT INTO "area" VALUES('IGNF','37','MANGAREVA (ILES GAMBIER)','MANGAREVA (ILES GAMBIER)',-23.45,-22.83,-135.33,-134.58,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MANGA51','Mangareva 1951 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5590001','IGNF','37',NULL,0);
INSERT INTO "area" VALUES('IGNF','38','MARE (ILES LOYAUTE)','MARE (ILES LOYAUTE)',-21.69,-21.29,167.69,168.18,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MARE53','Mare IGN 1953 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6641','IGNF','38',NULL,0);
INSERT INTO "area" VALUES('IGNF','39','MARTINIQUE','MARTINIQUE',14.27,15,-61.25,-60.75,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MARTFD','Martinique Fort-Desaix cartesiennes',NULL,NULL,'geocentric','EPSG','6500','EPSG','6625','IGNF','39',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MART38','Martinique Fort-Desaix cartesiennes',NULL,NULL,'geocentric','EPSG','6500','EPSG','6625','IGNF','39',NULL,0);
INSERT INTO "area" VALUES('IGNF','40','MAUPITI','MAUPITI',-16.75,-16.25,-152.5,-152,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MAUPITI','Maupiti MOP 1983 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0340001','IGNF','40',NULL,0);
INSERT INTO "area" VALUES('IGNF','41','MOHOTANI (ARCHIPEL DES MARQUISES)','MOHOTANI (ARCHIPEL DES MARQUISES)',-10.08,-9.83,-138.92,-138.67,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MOHO55','Mohotani MHEFO 1955 cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5640001','IGNF','41',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MHEFO55M','Mohotani MHEFO 1955 cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5640001','IGNF','41',NULL,0);
INSERT INTO "area" VALUES('IGNF','42','MOOREA (ARCHIPEL DE LA SOCIETE)','MOOREA (ARCHIPEL DE LA SOCIETE)',-17.75,-17.25,-150,-149.75,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MOOREA87','MOOREA 1987 CARTESIENNES GEOCENTRIQUES',NULL,NULL,'geocentric','EPSG','6500','EPSG','6691','IGNF','42',NULL,0);
INSERT INTO "area" VALUES('IGNF','43','MURUROA (ARCHIPEL DES TUAMOTU)','MURUROA (ARCHIPEL DES TUAMOTU)',-22,-21.67,-139.17,-138.58,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MURU78','Mururoa IGN 1978 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5870001','IGNF','43',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MURU51','Mururoa MGT 1951 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5850001','IGNF','43',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MURU62','Mururoa MHOI 1962 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5860001','IGNF','43',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MURU59','Mururoa MHPF 1959 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5840001','IGNF','43',NULL,0);
INSERT INTO "area" VALUES('IGNF','44','NOUMEA (NOUVELLE-CALEDONIE)','NOUMEA (NOUVELLE-CALEDONIE)',-22.36,-22.14,166.36,166.54,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','NEA74','Noumea 1974 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG7080001','IGNF','44',NULL,0);
INSERT INTO "area" VALUES('IGNF','45','LUXEMBOURG (pays_cid : 137)','LUXEMBOURG (pays_cid : 137)',49.45,50.18,5.73,6.53,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','LURES','Nouvelle Triangulation Luxembourg cartesiennes',NULL,NULL,'geocentric','EPSG','6500','EPSG','6181','IGNF','45',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','LUREF','Nouvelle Triangulation Luxembourg cartesiennes',NULL,NULL,'geocentric','EPSG','6500','EPSG','6181','IGNF','45',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','NTF','NTF cartesiennes',NULL,NULL,'geocentric','EPSG','6500','EPSG','6275','IGNF','4',NULL,0);
INSERT INTO "area" VALUES('IGNF','46','NUKU HIVA, UA HUKA ET UA POU (ARCHIPEL DES MARQUISES)','NUKU HIVA, UA HUKA ET UA POU (ARCHIPEL DES MARQUISES)',-9.5,-8.77,-140.27,-139.48,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','NUKU72','Nuku Hiva IGN 1972 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6630','IGNF','46',NULL,0);
INSERT INTO "area" VALUES('IGNF','47','OUVEA (ILES LOYAUTE)','OUVEA (ILES LOYAUTE)',-20.78,-20.25,166.11,166.71,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','OUVE72','Ouvea MHNC 1972 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6634','IGNF','47',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','OUVEA72','Ouvea MHNC 1972 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6634','IGNF','47',NULL,0);
INSERT INTO "area" VALUES('IGNF','48','ILE DES PETRELS (TERRE ADELIE)','ILE DES PETRELS (TERRE ADELIE)',-68,-66.17,139.67,140.17,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','PETRELS72','Petrels IGN 1972 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6636','IGNF','48',NULL,0);
INSERT INTO "area" VALUES('IGNF','49','ARCHIPEL POINTE GEOLOGIE (TERRE ADELIE)','ARCHIPEL POINTE GEOLOGIE (TERRE ADELIE)',-66.72,-66.6,139.67,140.12,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','PGP50','Pointe Geologie Perroud 1950 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','EPSG','6637','IGNF','49',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TERA50','Pointe Geologie Perroud 1950 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','EPSG','6637','IGNF','49',NULL,0);
INSERT INTO "area" VALUES('IGNF','50','PORT-MARTIN (TERRE ADELIE)','PORT-MARTIN (TERRE ADELIE)',-67,-66.5,141,141.83,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','PMARP55','Port Martin Perroud 1955 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0120001','IGNF','50',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','PMAR55','Port Martin Perroud 1955 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0120001','IGNF','50',NULL,0);
INSERT INTO "area" VALUES('IGNF','51','RAIATEA, TAHAA (ARCHIPEL DE LA SOCIETE)','RAIATEA, TAHAA (ARCHIPEL DE LA SOCIETE)',-17,-16.5,-151.67,-151.33,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TAHAA53','Raiatea Tahaa Bora Bora Huahine 1953 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0300001','IGNF','51',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RAIA53','Raiatea Tahaa Bora Bora Huahine 1953 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0300001','IGNF','51',NULL,0);
INSERT INTO "area" VALUES('IGNF','52','RAIVAVAE (ARCHIPEL DES AUSTRALES)','RAIVAVAE (ARCHIPEL DES AUSTRALES)',-23.92,-23.75,-147.75,-147.58,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RAIV54','Raivavae cadastre 1953-1954 cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5530001','IGNF','52',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RAIV66','Raivavae MHPF 1966 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5540001','IGNF','52',NULL,0);
INSERT INTO "area" VALUES('IGNF','53','RANGIROA (ARCHIPEL DES TUAMOTU)','RANGIROA (ARCHIPEL DES TUAMOTU)',-14.83,-14.42,-148,-147.15,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RANGI47','Rangiroa MGT 1947 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5880001','IGNF','53',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RANGI59','Rangiroa MHPF 1959 cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5890001','IGNF','53',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RANGI68','Rangiroa MHPF 1966-1968 cartesiennes geocent.',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5900001','IGNF','53',NULL,0);
INSERT INTO "area" VALUES('IGNF','54','RAPA (ARCHIPEL DES AUSTRALES)','RAPA (ARCHIPEL DES AUSTRALES)',-27.75,-27.5,-144.5,-144.25,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RAPA55','Rapa MHEFO 1955 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5550001','IGNF','54',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RAPA80','Rapa SEQ 1980 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5560001','IGNF','54',NULL,0);
INSERT INTO "area" VALUES('IGNF','55','ILE DE LA REUNION','ILE DE LA REUNION',-21.42,-20.75,55.17,55.92,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','REUN49','Reunion Piton des Neiges 1949 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','EPSG','6626','IGNF','55',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','REUN47','Reunion Piton des Neiges 1949 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','EPSG','6626','IGNF','55',NULL,0);
INSERT INTO "area" VALUES('IGNF','56','ANTILLES FRANCAISES','ANTILLES FRANCAISES',14.25,18.2,-63.2,-60.73,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGAF09','RGAF09 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG9150001','IGNF','56',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGF93','RGF93 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6171','IGNF','4',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGFG95','RGFG95 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6624','IGNF','10',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGM04','RGM04 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG7020001','IGNF','5',NULL,0);
INSERT INTO "area" VALUES('IGNF','57','NOUVELLE-CALEDONIE','NOUVELLE-CALEDONIE',-26.65,-14.6,156.1,174.5,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGNC','RGNC cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6645','IGNF','57',NULL,0);
INSERT INTO "area" VALUES('IGNF','58','POLYNESIE FRANCAISE','POLYNESIE FRANCAISE',-28,-7,-156,-134,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGPF','RGPF cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6687','IGNF','58',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGR92','RGR92 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6627','IGNF','55',NULL,0);
INSERT INTO "area" VALUES('IGNF','59','SAINT-PIERRE-ET-MIQUELON','SAINT-PIERRE-ET-MIQUELON',46.7,47.2,-56.49,-56.1,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGSPM06','RGSPM06 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG7060001','IGNF','59',NULL,0);
INSERT INTO "area" VALUES('IGNF','60','TERRES AUSTRALES ET ANTARCTIQUES FRANCAISES (TAAF)','TERRES AUSTRALES ET ANTARCTIQUES FRANCAISES (TAAF)',-90,-11,39,142,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGTAAF07','RGTAAF07 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0360001','IGNF','60',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RRAF','RRAF cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6640','IGNF','56',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','WGS84GUAD','RRAF cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6640','IGNF','56',NULL,0);
INSERT INTO "area" VALUES('IGNF','61','RURUTU (ARCHIPEL DES AUSTRALES)','RURUTU (ARCHIPEL DES AUSTRALES)',-22.58,-22.25,-151.5,-151.33,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RUSAT84','Rurutu SAT84 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0310001','IGNF','61',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','SAT84','Rurutu SAT84 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0310001','IGNF','61',NULL,0);
INSERT INTO "area" VALUES('IGNF','62','ILE SAINT-PAUL','ILE SAINT-PAUL',-38.77,-38.67,77.48,77.58,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','STPL69','Saint-Paul 1969 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0150001','IGNF','62',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ST87','ST 87 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG7090001','IGNF','47',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','STPM50','St Pierre Miquelon 1950 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','EPSG','6638','IGNF','59',NULL,0);
INSERT INTO "area" VALUES('IGNF','63','TAHAA (ARCHIPEL DE LA SOCIETE)','TAHAA (ARCHIPEL DE LA SOCIETE)',-16.7,-16.53,-151.58,-151.38,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TAHAA','Tahaa 1951 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6629','IGNF','63',NULL,0);
INSERT INTO "area" VALUES('IGNF','64','TAHITI (ARCHIPEL DE LA SOCIETE)','TAHITI (ARCHIPEL DE LA SOCIETE)',-18,-17,-150,-149,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TAHI79','Tahiti IGN 1979 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6690','IGNF','64',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TAHI51','TAHITI TERME NORD CARTESIENNES GEOCENTRIQUES',NULL,NULL,'geocentric','EPSG','6500','EPSG','6628','IGNF','64',NULL,0);
INSERT INTO "area" VALUES('IGNF','65','TAKAROA ET TAKAPOTO (ARCHIPEL DES TUAMOTU)','TAKAROA ET TAKAPOTO (ARCHIPEL DES TUAMOTU)',-14.75,-14.25,-145.33,-144.75,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TAKA69','Takaroa Takapoto SHM 1969 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5910001','IGNF','65',NULL,0);
INSERT INTO "area" VALUES('IGNF','66','TANNA (ARCHIPEL DU VANUATU)','TANNA (ARCHIPEL DU VANUATU)',-19.67,-19.08,169.17,169.83,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TANNA','Tanna Bloc Sud 1957 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5250001','IGNF','66',NULL,0);
INSERT INTO "area" VALUES('IGNF','67','TETIAROA (ARCHIPEL DE LA SOCIETE)','TETIAROA (ARCHIPEL DE LA SOCIETE)',-17.1,-17.02,-149.6,-149.53,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TETIA90','Tetiaroa (MOP90) cartesiennes',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0280001','IGNF','67',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MOP90','Tetiaroa (MOP90) cartesiennes',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0280001','IGNF','67',NULL,0);
INSERT INTO "area" VALUES('IGNF','68','TIKEHAU (ARCHIPEL DES TUAMOTU)','TIKEHAU (ARCHIPEL DES TUAMOTU)',-15.2,-14.83,-148.5,-148,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TIKE60','Tikehau MHPF 1960 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5920001','IGNF','68',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TIKE50','Tikehau SHM 1947-1950 cartesiennes',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5930001','IGNF','68',NULL,0);
INSERT INTO "area" VALUES('IGNF','69','ILE TROMELIN','ILE TROMELIN',-15.9,-15.87,54.51,54.53,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TROM56','Tromelin SGM 1956 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG3820001','IGNF','69',NULL,0);
INSERT INTO "area" VALUES('IGNF','70','APATAKI, RAPA et HAO','APATAKI, RAPA et HAO',-27.75,-15.293,-146.4644,-140.5833,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TUAM86','TUAMOTU (MOP86) CARTESIENNES',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5960001','IGNF','70',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','APAT86','TUAMOTU (MOP86) CARTESIENNES',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5960001','IGNF','70',NULL,0);
INSERT INTO "area" VALUES('IGNF','71','TUBUAI (ARCHIPEL DES AUSTRALES)','TUBUAI (ARCHIPEL DES AUSTRALES)',-23.45,-23.25,-149.58,-149.33,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TUBU55','Tubuai MGT 1955 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5570001','IGNF','71',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TUBU69','Tubuai MHPF 1969 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5580001','IGNF','71',NULL,0);
INSERT INTO "area" VALUES('IGNF','72','TUREIA (ARCHIPEL DES TUAMOTU)','TUREIA (ARCHIPEL DES TUAMOTU)',-21,-20.67,-139.83,-138.83,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TURI69','Tureia SHM 1969 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG5940001','IGNF','72',NULL,0);
INSERT INTO "area" VALUES('IGNF','73','ILE D''UVEA (WALLIS)','ILE D''UVEA (WALLIS)',-13.42,-13.17,-176.3,-176.1,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','WALL76','Wallis - Uvea MOP 1976 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','IGNF','REG0160001','IGNF','73',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','WALL78','Wallis - Uvea Shom 1978 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6639','IGNF','73',NULL,0);
INSERT INTO "area" VALUES('IGNF','74','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE',-90,90,-180,180,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','WGS72','WGS72 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6322','IGNF','74',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','WGS84','WGS84 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6326','IGNF','74',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RRAF91','WGS84 cartesiennes geocentriques',NULL,NULL,'geocentric','EPSG','6500','EPSG','6326','IGNF','74',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','AMANU63G','Amanu (MHPF 1963) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5660001','IGNF','1',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','AMANU49G','Amanu (NGT 1949) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5650001','IGNF','1',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','AMST63G','Amsterdam 1963 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0140001','IGNF','30',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ANAA92G','Anaa (MOP92) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5980001','IGNF','2',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ANAA92GEO','Anaa (MOP92) geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG5980001','IGNF','2',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ANAA47G','Anaa (SHM 1947) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5670001','IGNF','2',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','APAT80G','Apataki (Cadastre 1980) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5680001','IGNF','3',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','CADA80G','Apataki (Cadastre 1980) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5680001','IGNF','3',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','APAT49G','Apataki (FG 1949) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5690001','IGNF','3',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','APAT48G','Apataki (MGT 1948) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5700001','IGNF','3',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ATIGG','ATIG geographiques grades Paris (gr)',NULL,NULL,'geographic 2D','EPSG','6425','EPSG','6901','IGNF','4',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','CAD97GEO','Cadastre 1997 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG7010001','IGNF','5',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','CAD97G','Cadastre 1997 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG7010001','IGNF','5',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','CAPBP55G','Cap Bienvenue geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0100001','IGNF','6',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','BIEN55G','Cap Bienvenue geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0100001','IGNF','6',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','CAPJP55G','Cap Jules geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0110001','IGNF','7',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','JULES55G','Cap Jules geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0110001','IGNF','7',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','CLIP67G','Clipperton 1967 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5060001','IGNF','8',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MAYO50GEO','Combani geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6632','IGNF','5',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MAYO50G','Combani triangulation IGN 1950 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6632','IGNF','5',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','CROZ63GEO','Crozet - Possession 1963 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG0130001','IGNF','9',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','CROZ63G','Crozet Possession 1963 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0130001','IGNF','9',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','CSG67GEO','CSG67 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6623','IGNF','10',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','CSG67G','CSG67 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6623','IGNF','10',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','C67IG95G','CSG67 (IGN 1995) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG4070101','IGNF','10',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ED50G','ED50 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6230','IGNF','11',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ED50GEO','ED50 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6230','IGNF','11',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','EFATE57GEO','Efate geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG5050001','IGNF','12',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','EFATE57G','Efate geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5050001','IGNF','12',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ETRS89G','ETRS89 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6258','IGNF','14',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ETRS89GEO','ETRS89 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6258','IGNF','14',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','EUROPA54G','Europa geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG3790001','IGNF','15',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','FAKA50G','Fakarava (SHM 1947-1950) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5710001','IGNF','16',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','FANGA50G','Fangataufa (MGT 1950) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5730001','IGNF','17',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','FANGA64G','Fangataufa (MHPF 1964) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5740001','IGNF','17',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','FANG651G','Fangataufa (MHPF 1965-1) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5750001','IGNF','17',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','FANGA651G','Fangataufa (MHPF 1965-1) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5750001','IGNF','17',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','FANG652G','Fangataufa (MHPF 1965-2) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5760001','IGNF','17',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','FANGA652G','Fangataufa (MHPF 1965-2) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5760001','IGNF','17',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','FANGA66G','Fangataufa (MHPF 1966) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5770001','IGNF','17',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','FANGA84G','Fangataufa (MOP84) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5720001','IGNF','17',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','FATU55FG','Fatu Huku (MHEFO 1955) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5600001','IGNF','18',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MHEFO55FG','Fatu Huku (MHEFO 1955) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5600001','IGNF','18',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','GLOR77G','Glorieuses geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG3800001','IGNF','20',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','GTN51G','Gomen Terme Nord 1951 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5040001','IGNF','21',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','NC51G','Gomen Terme Nord 1951 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5040001','IGNF','21',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','GUADFMG','Guadeloupe Fort-Marigot geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG4260001','IGNF','22',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','GUAFM48G','Guadeloupe Fort-Marigot geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG4260001','IGNF','22',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','GUADFM49GEO','Guadeloupe Fort-Marigot geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG4260001','IGNF','22',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','GUADANNG','Guadeloupe Sainte-Anne geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6622','IGNF','23',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','GUAD48G','Guadeloupe Sainte-Anne geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6622','IGNF','23',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','GUAD48GEO','Guadeloupe Sainte-Anne geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6622','IGNF','23',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','HAOAM67G','Hao Amanu (MHPF 1967) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5790001','IGNF','24',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','HAOAMA67G','Hao Amanu (MHPF 1967) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5790001','IGNF','24',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','HAO49G','Hao (MGT 1949) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5780001','IGNF','25',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','HAO58G','Hao (MHPF 1958) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5800001','IGNF','25',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','HARA49G','Haraiki (SHM 1949) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5810001','IGNF','26',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','HIKU50G','Hikueru (SHM 1947-1950) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5820001','IGNF','27',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','HIVA60G','Hiva Oa (MHPF 1960) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5610001','IGNF','28',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','HIVA67G','Hiva Oa (MHPF 1967) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5620001','IGNF','28',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ATUO63G','IGN 1963 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5630001','IGNF','29',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','IGN63G','IGN 1963 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5630001','IGNF','29',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TAHAA53G','IGN53 Societe geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0300001','IGNF','51',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RAIA53G','IGN53 Societe geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0300001','IGNF','51',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','IGN63GEO','IGN63 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG5630001','IGNF','29',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','IGN72GEO','IGN72 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6634','IGNF','21',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','IGN72G','IGN72 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6634','IGNF','21',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','AMST63GEO','Ile Amsterdam 1963 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG0140001','IGNF','30',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','STPL69GEO','Ile Saint-Paul 1969 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG0150001','IGNF','62',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','NOVA53G','Juan de Nova  geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG3810001','IGNF','32',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','KAUE70G','Kauehi (MHPF70) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0290001','IGNF','33',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','KERG62G','Kerguelen geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0060001','IGNF','34',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','KERG62GEO','Kerguelen - K0 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG0060001','IGNF','34',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','LNGPGG','Lambert Nord de Guerre grades Paris',NULL,NULL,'geographic 2D','EPSG','6425','EPSG','6902','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','SYSLNG','Lambert Nord de Guerre grades Paris',NULL,NULL,'geographic 2D','EPSG','6425','EPSG','6902','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','LIFOU56G','Lifou IGN 56 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6633','IGNF','35',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MAKE50G','Makemo (SHM 1947-1950) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5830001','IGNF','36',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MANGA51G','Mangareva 1951 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5590001','IGNF','37',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MARE53G','Mare IGN53 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6641','IGNF','38',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MARQUI72G','Marquises (IGN72) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5970001','IGNF','13',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MART38GEO','Martinique Fort-Desaix geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6625','IGNF','39',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MARTFDG','Martinique Fort-Desaix geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6625','IGNF','39',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MART38G','Martinique Fort-Desaix geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6625','IGNF','39',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MAUPITIG','Maupiti (MOP 1983) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0340001','IGNF','40',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RANGI47GEO','MGT 1947 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG5880001','IGNF','53',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MHPF67G','MHPF 1967 GEOGRAPHIQUES (DMS)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0270001','IGNF','19',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MOHO55G','Mohotani (MHEFO 1955) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5640001','IGNF','41',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MHEFO55MG','Mohotani (MHEFO 1955) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5640001','IGNF','41',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MOOREA87G','Moorea 1987 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6691','IGNF','42',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MOOREA87GEO','Moorea 1987 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6691','IGNF','42',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','WALL78GEO','MOP 1978 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6639','IGNF','73',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MURU78G','Mururoa (IGN 1978) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5870001','IGNF','43',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MURU51G','Mururoa (MGT 1951) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5850001','IGNF','43',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MURU62G','Mururoa (MHOI 1962) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5860001','IGNF','43',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MURU59G','Mururoa (MHPF 1959) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5840001','IGNF','43',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','NEA74G','NEA74 NOUMEA geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG7080001','IGNF','44',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','LURESG','NOUVELLE TRIANGULATION DU DUCHE DU LUXEMBOURG GEOGRAPHIQUES (DMS)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6181','IGNF','45',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','LUXGEO','NOUVELLE TRIANGULATION DU DUCHE DU LUXEMBOURG GEOGRAPHIQUES (DMS)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6181','IGNF','45',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','NTFG','NTF GEOGRAPHIQUES GREENWICH (DMS)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6275','IGNF','4',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','NTFPGRAD','NTF geographiques Paris (gr)',NULL,NULL,'geographic 2D','EPSG','6425','EPSG','6807','IGNF','4',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','NTFP','NTF geographiques Paris (gr)',NULL,NULL,'geographic 2D','EPSG','6425','EPSG','6807','IGNF','4',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','NUKU72G','Nuku Hiva 1972 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6630','IGNF','46',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','NUKU72GEO','Nuku Hiva 1972 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6630','IGNF','46',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','OUVE72G','Ouvea MHNC 1972 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6634','IGNF','47',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','OUVEA72G','Ouvea MHNC 1972 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6634','IGNF','47',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','PETRELS72G','Petrels geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6636','IGNF','48',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','PDN92G','PITON DES NEIGES (1992) GEOGRAPHIQUES (DMS)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG3170201','IGNF','55',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','PDN08G','PITON DES NEIGES (2008) GEOGRAPHIQUES (DMS)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG3170301','IGNF','55',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TERA50GEO','Pointe Geologie Perroud 1950 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6637','IGNF','49',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','PGP50G','Pointe Geologie Perroud 1950 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6637','IGNF','49',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TERA50G','Pointe Geologie Perroud 1950 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6637','IGNF','49',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','PMARP55G','Port Martin geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0120001','IGNF','50',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','PMAR55G','Port Martin geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0120001','IGNF','50',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RAIV54G','Raivavae (Cadastre) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5530001','IGNF','52',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RAIV66G','Raivavae (MHPF 1966) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5540001','IGNF','52',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RANGI47G','Rangiroa (MGT 1947) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5880001','IGNF','53',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RANGI59G','Rangiroa (MHPF 1959) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5890001','IGNF','53',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RANGI68G','Rangiroa (MHPF 1966-68) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5900001','IGNF','53',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RAPA55G','Rapa (MHEFO 1955) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5550001','IGNF','54',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RAPA80G','Rapa (SEQ 1980) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5560001','IGNF','54',NULL,0);
INSERT INTO "area" VALUES('IGNF','75','ILES WALLIS, FUTUNA ET ALOFI','ILES WALLIS, FUTUNA ET ALOFI',-14.39,-13.16,-179.98,-176.3,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGWF96GEO','RESEAU GEODESIQUE DE WALLIS ET FUTUNA 1996 GEOGRAPHIQUE DMS',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG0890001','IGNF','75',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGWF96G','RESEAU GEODESIQUE DE WALLIS ET FUTUNA 1996 GEOGRAPHIQUE DMS',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0890001','IGNF','75',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','REUN47GEO','Reunion Piton des Neiges geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6626','IGNF','55',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','REUN49G','Reunion Piton des Neiges geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6626','IGNF','55',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','REUN47G','Reunion Piton des Neiges geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6626','IGNF','55',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGAF09GEODD','RGAF09 geographiques (dd)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG9150001','IGNF','56',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGAF09GDD','RGAF09 geographiques (dd)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG9150001','IGNF','56',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGAF09GEO','RGAF09 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG9150001','IGNF','56',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGAF09G','RGAF09 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG9150001','IGNF','56',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGF93GDD','RGF93 geographiques (dd)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6171','IGNF','4',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGF93GEODD','RGF93 geographiques (dd)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6171','IGNF','4',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGF93G','RGF93 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6171','IGNF','4',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGF93GEO','RGF93 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6171','IGNF','4',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGFG95GEODD','RGFG95 geographiques (dd)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6624','IGNF','10',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGFG95GDD','RGFG95 geographiques (dd)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6624','IGNF','10',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGFG95GEO','RGFG95 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6624','IGNF','10',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGFG95G','RGFG95 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6624','IGNF','10',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGM04GEODD','RGM04 geographiques (dd)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG7020001','IGNF','5',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGM04GDD','RGM04 geographiques (dd)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG7020001','IGNF','5',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGM04GEO','RGM04 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG7020001','IGNF','5',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGM04G','RGM04 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG7020001','IGNF','5',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGNCGEODD','RGNC GEOGRAPHIQUES (DD)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6645','IGNF','57',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGNCGEO','RGNC geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6645','IGNF','57',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGNCG','RGNC geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6645','IGNF','57',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGPFGDD','RGPF geographiques (dd)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6687','IGNF','58',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGPFGEO','RGPF geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6687','IGNF','58',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGPFG','RGPF geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6687','IGNF','58',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGR92GEODD','RGR92 geographiques (dd)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6627','IGNF','55',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGR92GDD','RGR92 geographiques (dd)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6627','IGNF','55',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGR92GEO','RGR92 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6627','IGNF','55',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGR92G','RGR92 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6627','IGNF','55',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGSPM06GEODD','RGSPM06 geographiques (dd)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG7060001','IGNF','59',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGSPM06GDD','RGSPM06 geographiques (dd)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG7060001','IGNF','59',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGSPM06GEO','RGSPM06 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG7060001','IGNF','59',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGSPM06G','RGSPM06 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG7060001','IGNF','59',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGTAAFGEODD','RGTAAF07 geographiques (dd)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG0360001','IGNF','60',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGTAAF07GDD','RGTAAF07 geographiques (dd)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0360001','IGNF','60',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGTAAF07G','RGTAAF07 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0360001','IGNF','60',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RGTAAFGEO','RGTAAF07 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG0360001','IGNF','60',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RRAFGDD','RRAF geographiques (dd)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6640','IGNF','56',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','WGS84MARTGDD','RRAF geographiques (dd)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6640','IGNF','56',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RRAFGEODD','RRAF geographiques (dd)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6640','IGNF','56',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','W84MARTGEODD','RRAF geographiques (dd)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6640','IGNF','56',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RRAFGEO','RRAF geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6640','IGNF','56',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','WGS84GUADGEO','RRAF geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6640','IGNF','56',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RRAFG','RRAF geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6640','IGNF','56',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','WGS84MARTG','RRAF geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6640','IGNF','56',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','RUSAT84G','Rurutu (SAT84) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0310001','IGNF','61',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','SAT84G','Rurutu (SAT84) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0310001','IGNF','61',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','STPL69G','Saint-Paul geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0150001','IGNF','62',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ST84G','ST 84 ILE DES PINS geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG7100001','IGNF','31',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ST87G','ST 87 OUVEA geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG7090001','IGNF','47',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','ST87GEO','ST 87 OUVEA geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG7090001','IGNF','47',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','STPM50G','St Pierre Miquelon 1950 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6638','IGNF','59',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','STPM50GEO','St Pierre Miquelon 1950 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6638','IGNF','59',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TAHAAGEO','Tahaa geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6629','IGNF','63',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TAHAAG','Tahaa geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6629','IGNF','63',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TAHI79G','Tahiti (IGN79) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6690','IGNF','64',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TAHI79GEO','Tahiti (IGN79) geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6690','IGNF','64',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TAHI51G','TAHITI TERME NORD GEOGRAPHIQUES (DMS)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6628','IGNF','64',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TAKA69G','Takaroa Takapoto (SHM 1969) geo. (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5910001','IGNF','65',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TANNAG','Tanna geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5250001','IGNF','66',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TETIA90G','Tetiaroa (MOP90) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0280001','IGNF','67',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','MOP90G','Tetiaroa (MOP90) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0280001','IGNF','67',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TIKE60G','Tikehau (MHPF 1960) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5920001','IGNF','68',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TIKE88G','TIKEHAU (MOP88) GEOGRAPHIQUES (DMS)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0870001','IGNF','68',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TIKE88GEO','TIKEHAU (MOP88) GEOGRAPHIQUES (DMS)',NULL,NULL,'geographic 3D','EPSG','6426','IGNF','REG0870001','IGNF','68',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TIKE50G','Tikehau (SHM 1947-1950) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5930001','IGNF','68',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TROM56G','Tromelin geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG3820001','IGNF','69',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TUAM86G','Tuamotu (MOP86) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5960001','IGNF','70',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','APAT86G','Tuamotu (MOP86) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5960001','IGNF','70',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TUBU55G','Tubuai (MGT 1955) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5570001','IGNF','71',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TUBU69G','Tubuai (MHPF 1969) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5580001','IGNF','71',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','TURI69G','Tureia (SHM 1969) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG5940001','IGNF','72',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','WALL76G','Wallis (MOP 1976) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','IGNF','REG0160001','IGNF','73',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','WALL78G','Wallis (MOP 1978) geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6639','IGNF','73',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','WGS72GEO','WGS72 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6322','IGNF','74',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','WGS72G','WGS72 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6322','IGNF','74',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','WGS84GEODD','WGS84 geographiques (dd)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6326','IGNF','74',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','WGS84GDD','WGS84 geographiques (dd)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6326','IGNF','74',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','WGS84G','WGS84 geographiques (dms)',NULL,NULL,'geographic 2D','EPSG','6424','EPSG','6326','IGNF','74',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','WGS84GEO','WGS84 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6326','IGNF','74',NULL,0);
INSERT INTO "geodetic_crs" VALUES('IGNF','WGS84RRAFGEO','WGS84 geographiques (dms)',NULL,NULL,'geographic 3D','EPSG','6426','EPSG','6326','IGNF','74',NULL,0);
INSERT INTO "area" VALUES('IGNF','76','BORA BORA (ARCHIPEL DE LA SOCIETE)','BORA BORA (ARCHIPEL DE LA SOCIETE)',-16.58,-16.42,-151.83,-151.67,0);
INSERT INTO "vertical_crs" VALUES('IGNF','BORA01','BORA_SAU 2001',NULL,NULL,'EPSG','6499','IGNF','REA052','IGNF','76',0);
INSERT INTO "vertical_crs" VALUES('IGNF','STPM50_V','DANGER 1950 (SAINT-PIERRE-ET-MIQUELON)',NULL,NULL,'EPSG','6499','IGNF','REA018','IGNF','59',0);
INSERT INTO "vertical_crs" VALUES('IGNF','PETRELS52','EPF 1952 (ILE DES PETRELS)',NULL,NULL,'EPSG','6499','IGNF','REA034','IGNF','48',0);
INSERT INTO "area" VALUES('IGNF','77','EUROPE (RESEAU VERTICAL UNIFIE)','EUROPE (RESEAU VERTICAL UNIFIE)',36,71.2,-10,32,0);
INSERT INTO "vertical_crs" VALUES('IGNF','EVRF2000','EVRF2000 (UELN-95/98)(EUROPEAN VERTICAL REFERENCE FRAME)',NULL,NULL,'EPSG','6499','IGNF','REA122','IGNF','77',0);
INSERT INTO "vertical_crs" VALUES('IGNF','EVRF2007','EVRF2007 (EUROPEAN VERTICAL REFERENCE FRAME 2007)',NULL,NULL,'EPSG','6499','IGNF','REA125','IGNF','77',0);
INSERT INTO "area" VALUES('IGNF','78','HUAHINE (ARCHIPEL DE LA SOCIETE)','HUAHINE (ARCHIPEL DE LA SOCIETE)',-17,-16.5,-151.5,-150.75,0);
INSERT INTO "vertical_crs" VALUES('IGNF','HUAH01','HUAHINE_SAU 2001',NULL,NULL,'EPSG','6499','IGNF','REA051','IGNF','78',0);
INSERT INTO "vertical_crs" VALUES('IGNF','KERG62','IGN 1962 (KERGUELEN)',NULL,NULL,'EPSG','6499','IGNF','REA026','IGNF','34',0);
INSERT INTO "vertical_crs" VALUES('IGNF','TAHITI66','IGN 1966 (TAHITI)',NULL,NULL,'EPSG','6499','IGNF','REA028','IGNF','64',0);
INSERT INTO "vertical_crs" VALUES('IGNF','UVEA84','IGN 1984 (ILE UVEA)',NULL,NULL,'EPSG','6499','IGNF','REA027','IGNF','73',0);
INSERT INTO "vertical_crs" VALUES('IGNF','MART87','IGN 1987 (MARTINIQUE)',NULL,NULL,'EPSG','6499','IGNF','REA014','IGNF','39',0);
INSERT INTO "area" VALUES('IGNF','79','GRANDE-TERRE ET BASSE-TERRE (GUADELOUPE)','GRANDE-TERRE ET BASSE-TERRE (GUADELOUPE)',15.88,16.63,-61.85,-61.08,0);
INSERT INTO "vertical_crs" VALUES('IGNF','GUAD88','IGN 1988 (GUADELOUPE)',NULL,NULL,'EPSG','6499','IGNF','REA006','IGNF','79',0);
INSERT INTO "area" VALUES('IGNF','80','ILE DES SAINTES (GUADELOUPE)','ILE DES SAINTES (GUADELOUPE)',15.8,15.93,-61.7,-61.48,0);
INSERT INTO "vertical_crs" VALUES('IGNF','GUAD88LS','IGN 1988 LS (GUADELOUPE / LES SAINTES)',NULL,NULL,'EPSG','6499','IGNF','REA008','IGNF','80',0);
INSERT INTO "area" VALUES('IGNF','81','ILE DE MARIE-GALANTE (GUADELOUPE)','ILE DE MARIE-GALANTE (GUADELOUPE)',15.8,16.13,-61.4,-61.08,0);
INSERT INTO "vertical_crs" VALUES('IGNF','GUAD88MG','IGN 1988 MG (GUADELOUPE / MARIE-GALANTE)',NULL,NULL,'EPSG','6499','IGNF','REA007','IGNF','81',0);
INSERT INTO "area" VALUES('IGNF','82','ILE DE SAINT-BARTHELEMY','ILE DE SAINT-BARTHELEMY',17.8,18.03,-63,-62.73,0);
INSERT INTO "vertical_crs" VALUES('IGNF','GUAD88SB','IGN 1988 SB (GUADELOUPE / SAINT-BARTHELEMY)',NULL,NULL,'EPSG','6499','IGNF','REA012','IGNF','82',0);
INSERT INTO "area" VALUES('IGNF','83','ILE DE SAINT-MARTIN (GUADELOUPE)','ILE DE SAINT-MARTIN (GUADELOUPE)',18,18.2,-63.2,-62.5,0);
INSERT INTO "vertical_crs" VALUES('IGNF','GUAD88SM','IGN 1988 SM (GUADELOUPE / SAINT-MARTIN)',NULL,NULL,'EPSG','6499','IGNF','REA009','IGNF','83',0);
INSERT INTO "vertical_crs" VALUES('IGNF','REUN89','IGN 1989 (REUNION)',NULL,NULL,'EPSG','6499','IGNF','REA033','IGNF','55',0);
INSERT INTO "area" VALUES('IGNF','84','ILE DE LA DESIRADE (GUADELOUPE)','ILE DE LA DESIRADE (GUADELOUPE)',16.25,16.4,-61.2,-60.75,0);
INSERT INTO "vertical_crs" VALUES('IGNF','GUAD92LD','IGN 1992 LD (GUADELOUPE / LA DESIRADE)',NULL,NULL,'EPSG','6499','IGNF','REA037','IGNF','84',0);
INSERT INTO "vertical_crs" VALUES('IGNF','GUAD2008LD','IGN 2008 LD (GUADELOUPE / LA DESIRADE)',NULL,NULL,'EPSG','6499','IGNF','REA053','IGNF','84',0);
INSERT INTO "vertical_crs" VALUES('IGNF','MAUPITI01','MAUPITI_SAU 2001',NULL,NULL,'EPSG','6499','IGNF','REA047','IGNF','40',0);
INSERT INTO "vertical_crs" VALUES('IGNF','MOOREA81','MOOREA 1981 (MOOREA_SAU 2001)',NULL,NULL,'EPSG','6499','IGNF','REA029','IGNF','42',0);
INSERT INTO "area" VALUES('IGNF','85','FRANCE CONTINENTALE (CORSE EXCLUE)','FRANCE CONTINENTALE (CORSE EXCLUE)',42,51.5,-5.5,8.5,0);
INSERT INTO "vertical_crs" VALUES('IGNF','BOURD','NGF-BOURDALOUE',NULL,NULL,'EPSG','6499','IGNF','REA001','IGNF','85',0);
INSERT INTO "vertical_crs" VALUES('IGNF','IGN69','NGF-IGN 1969',NULL,NULL,'EPSG','6499','IGNF','REA003','IGNF','85',0);
INSERT INTO "area" VALUES('IGNF','86','CORSE','CORSE',41.2,43.5,8,10,0);
INSERT INTO "vertical_crs" VALUES('IGNF','IGN78C','NGF-IGN 1978',NULL,NULL,'EPSG','6499','IGNF','REA011','IGNF','86',0);
INSERT INTO "vertical_crs" VALUES('IGNF','NGF84','NGF-LALLEMAND',NULL,NULL,'EPSG','6499','IGNF','REA002','IGNF','85',0);
INSERT INTO "area" VALUES('IGNF','87','ILES FUTUNA ET ALOFI (ILES HORN)','ILES FUTUNA ET ALOFI (ILES HORN)',-14.39,-14.23,-179.98,-178.2,0);
INSERT INTO "vertical_crs" VALUES('IGNF','FUTUNA1997','NGWF ILES HORN (FUTUNA ET ALOFI)',NULL,NULL,'EPSG','6499','IGNF','REA054','IGNF','87',0);
INSERT INTO "vertical_crs" VALUES('IGNF','WALLIS96','NGWF WALLIS (MOP 1996)',NULL,NULL,'EPSG','6499','IGNF','REA041','IGNF','73',0);
INSERT INTO "vertical_crs" VALUES('IGNF','GUYA77','NIVELLEMENT GENERAL DE GUYANE (NGG) 1977',NULL,NULL,'EPSG','6499','IGNF','REA016','IGNF','10',0);
INSERT INTO "vertical_crs" VALUES('IGNF','NGC48','NIVELLEMENT GENERAL DE LA CORSE (NGC)',NULL,NULL,'EPSG','6499','IGNF','REA010','IGNF','86',0);
INSERT INTO "vertical_crs" VALUES('IGNF','LIFOU91','NIVELLEMENT GENERAL DE LIFOU (IGN 1991 LF)',NULL,NULL,'EPSG','6499','IGNF','REA036','IGNF','35',0);
INSERT INTO "vertical_crs" VALUES('IGNF','MARE91','NIVELLEMENT GENERAL DE MARE (IGN 1991 MR)',NULL,NULL,'EPSG','6499','IGNF','REA035','IGNF','38',0);
INSERT INTO "vertical_crs" VALUES('IGNF','NCAL69','NIVELLEMENT GENERAL DE NOUVELLE-CALEDONIE (NGNC)',NULL,NULL,'EPSG','6499','IGNF','REA019','IGNF','21',0);
INSERT INTO "vertical_crs" VALUES('IGNF','NNLUX','NIVELLEMENT GENERAL DU LUXEMBOURG',NULL,NULL,'EPSG','6499','IGNF','REA109','IGNF','45',0);
INSERT INTO "vertical_crs" VALUES('IGNF','RAIA01','RAIATEA_SAU 2001',NULL,NULL,'EPSG','6499','IGNF','REA049','IGNF','51',0);
INSERT INTO "vertical_crs" VALUES('IGNF','MAYO53','SHOM 1953 (MAYOTTE)',NULL,NULL,'EPSG','6499','IGNF','REA038','IGNF','5',0);
INSERT INTO "vertical_crs" VALUES('IGNF','GLOR77','SHOM 1977 (ILES GLORIEUSES - CANAL DE MOZAMBIQUE)',NULL,NULL,'EPSG','6499','IGNF','REA042','IGNF','20',0);
INSERT INTO "vertical_crs" VALUES('IGNF','PINS78','SHOM 1978 (ILE DES PINS)',NULL,NULL,'EPSG','6499','IGNF','REA020','IGNF','31',0);
INSERT INTO "vertical_crs" VALUES('IGNF','SHOM1984WF','SHOM 1984 (WALLIS ET FUTUNA)',NULL,NULL,'EPSG','6499','IGNF','REA027','IGNF','73',0);
INSERT INTO "vertical_crs" VALUES('IGNF','TAHAA01','TAHAA_SAU 2001',NULL,NULL,'EPSG','6499','IGNF','REA050','IGNF','63',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG682','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers NOUVELLE TRIANGULATION DE LA FRANCE (NTF)',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ATIG','IGNF','NTF','IGNF','4',NULL,1286,83,-254,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG682_ATI_NTF','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers NOUVELLE TRIANGULATION DE LA FRANCE (NTF)',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ATI','IGNF','NTF','IGNF','4',NULL,1286,83,-254,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG682_ATIGG_TO_NTFG','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers NOUVELLE TRIANGULATION DE LA FRANCE (NTF)',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ATIGG','IGNF','NTFG','IGNF','4',NULL,1286,83,-254,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG683','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers NOUVELLE TRIANGULATION DE LA FRANCE (NTF)',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ATIG','IGNF','NTF','IGNF','85',NULL,1295,82,-263,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG683_ATI_NTF','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers NOUVELLE TRIANGULATION DE LA FRANCE (NTF)',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ATI','IGNF','NTF','IGNF','85',NULL,1295,82,-263,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG683_ATIGG_TO_NTFG','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers NOUVELLE TRIANGULATION DE LA FRANCE (NTF)',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ATIGG','IGNF','NTFG','IGNF','85',NULL,1295,82,-263,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG681','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ATIG','IGNF','WGS84','IGNF','4',NULL,1118,23,66,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG681_ATIG_RRAF91','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ATIG','IGNF','RRAF91','IGNF','4',NULL,1118,23,66,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG681_ATIG_4978','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ATIG','EPSG','4978','IGNF','4',NULL,1118,23,66,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG681_ATI_WGS84','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ATI','IGNF','WGS84','IGNF','4',NULL,1118,23,66,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG681_ATI_RRAF91','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ATI','IGNF','RRAF91','IGNF','4',NULL,1118,23,66,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG681_ATI_4978','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ATI','EPSG','4978','IGNF','4',NULL,1118,23,66,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG681_ATIGG_TO_WGS84GEODD','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ATIGG','IGNF','WGS84GEODD','IGNF','4',NULL,1118,23,66,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG681_ATIGG_TO_WGS84GDD','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ATIGG','IGNF','WGS84GDD','IGNF','4',NULL,1118,23,66,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG681_ATIGG_TO_WGS84G','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ATIGG','IGNF','WGS84G','IGNF','4',NULL,1118,23,66,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG681_ATIGG_TO_4326','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ATIGG','EPSG','4326','IGNF','4',NULL,1118,23,66,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG681_ATIGG_TO_WGS84GEO','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ATIGG','IGNF','WGS84GEO','IGNF','4',NULL,1118,23,66,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG681_ATIGG_TO_WGS84RRAFGEO','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ATIGG','IGNF','WGS84RRAFGEO','IGNF','4',NULL,1118,23,66,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG684','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ATIG','IGNF','WGS84','IGNF','85',NULL,1127,22,57,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG684_ATIG_RRAF91','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ATIG','IGNF','RRAF91','IGNF','85',NULL,1127,22,57,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG684_ATIG_4978','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ATIG','EPSG','4978','IGNF','85',NULL,1127,22,57,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG684_ATI_WGS84','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ATI','IGNF','WGS84','IGNF','85',NULL,1127,22,57,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG684_ATI_RRAF91','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ATI','IGNF','RRAF91','IGNF','85',NULL,1127,22,57,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG684_ATI_4978','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ATI','EPSG','4978','IGNF','85',NULL,1127,22,57,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG684_ATIGG_TO_WGS84GEODD','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ATIGG','IGNF','WGS84GEODD','IGNF','85',NULL,1127,22,57,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG684_ATIGG_TO_WGS84GDD','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ATIGG','IGNF','WGS84GDD','IGNF','85',NULL,1127,22,57,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG684_ATIGG_TO_WGS84G','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ATIGG','IGNF','WGS84G','IGNF','85',NULL,1127,22,57,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG684_ATIGG_TO_4326','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ATIGG','EPSG','4326','IGNF','85',NULL,1127,22,57,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG684_ATIGG_TO_WGS84GEO','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ATIGG','IGNF','WGS84GEO','IGNF','85',NULL,1127,22,57,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG684_ATIGG_TO_WGS84RRAFGEO','ANCIENNE TRIANGULATION DES INGENIEURS GEOGRAPHES (ATIG) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ATIGG','IGNF','WGS84RRAFGEO','IGNF','85',NULL,1127,22,57,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','88','ILE DE BORA-BORA','ILE DE BORA-BORA',-16.75,-16.25,-152.0,-151.5,0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1149','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers BORA_SAU 2001',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGPFGEO','IGNF','BORA01','IGNF','88',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggpf02-Bora.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','89','MAYOTTE','MAYOTTE',-13.05,-12.5,44.95,45.4,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG786','CADASTRE 1997 vers RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','CAD97','IGNF','RGM04','IGNF','89',NULL,-381.788,-57.501,-256.673,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG786_CAD97GEO_TO_RGM04GEODD','CADASTRE 1997 vers RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CAD97GEO','IGNF','RGM04GEODD','IGNF','89',NULL,-381.788,-57.501,-256.673,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG786_CAD97GEO_TO_RGM04GDD','CADASTRE 1997 vers RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CAD97GEO','IGNF','RGM04GDD','IGNF','89',NULL,-381.788,-57.501,-256.673,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG786_CAD97GEO_TO_RGM04GEO','CADASTRE 1997 vers RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CAD97GEO','IGNF','RGM04GEO','IGNF','89',NULL,-381.788,-57.501,-256.673,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG786_CAD97GEO_TO_RGM04G','CADASTRE 1997 vers RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CAD97GEO','IGNF','RGM04G','IGNF','89',NULL,-381.788,-57.501,-256.673,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG786_CAD97G_TO_RGM04GEODD','CADASTRE 1997 vers RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CAD97G','IGNF','RGM04GEODD','IGNF','89',NULL,-381.788,-57.501,-256.673,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG786_CAD97G_TO_RGM04GDD','CADASTRE 1997 vers RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CAD97G','IGNF','RGM04GDD','IGNF','89',NULL,-381.788,-57.501,-256.673,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG786_CAD97G_TO_RGM04GEO','CADASTRE 1997 vers RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CAD97G','IGNF','RGM04GEO','IGNF','89',NULL,-381.788,-57.501,-256.673,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG786_CAD97G_TO_RGM04G','CADASTRE 1997 vers RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CAD97G','IGNF','RGM04G','IGNF','89',NULL,-381.788,-57.501,-256.673,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG787','COMBANI vers RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','MAYO50','IGNF','RGM04','IGNF','89',NULL,-599.928,-275.552,-195.665,'EPSG','9001',-0.0835,-0.4715,0.0602,'EPSG','9104',49.2814,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG787_MAYO50GEO_TO_RGM04GEODD','COMBANI vers RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MAYO50GEO','IGNF','RGM04GEODD','IGNF','89',NULL,-599.928,-275.552,-195.665,'EPSG','9001',-0.0835,-0.4715,0.0602,'EPSG','9104',49.2814,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG787_MAYO50GEO_TO_RGM04GDD','COMBANI vers RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MAYO50GEO','IGNF','RGM04GDD','IGNF','89',NULL,-599.928,-275.552,-195.665,'EPSG','9001',-0.0835,-0.4715,0.0602,'EPSG','9104',49.2814,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG787_MAYO50GEO_TO_RGM04GEO','COMBANI vers RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MAYO50GEO','IGNF','RGM04GEO','IGNF','89',NULL,-599.928,-275.552,-195.665,'EPSG','9001',-0.0835,-0.4715,0.0602,'EPSG','9104',49.2814,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG787_MAYO50GEO_TO_RGM04G','COMBANI vers RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MAYO50GEO','IGNF','RGM04G','IGNF','89',NULL,-599.928,-275.552,-195.665,'EPSG','9001',-0.0835,-0.4715,0.0602,'EPSG','9104',49.2814,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG787_MAYO50G_TO_RGM04GEODD','COMBANI vers RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MAYO50G','IGNF','RGM04GEODD','IGNF','89',NULL,-599.928,-275.552,-195.665,'EPSG','9001',-0.0835,-0.4715,0.0602,'EPSG','9104',49.2814,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG787_MAYO50G_TO_RGM04GDD','COMBANI vers RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MAYO50G','IGNF','RGM04GDD','IGNF','89',NULL,-599.928,-275.552,-195.665,'EPSG','9001',-0.0835,-0.4715,0.0602,'EPSG','9104',49.2814,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG787_MAYO50G_TO_RGM04GEO','COMBANI vers RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MAYO50G','IGNF','RGM04GEO','IGNF','89',NULL,-599.928,-275.552,-195.665,'EPSG','9001',-0.0835,-0.4715,0.0602,'EPSG','9104',49.2814,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG787_MAYO50G_TO_RGM04G','COMBANI vers RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MAYO50G','IGNF','RGM04G','IGNF','89',NULL,-599.928,-275.552,-195.665,'EPSG','9001',-0.0835,-0.4715,0.0602,'EPSG','9104',49.2814,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG642','COMBANI vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MAYO50','IGNF','WGS84','IGNF','89',NULL,-382,-59,-262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG642_MAYO50_RRAF91','COMBANI vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MAYO50','IGNF','RRAF91','IGNF','89',NULL,-382,-59,-262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG642_MAYO50_4978','COMBANI vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MAYO50','EPSG','4978','IGNF','89',NULL,-382,-59,-262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG642_MAYO50GEO_TO_WGS84GEODD','COMBANI vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MAYO50GEO','IGNF','WGS84GEODD','IGNF','89',NULL,-382,-59,-262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG642_MAYO50GEO_TO_WGS84GDD','COMBANI vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MAYO50GEO','IGNF','WGS84GDD','IGNF','89',NULL,-382,-59,-262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG642_MAYO50GEO_TO_WGS84G','COMBANI vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MAYO50GEO','IGNF','WGS84G','IGNF','89',NULL,-382,-59,-262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG642_MAYO50GEO_TO_4326','COMBANI vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MAYO50GEO','EPSG','4326','IGNF','89',NULL,-382,-59,-262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG642_MAYO50GEO_TO_WGS84GEO','COMBANI vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MAYO50GEO','IGNF','WGS84GEO','IGNF','89',NULL,-382,-59,-262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG642_MAYO50GEO_TO_WGS84RRAFGEO','COMBANI vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MAYO50GEO','IGNF','WGS84RRAFGEO','IGNF','89',NULL,-382,-59,-262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG642_MAYO50G_TO_WGS84GEODD','COMBANI vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MAYO50G','IGNF','WGS84GEODD','IGNF','89',NULL,-382,-59,-262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG642_MAYO50G_TO_WGS84GDD','COMBANI vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MAYO50G','IGNF','WGS84GDD','IGNF','89',NULL,-382,-59,-262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG642_MAYO50G_TO_WGS84G','COMBANI vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MAYO50G','IGNF','WGS84G','IGNF','89',NULL,-382,-59,-262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG642_MAYO50G_TO_4326','COMBANI vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MAYO50G','EPSG','4326','IGNF','89',NULL,-382,-59,-262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG642_MAYO50G_TO_WGS84GEO','COMBANI vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MAYO50G','IGNF','WGS84GEO','IGNF','89',NULL,-382,-59,-262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG642_MAYO50G_TO_WGS84RRAFGEO','COMBANI vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MAYO50G','IGNF','WGS84RRAFGEO','IGNF','89',NULL,-382,-59,-262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG590','CSG 1967 vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','CSG67','IGNF','WGS84','EPSG','1262',NULL,-186,230,110,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG590_CSG67_RRAF91','CSG 1967 vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','CSG67','IGNF','RRAF91','EPSG','1262',NULL,-186,230,110,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG590_CSG67_4978','CSG 1967 vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','CSG67','EPSG','4978','EPSG','1262',NULL,-186,230,110,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG590_CSG67GEO_TO_WGS84GEODD','CSG 1967 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CSG67GEO','IGNF','WGS84GEODD','EPSG','1262',NULL,-186,230,110,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG590_CSG67GEO_TO_WGS84GDD','CSG 1967 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CSG67GEO','IGNF','WGS84GDD','EPSG','1262',NULL,-186,230,110,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG590_CSG67GEO_TO_WGS84G','CSG 1967 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CSG67GEO','IGNF','WGS84G','EPSG','1262',NULL,-186,230,110,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG590_CSG67GEO_TO_4326','CSG 1967 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CSG67GEO','EPSG','4326','EPSG','1262',NULL,-186,230,110,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG590_CSG67GEO_TO_WGS84GEO','CSG 1967 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CSG67GEO','IGNF','WGS84GEO','EPSG','1262',NULL,-186,230,110,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG590_CSG67GEO_TO_WGS84RRAFGEO','CSG 1967 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CSG67GEO','IGNF','WGS84RRAFGEO','EPSG','1262',NULL,-186,230,110,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG590_CSG67G_TO_WGS84GEODD','CSG 1967 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CSG67G','IGNF','WGS84GEODD','EPSG','1262',NULL,-186,230,110,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG590_CSG67G_TO_WGS84GDD','CSG 1967 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CSG67G','IGNF','WGS84GDD','EPSG','1262',NULL,-186,230,110,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG590_CSG67G_TO_WGS84G','CSG 1967 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CSG67G','IGNF','WGS84G','EPSG','1262',NULL,-186,230,110,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG590_CSG67G_TO_4326','CSG 1967 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CSG67G','EPSG','4326','EPSG','1262',NULL,-186,230,110,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG590_CSG67G_TO_WGS84GEO','CSG 1967 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CSG67G','IGNF','WGS84GEO','EPSG','1262',NULL,-186,230,110,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG590_CSG67G_TO_WGS84RRAFGEO','CSG 1967 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','CSG67G','IGNF','WGS84RRAFGEO','EPSG','1262',NULL,-186,230,110,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','90','GUYANE','GUYANE',2.05,5.95,-54.95,-51.05,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG417','CSG 1967 (IGN 1995) vers RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','C67I95','IGNF','RGFG95','IGNF','90',NULL,-193.066,236.993,105.447,'EPSG','9001',0.4814,-0.8074,0.1276,'EPSG','9104',1.5649,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG417_C67IG95G_TO_RGFG95GEODD','CSG 1967 (IGN 1995) vers RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','C67IG95G','IGNF','RGFG95GEODD','IGNF','90',NULL,-193.066,236.993,105.447,'EPSG','9001',0.4814,-0.8074,0.1276,'EPSG','9104',1.5649,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG417_C67IG95G_TO_RGFG95GDD','CSG 1967 (IGN 1995) vers RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','C67IG95G','IGNF','RGFG95GDD','IGNF','90',NULL,-193.066,236.993,105.447,'EPSG','9001',0.4814,-0.8074,0.1276,'EPSG','9104',1.5649,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG417_C67IG95G_TO_RGFG95GEO','CSG 1967 (IGN 1995) vers RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','C67IG95G','IGNF','RGFG95GEO','IGNF','90',NULL,-193.066,236.993,105.447,'EPSG','9001',0.4814,-0.8074,0.1276,'EPSG','9104',1.5649,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG417_C67IG95G_TO_RGFG95G','CSG 1967 (IGN 1995) vers RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','C67IG95G','IGNF','RGFG95G','IGNF','90',NULL,-193.066,236.993,105.447,'EPSG','9001',0.4814,-0.8074,0.1276,'EPSG','9104',1.5649,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1156','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers DANGER 1950 (SAINT-PIERRE-ET-MIQUELON)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGSPM06GEO','IGNF','STPM50_V','IGNF','59',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggspm06v1.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','91','FRANCE','FRANCE',41,52,-5.5,10,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG348','DOD WORLD GEODETIC SYSTEM 1972 (WGS 72) vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','WGS72','IGNF','WGS84','IGNF','91',NULL,0,12,6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG348_WGS72_RRAF91','DOD WORLD GEODETIC SYSTEM 1972 (WGS 72) vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','WGS72','IGNF','RRAF91','IGNF','91',NULL,0,12,6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG348_WGS72_4978','DOD WORLD GEODETIC SYSTEM 1972 (WGS 72) vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','WGS72','EPSG','4978','IGNF','91',NULL,0,12,6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG348_WGS72GEO_TO_WGS84GEODD','DOD WORLD GEODETIC SYSTEM 1972 (WGS 72) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WGS72GEO','IGNF','WGS84GEODD','IGNF','91',NULL,0,12,6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG348_WGS72GEO_TO_WGS84GDD','DOD WORLD GEODETIC SYSTEM 1972 (WGS 72) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WGS72GEO','IGNF','WGS84GDD','IGNF','91',NULL,0,12,6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG348_WGS72GEO_TO_WGS84G','DOD WORLD GEODETIC SYSTEM 1972 (WGS 72) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WGS72GEO','IGNF','WGS84G','IGNF','91',NULL,0,12,6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG348_WGS72GEO_TO_4326','DOD WORLD GEODETIC SYSTEM 1972 (WGS 72) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WGS72GEO','EPSG','4326','IGNF','91',NULL,0,12,6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG348_WGS72GEO_TO_WGS84GEO','DOD WORLD GEODETIC SYSTEM 1972 (WGS 72) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WGS72GEO','IGNF','WGS84GEO','IGNF','91',NULL,0,12,6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG348_WGS72GEO_TO_WGS84RRAFGEO','DOD WORLD GEODETIC SYSTEM 1972 (WGS 72) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WGS72GEO','IGNF','WGS84RRAFGEO','IGNF','91',NULL,0,12,6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG348_WGS72G_TO_WGS84GEODD','DOD WORLD GEODETIC SYSTEM 1972 (WGS 72) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WGS72G','IGNF','WGS84GEODD','IGNF','91',NULL,0,12,6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG348_WGS72G_TO_WGS84GDD','DOD WORLD GEODETIC SYSTEM 1972 (WGS 72) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WGS72G','IGNF','WGS84GDD','IGNF','91',NULL,0,12,6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG348_WGS72G_TO_WGS84G','DOD WORLD GEODETIC SYSTEM 1972 (WGS 72) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WGS72G','IGNF','WGS84G','IGNF','91',NULL,0,12,6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG348_WGS72G_TO_4326','DOD WORLD GEODETIC SYSTEM 1972 (WGS 72) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WGS72G','EPSG','4326','IGNF','91',NULL,0,12,6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG348_WGS72G_TO_WGS84GEO','DOD WORLD GEODETIC SYSTEM 1972 (WGS 72) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WGS72G','IGNF','WGS84GEO','IGNF','91',NULL,0,12,6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG348_WGS72G_TO_WGS84RRAFGEO','DOD WORLD GEODETIC SYSTEM 1972 (WGS 72) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WGS72G','IGNF','WGS84RRAFGEO','IGNF','91',NULL,0,12,6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','92','VANUATU','VANUATU',-18,-17.25,168,168.67,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG518','EFATE-IGN 1957 vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','EFATE57','IGNF','WGS84','IGNF','92',NULL,-127,-769,472,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG518_EFATE57_RRAF91','EFATE-IGN 1957 vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','EFATE57','IGNF','RRAF91','IGNF','92',NULL,-127,-769,472,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG518_EFATE57_4978','EFATE-IGN 1957 vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','EFATE57','EPSG','4978','IGNF','92',NULL,-127,-769,472,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG518_EFATE57GEO_TO_WGS84GEODD','EFATE-IGN 1957 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','EFATE57GEO','IGNF','WGS84GEODD','IGNF','92',NULL,-127,-769,472,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG518_EFATE57GEO_TO_WGS84GDD','EFATE-IGN 1957 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','EFATE57GEO','IGNF','WGS84GDD','IGNF','92',NULL,-127,-769,472,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG518_EFATE57GEO_TO_WGS84G','EFATE-IGN 1957 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','EFATE57GEO','IGNF','WGS84G','IGNF','92',NULL,-127,-769,472,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG518_EFATE57GEO_TO_4326','EFATE-IGN 1957 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','EFATE57GEO','EPSG','4326','IGNF','92',NULL,-127,-769,472,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG518_EFATE57GEO_TO_WGS84GEO','EFATE-IGN 1957 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','EFATE57GEO','IGNF','WGS84GEO','IGNF','92',NULL,-127,-769,472,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG518_EFATE57GEO_TO_WGS84RRAFGEO','EFATE-IGN 1957 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','EFATE57GEO','IGNF','WGS84RRAFGEO','IGNF','92',NULL,-127,-769,472,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG518_EFATE57G_TO_WGS84GEODD','EFATE-IGN 1957 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','EFATE57G','IGNF','WGS84GEODD','IGNF','92',NULL,-127,-769,472,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG518_EFATE57G_TO_WGS84GDD','EFATE-IGN 1957 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','EFATE57G','IGNF','WGS84GDD','IGNF','92',NULL,-127,-769,472,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG518_EFATE57G_TO_WGS84G','EFATE-IGN 1957 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','EFATE57G','IGNF','WGS84G','IGNF','92',NULL,-127,-769,472,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG518_EFATE57G_TO_4326','EFATE-IGN 1957 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','EFATE57G','EPSG','4326','IGNF','92',NULL,-127,-769,472,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG518_EFATE57G_TO_WGS84GEO','EFATE-IGN 1957 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','EFATE57G','IGNF','WGS84GEO','IGNF','92',NULL,-127,-769,472,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG518_EFATE57G_TO_WGS84RRAFGEO','EFATE-IGN 1957 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','EFATE57G','IGNF','WGS84RRAFGEO','IGNF','92',NULL,-127,-769,472,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1214','ETRS 89 vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ETRS89','IGNF','WGS84','IGNF','14',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1214_ETRS89_RRAF91','ETRS 89 vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ETRS89','IGNF','RRAF91','IGNF','14',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1214_ETRS89_4978','ETRS 89 vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ETRS89','EPSG','4978','IGNF','14',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1214_ETRS89G_TO_WGS84GEODD','ETRS 89 vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ETRS89G','IGNF','WGS84GEODD','IGNF','14',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1214_ETRS89G_TO_WGS84GDD','ETRS 89 vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ETRS89G','IGNF','WGS84GDD','IGNF','14',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1214_ETRS89G_TO_WGS84G','ETRS 89 vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ETRS89G','IGNF','WGS84G','IGNF','14',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1214_ETRS89G_TO_4326','ETRS 89 vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ETRS89G','EPSG','4326','IGNF','14',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1214_ETRS89G_TO_WGS84GEO','ETRS 89 vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ETRS89G','IGNF','WGS84GEO','IGNF','14',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1214_ETRS89G_TO_WGS84RRAFGEO','ETRS 89 vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ETRS89G','IGNF','WGS84RRAFGEO','IGNF','14',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1214_ETRS89GEO_TO_WGS84GEODD','ETRS 89 vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ETRS89GEO','IGNF','WGS84GEODD','IGNF','14',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1214_ETRS89GEO_TO_WGS84GDD','ETRS 89 vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ETRS89GEO','IGNF','WGS84GDD','IGNF','14',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1214_ETRS89GEO_TO_WGS84G','ETRS 89 vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ETRS89GEO','IGNF','WGS84G','IGNF','14',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1214_ETRS89GEO_TO_4326','ETRS 89 vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ETRS89GEO','EPSG','4326','IGNF','14',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1214_ETRS89GEO_TO_WGS84GEO','ETRS 89 vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ETRS89GEO','IGNF','WGS84GEO','IGNF','14',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1214_ETRS89GEO_TO_WGS84RRAFGEO','ETRS 89 vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ETRS89GEO','IGNF','WGS84RRAFGEO','IGNF','14',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG709','EUROPE 1950 (ED50) vers WGS 84',NULL,'NATIONALE, HISTORIQUE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ED50','IGNF','WGS84','IGNF','91',NULL,-84,-97,-117,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG709_ED50_RRAF91','EUROPE 1950 (ED50) vers WGS 84',NULL,'NATIONALE, HISTORIQUE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ED50','IGNF','RRAF91','IGNF','91',NULL,-84,-97,-117,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG709_ED50_4978','EUROPE 1950 (ED50) vers WGS 84',NULL,'NATIONALE, HISTORIQUE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ED50','EPSG','4978','IGNF','91',NULL,-84,-97,-117,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG709_ED50G_TO_WGS84GEODD','EUROPE 1950 (ED50) vers WGS 84',NULL,'NATIONALE, HISTORIQUE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ED50G','IGNF','WGS84GEODD','IGNF','91',NULL,-84,-97,-117,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG709_ED50GEO_TO_WGS84GEODD','EUROPE 1950 (ED50) vers WGS 84',NULL,'NATIONALE, HISTORIQUE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ED50GEO','IGNF','WGS84GEODD','IGNF','91',NULL,-84,-97,-117,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG709_ED50G_TO_WGS84GDD','EUROPE 1950 (ED50) vers WGS 84',NULL,'NATIONALE, HISTORIQUE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ED50G','IGNF','WGS84GDD','IGNF','91',NULL,-84,-97,-117,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG709_ED50GEO_TO_WGS84GDD','EUROPE 1950 (ED50) vers WGS 84',NULL,'NATIONALE, HISTORIQUE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ED50GEO','IGNF','WGS84GDD','IGNF','91',NULL,-84,-97,-117,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG709_ED50G_TO_WGS84G','EUROPE 1950 (ED50) vers WGS 84',NULL,'NATIONALE, HISTORIQUE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ED50G','IGNF','WGS84G','IGNF','91',NULL,-84,-97,-117,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG709_ED50G_TO_4326','EUROPE 1950 (ED50) vers WGS 84',NULL,'NATIONALE, HISTORIQUE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ED50G','EPSG','4326','IGNF','91',NULL,-84,-97,-117,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG709_ED50GEO_TO_WGS84G','EUROPE 1950 (ED50) vers WGS 84',NULL,'NATIONALE, HISTORIQUE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ED50GEO','IGNF','WGS84G','IGNF','91',NULL,-84,-97,-117,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG709_ED50GEO_TO_4326','EUROPE 1950 (ED50) vers WGS 84',NULL,'NATIONALE, HISTORIQUE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ED50GEO','EPSG','4326','IGNF','91',NULL,-84,-97,-117,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG709_ED50G_TO_WGS84GEO','EUROPE 1950 (ED50) vers WGS 84',NULL,'NATIONALE, HISTORIQUE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ED50G','IGNF','WGS84GEO','IGNF','91',NULL,-84,-97,-117,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG709_ED50G_TO_WGS84RRAFGEO','EUROPE 1950 (ED50) vers WGS 84',NULL,'NATIONALE, HISTORIQUE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ED50G','IGNF','WGS84RRAFGEO','IGNF','91',NULL,-84,-97,-117,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG709_ED50GEO_TO_WGS84GEO','EUROPE 1950 (ED50) vers WGS 84',NULL,'NATIONALE, HISTORIQUE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ED50GEO','IGNF','WGS84GEO','IGNF','91',NULL,-84,-97,-117,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG709_ED50GEO_TO_WGS84RRAFGEO','EUROPE 1950 (ED50) vers WGS 84',NULL,'NATIONALE, HISTORIQUE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ED50GEO','IGNF','WGS84RRAFGEO','IGNF','91',NULL,-84,-97,-117,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','93','GUADELOUPE (ILES ST-MARTIN ET ST-BARTHELEMY)','GUADELOUPE (ILES ST-MARTIN ET ST-BARTHELEMY)',17.82,18.18,-63.18,-62.25,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','GUADFM','IGNF','RRAF','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFM_WGS84GUAD','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','GUADFM','IGNF','WGS84GUAD','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFM49_RRAF','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','GUADFM49','IGNF','RRAF','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFM49_WGS84GUAD','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','GUADFM49','IGNF','WGS84GUAD','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFMG_TO_RRAFGDD','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADFMG','IGNF','RRAFGDD','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFMG_TO_WGS84MARTGDD','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADFMG','IGNF','WGS84MARTGDD','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUAFM48G_TO_RRAFGDD','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAFM48G','IGNF','RRAFGDD','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUAFM48G_TO_WGS84MARTGDD','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAFM48G','IGNF','WGS84MARTGDD','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFMG_TO_RRAFGEODD','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADFMG','IGNF','RRAFGEODD','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFMG_TO_W84MARTGEODD','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADFMG','IGNF','W84MARTGEODD','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUAFM48G_TO_RRAFGEODD','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAFM48G','IGNF','RRAFGEODD','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUAFM48G_TO_W84MARTGEODD','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAFM48G','IGNF','W84MARTGEODD','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFMG_TO_RRAFGEO','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADFMG','IGNF','RRAFGEO','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFMG_TO_WGS84GUADGEO','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADFMG','IGNF','WGS84GUADGEO','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUAFM48G_TO_RRAFGEO','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAFM48G','IGNF','RRAFGEO','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUAFM48G_TO_WGS84GUADGEO','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAFM48G','IGNF','WGS84GUADGEO','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFMG_TO_RRAFG','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADFMG','IGNF','RRAFG','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFMG_TO_WGS84MARTG','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADFMG','IGNF','WGS84MARTG','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUAFM48G_TO_RRAFG','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAFM48G','IGNF','RRAFG','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUAFM48G_TO_WGS84MARTG','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAFM48G','IGNF','WGS84MARTG','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFM49GEO_TO_RRAFGDD','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADFM49GEO','IGNF','RRAFGDD','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFM49GEO_TO_WGS84MARTGDD','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADFM49GEO','IGNF','WGS84MARTGDD','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFM49GEO_TO_RRAFGEODD','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADFM49GEO','IGNF','RRAFGEODD','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFM49GEO_TO_W84MARTGEODD','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADFM49GEO','IGNF','W84MARTGEODD','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFM49GEO_TO_RRAFGEO','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADFM49GEO','IGNF','RRAFGEO','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFM49GEO_TO_WGS84GUADGEO','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADFM49GEO','IGNF','WGS84GUADGEO','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFM49GEO_TO_RRAFG','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADFM49GEO','IGNF','RRAFG','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG464_GUADFM49GEO_TO_WGS84MARTG','GUADELOUPE - FORT MARIGOT vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADFM49GEO','IGNF','WGS84MARTG','IGNF','93',NULL,136.596,248.148,-429.789,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','94','BASSE TERRE - GRANDE TERRE','BASSE TERRE - GRANDE TERRE',15.88,16.63,-61.85,-61.08,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','GUADANN','IGNF','WGS84','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUADANN_RRAF91','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','GUADANN','IGNF','RRAF91','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUADANN_4978','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','GUADANN','EPSG','4978','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUAD48_WGS84','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','GUAD48','IGNF','WGS84','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUAD48_RRAF91','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','GUAD48','IGNF','RRAF91','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUAD48_4978','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','GUAD48','EPSG','4978','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUADANNG_TO_WGS84GEODD','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADANNG','IGNF','WGS84GEODD','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUAD48G_TO_WGS84GEODD','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAD48G','IGNF','WGS84GEODD','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUADANNG_TO_WGS84GDD','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADANNG','IGNF','WGS84GDD','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUAD48G_TO_WGS84GDD','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAD48G','IGNF','WGS84GDD','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUADANNG_TO_WGS84G','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADANNG','IGNF','WGS84G','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUADANNG_TO_4326','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADANNG','EPSG','4326','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUAD48G_TO_WGS84G','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAD48G','IGNF','WGS84G','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUAD48G_TO_4326','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAD48G','EPSG','4326','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUADANNG_TO_WGS84GEO','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADANNG','IGNF','WGS84GEO','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUADANNG_TO_WGS84RRAFGEO','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUADANNG','IGNF','WGS84RRAFGEO','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUAD48G_TO_WGS84GEO','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAD48G','IGNF','WGS84GEO','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUAD48G_TO_WGS84RRAFGEO','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAD48G','IGNF','WGS84RRAFGEO','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUAD48GEO_TO_WGS84GEODD','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAD48GEO','IGNF','WGS84GEODD','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUAD48GEO_TO_WGS84GDD','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAD48GEO','IGNF','WGS84GDD','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUAD48GEO_TO_WGS84G','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAD48GEO','IGNF','WGS84G','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUAD48GEO_TO_4326','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAD48GEO','EPSG','4326','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUAD48GEO_TO_WGS84GEO','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAD48GEO','IGNF','WGS84GEO','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG592_GUAD48GEO_TO_WGS84RRAFGEO','GUADELOUPE - STE ANNE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','GUAD48GEO','IGNF','WGS84RRAFGEO','IGNF','94',NULL,-467,-16,-300,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','95','GUADELOUPE (TOUTES ILES SAUF ST-BARTHELEMY ET ST-MARTIN)','GUADELOUPE (TOUTES ILES SAUF ST-BARTHELEMY ET ST-MARTIN)',15.82,16.6,-61.83,-60.77,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','GUADANN','IGNF','RRAF','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUADANN_WGS84GUAD','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','GUADANN','IGNF','WGS84GUAD','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUAD48_RRAF','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','GUAD48','IGNF','RRAF','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUAD48_WGS84GUAD','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','GUAD48','IGNF','WGS84GUAD','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUADANNG_TO_RRAFGDD','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUADANNG','IGNF','RRAFGDD','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUADANNG_TO_WGS84MARTGDD','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUADANNG','IGNF','WGS84MARTGDD','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUAD48G_TO_RRAFGDD','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUAD48G','IGNF','RRAFGDD','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUAD48G_TO_WGS84MARTGDD','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUAD48G','IGNF','WGS84MARTGDD','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUADANNG_TO_RRAFGEODD','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUADANNG','IGNF','RRAFGEODD','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUADANNG_TO_W84MARTGEODD','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUADANNG','IGNF','W84MARTGEODD','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUAD48G_TO_RRAFGEODD','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUAD48G','IGNF','RRAFGEODD','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUAD48G_TO_W84MARTGEODD','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUAD48G','IGNF','W84MARTGEODD','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUADANNG_TO_RRAFGEO','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUADANNG','IGNF','RRAFGEO','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUADANNG_TO_WGS84GUADGEO','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUADANNG','IGNF','WGS84GUADGEO','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUAD48G_TO_RRAFGEO','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUAD48G','IGNF','RRAFGEO','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUAD48G_TO_WGS84GUADGEO','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUAD48G','IGNF','WGS84GUADGEO','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUADANNG_TO_RRAFG','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUADANNG','IGNF','RRAFG','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUADANNG_TO_WGS84MARTG','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUADANNG','IGNF','WGS84MARTG','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUAD48G_TO_RRAFG','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUAD48G','IGNF','RRAFG','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUAD48G_TO_WGS84MARTG','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUAD48G','IGNF','WGS84MARTG','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUAD48GEO_TO_RRAFGDD','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUAD48GEO','IGNF','RRAFGDD','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUAD48GEO_TO_WGS84MARTGDD','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUAD48GEO','IGNF','WGS84MARTGDD','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUAD48GEO_TO_RRAFGEODD','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUAD48GEO','IGNF','RRAFGEODD','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUAD48GEO_TO_W84MARTGEODD','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUAD48GEO','IGNF','W84MARTGEODD','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUAD48GEO_TO_RRAFGEO','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUAD48GEO','IGNF','RRAFGEO','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUAD48GEO_TO_WGS84GUADGEO','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUAD48GEO','IGNF','WGS84GUADGEO','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUAD48GEO_TO_RRAFG','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUAD48GEO','IGNF','RRAFG','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG465_GUAD48GEO_TO_WGS84MARTG','GUADELOUPE - STE ANNE vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','GUAD48GEO','IGNF','WGS84MARTG','IGNF','95',NULL,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','96','ILE DE HUAHINE','ILE DE HUAHINE',-17.0,-16.5,-151.5,-150.75,0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1150','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers HUAHINE_SAU 2001',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGPFGEO','IGNF','HUAH01','IGNF','96',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggpf02-Huahine.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','97','GRANDE TERRE DES ILES KERGUELEN','GRANDE TERRE DES ILES KERGUELEN',-50.5,-48.0,67.0,71.0,0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1148','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers IGN 1962 (KERGUELEN)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGTAAFGEO','IGNF','KERG62','IGNF','97',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggker08v2.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','98','HIVA OA, TAHUATA, MOHOTANI','HIVA OA, TAHUATA, MOHOTANI',-9.88,-9.65,-139.2,-138.75,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1006','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','ATUO63','IGNF','RGPF','IGNF','98',NULL,410.721,55.049,80.746,'EPSG','9001',-2.5779,-2.3514,-0.6664,'EPSG','9104',17.3311,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1006_IGN63_RGPF','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','IGN63','IGNF','RGPF','IGNF','98',NULL,410.721,55.049,80.746,'EPSG','9001',-2.5779,-2.3514,-0.6664,'EPSG','9104',17.3311,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1006_ATUO63G_TO_RGPFGDD','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','ATUO63G','IGNF','RGPFGDD','IGNF','98',NULL,410.721,55.049,80.746,'EPSG','9001',-2.5779,-2.3514,-0.6664,'EPSG','9104',17.3311,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1006_IGN63G_TO_RGPFGDD','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','IGN63G','IGNF','RGPFGDD','IGNF','98',NULL,410.721,55.049,80.746,'EPSG','9001',-2.5779,-2.3514,-0.6664,'EPSG','9104',17.3311,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1006_ATUO63G_TO_RGPFGEO','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','ATUO63G','IGNF','RGPFGEO','IGNF','98',NULL,410.721,55.049,80.746,'EPSG','9001',-2.5779,-2.3514,-0.6664,'EPSG','9104',17.3311,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1006_IGN63G_TO_RGPFGEO','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','IGN63G','IGNF','RGPFGEO','IGNF','98',NULL,410.721,55.049,80.746,'EPSG','9001',-2.5779,-2.3514,-0.6664,'EPSG','9104',17.3311,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1006_ATUO63G_TO_RGPFG','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','ATUO63G','IGNF','RGPFG','IGNF','98',NULL,410.721,55.049,80.746,'EPSG','9001',-2.5779,-2.3514,-0.6664,'EPSG','9104',17.3311,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1006_IGN63G_TO_RGPFG','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','IGN63G','IGNF','RGPFG','IGNF','98',NULL,410.721,55.049,80.746,'EPSG','9001',-2.5779,-2.3514,-0.6664,'EPSG','9104',17.3311,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1006_IGN63GEO_TO_RGPFGDD','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','IGN63GEO','IGNF','RGPFGDD','IGNF','98',NULL,410.721,55.049,80.746,'EPSG','9001',-2.5779,-2.3514,-0.6664,'EPSG','9104',17.3311,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1006_IGN63GEO_TO_RGPFGEO','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','IGN63GEO','IGNF','RGPFGEO','IGNF','98',NULL,410.721,55.049,80.746,'EPSG','9001',-2.5779,-2.3514,-0.6664,'EPSG','9104',17.3311,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1006_IGN63GEO_TO_RGPFG','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','IGN63GEO','IGNF','RGPFG','IGNF','98',NULL,410.721,55.049,80.746,'EPSG','9001',-2.5779,-2.3514,-0.6664,'EPSG','9104',17.3311,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','99','TAHUATA','TAHUATA',-10.05,-9.85,-139.2,-139,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1008','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','ATUO63','IGNF','RGPF','IGNF','99',NULL,374.715,-58.407,-0.957,'EPSG','9001',-16.2111,-11.4626,-5.5357,'EPSG','9104',-0.5409,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1008_IGN63_RGPF','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','IGN63','IGNF','RGPF','IGNF','99',NULL,374.715,-58.407,-0.957,'EPSG','9001',-16.2111,-11.4626,-5.5357,'EPSG','9104',-0.5409,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1008_ATUO63G_TO_RGPFGDD','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','ATUO63G','IGNF','RGPFGDD','IGNF','99',NULL,374.715,-58.407,-0.957,'EPSG','9001',-16.2111,-11.4626,-5.5357,'EPSG','9104',-0.5409,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1008_IGN63G_TO_RGPFGDD','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','IGN63G','IGNF','RGPFGDD','IGNF','99',NULL,374.715,-58.407,-0.957,'EPSG','9001',-16.2111,-11.4626,-5.5357,'EPSG','9104',-0.5409,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1008_ATUO63G_TO_RGPFGEO','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','ATUO63G','IGNF','RGPFGEO','IGNF','99',NULL,374.715,-58.407,-0.957,'EPSG','9001',-16.2111,-11.4626,-5.5357,'EPSG','9104',-0.5409,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1008_IGN63G_TO_RGPFGEO','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','IGN63G','IGNF','RGPFGEO','IGNF','99',NULL,374.715,-58.407,-0.957,'EPSG','9001',-16.2111,-11.4626,-5.5357,'EPSG','9104',-0.5409,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1008_ATUO63G_TO_RGPFG','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','ATUO63G','IGNF','RGPFG','IGNF','99',NULL,374.715,-58.407,-0.957,'EPSG','9001',-16.2111,-11.4626,-5.5357,'EPSG','9104',-0.5409,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1008_IGN63G_TO_RGPFG','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','IGN63G','IGNF','RGPFG','IGNF','99',NULL,374.715,-58.407,-0.957,'EPSG','9001',-16.2111,-11.4626,-5.5357,'EPSG','9104',-0.5409,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1008_IGN63GEO_TO_RGPFGDD','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','IGN63GEO','IGNF','RGPFGDD','IGNF','99',NULL,374.715,-58.407,-0.957,'EPSG','9001',-16.2111,-11.4626,-5.5357,'EPSG','9104',-0.5409,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1008_IGN63GEO_TO_RGPFGEO','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','IGN63GEO','IGNF','RGPFGEO','IGNF','99',NULL,374.715,-58.407,-0.957,'EPSG','9001',-16.2111,-11.4626,-5.5357,'EPSG','9104',-0.5409,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1008_IGN63GEO_TO_RGPFG','IGN 1963 (HIVA OA - TAHUATA - MOHOTANI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','IGN63GEO','IGNF','RGPFG','IGNF','99',NULL,374.715,-58.407,-0.957,'EPSG','9001',-16.2111,-11.4626,-5.5357,'EPSG','9104',-0.5409,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','100','ILE DE FAKARAVA','ILE DE FAKARAVA',-16.65,-15.95,-145.9,-145.3,0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1185','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers IGN 1966 (TAHITI)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGPFGEO','IGNF','TAHITI66','IGNF','100',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggpf08-Fakarava.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','101','ILE DE TAHITI','ILE DE TAHITI',-18.0,-17.0,-149.69,-149.0,0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1195','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers IGN 1966 (TAHITI)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGPFGEO','IGNF','TAHITI66','IGNF','101',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggpf10-Tahiti.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','102','NUKU HIVA','NUKU HIVA',-9,-8.7,-140.3,-140,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1007','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','NUKU72','IGNF','RGPF','IGNF','102',NULL,165.732,216.720,180.505,'EPSG','9001',-0.6434,-0.4512,-0.0791,'EPSG','9104',7.4204,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1007_NUKU72G_TO_RGPFGDD','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','NUKU72G','IGNF','RGPFGDD','IGNF','102',NULL,165.732,216.720,180.505,'EPSG','9001',-0.6434,-0.4512,-0.0791,'EPSG','9104',7.4204,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1007_NUKU72G_TO_RGPFGEO','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','NUKU72G','IGNF','RGPFGEO','IGNF','102',NULL,165.732,216.720,180.505,'EPSG','9001',-0.6434,-0.4512,-0.0791,'EPSG','9104',7.4204,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1007_NUKU72G_TO_RGPFG','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','NUKU72G','IGNF','RGPFG','IGNF','102',NULL,165.732,216.720,180.505,'EPSG','9001',-0.6434,-0.4512,-0.0791,'EPSG','9104',7.4204,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1007_NUKU72GEO_TO_RGPFGDD','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','NUKU72GEO','IGNF','RGPFGDD','IGNF','102',NULL,165.732,216.720,180.505,'EPSG','9001',-0.6434,-0.4512,-0.0791,'EPSG','9104',7.4204,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1007_NUKU72GEO_TO_RGPFGEO','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','NUKU72GEO','IGNF','RGPFGEO','IGNF','102',NULL,165.732,216.720,180.505,'EPSG','9001',-0.6434,-0.4512,-0.0791,'EPSG','9104',7.4204,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1007_NUKU72GEO_TO_RGPFG','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','NUKU72GEO','IGNF','RGPFG','IGNF','102',NULL,165.732,216.720,180.505,'EPSG','9001',-0.6434,-0.4512,-0.0791,'EPSG','9104',7.4204,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','103','UA HUKA','UA HUKA',-9.09,-8.75,-139.65,-139.25,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1009','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','NUKU72','IGNF','RGPF','IGNF','103',NULL,1363.785,1362.687,398.811,'EPSG','9001',-4.5322,-6.7579,-1.0574,'EPSG','9104',268.361,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1009_NUKU72G_TO_RGPFGDD','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','NUKU72G','IGNF','RGPFGDD','IGNF','103',NULL,1363.785,1362.687,398.811,'EPSG','9001',-4.5322,-6.7579,-1.0574,'EPSG','9104',268.361,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1009_NUKU72G_TO_RGPFGEO','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','NUKU72G','IGNF','RGPFGEO','IGNF','103',NULL,1363.785,1362.687,398.811,'EPSG','9001',-4.5322,-6.7579,-1.0574,'EPSG','9104',268.361,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1009_NUKU72G_TO_RGPFG','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','NUKU72G','IGNF','RGPFG','IGNF','103',NULL,1363.785,1362.687,398.811,'EPSG','9001',-4.5322,-6.7579,-1.0574,'EPSG','9104',268.361,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1009_NUKU72GEO_TO_RGPFGDD','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','NUKU72GEO','IGNF','RGPFGDD','IGNF','103',NULL,1363.785,1362.687,398.811,'EPSG','9001',-4.5322,-6.7579,-1.0574,'EPSG','9104',268.361,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1009_NUKU72GEO_TO_RGPFGEO','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','NUKU72GEO','IGNF','RGPFGEO','IGNF','103',NULL,1363.785,1362.687,398.811,'EPSG','9001',-4.5322,-6.7579,-1.0574,'EPSG','9104',268.361,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1009_NUKU72GEO_TO_RGPFG','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','NUKU72GEO','IGNF','RGPFG','IGNF','103',NULL,1363.785,1362.687,398.811,'EPSG','9001',-4.5322,-6.7579,-1.0574,'EPSG','9104',268.361,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','104','UA POU','UA POU',-9.75,-9.15,-140.25,-139.91,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1010','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','NUKU72','IGNF','RGPF','IGNF','104',NULL,259.551,297.612,197.833,'EPSG','9001',1.4866,2.1224,0.4612,'EPSG','9104',27.0249,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1010_NUKU72G_TO_RGPFGDD','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','NUKU72G','IGNF','RGPFGDD','IGNF','104',NULL,259.551,297.612,197.833,'EPSG','9001',1.4866,2.1224,0.4612,'EPSG','9104',27.0249,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1010_NUKU72G_TO_RGPFGEO','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','NUKU72G','IGNF','RGPFGEO','IGNF','104',NULL,259.551,297.612,197.833,'EPSG','9001',1.4866,2.1224,0.4612,'EPSG','9104',27.0249,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1010_NUKU72G_TO_RGPFG','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','NUKU72G','IGNF','RGPFG','IGNF','104',NULL,259.551,297.612,197.833,'EPSG','9001',1.4866,2.1224,0.4612,'EPSG','9104',27.0249,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1010_NUKU72GEO_TO_RGPFGDD','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','NUKU72GEO','IGNF','RGPFGDD','IGNF','104',NULL,259.551,297.612,197.833,'EPSG','9001',1.4866,2.1224,0.4612,'EPSG','9104',27.0249,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1010_NUKU72GEO_TO_RGPFGEO','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','NUKU72GEO','IGNF','RGPFGEO','IGNF','104',NULL,259.551,297.612,197.833,'EPSG','9001',1.4866,2.1224,0.4612,'EPSG','9104',27.0249,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1010_NUKU72GEO_TO_RGPFG','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','NUKU72GEO','IGNF','RGPFG','IGNF','104',NULL,259.551,297.612,197.833,'EPSG','9001',1.4866,2.1224,0.4612,'EPSG','9104',27.0249,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','105','NUKU HIVA - ILES MARQUISES - POLYNESIE FRANCAISE','NUKU HIVA - ILES MARQUISES - POLYNESIE FRANCAISE',-9.5,-8.77,-140.27,-139.48,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG606','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','NUKU72','IGNF','WGS84','IGNF','105',NULL,84,274,65,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG606_NUKU72_RRAF91','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','NUKU72','IGNF','RRAF91','IGNF','105',NULL,84,274,65,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG606_NUKU72_4978','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','NUKU72','EPSG','4978','IGNF','105',NULL,84,274,65,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG606_NUKU72G_TO_WGS84GEODD','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72G','IGNF','WGS84GEODD','IGNF','105',NULL,84,274,65,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG606_NUKU72G_TO_WGS84GDD','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72G','IGNF','WGS84GDD','IGNF','105',NULL,84,274,65,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG606_NUKU72G_TO_WGS84G','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72G','IGNF','WGS84G','IGNF','105',NULL,84,274,65,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG606_NUKU72G_TO_4326','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72G','EPSG','4326','IGNF','105',NULL,84,274,65,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG606_NUKU72G_TO_WGS84GEO','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72G','IGNF','WGS84GEO','IGNF','105',NULL,84,274,65,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG606_NUKU72G_TO_WGS84RRAFGEO','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72G','IGNF','WGS84RRAFGEO','IGNF','105',NULL,84,274,65,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG606_NUKU72GEO_TO_WGS84GEODD','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72GEO','IGNF','WGS84GEODD','IGNF','105',NULL,84,274,65,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG606_NUKU72GEO_TO_WGS84GDD','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72GEO','IGNF','WGS84GDD','IGNF','105',NULL,84,274,65,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG606_NUKU72GEO_TO_WGS84G','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72GEO','IGNF','WGS84G','IGNF','105',NULL,84,274,65,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG606_NUKU72GEO_TO_4326','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72GEO','EPSG','4326','IGNF','105',NULL,84,274,65,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG606_NUKU72GEO_TO_WGS84GEO','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72GEO','IGNF','WGS84GEO','IGNF','105',NULL,84,274,65,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG606_NUKU72GEO_TO_WGS84RRAFGEO','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72GEO','IGNF','WGS84RRAFGEO','IGNF','105',NULL,84,274,65,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','106','NUKU HIVA - MARQUISES','NUKU HIVA - MARQUISES',-9,-8.7,-140.3,-140,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG751','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','NUKU72','IGNF','WGS84','IGNF','106',NULL,130.85,185.17,174.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG751_NUKU72_RRAF91','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','NUKU72','IGNF','RRAF91','IGNF','106',NULL,130.85,185.17,174.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG751_NUKU72_4978','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','NUKU72','EPSG','4978','IGNF','106',NULL,130.85,185.17,174.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG751_NUKU72G_TO_WGS84GEODD','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72G','IGNF','WGS84GEODD','IGNF','106',NULL,130.85,185.17,174.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG751_NUKU72G_TO_WGS84GDD','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72G','IGNF','WGS84GDD','IGNF','106',NULL,130.85,185.17,174.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG751_NUKU72G_TO_WGS84G','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72G','IGNF','WGS84G','IGNF','106',NULL,130.85,185.17,174.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG751_NUKU72G_TO_4326','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72G','EPSG','4326','IGNF','106',NULL,130.85,185.17,174.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG751_NUKU72G_TO_WGS84GEO','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72G','IGNF','WGS84GEO','IGNF','106',NULL,130.85,185.17,174.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG751_NUKU72G_TO_WGS84RRAFGEO','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72G','IGNF','WGS84RRAFGEO','IGNF','106',NULL,130.85,185.17,174.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG751_NUKU72GEO_TO_WGS84GEODD','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72GEO','IGNF','WGS84GEODD','IGNF','106',NULL,130.85,185.17,174.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG751_NUKU72GEO_TO_WGS84GDD','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72GEO','IGNF','WGS84GDD','IGNF','106',NULL,130.85,185.17,174.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG751_NUKU72GEO_TO_WGS84G','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72GEO','IGNF','WGS84G','IGNF','106',NULL,130.85,185.17,174.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG751_NUKU72GEO_TO_4326','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72GEO','EPSG','4326','IGNF','106',NULL,130.85,185.17,174.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG751_NUKU72GEO_TO_WGS84GEO','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72GEO','IGNF','WGS84GEO','IGNF','106',NULL,130.85,185.17,174.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG751_NUKU72GEO_TO_WGS84RRAFGEO','IGN 1972 (NUKU HIVA - UA HUKA - UA POU) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NUKU72GEO','IGNF','WGS84RRAFGEO','IGNF','106',NULL,130.85,185.17,174.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1176','RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009) vers IGN 1987 (MARTINIQUE)',NULL,'NATIONALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGAF09GEODD','IGNF','MART87','IGNF','39',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RAMART2016.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1241','RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009) vers IGN 1987 (MARTINIQUE)',NULL,'NATIONALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGAF09GEODD','IGNF','MART87','IGNF','39',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RAMART2016.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1155','WGS 84 (RRAF) vers IGN 1987 (MARTINIQUE)',NULL,'NATIONALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RRAFGEO','IGNF','MART87','IGNF','39',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggm00v2.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','107','GUADELOUPE GRANDE-TERRE + BASSE-TERRE','GUADELOUPE GRANDE-TERRE + BASSE-TERRE',15.875,16.625,-61.9,-61.075,0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1177','RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009) vers IGN 1988 (GUADELOUPE)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGAF09GEODD','IGNF','GUAD88','IGNF','107',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RAGTBT2016.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','108','GUADELOUPE (GRANDE-TERRE ET BASSE-TERRE)','GUADELOUPE (GRANDE-TERRE ET BASSE-TERRE)',15.875,16.589,-61.9,-61.072,0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1242','RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009) vers IGN 1988 (GUADELOUPE)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGAF09GEODD','IGNF','GUAD88','IGNF','108',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RAGTBT2016.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1165','WGS 84 (RRAF) vers IGN 1988 (GUADELOUPE)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RRAFGEO','IGNF','GUAD88','IGNF','107',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggg00v2.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','109','ARCHIPEL DES SAINTES (GUADELOUPE)','ARCHIPEL DES SAINTES (GUADELOUPE)',15.8,15.925,-61.7,-61.475,0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1180','RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009) vers IGN 1988 LS (GUADELOUPE / LES SAINTES)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGAF09GEODD','IGNF','GUAD88LS','IGNF','109',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RALS2016.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1245','RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009) vers IGN 1988 LS (GUADELOUPE / LES SAINTES)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGAF09GEODD','IGNF','GUAD88LS','IGNF','109',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RALS2016.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1167','WGS 84 (RRAF) vers IGN 1988 LS (GUADELOUPE / LES SAINTES)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RRAFGEO','IGNF','GUAD88LS','IGNF','109',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggg00_lsv2.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1247','WGS 84 (RRAF) vers IGN 1988 LS (GUADELOUPE / LES SAINTES)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RRAFGEO','IGNF','GUAD88LS','IGNF','109',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggg00_lsv2.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'2.1.0',0);
INSERT INTO "area" VALUES('IGNF','110','ILE DE MARIE-GALANTE','ILE DE MARIE-GALANTE',15.8,16.125,-61.4,-61.075,0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1178','RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009) vers IGN 1988 MG (GUADELOUPE / MARIE-GALANTE)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGAF09GEODD','IGNF','GUAD88MG','IGNF','110',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RAMG2016.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1244','RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009) vers IGN 1988 MG (GUADELOUPE / MARIE-GALANTE)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGAF09GEODD','IGNF','GUAD88MG','IGNF','110',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RAMG2016.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','111','SAINT BARTHELEMY','SAINT BARTHELEMY',17.8,18.025,-63.0,-62.725,0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1181','RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009) vers IGN 1988 SB (GUADELOUPE / SAINT-BARTHELEMY)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGAF09GEODD','IGNF','GUAD88SB','IGNF','111',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/gg10_sbv2.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','112','SAINT-BARTHELEMY','SAINT-BARTHELEMY',17.8,18.025,-63.0,-62.725,0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1249','RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009) vers IGN 1988 SB (GUADELOUPE / SAINT-BARTHELEMY)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGAF09GEODD','IGNF','GUAD88SB','IGNF','112',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/gg10_sbv2.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'2.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1169','WGS 84 (RRAF) vers IGN 1988 SB (GUADELOUPE / SAINT-BARTHELEMY)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RRAFGEO','IGNF','GUAD88SB','IGNF','112',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggg00_sbv2.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','113','SAINT-MARTIN (PARTIE FRANCAISE)','SAINT-MARTIN (PARTIE FRANCAISE)',18.0,18.2,-63.2,-62.9,0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1182','RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009) vers IGN 1988 SM (GUADELOUPE / SAINT-MARTIN)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGAF09GEODD','IGNF','GUAD88SM','IGNF','113',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/gg10_smv2.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1248','RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009) vers IGN 1988 SM (GUADELOUPE / SAINT-MARTIN)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGAF09GEODD','IGNF','GUAD88SM','IGNF','113',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/gg10_smv2.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'2.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1154','WGS 84 (RRAF) vers IGN 1988 SM (GUADELOUPE / SAINT-MARTIN)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RRAFGEO','IGNF','GUAD88SM','IGNF','113',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggg00_smv2.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1160','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers IGN 1989 (REUNION)',NULL,'NATIONALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGR92GEO','IGNF','REUN89','IGNF','55',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RAR07_bl.gra',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','114','ILE DE LA DESIRADE','ILE DE LA DESIRADE',16.25,16.4,-61.2,-60.75,0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1179','RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009) vers IGN 1992 LD (GUADELOUPE / LA DESIRADE)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGAF09GEODD','IGNF','GUAD92LD','IGNF','114',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RALD2016.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1166','WGS 84 (RRAF) vers IGN 1992 LD (GUADELOUPE / LA DESIRADE)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RRAFGEO','IGNF','GUAD92LD','IGNF','114',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RALDW842016.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1243','RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009) vers IGN 2008 LD (GUADELOUPE / LA DESIRADE)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGAF09GEODD','IGNF','GUAD2008LD','IGNF','114',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RALD2016.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1246','WGS 84 (RRAF) vers IGN 2008 LD (GUADELOUPE / LA DESIRADE)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RRAFGEO','IGNF','GUAD2008LD','IGNF','114',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RALDW842016.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','115','RAIATEA','RAIATEA',-16.94,-16.54,-151.59,-151.32,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG779','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','TAHAA53','IGNF','RGPF','IGNF','115',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG779_RAIA53_RGPF','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','RAIA53','IGNF','RGPF','IGNF','115',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG779_TAHAA53G_TO_RGPFGDD','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHAA53G','IGNF','RGPFGDD','IGNF','115',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG779_RAIA53G_TO_RGPFGDD','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RAIA53G','IGNF','RGPFGDD','IGNF','115',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG779_TAHAA53G_TO_RGPFGEO','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHAA53G','IGNF','RGPFGEO','IGNF','115',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG779_RAIA53G_TO_RGPFGEO','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RAIA53G','IGNF','RGPFGEO','IGNF','115',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG779_TAHAA53G_TO_RGPFG','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHAA53G','IGNF','RGPFG','IGNF','115',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG779_RAIA53G_TO_RGPFG','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RAIA53G','IGNF','RGPFG','IGNF','115',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','116','TAHAA','TAHAA',-16.7,-16.53,-151.58,-151.38,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG780','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','TAHAA53','IGNF','RGPF','IGNF','116',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG780_RAIA53_RGPF','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','RAIA53','IGNF','RGPF','IGNF','116',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG780_TAHAA53G_TO_RGPFGDD','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHAA53G','IGNF','RGPFGDD','IGNF','116',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG780_RAIA53G_TO_RGPFGDD','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RAIA53G','IGNF','RGPFGDD','IGNF','116',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG780_TAHAA53G_TO_RGPFGEO','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHAA53G','IGNF','RGPFGEO','IGNF','116',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG780_RAIA53G_TO_RGPFGEO','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RAIA53G','IGNF','RGPFGEO','IGNF','116',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG780_TAHAA53G_TO_RGPFG','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHAA53G','IGNF','RGPFG','IGNF','116',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG780_RAIA53G_TO_RGPFG','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RAIA53G','IGNF','RGPFG','IGNF','116',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','117','BORA BORA','BORA BORA',-16.58,-16.42,-151.83,-151.67,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG781','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','TAHAA53','IGNF','RGPF','IGNF','117',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG781_RAIA53_RGPF','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','RAIA53','IGNF','RGPF','IGNF','117',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG781_TAHAA53G_TO_RGPFGDD','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHAA53G','IGNF','RGPFGDD','IGNF','117',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG781_RAIA53G_TO_RGPFGDD','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RAIA53G','IGNF','RGPFGDD','IGNF','117',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG781_TAHAA53G_TO_RGPFGEO','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHAA53G','IGNF','RGPFGEO','IGNF','117',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG781_RAIA53G_TO_RGPFGEO','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RAIA53G','IGNF','RGPFGEO','IGNF','117',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG781_TAHAA53G_TO_RGPFG','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHAA53G','IGNF','RGPFG','IGNF','117',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG781_RAIA53G_TO_RGPFG','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RAIA53G','IGNF','RGPFG','IGNF','117',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','118','HUAHINE','HUAHINE',-17,-16.5,-151.5,-150.75,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG782','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','TAHAA53','IGNF','RGPF','IGNF','118',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG782_RAIA53_RGPF','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','RAIA53','IGNF','RGPF','IGNF','118',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG782_TAHAA53G_TO_RGPFGDD','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHAA53G','IGNF','RGPFGDD','IGNF','118',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG782_RAIA53G_TO_RGPFGDD','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RAIA53G','IGNF','RGPFGDD','IGNF','118',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG782_TAHAA53G_TO_RGPFGEO','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHAA53G','IGNF','RGPFGEO','IGNF','118',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG782_RAIA53G_TO_RGPFGEO','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RAIA53G','IGNF','RGPFGEO','IGNF','118',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG782_TAHAA53G_TO_RGPFG','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHAA53G','IGNF','RGPFG','IGNF','118',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG782_RAIA53G_TO_RGPFG','IGN53 (IGN RAIATEA-TAHAA) RAIATEA-TAHAA-BORA BORA-HUAHINE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RAIA53G','IGNF','RGPFG','IGNF','118',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','119','ILE DE MARE','ILE DE MARE',-21.69,-21.29,167.69,168.18,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG727','IGN53 MARE - ILES LOYAUTE vers RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','MARE53','IGNF','RGNC','IGNF','119',NULL,-533.321,238.077,-224.713,'EPSG','9001',2.381004,-7.580876,-2.346668,'EPSG','9104',-124.2432,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG727_MARE53G_TO_RGNCGEODD','IGN53 MARE - ILES LOYAUTE vers RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MARE53G','IGNF','RGNCGEODD','IGNF','119',NULL,-533.321,238.077,-224.713,'EPSG','9001',2.381004,-7.580876,-2.346668,'EPSG','9104',-124.2432,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG727_MARE53G_TO_RGNCGEO','IGN53 MARE - ILES LOYAUTE vers RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MARE53G','IGNF','RGNCGEO','IGNF','119',NULL,-533.321,238.077,-224.713,'EPSG','9001',2.381004,-7.580876,-2.346668,'EPSG','9104',-124.2432,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG727_MARE53G_TO_RGNCG','IGN53 MARE - ILES LOYAUTE vers RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MARE53G','IGNF','RGNCG','IGNF','119',NULL,-533.321,238.077,-224.713,'EPSG','9001',2.381004,-7.580876,-2.346668,'EPSG','9104',-124.2432,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','120','MOHOTANI - MARQUISES','MOHOTANI - MARQUISES',-10.08,-9.83,-138.92,-138.67,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG760','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MARQUI72','IGNF','WGS84','IGNF','120',NULL,330.91,-13.92,58.56,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG760_MARQUI72_RRAF91','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MARQUI72','IGNF','RRAF91','IGNF','120',NULL,330.91,-13.92,58.56,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG760_MARQUI72_4978','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MARQUI72','EPSG','4978','IGNF','120',NULL,330.91,-13.92,58.56,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG760_MARQUI72G_TO_WGS84GEODD','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARQUI72G','IGNF','WGS84GEODD','IGNF','120',NULL,330.91,-13.92,58.56,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG760_MARQUI72G_TO_WGS84GDD','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARQUI72G','IGNF','WGS84GDD','IGNF','120',NULL,330.91,-13.92,58.56,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG760_MARQUI72G_TO_WGS84G','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARQUI72G','IGNF','WGS84G','IGNF','120',NULL,330.91,-13.92,58.56,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG760_MARQUI72G_TO_4326','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARQUI72G','EPSG','4326','IGNF','120',NULL,330.91,-13.92,58.56,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG760_MARQUI72G_TO_WGS84GEO','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARQUI72G','IGNF','WGS84GEO','IGNF','120',NULL,330.91,-13.92,58.56,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG760_MARQUI72G_TO_WGS84RRAFGEO','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARQUI72G','IGNF','WGS84RRAFGEO','IGNF','120',NULL,330.91,-13.92,58.56,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','121','HIVA OA - MARQUISES','HIVA OA - MARQUISES',-9.87,-9.6,-139.25,-138.58,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG761','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MARQUI72','IGNF','WGS84','IGNF','121',NULL,327.84,-14.96,59.33,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG761_MARQUI72_RRAF91','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MARQUI72','IGNF','RRAF91','IGNF','121',NULL,327.84,-14.96,59.33,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG761_MARQUI72_4978','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MARQUI72','EPSG','4978','IGNF','121',NULL,327.84,-14.96,59.33,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG761_MARQUI72G_TO_WGS84GEODD','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARQUI72G','IGNF','WGS84GEODD','IGNF','121',NULL,327.84,-14.96,59.33,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG761_MARQUI72G_TO_WGS84GDD','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARQUI72G','IGNF','WGS84GDD','IGNF','121',NULL,327.84,-14.96,59.33,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG761_MARQUI72G_TO_WGS84G','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARQUI72G','IGNF','WGS84G','IGNF','121',NULL,327.84,-14.96,59.33,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG761_MARQUI72G_TO_4326','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARQUI72G','EPSG','4326','IGNF','121',NULL,327.84,-14.96,59.33,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG761_MARQUI72G_TO_WGS84GEO','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARQUI72G','IGNF','WGS84GEO','IGNF','121',NULL,327.84,-14.96,59.33,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG761_MARQUI72G_TO_WGS84RRAFGEO','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARQUI72G','IGNF','WGS84RRAFGEO','IGNF','121',NULL,327.84,-14.96,59.33,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','122','EIAO - MARQUISES','EIAO - MARQUISES',-8.06,-7.95,-140.73,-140.63,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG762','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MARQUI72','IGNF','WGS84','IGNF','122',NULL,333.71,-71.31,247.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG762_MARQUI72_RRAF91','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MARQUI72','IGNF','RRAF91','IGNF','122',NULL,333.71,-71.31,247.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG762_MARQUI72_4978','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MARQUI72','EPSG','4978','IGNF','122',NULL,333.71,-71.31,247.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG762_MARQUI72G_TO_WGS84GEODD','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARQUI72G','IGNF','WGS84GEODD','IGNF','122',NULL,333.71,-71.31,247.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG762_MARQUI72G_TO_WGS84GDD','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARQUI72G','IGNF','WGS84GDD','IGNF','122',NULL,333.71,-71.31,247.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG762_MARQUI72G_TO_WGS84G','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARQUI72G','IGNF','WGS84G','IGNF','122',NULL,333.71,-71.31,247.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG762_MARQUI72G_TO_4326','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARQUI72G','EPSG','4326','IGNF','122',NULL,333.71,-71.31,247.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG762_MARQUI72G_TO_WGS84GEO','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARQUI72G','IGNF','WGS84GEO','IGNF','122',NULL,333.71,-71.31,247.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG762_MARQUI72G_TO_WGS84RRAFGEO','IGN72 (EIAO - HIVA OA - MOHOTANI) MARQUISES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARQUI72G','IGNF','WGS84RRAFGEO','IGNF','122',NULL,333.71,-71.31,247.72,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','123','NOUVELLE-CALEDONIE - GRANDE TERRE','NOUVELLE-CALEDONIE - GRANDE TERRE',-22.75,-19.5,163.5,167.67,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG677','IGN72 GRANDE-TERRE / ILE DES PINS vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','IGN72','IGNF','WGS84','IGNF','123',NULL,-13,-348,292,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG677_IGN72_RRAF91','IGN72 GRANDE-TERRE / ILE DES PINS vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','IGN72','IGNF','RRAF91','IGNF','123',NULL,-13,-348,292,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG677_IGN72_4978','IGN72 GRANDE-TERRE / ILE DES PINS vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','IGN72','EPSG','4978','IGNF','123',NULL,-13,-348,292,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG677_IGN72GEO_TO_WGS84GEODD','IGN72 GRANDE-TERRE / ILE DES PINS vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','IGN72GEO','IGNF','WGS84GEODD','IGNF','123',NULL,-13,-348,292,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG677_IGN72GEO_TO_WGS84GDD','IGN72 GRANDE-TERRE / ILE DES PINS vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','IGN72GEO','IGNF','WGS84GDD','IGNF','123',NULL,-13,-348,292,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG677_IGN72GEO_TO_WGS84G','IGN72 GRANDE-TERRE / ILE DES PINS vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','IGN72GEO','IGNF','WGS84G','IGNF','123',NULL,-13,-348,292,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG677_IGN72GEO_TO_4326','IGN72 GRANDE-TERRE / ILE DES PINS vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','IGN72GEO','EPSG','4326','IGNF','123',NULL,-13,-348,292,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG677_IGN72GEO_TO_WGS84GEO','IGN72 GRANDE-TERRE / ILE DES PINS vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','IGN72GEO','IGNF','WGS84GEO','IGNF','123',NULL,-13,-348,292,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG677_IGN72GEO_TO_WGS84RRAFGEO','IGN72 GRANDE-TERRE / ILE DES PINS vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','IGN72GEO','IGNF','WGS84RRAFGEO','IGNF','123',NULL,-13,-348,292,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG677_IGN72G_TO_WGS84GEODD','IGN72 GRANDE-TERRE / ILE DES PINS vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','IGN72G','IGNF','WGS84GEODD','IGNF','123',NULL,-13,-348,292,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG677_IGN72G_TO_WGS84GDD','IGN72 GRANDE-TERRE / ILE DES PINS vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','IGN72G','IGNF','WGS84GDD','IGNF','123',NULL,-13,-348,292,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG677_IGN72G_TO_WGS84G','IGN72 GRANDE-TERRE / ILE DES PINS vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','IGN72G','IGNF','WGS84G','IGNF','123',NULL,-13,-348,292,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG677_IGN72G_TO_4326','IGN72 GRANDE-TERRE / ILE DES PINS vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','IGN72G','EPSG','4326','IGNF','123',NULL,-13,-348,292,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG677_IGN72G_TO_WGS84GEO','IGN72 GRANDE-TERRE / ILE DES PINS vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','IGN72G','IGNF','WGS84GEO','IGNF','123',NULL,-13,-348,292,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG677_IGN72G_TO_WGS84RRAFGEO','IGN72 GRANDE-TERRE / ILE DES PINS vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','IGN72G','IGNF','WGS84RRAFGEO','IGNF','123',NULL,-13,-348,292,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG783','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','TAHI79','IGNF','RGPF','IGNF','101',NULL,221.525,152.948,176.768,'EPSG','9001',2.3847,1.3896,0.8770,'EPSG','9104',11.4741,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG783_TAHI79G_TO_RGPFGDD','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHI79G','IGNF','RGPFGDD','IGNF','101',NULL,221.525,152.948,176.768,'EPSG','9001',2.3847,1.3896,0.8770,'EPSG','9104',11.4741,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG783_TAHI79G_TO_RGPFGEO','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHI79G','IGNF','RGPFGEO','IGNF','101',NULL,221.525,152.948,176.768,'EPSG','9001',2.3847,1.3896,0.8770,'EPSG','9104',11.4741,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG783_TAHI79G_TO_RGPFG','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHI79G','IGNF','RGPFG','IGNF','101',NULL,221.525,152.948,176.768,'EPSG','9001',2.3847,1.3896,0.8770,'EPSG','9104',11.4741,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG783_TAHI79GEO_TO_RGPFGDD','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHI79GEO','IGNF','RGPFGDD','IGNF','101',NULL,221.525,152.948,176.768,'EPSG','9001',2.3847,1.3896,0.8770,'EPSG','9104',11.4741,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG783_TAHI79GEO_TO_RGPFGEO','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHI79GEO','IGNF','RGPFGEO','IGNF','101',NULL,221.525,152.948,176.768,'EPSG','9001',2.3847,1.3896,0.8770,'EPSG','9104',11.4741,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG783_TAHI79GEO_TO_RGPFG','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHI79GEO','IGNF','RGPFG','IGNF','101',NULL,221.525,152.948,176.768,'EPSG','9001',2.3847,1.3896,0.8770,'EPSG','9104',11.4741,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','124','TAHITI - SOCIETE','TAHITI - SOCIETE',-18,-17,-150,-149,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG757','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TAHI79','IGNF','WGS84','IGNF','124',NULL,160.61,116.05,153.69,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG757_TAHI79_RRAF91','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TAHI79','IGNF','RRAF91','IGNF','124',NULL,160.61,116.05,153.69,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG757_TAHI79_4978','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TAHI79','EPSG','4978','IGNF','124',NULL,160.61,116.05,153.69,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG757_TAHI79G_TO_WGS84GEODD','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHI79G','IGNF','WGS84GEODD','IGNF','124',NULL,160.61,116.05,153.69,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG757_TAHI79G_TO_WGS84GDD','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHI79G','IGNF','WGS84GDD','IGNF','124',NULL,160.61,116.05,153.69,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG757_TAHI79G_TO_WGS84G','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHI79G','IGNF','WGS84G','IGNF','124',NULL,160.61,116.05,153.69,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG757_TAHI79G_TO_4326','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHI79G','EPSG','4326','IGNF','124',NULL,160.61,116.05,153.69,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG757_TAHI79G_TO_WGS84GEO','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHI79G','IGNF','WGS84GEO','IGNF','124',NULL,160.61,116.05,153.69,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG757_TAHI79G_TO_WGS84RRAFGEO','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHI79G','IGNF','WGS84RRAFGEO','IGNF','124',NULL,160.61,116.05,153.69,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG757_TAHI79GEO_TO_WGS84GEODD','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHI79GEO','IGNF','WGS84GEODD','IGNF','124',NULL,160.61,116.05,153.69,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG757_TAHI79GEO_TO_WGS84GDD','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHI79GEO','IGNF','WGS84GDD','IGNF','124',NULL,160.61,116.05,153.69,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG757_TAHI79GEO_TO_WGS84G','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHI79GEO','IGNF','WGS84G','IGNF','124',NULL,160.61,116.05,153.69,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG757_TAHI79GEO_TO_4326','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHI79GEO','EPSG','4326','IGNF','124',NULL,160.61,116.05,153.69,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG757_TAHI79GEO_TO_WGS84GEO','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHI79GEO','IGNF','WGS84GEO','IGNF','124',NULL,160.61,116.05,153.69,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG757_TAHI79GEO_TO_WGS84RRAFGEO','IGN79 (TAHITI 1979) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHI79GEO','IGNF','WGS84RRAFGEO','IGNF','124',NULL,160.61,116.05,153.69,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','125','KERGUELEN (TAAF)','KERGUELEN (TAAF)',-50.5,-48,67,71,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG195','KERGUELEN - K0 (IGN 1962) vers DOD WORLD GEODETIC SYSTEM 1972 (WGS 72)',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','KERG62K0','IGNF','WGS72','IGNF','125',NULL,155,-191,99,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG195_KERG62CAR_WGS72','KERGUELEN - K0 (IGN 1962) vers DOD WORLD GEODETIC SYSTEM 1972 (WGS 72)',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','KERG62CAR','IGNF','WGS72','IGNF','125',NULL,155,-191,99,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG195_KERG62G_TO_WGS72GEO','KERGUELEN - K0 (IGN 1962) vers DOD WORLD GEODETIC SYSTEM 1972 (WGS 72)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','KERG62G','IGNF','WGS72GEO','IGNF','125',NULL,155,-191,99,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG195_KERG62G_TO_WGS72G','KERGUELEN - K0 (IGN 1962) vers DOD WORLD GEODETIC SYSTEM 1972 (WGS 72)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','KERG62G','IGNF','WGS72G','IGNF','125',NULL,155,-191,99,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG195_KERG62GEO_TO_WGS72GEO','KERGUELEN - K0 (IGN 1962) vers DOD WORLD GEODETIC SYSTEM 1972 (WGS 72)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','KERG62GEO','IGNF','WGS72GEO','IGNF','125',NULL,155,-191,99,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG195_KERG62GEO_TO_WGS72G','KERGUELEN - K0 (IGN 1962) vers DOD WORLD GEODETIC SYSTEM 1972 (WGS 72)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','KERG62GEO','IGNF','WGS72G','IGNF','125',NULL,155,-191,99,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','126','ILES KERGUELEN','ILES KERGUELEN',-50.5,-48,67,71,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG825','KERGUELEN - K0 (IGN 1962) vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE A CARACTERE LEGAL','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','KERG62K0','IGNF','RGTAAF07','IGNF','126',NULL,144.899,-186.770,100.923,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG825_KERG62CAR_RGTAAF07','KERGUELEN - K0 (IGN 1962) vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE A CARACTERE LEGAL','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','KERG62CAR','IGNF','RGTAAF07','IGNF','126',NULL,144.899,-186.770,100.923,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG825_KERG62G_TO_RGTAAFGEODD','KERGUELEN - K0 (IGN 1962) vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE A CARACTERE LEGAL','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','KERG62G','IGNF','RGTAAFGEODD','IGNF','126',NULL,144.899,-186.770,100.923,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG825_KERG62G_TO_RGTAAF07GDD','KERGUELEN - K0 (IGN 1962) vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE A CARACTERE LEGAL','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','KERG62G','IGNF','RGTAAF07GDD','IGNF','126',NULL,144.899,-186.770,100.923,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG825_KERG62G_TO_RGTAAF07G','KERGUELEN - K0 (IGN 1962) vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE A CARACTERE LEGAL','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','KERG62G','IGNF','RGTAAF07G','IGNF','126',NULL,144.899,-186.770,100.923,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG825_KERG62G_TO_RGTAAFGEO','KERGUELEN - K0 (IGN 1962) vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE A CARACTERE LEGAL','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','KERG62G','IGNF','RGTAAFGEO','IGNF','126',NULL,144.899,-186.770,100.923,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG825_KERG62GEO_TO_RGTAAFGEODD','KERGUELEN - K0 (IGN 1962) vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE A CARACTERE LEGAL','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','KERG62GEO','IGNF','RGTAAFGEODD','IGNF','126',NULL,144.899,-186.770,100.923,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG825_KERG62GEO_TO_RGTAAF07GDD','KERGUELEN - K0 (IGN 1962) vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE A CARACTERE LEGAL','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','KERG62GEO','IGNF','RGTAAF07GDD','IGNF','126',NULL,144.899,-186.770,100.923,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG825_KERG62GEO_TO_RGTAAF07G','KERGUELEN - K0 (IGN 1962) vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE A CARACTERE LEGAL','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','KERG62GEO','IGNF','RGTAAF07G','IGNF','126',NULL,144.899,-186.770,100.923,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG825_KERG62GEO_TO_RGTAAFGEO','KERGUELEN - K0 (IGN 1962) vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE A CARACTERE LEGAL','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','KERG62GEO','IGNF','RGTAAFGEO','IGNF','126',NULL,144.899,-186.770,100.923,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','MARTFD','IGNF','RRAF','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MARTFD_WGS84GUAD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','MARTFD','IGNF','WGS84GUAD','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MART38_RRAF','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','MART38','IGNF','RRAF','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MART38_WGS84GUAD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','MART38','IGNF','WGS84GUAD','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MART38GEO_TO_RRAFGDD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MART38GEO','IGNF','RRAFGDD','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MART38GEO_TO_WGS84MARTGDD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MART38GEO','IGNF','WGS84MARTGDD','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MART38GEO_TO_RRAFGEODD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MART38GEO','IGNF','RRAFGEODD','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MART38GEO_TO_W84MARTGEODD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MART38GEO','IGNF','W84MARTGEODD','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MART38GEO_TO_RRAFGEO','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MART38GEO','IGNF','RRAFGEO','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MART38GEO_TO_WGS84GUADGEO','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MART38GEO','IGNF','WGS84GUADGEO','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MART38GEO_TO_RRAFG','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MART38GEO','IGNF','RRAFG','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MART38GEO_TO_WGS84MARTG','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MART38GEO','IGNF','WGS84MARTG','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MARTFDG_TO_RRAFGDD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MARTFDG','IGNF','RRAFGDD','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MARTFDG_TO_WGS84MARTGDD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MARTFDG','IGNF','WGS84MARTGDD','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MART38G_TO_RRAFGDD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MART38G','IGNF','RRAFGDD','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MART38G_TO_WGS84MARTGDD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MART38G','IGNF','WGS84MARTGDD','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MARTFDG_TO_RRAFGEODD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MARTFDG','IGNF','RRAFGEODD','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MARTFDG_TO_W84MARTGEODD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MARTFDG','IGNF','W84MARTGEODD','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MART38G_TO_RRAFGEODD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MART38G','IGNF','RRAFGEODD','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MART38G_TO_W84MARTGEODD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MART38G','IGNF','W84MARTGEODD','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MARTFDG_TO_RRAFGEO','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MARTFDG','IGNF','RRAFGEO','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MARTFDG_TO_WGS84GUADGEO','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MARTFDG','IGNF','WGS84GUADGEO','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MART38G_TO_RRAFGEO','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MART38G','IGNF','RRAFGEO','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MART38G_TO_WGS84GUADGEO','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MART38G','IGNF','WGS84GUADGEO','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MARTFDG_TO_RRAFG','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MARTFDG','IGNF','RRAFG','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MARTFDG_TO_WGS84MARTG','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MARTFDG','IGNF','WGS84MARTG','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MART38G_TO_RRAFG','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MART38G','IGNF','RRAFG','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG467_MART38G_TO_WGS84MARTG','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MART38G','IGNF','WGS84MARTG','IGNF','39',NULL,126.926,547.939,130.409,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MARTFD','IGNF','RRAF','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MARTFD_WGS84GUAD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MARTFD','IGNF','WGS84GUAD','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MART38_RRAF','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MART38','IGNF','RRAF','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MART38_WGS84GUAD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MART38','IGNF','WGS84GUAD','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MART38GEO_TO_RRAFGDD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MART38GEO','IGNF','RRAFGDD','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MART38GEO_TO_WGS84MARTGDD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MART38GEO','IGNF','WGS84MARTGDD','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MART38GEO_TO_RRAFGEODD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MART38GEO','IGNF','RRAFGEODD','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MART38GEO_TO_W84MARTGEODD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MART38GEO','IGNF','W84MARTGEODD','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MART38GEO_TO_RRAFGEO','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MART38GEO','IGNF','RRAFGEO','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MART38GEO_TO_WGS84GUADGEO','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MART38GEO','IGNF','WGS84GUADGEO','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MART38GEO_TO_RRAFG','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MART38GEO','IGNF','RRAFG','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MART38GEO_TO_WGS84MARTG','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MART38GEO','IGNF','WGS84MARTG','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MARTFDG_TO_RRAFGDD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARTFDG','IGNF','RRAFGDD','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MARTFDG_TO_WGS84MARTGDD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARTFDG','IGNF','WGS84MARTGDD','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MART38G_TO_RRAFGDD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MART38G','IGNF','RRAFGDD','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MART38G_TO_WGS84MARTGDD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MART38G','IGNF','WGS84MARTGDD','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MARTFDG_TO_RRAFGEODD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARTFDG','IGNF','RRAFGEODD','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MARTFDG_TO_W84MARTGEODD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARTFDG','IGNF','W84MARTGEODD','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MART38G_TO_RRAFGEODD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MART38G','IGNF','RRAFGEODD','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MART38G_TO_W84MARTGEODD','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MART38G','IGNF','W84MARTGEODD','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MARTFDG_TO_RRAFGEO','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARTFDG','IGNF','RRAFGEO','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MARTFDG_TO_WGS84GUADGEO','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARTFDG','IGNF','WGS84GUADGEO','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MART38G_TO_RRAFGEO','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MART38G','IGNF','RRAFGEO','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MART38G_TO_WGS84GUADGEO','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MART38G','IGNF','WGS84GUADGEO','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MARTFDG_TO_RRAFG','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARTFDG','IGNF','RRAFG','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MARTFDG_TO_WGS84MARTG','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MARTFDG','IGNF','WGS84MARTG','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MART38G_TO_RRAFG','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MART38G','IGNF','RRAFG','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG591_MART38G_TO_WGS84MARTG','MARTINIQUE - FORT DESAIX vers WGS 84 (RRAF)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MART38G','IGNF','WGS84MARTG','IGNF','39',NULL,186,482,151,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','127','ILE DE MAUPITI','ILE DE MAUPITI',-16.75,-16.25,-152.5,-152,0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1138','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers MAUPITI_SAU 2001',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGPFGEO','IGNF','MAUPITI01','IGNF','127',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggpf02-Maupiti.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','128','FATU HIVA','FATU HIVA',-10.6,-10.4,-138.7,138.6,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1005','MHEFO 1955 (FATU HUKU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','FATU55','IGNF','RGPF','IGNF','128',NULL,347.103,1078.125,2623.922,'EPSG','9001',33.8875,-70.6773,9.3943,'EPSG','9104',186.074,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1005_MHEFO55F_RGPF','MHEFO 1955 (FATU HUKU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','MHEFO55F','IGNF','RGPF','IGNF','128',NULL,347.103,1078.125,2623.922,'EPSG','9001',33.8875,-70.6773,9.3943,'EPSG','9104',186.074,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1005_FATU55FG_TO_RGPFGDD','MHEFO 1955 (FATU HUKU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','FATU55FG','IGNF','RGPFGDD','IGNF','128',NULL,347.103,1078.125,2623.922,'EPSG','9001',33.8875,-70.6773,9.3943,'EPSG','9104',186.074,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1005_MHEFO55FG_TO_RGPFGDD','MHEFO 1955 (FATU HUKU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MHEFO55FG','IGNF','RGPFGDD','IGNF','128',NULL,347.103,1078.125,2623.922,'EPSG','9001',33.8875,-70.6773,9.3943,'EPSG','9104',186.074,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1005_FATU55FG_TO_RGPFGEO','MHEFO 1955 (FATU HUKU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','FATU55FG','IGNF','RGPFGEO','IGNF','128',NULL,347.103,1078.125,2623.922,'EPSG','9001',33.8875,-70.6773,9.3943,'EPSG','9104',186.074,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1005_MHEFO55FG_TO_RGPFGEO','MHEFO 1955 (FATU HUKU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MHEFO55FG','IGNF','RGPFGEO','IGNF','128',NULL,347.103,1078.125,2623.922,'EPSG','9001',33.8875,-70.6773,9.3943,'EPSG','9104',186.074,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1005_FATU55FG_TO_RGPFG','MHEFO 1955 (FATU HUKU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','FATU55FG','IGNF','RGPFG','IGNF','128',NULL,347.103,1078.125,2623.922,'EPSG','9001',33.8875,-70.6773,9.3943,'EPSG','9104',186.074,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1005_MHEFO55FG_TO_RGPFG','MHEFO 1955 (FATU HUKU) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MHEFO55FG','IGNF','RGPFG','IGNF','128',NULL,347.103,1078.125,2623.922,'EPSG','9001',33.8875,-70.6773,9.3943,'EPSG','9104',186.074,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','129','RAIVAVAE','RAIVAVAE',-23.92,-23.75,-147.75,-147.58,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1020','MHPF 1966 (ATOLL RAIVAVAE) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RAIV66','IGNF','RGPF','IGNF','129',NULL,248.078,264.693,-207.097,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1020_RAIV66G_TO_RGPFGDD','MHPF 1966 (ATOLL RAIVAVAE) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RAIV66G','IGNF','RGPFGDD','IGNF','129',NULL,248.078,264.693,-207.097,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1020_RAIV66G_TO_RGPFGEO','MHPF 1966 (ATOLL RAIVAVAE) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RAIV66G','IGNF','RGPFGEO','IGNF','129',NULL,248.078,264.693,-207.097,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1020_RAIV66G_TO_RGPFG','MHPF 1966 (ATOLL RAIVAVAE) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RAIV66G','IGNF','RGPFG','IGNF','129',NULL,248.078,264.693,-207.097,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','130','MANGAREVA - GAMBIER','MANGAREVA - GAMBIER',-23.45,-22.83,-135.33,-134.58,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG756','MHPF 1967 (MANGAREVA - AGAKAUITAI - AUKENA - MEKIRO) GAMBIER vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MHPF67','IGNF','WGS84','IGNF','130',NULL,338.08,212.58,-296.17,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG756_MHPF67_RRAF91','MHPF 1967 (MANGAREVA - AGAKAUITAI - AUKENA - MEKIRO) GAMBIER vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MHPF67','IGNF','RRAF91','IGNF','130',NULL,338.08,212.58,-296.17,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG756_MHPF67_4978','MHPF 1967 (MANGAREVA - AGAKAUITAI - AUKENA - MEKIRO) GAMBIER vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MHPF67','EPSG','4978','IGNF','130',NULL,338.08,212.58,-296.17,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG756_MHPF67G_TO_WGS84GEODD','MHPF 1967 (MANGAREVA - AGAKAUITAI - AUKENA - MEKIRO) GAMBIER vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MHPF67G','IGNF','WGS84GEODD','IGNF','130',NULL,338.08,212.58,-296.17,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG756_MHPF67G_TO_WGS84GDD','MHPF 1967 (MANGAREVA - AGAKAUITAI - AUKENA - MEKIRO) GAMBIER vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MHPF67G','IGNF','WGS84GDD','IGNF','130',NULL,338.08,212.58,-296.17,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG756_MHPF67G_TO_WGS84G','MHPF 1967 (MANGAREVA - AGAKAUITAI - AUKENA - MEKIRO) GAMBIER vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MHPF67G','IGNF','WGS84G','IGNF','130',NULL,338.08,212.58,-296.17,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG756_MHPF67G_TO_4326','MHPF 1967 (MANGAREVA - AGAKAUITAI - AUKENA - MEKIRO) GAMBIER vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MHPF67G','EPSG','4326','IGNF','130',NULL,338.08,212.58,-296.17,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG756_MHPF67G_TO_WGS84GEO','MHPF 1967 (MANGAREVA - AGAKAUITAI - AUKENA - MEKIRO) GAMBIER vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MHPF67G','IGNF','WGS84GEO','IGNF','130',NULL,338.08,212.58,-296.17,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG756_MHPF67G_TO_WGS84RRAFGEO','MHPF 1967 (MANGAREVA - AGAKAUITAI - AUKENA - MEKIRO) GAMBIER vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MHPF67G','IGNF','WGS84RRAFGEO','IGNF','130',NULL,338.08,212.58,-296.17,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','131','TUBUAI - AUSTRALES','TUBUAI - AUSTRALES',-23.45,-23.25,-149.58,-149.33,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG766','MHPF 1969 (TUBUAI) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TUBU69','IGNF','WGS84','IGNF','131',NULL,237.17,171.61,-77.84,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG766_TUBU69_RRAF91','MHPF 1969 (TUBUAI) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TUBU69','IGNF','RRAF91','IGNF','131',NULL,237.17,171.61,-77.84,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG766_TUBU69_4978','MHPF 1969 (TUBUAI) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TUBU69','EPSG','4978','IGNF','131',NULL,237.17,171.61,-77.84,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG766_TUBU69G_TO_WGS84GEODD','MHPF 1969 (TUBUAI) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUBU69G','IGNF','WGS84GEODD','IGNF','131',NULL,237.17,171.61,-77.84,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG766_TUBU69G_TO_WGS84GDD','MHPF 1969 (TUBUAI) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUBU69G','IGNF','WGS84GDD','IGNF','131',NULL,237.17,171.61,-77.84,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG766_TUBU69G_TO_WGS84G','MHPF 1969 (TUBUAI) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUBU69G','IGNF','WGS84G','IGNF','131',NULL,237.17,171.61,-77.84,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG766_TUBU69G_TO_4326','MHPF 1969 (TUBUAI) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUBU69G','EPSG','4326','IGNF','131',NULL,237.17,171.61,-77.84,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG766_TUBU69G_TO_WGS84GEO','MHPF 1969 (TUBUAI) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUBU69G','IGNF','WGS84GEO','IGNF','131',NULL,237.17,171.61,-77.84,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG766_TUBU69G_TO_WGS84RRAFGEO','MHPF 1969 (TUBUAI) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUBU69G','IGNF','WGS84RRAFGEO','IGNF','131',NULL,237.17,171.61,-77.84,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','132','KAUEHI - TUAMOTU','KAUEHI - TUAMOTU',-16,-15.67,-145.33,-145,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG754','MHPF70 (KAUEHI) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','KAUE70','IGNF','WGS84','IGNF','132',NULL,126.74,300.10,-75.49,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG754_KAUE70_RRAF91','MHPF70 (KAUEHI) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','KAUE70','IGNF','RRAF91','IGNF','132',NULL,126.74,300.10,-75.49,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG754_KAUE70_4978','MHPF70 (KAUEHI) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','KAUE70','EPSG','4978','IGNF','132',NULL,126.74,300.10,-75.49,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG754_KAUE70G_TO_WGS84GEODD','MHPF70 (KAUEHI) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','KAUE70G','IGNF','WGS84GEODD','IGNF','132',NULL,126.74,300.10,-75.49,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG754_KAUE70G_TO_WGS84GDD','MHPF70 (KAUEHI) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','KAUE70G','IGNF','WGS84GDD','IGNF','132',NULL,126.74,300.10,-75.49,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG754_KAUE70G_TO_WGS84G','MHPF70 (KAUEHI) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','KAUE70G','IGNF','WGS84G','IGNF','132',NULL,126.74,300.10,-75.49,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG754_KAUE70G_TO_4326','MHPF70 (KAUEHI) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','KAUE70G','EPSG','4326','IGNF','132',NULL,126.74,300.10,-75.49,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG754_KAUE70G_TO_WGS84GEO','MHPF70 (KAUEHI) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','KAUE70G','IGNF','WGS84GEO','IGNF','132',NULL,126.74,300.10,-75.49,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG754_KAUE70G_TO_WGS84RRAFGEO','MHPF70 (KAUEHI) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','KAUE70G','IGNF','WGS84RRAFGEO','IGNF','132',NULL,126.74,300.10,-75.49,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','133','ILE DE MOOREA','ILE DE MOOREA',-17.7000000000,-17.3500000000,-150.0500000000,-149.6500000000,0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1189','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers MOOREA 1981 (MOOREA_SAU 2001)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGPFGEO','IGNF','MOOREA81','IGNF','133',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggpf10-Moorea.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1011','MOOREA 1987 vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','MOOREA87','IGNF','RGPF','IGNF','133',NULL,218.697,151.257,176.995,'EPSG','9001',3.5048,2.0040,1.2810,'EPSG','9104',10.9910,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1011_MOOREA87G_TO_RGPFGDD','MOOREA 1987 vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MOOREA87G','IGNF','RGPFGDD','IGNF','133',NULL,218.697,151.257,176.995,'EPSG','9001',3.5048,2.0040,1.2810,'EPSG','9104',10.9910,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1011_MOOREA87G_TO_RGPFGEO','MOOREA 1987 vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MOOREA87G','IGNF','RGPFGEO','IGNF','133',NULL,218.697,151.257,176.995,'EPSG','9001',3.5048,2.0040,1.2810,'EPSG','9104',10.9910,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1011_MOOREA87G_TO_RGPFG','MOOREA 1987 vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MOOREA87G','IGNF','RGPFG','IGNF','133',NULL,218.697,151.257,176.995,'EPSG','9001',3.5048,2.0040,1.2810,'EPSG','9104',10.9910,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1011_MOOREA87GEO_TO_RGPFGDD','MOOREA 1987 vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MOOREA87GEO','IGNF','RGPFGDD','IGNF','133',NULL,218.697,151.257,176.995,'EPSG','9001',3.5048,2.0040,1.2810,'EPSG','9104',10.9910,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1011_MOOREA87GEO_TO_RGPFGEO','MOOREA 1987 vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MOOREA87GEO','IGNF','RGPFGEO','IGNF','133',NULL,218.697,151.257,176.995,'EPSG','9001',3.5048,2.0040,1.2810,'EPSG','9104',10.9910,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1011_MOOREA87GEO_TO_RGPFG','MOOREA 1987 vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','MOOREA87GEO','IGNF','RGPFG','IGNF','133',NULL,218.697,151.257,176.995,'EPSG','9001',3.5048,2.0040,1.2810,'EPSG','9104',10.9910,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG785','MOP 1983 (MAUPITI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MAUPITI','IGNF','RGPF','IGNF','40',NULL,217.037,86.959,23.956,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG785_MAUPITIG_TO_RGPFGDD','MOP 1983 (MAUPITI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MAUPITIG','IGNF','RGPFGDD','IGNF','40',NULL,217.037,86.959,23.956,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG785_MAUPITIG_TO_RGPFGEO','MOP 1983 (MAUPITI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MAUPITIG','IGNF','RGPFGEO','IGNF','40',NULL,217.037,86.959,23.956,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG785_MAUPITIG_TO_RGPFG','MOP 1983 (MAUPITI) vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MAUPITIG','IGNF','RGPFG','IGNF','40',NULL,217.037,86.959,23.956,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','134','FANGATAUFA - TUAMOTU','FANGATAUFA - TUAMOTU',-22.33,-22.15,-138.83,-138.58,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG749','MOP84 (FANGATAUFA 1984) vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','FANGA84','IGNF','WGS84','IGNF','134',NULL,150.57,158.33,118.32,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG749_FANGA84_RRAF91','MOP84 (FANGATAUFA 1984) vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','FANGA84','IGNF','RRAF91','IGNF','134',NULL,150.57,158.33,118.32,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG749_FANGA84_4978','MOP84 (FANGATAUFA 1984) vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','FANGA84','EPSG','4978','IGNF','134',NULL,150.57,158.33,118.32,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG749_FANGA84G_TO_WGS84GEODD','MOP84 (FANGATAUFA 1984) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','FANGA84G','IGNF','WGS84GEODD','IGNF','134',NULL,150.57,158.33,118.32,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG749_FANGA84G_TO_WGS84GDD','MOP84 (FANGATAUFA 1984) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','FANGA84G','IGNF','WGS84GDD','IGNF','134',NULL,150.57,158.33,118.32,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG749_FANGA84G_TO_WGS84G','MOP84 (FANGATAUFA 1984) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','FANGA84G','IGNF','WGS84G','IGNF','134',NULL,150.57,158.33,118.32,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG749_FANGA84G_TO_4326','MOP84 (FANGATAUFA 1984) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','FANGA84G','EPSG','4326','IGNF','134',NULL,150.57,158.33,118.32,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG749_FANGA84G_TO_WGS84GEO','MOP84 (FANGATAUFA 1984) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','FANGA84G','IGNF','WGS84GEO','IGNF','134',NULL,150.57,158.33,118.32,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG749_FANGA84G_TO_WGS84RRAFGEO','MOP84 (FANGATAUFA 1984) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','FANGA84G','IGNF','WGS84RRAFGEO','IGNF','134',NULL,150.57,158.33,118.32,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','135','HAO - TUAMOTU','HAO - TUAMOTU',-18.5,-18,-141.17,-140.58,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG763','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TUAM86','IGNF','WGS84','IGNF','135',NULL,143.60,197.82,74.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG763_TUAM86_RRAF91','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TUAM86','IGNF','RRAF91','IGNF','135',NULL,143.60,197.82,74.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG763_TUAM86_4978','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TUAM86','EPSG','4978','IGNF','135',NULL,143.60,197.82,74.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG763_APAT86_WGS84','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','APAT86','IGNF','WGS84','IGNF','135',NULL,143.60,197.82,74.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG763_APAT86_RRAF91','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','APAT86','IGNF','RRAF91','IGNF','135',NULL,143.60,197.82,74.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG763_APAT86_4978','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','APAT86','EPSG','4978','IGNF','135',NULL,143.60,197.82,74.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG763_TUAM86G_TO_WGS84GEODD','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUAM86G','IGNF','WGS84GEODD','IGNF','135',NULL,143.60,197.82,74.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG763_APAT86G_TO_WGS84GEODD','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','APAT86G','IGNF','WGS84GEODD','IGNF','135',NULL,143.60,197.82,74.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG763_TUAM86G_TO_WGS84GDD','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUAM86G','IGNF','WGS84GDD','IGNF','135',NULL,143.60,197.82,74.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG763_APAT86G_TO_WGS84GDD','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','APAT86G','IGNF','WGS84GDD','IGNF','135',NULL,143.60,197.82,74.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG763_TUAM86G_TO_WGS84G','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUAM86G','IGNF','WGS84G','IGNF','135',NULL,143.60,197.82,74.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG763_TUAM86G_TO_4326','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUAM86G','EPSG','4326','IGNF','135',NULL,143.60,197.82,74.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG763_APAT86G_TO_WGS84G','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','APAT86G','IGNF','WGS84G','IGNF','135',NULL,143.60,197.82,74.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG763_APAT86G_TO_4326','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','APAT86G','EPSG','4326','IGNF','135',NULL,143.60,197.82,74.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG763_TUAM86G_TO_WGS84GEO','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUAM86G','IGNF','WGS84GEO','IGNF','135',NULL,143.60,197.82,74.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG763_TUAM86G_TO_WGS84RRAFGEO','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUAM86G','IGNF','WGS84RRAFGEO','IGNF','135',NULL,143.60,197.82,74.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG763_APAT86G_TO_WGS84GEO','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','APAT86G','IGNF','WGS84GEO','IGNF','135',NULL,143.60,197.82,74.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG763_APAT86G_TO_WGS84RRAFGEO','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','APAT86G','IGNF','WGS84RRAFGEO','IGNF','135',NULL,143.60,197.82,74.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','136','RAPA - AUSTRALES','RAPA - AUSTRALES',-27.75,-27.5,-144.5,-144.25,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG764','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TUAM86','IGNF','WGS84','IGNF','136',NULL,207.14,128.41,38.50,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG764_TUAM86_RRAF91','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TUAM86','IGNF','RRAF91','IGNF','136',NULL,207.14,128.41,38.50,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG764_TUAM86_4978','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TUAM86','EPSG','4978','IGNF','136',NULL,207.14,128.41,38.50,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG764_APAT86_WGS84','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','APAT86','IGNF','WGS84','IGNF','136',NULL,207.14,128.41,38.50,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG764_APAT86_RRAF91','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','APAT86','IGNF','RRAF91','IGNF','136',NULL,207.14,128.41,38.50,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG764_APAT86_4978','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','APAT86','EPSG','4978','IGNF','136',NULL,207.14,128.41,38.50,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG764_TUAM86G_TO_WGS84GEODD','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUAM86G','IGNF','WGS84GEODD','IGNF','136',NULL,207.14,128.41,38.50,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG764_APAT86G_TO_WGS84GEODD','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','APAT86G','IGNF','WGS84GEODD','IGNF','136',NULL,207.14,128.41,38.50,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG764_TUAM86G_TO_WGS84GDD','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUAM86G','IGNF','WGS84GDD','IGNF','136',NULL,207.14,128.41,38.50,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG764_APAT86G_TO_WGS84GDD','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','APAT86G','IGNF','WGS84GDD','IGNF','136',NULL,207.14,128.41,38.50,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG764_TUAM86G_TO_WGS84G','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUAM86G','IGNF','WGS84G','IGNF','136',NULL,207.14,128.41,38.50,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG764_TUAM86G_TO_4326','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUAM86G','EPSG','4326','IGNF','136',NULL,207.14,128.41,38.50,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG764_APAT86G_TO_WGS84G','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','APAT86G','IGNF','WGS84G','IGNF','136',NULL,207.14,128.41,38.50,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG764_APAT86G_TO_4326','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','APAT86G','EPSG','4326','IGNF','136',NULL,207.14,128.41,38.50,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG764_TUAM86G_TO_WGS84GEO','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUAM86G','IGNF','WGS84GEO','IGNF','136',NULL,207.14,128.41,38.50,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG764_TUAM86G_TO_WGS84RRAFGEO','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUAM86G','IGNF','WGS84RRAFGEO','IGNF','136',NULL,207.14,128.41,38.50,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG764_APAT86G_TO_WGS84GEO','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','APAT86G','IGNF','WGS84GEO','IGNF','136',NULL,207.14,128.41,38.50,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG764_APAT86G_TO_WGS84RRAFGEO','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','APAT86G','IGNF','WGS84RRAFGEO','IGNF','136',NULL,207.14,128.41,38.50,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','137','APATAKI - TUAMOTU','APATAKI - TUAMOTU',-15.63,-15.29,-146.46,-146.18,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG765','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TUAM86','IGNF','WGS84','IGNF','137',NULL,216.84,118.81,19.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG765_TUAM86_RRAF91','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TUAM86','IGNF','RRAF91','IGNF','137',NULL,216.84,118.81,19.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG765_TUAM86_4978','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TUAM86','EPSG','4978','IGNF','137',NULL,216.84,118.81,19.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG765_APAT86_WGS84','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','APAT86','IGNF','WGS84','IGNF','137',NULL,216.84,118.81,19.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG765_APAT86_RRAF91','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','APAT86','IGNF','RRAF91','IGNF','137',NULL,216.84,118.81,19.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG765_APAT86_4978','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','APAT86','EPSG','4978','IGNF','137',NULL,216.84,118.81,19.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG765_TUAM86G_TO_WGS84GEODD','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUAM86G','IGNF','WGS84GEODD','IGNF','137',NULL,216.84,118.81,19.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG765_APAT86G_TO_WGS84GEODD','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','APAT86G','IGNF','WGS84GEODD','IGNF','137',NULL,216.84,118.81,19.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG765_TUAM86G_TO_WGS84GDD','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUAM86G','IGNF','WGS84GDD','IGNF','137',NULL,216.84,118.81,19.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG765_APAT86G_TO_WGS84GDD','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','APAT86G','IGNF','WGS84GDD','IGNF','137',NULL,216.84,118.81,19.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG765_TUAM86G_TO_WGS84G','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUAM86G','IGNF','WGS84G','IGNF','137',NULL,216.84,118.81,19.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG765_TUAM86G_TO_4326','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUAM86G','EPSG','4326','IGNF','137',NULL,216.84,118.81,19.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG765_APAT86G_TO_WGS84G','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','APAT86G','IGNF','WGS84G','IGNF','137',NULL,216.84,118.81,19.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG765_APAT86G_TO_4326','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','APAT86G','EPSG','4326','IGNF','137',NULL,216.84,118.81,19.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG765_TUAM86G_TO_WGS84GEO','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUAM86G','IGNF','WGS84GEO','IGNF','137',NULL,216.84,118.81,19.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG765_TUAM86G_TO_WGS84RRAFGEO','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TUAM86G','IGNF','WGS84RRAFGEO','IGNF','137',NULL,216.84,118.81,19.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG765_APAT86G_TO_WGS84GEO','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','APAT86G','IGNF','WGS84GEO','IGNF','137',NULL,216.84,118.81,19.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG765_APAT86G_TO_WGS84RRAFGEO','MOP86 (APATAKI - RAPA - HAO) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','APAT86G','IGNF','WGS84RRAFGEO','IGNF','137',NULL,216.84,118.81,19.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1003','MOP90 (TETIAROA) ILES DE LA SOCIETE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TETIA90','IGNF','RGPF','IGNF','40',NULL,217.037,86.959,23.956,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1003_MOP90_RGPF','MOP90 (TETIAROA) ILES DE LA SOCIETE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MOP90','IGNF','RGPF','IGNF','40',NULL,217.037,86.959,23.956,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1003_TETIA90G_TO_RGPFGDD','MOP90 (TETIAROA) ILES DE LA SOCIETE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TETIA90G','IGNF','RGPFGDD','IGNF','40',NULL,217.037,86.959,23.956,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1003_MOP90G_TO_RGPFGDD','MOP90 (TETIAROA) ILES DE LA SOCIETE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MOP90G','IGNF','RGPFGDD','IGNF','40',NULL,217.037,86.959,23.956,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1003_TETIA90G_TO_RGPFGEO','MOP90 (TETIAROA) ILES DE LA SOCIETE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TETIA90G','IGNF','RGPFGEO','IGNF','40',NULL,217.037,86.959,23.956,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1003_MOP90G_TO_RGPFGEO','MOP90 (TETIAROA) ILES DE LA SOCIETE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MOP90G','IGNF','RGPFGEO','IGNF','40',NULL,217.037,86.959,23.956,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1003_TETIA90G_TO_RGPFG','MOP90 (TETIAROA) ILES DE LA SOCIETE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TETIA90G','IGNF','RGPFG','IGNF','40',NULL,217.037,86.959,23.956,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1003_MOP90G_TO_RGPFG','MOP90 (TETIAROA) ILES DE LA SOCIETE vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MOP90G','IGNF','RGPFG','IGNF','40',NULL,217.037,86.959,23.956,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','138','TETIAROA - SOCIETE','TETIAROA - SOCIETE',-17.1,-17.02,-149.6,-149.53,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG755','MOP90 (TETIAROA) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TETIA90','IGNF','WGS84','IGNF','138',NULL,-10.80,-1.80,12.77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG755_TETIA90_RRAF91','MOP90 (TETIAROA) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TETIA90','IGNF','RRAF91','IGNF','138',NULL,-10.80,-1.80,12.77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG755_TETIA90_4978','MOP90 (TETIAROA) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TETIA90','EPSG','4978','IGNF','138',NULL,-10.80,-1.80,12.77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG755_MOP90_WGS84','MOP90 (TETIAROA) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MOP90','IGNF','WGS84','IGNF','138',NULL,-10.80,-1.80,12.77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG755_MOP90_RRAF91','MOP90 (TETIAROA) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MOP90','IGNF','RRAF91','IGNF','138',NULL,-10.80,-1.80,12.77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG755_MOP90_4978','MOP90 (TETIAROA) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','MOP90','EPSG','4978','IGNF','138',NULL,-10.80,-1.80,12.77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG755_TETIA90G_TO_WGS84GEODD','MOP90 (TETIAROA) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TETIA90G','IGNF','WGS84GEODD','IGNF','138',NULL,-10.80,-1.80,12.77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG755_MOP90G_TO_WGS84GEODD','MOP90 (TETIAROA) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MOP90G','IGNF','WGS84GEODD','IGNF','138',NULL,-10.80,-1.80,12.77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG755_TETIA90G_TO_WGS84GDD','MOP90 (TETIAROA) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TETIA90G','IGNF','WGS84GDD','IGNF','138',NULL,-10.80,-1.80,12.77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG755_MOP90G_TO_WGS84GDD','MOP90 (TETIAROA) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MOP90G','IGNF','WGS84GDD','IGNF','138',NULL,-10.80,-1.80,12.77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG755_TETIA90G_TO_WGS84G','MOP90 (TETIAROA) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TETIA90G','IGNF','WGS84G','IGNF','138',NULL,-10.80,-1.80,12.77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG755_TETIA90G_TO_4326','MOP90 (TETIAROA) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TETIA90G','EPSG','4326','IGNF','138',NULL,-10.80,-1.80,12.77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG755_MOP90G_TO_WGS84G','MOP90 (TETIAROA) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MOP90G','IGNF','WGS84G','IGNF','138',NULL,-10.80,-1.80,12.77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG755_MOP90G_TO_4326','MOP90 (TETIAROA) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MOP90G','EPSG','4326','IGNF','138',NULL,-10.80,-1.80,12.77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG755_TETIA90G_TO_WGS84GEO','MOP90 (TETIAROA) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TETIA90G','IGNF','WGS84GEO','IGNF','138',NULL,-10.80,-1.80,12.77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG755_TETIA90G_TO_WGS84RRAFGEO','MOP90 (TETIAROA) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TETIA90G','IGNF','WGS84RRAFGEO','IGNF','138',NULL,-10.80,-1.80,12.77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG755_MOP90G_TO_WGS84GEO','MOP90 (TETIAROA) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MOP90G','IGNF','WGS84GEO','IGNF','138',NULL,-10.80,-1.80,12.77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG755_MOP90G_TO_WGS84RRAFGEO','MOP90 (TETIAROA) ILES DE LA SOCIETE vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','MOP90G','IGNF','WGS84RRAFGEO','IGNF','138',NULL,-10.80,-1.80,12.77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','139','ANAA - TUAMOTU','ANAA - TUAMOTU',-17.5,-17.32,-145.6,-145.37,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG759','MOP92 (ANAA) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ANAA92','IGNF','WGS84','IGNF','139',NULL,1.50,3.84,4.81,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG759_ANAA92_RRAF91','MOP92 (ANAA) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ANAA92','IGNF','RRAF91','IGNF','139',NULL,1.50,3.84,4.81,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG759_ANAA92_4978','MOP92 (ANAA) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','ANAA92','EPSG','4978','IGNF','139',NULL,1.50,3.84,4.81,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG759_ANAA92G_TO_WGS84GEODD','MOP92 (ANAA) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ANAA92G','IGNF','WGS84GEODD','IGNF','139',NULL,1.50,3.84,4.81,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG759_ANAA92G_TO_WGS84GDD','MOP92 (ANAA) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ANAA92G','IGNF','WGS84GDD','IGNF','139',NULL,1.50,3.84,4.81,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG759_ANAA92G_TO_WGS84G','MOP92 (ANAA) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ANAA92G','IGNF','WGS84G','IGNF','139',NULL,1.50,3.84,4.81,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG759_ANAA92G_TO_4326','MOP92 (ANAA) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ANAA92G','EPSG','4326','IGNF','139',NULL,1.50,3.84,4.81,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG759_ANAA92G_TO_WGS84GEO','MOP92 (ANAA) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ANAA92G','IGNF','WGS84GEO','IGNF','139',NULL,1.50,3.84,4.81,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG759_ANAA92G_TO_WGS84RRAFGEO','MOP92 (ANAA) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ANAA92G','IGNF','WGS84RRAFGEO','IGNF','139',NULL,1.50,3.84,4.81,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG759_ANAA92GEO_TO_WGS84GEODD','MOP92 (ANAA) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ANAA92GEO','IGNF','WGS84GEODD','IGNF','139',NULL,1.50,3.84,4.81,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG759_ANAA92GEO_TO_WGS84GDD','MOP92 (ANAA) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ANAA92GEO','IGNF','WGS84GDD','IGNF','139',NULL,1.50,3.84,4.81,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG759_ANAA92GEO_TO_WGS84G','MOP92 (ANAA) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ANAA92GEO','IGNF','WGS84G','IGNF','139',NULL,1.50,3.84,4.81,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG759_ANAA92GEO_TO_4326','MOP92 (ANAA) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ANAA92GEO','EPSG','4326','IGNF','139',NULL,1.50,3.84,4.81,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG759_ANAA92GEO_TO_WGS84GEO','MOP92 (ANAA) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ANAA92GEO','IGNF','WGS84GEO','IGNF','139',NULL,1.50,3.84,4.81,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG759_ANAA92GEO_TO_WGS84RRAFGEO','MOP92 (ANAA) TUAMOTU vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','ANAA92GEO','IGNF','WGS84RRAFGEO','IGNF','139',NULL,1.50,3.84,4.81,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','140','EUROPE (EVRF2000)','EUROPE (EVRF2000)',36,71.2,-10,32,0);
INSERT INTO "other_transformation" VALUES('IGNF','TSG1250','NGF-IGN 1969 vers EVRF2000 (UELN-95/98)(EUROPEAN VERTICAL REFERENCE FRAME)',NULL,'CONTINENTALE, HISTORIQUE','EPSG','9616','Vertical Offset','IGNF','IGN69','IGNF','EVRF2000','IGNF','140',NULL,'EPSG','8603','Vertical Offset',-0.486,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0',0);
INSERT INTO "area" VALUES('IGNF','141','EUROPE (EVRF2007)','EUROPE (EVRF2007)',36,71.2,-10,32,0);
INSERT INTO "other_transformation" VALUES('IGNF','TSG1251','NGF-IGN 1969 vers EVRF2007 (EUROPEAN VERTICAL REFERENCE FRAME 2007)',NULL,'CONTINENTALE','EPSG','9616','Vertical Offset','IGNF','IGN69','IGNF','EVRF2007','IGNF','141',NULL,'EPSG','8603','Vertical Offset',-0.47,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0',0);
INSERT INTO "area" VALUES('IGNF','142','FRANCE CONTINENTALE','FRANCE CONTINENTALE',42.00,51.50,-5.50,8.50,0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1164','RGF93 (ETRS89) vers NGF-IGN 1969',NULL,'NATIONALE, HISTORIQUE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGF93GEODD','IGNF','IGN69','IGNF','142',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/metropole/RAF09.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1252','RGF93 (ETRS89) vers NGF-IGN 1969',NULL,'NATIONALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGF93GEODD','IGNF','IGN69','IGNF','142',NULL,'EPSG','8666','Geoid (height correction) model file','https://geodesie.ign.fr/contenu/fichiers/documentation/grilles/metropole/RAF18.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1163','RGF93 (ETRS89) vers NGF-IGN 1978',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGF93GEODD','IGNF','IGN78C','IGNF','86',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/metropole/RAC09.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1161','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers NIVELLEMENT GENERAL DE GUYANE (NGG) 1977',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGFG95GEO','IGNF','GUYA77','IGNF','10',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggguy15.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG62','NOUVELLE TRIANGULATION DE LA FRANCE (NTF) vers EUROPE 1950 (ED50)',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','NTF','IGNF','ED50','IGNF','91',NULL,-84,37,437,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG62_NTFG_TO_ED50G','NOUVELLE TRIANGULATION DE LA FRANCE (NTF) vers EUROPE 1950 (ED50)',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NTFG','IGNF','ED50G','IGNF','91',NULL,-84,37,437,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG62_NTFG_TO_ED50GEO','NOUVELLE TRIANGULATION DE LA FRANCE (NTF) vers EUROPE 1950 (ED50)',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NTFG','IGNF','ED50GEO','IGNF','91',NULL,-84,37,437,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','143','FRANCE METROPOLITAINE','FRANCE METROPOLITAINE',41.0,52.0,-5.5,10.0,0);
INSERT INTO "grid_transformation" VALUES('IGNF','NTFG_TO_RGF93G','NOUVELLE TRIANGULATION DE LA FRANCE (NTF) vers RGF93 (ETRS89)',NULL,'NATIONALE','EPSG','9615','NTv2','IGNF','NTFG','IGNF','RGF93G','IGNF','143',NULL,'EPSG','8656','Latitude and longitude difference file','ntf_r93.gsb',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','IGNF_NTFG_TO_EPSG_4326','NOUVELLE TRIANGULATION DE LA FRANCE (NTF) vers RGF93 (ETRS89)',NULL,'NATIONALE','EPSG','9615','NTv2','IGNF','NTFG','EPSG','4326','IGNF','143',NULL,'EPSG','8656','Latitude and longitude difference file','ntf_r93.gsb',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG399','NOUVELLE TRIANGULATION DE LA FRANCE (NTF) vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','NTF','IGNF','WGS84','IGNF','91',NULL,-168,-60,320,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG399_NTF_RRAF91','NOUVELLE TRIANGULATION DE LA FRANCE (NTF) vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','NTF','IGNF','RRAF91','IGNF','91',NULL,-168,-60,320,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG399_NTF_4978','NOUVELLE TRIANGULATION DE LA FRANCE (NTF) vers WGS 84',NULL,'NATIONALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','NTF','EPSG','4978','IGNF','91',NULL,-168,-60,320,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG399_NTFG_TO_WGS84GEODD','NOUVELLE TRIANGULATION DE LA FRANCE (NTF) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NTFG','IGNF','WGS84GEODD','IGNF','91',NULL,-168,-60,320,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG399_NTFG_TO_WGS84GDD','NOUVELLE TRIANGULATION DE LA FRANCE (NTF) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NTFG','IGNF','WGS84GDD','IGNF','91',NULL,-168,-60,320,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG399_NTFG_TO_WGS84G','NOUVELLE TRIANGULATION DE LA FRANCE (NTF) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NTFG','IGNF','WGS84G','IGNF','91',NULL,-168,-60,320,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG399_NTFG_TO_4326','NOUVELLE TRIANGULATION DE LA FRANCE (NTF) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NTFG','EPSG','4326','IGNF','91',NULL,-168,-60,320,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG399_NTFG_TO_WGS84GEO','NOUVELLE TRIANGULATION DE LA FRANCE (NTF) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NTFG','IGNF','WGS84GEO','IGNF','91',NULL,-168,-60,320,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG399_NTFG_TO_WGS84RRAFGEO','NOUVELLE TRIANGULATION DE LA FRANCE (NTF) vers WGS 84',NULL,'NATIONALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','NTFG','IGNF','WGS84RRAFGEO','IGNF','91',NULL,-168,-60,320,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','144','LUXEMBOURG','LUXEMBOURG',49.45,50.18,5.73,6.53,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG802','NOUVELLE TRIANGULATION DU GRAND DUCHE DE LUXEMBOURG (LURES) vers WGS 84',NULL,'NATIONALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','LURES','IGNF','WGS84','IGNF','144',NULL,-192.986,13.673,-39.309,'EPSG','9001',-0.409900,-2.933200,2.688100,'EPSG','9104',0.43,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG802_LURES_RRAF91','NOUVELLE TRIANGULATION DU GRAND DUCHE DE LUXEMBOURG (LURES) vers WGS 84',NULL,'NATIONALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','LURES','IGNF','RRAF91','IGNF','144',NULL,-192.986,13.673,-39.309,'EPSG','9001',-0.409900,-2.933200,2.688100,'EPSG','9104',0.43,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG802_LURES_4978','NOUVELLE TRIANGULATION DU GRAND DUCHE DE LUXEMBOURG (LURES) vers WGS 84',NULL,'NATIONALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','LURES','EPSG','4978','IGNF','144',NULL,-192.986,13.673,-39.309,'EPSG','9001',-0.409900,-2.933200,2.688100,'EPSG','9104',0.43,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG802_LUREF_WGS84','NOUVELLE TRIANGULATION DU GRAND DUCHE DE LUXEMBOURG (LURES) vers WGS 84',NULL,'NATIONALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','LUREF','IGNF','WGS84','IGNF','144',NULL,-192.986,13.673,-39.309,'EPSG','9001',-0.409900,-2.933200,2.688100,'EPSG','9104',0.43,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG802_LUREF_RRAF91','NOUVELLE TRIANGULATION DU GRAND DUCHE DE LUXEMBOURG (LURES) vers WGS 84',NULL,'NATIONALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','LUREF','IGNF','RRAF91','IGNF','144',NULL,-192.986,13.673,-39.309,'EPSG','9001',-0.409900,-2.933200,2.688100,'EPSG','9104',0.43,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG802_LUREF_4978','NOUVELLE TRIANGULATION DU GRAND DUCHE DE LUXEMBOURG (LURES) vers WGS 84',NULL,'NATIONALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','LUREF','EPSG','4978','IGNF','144',NULL,-192.986,13.673,-39.309,'EPSG','9001',-0.409900,-2.933200,2.688100,'EPSG','9104',0.43,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG802_LURESG_TO_WGS84GEODD','NOUVELLE TRIANGULATION DU GRAND DUCHE DE LUXEMBOURG (LURES) vers WGS 84',NULL,'NATIONALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','LURESG','IGNF','WGS84GEODD','IGNF','144',NULL,-192.986,13.673,-39.309,'EPSG','9001',-0.409900,-2.933200,2.688100,'EPSG','9104',0.43,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG802_LUXGEO_TO_WGS84GEODD','NOUVELLE TRIANGULATION DU GRAND DUCHE DE LUXEMBOURG (LURES) vers WGS 84',NULL,'NATIONALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','LUXGEO','IGNF','WGS84GEODD','IGNF','144',NULL,-192.986,13.673,-39.309,'EPSG','9001',-0.409900,-2.933200,2.688100,'EPSG','9104',0.43,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG802_LURESG_TO_WGS84GDD','NOUVELLE TRIANGULATION DU GRAND DUCHE DE LUXEMBOURG (LURES) vers WGS 84',NULL,'NATIONALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','LURESG','IGNF','WGS84GDD','IGNF','144',NULL,-192.986,13.673,-39.309,'EPSG','9001',-0.409900,-2.933200,2.688100,'EPSG','9104',0.43,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG802_LUXGEO_TO_WGS84GDD','NOUVELLE TRIANGULATION DU GRAND DUCHE DE LUXEMBOURG (LURES) vers WGS 84',NULL,'NATIONALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','LUXGEO','IGNF','WGS84GDD','IGNF','144',NULL,-192.986,13.673,-39.309,'EPSG','9001',-0.409900,-2.933200,2.688100,'EPSG','9104',0.43,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG802_LURESG_TO_WGS84G','NOUVELLE TRIANGULATION DU GRAND DUCHE DE LUXEMBOURG (LURES) vers WGS 84',NULL,'NATIONALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','LURESG','IGNF','WGS84G','IGNF','144',NULL,-192.986,13.673,-39.309,'EPSG','9001',-0.409900,-2.933200,2.688100,'EPSG','9104',0.43,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG802_LURESG_TO_4326','NOUVELLE TRIANGULATION DU GRAND DUCHE DE LUXEMBOURG (LURES) vers WGS 84',NULL,'NATIONALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','LURESG','EPSG','4326','IGNF','144',NULL,-192.986,13.673,-39.309,'EPSG','9001',-0.409900,-2.933200,2.688100,'EPSG','9104',0.43,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG802_LUXGEO_TO_WGS84G','NOUVELLE TRIANGULATION DU GRAND DUCHE DE LUXEMBOURG (LURES) vers WGS 84',NULL,'NATIONALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','LUXGEO','IGNF','WGS84G','IGNF','144',NULL,-192.986,13.673,-39.309,'EPSG','9001',-0.409900,-2.933200,2.688100,'EPSG','9104',0.43,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG802_LUXGEO_TO_4326','NOUVELLE TRIANGULATION DU GRAND DUCHE DE LUXEMBOURG (LURES) vers WGS 84',NULL,'NATIONALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','LUXGEO','EPSG','4326','IGNF','144',NULL,-192.986,13.673,-39.309,'EPSG','9001',-0.409900,-2.933200,2.688100,'EPSG','9104',0.43,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG802_LURESG_TO_WGS84GEO','NOUVELLE TRIANGULATION DU GRAND DUCHE DE LUXEMBOURG (LURES) vers WGS 84',NULL,'NATIONALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','LURESG','IGNF','WGS84GEO','IGNF','144',NULL,-192.986,13.673,-39.309,'EPSG','9001',-0.409900,-2.933200,2.688100,'EPSG','9104',0.43,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG802_LURESG_TO_WGS84RRAFGEO','NOUVELLE TRIANGULATION DU GRAND DUCHE DE LUXEMBOURG (LURES) vers WGS 84',NULL,'NATIONALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','LURESG','IGNF','WGS84RRAFGEO','IGNF','144',NULL,-192.986,13.673,-39.309,'EPSG','9001',-0.409900,-2.933200,2.688100,'EPSG','9104',0.43,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG802_LUXGEO_TO_WGS84GEO','NOUVELLE TRIANGULATION DU GRAND DUCHE DE LUXEMBOURG (LURES) vers WGS 84',NULL,'NATIONALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','LUXGEO','IGNF','WGS84GEO','IGNF','144',NULL,-192.986,13.673,-39.309,'EPSG','9001',-0.409900,-2.933200,2.688100,'EPSG','9104',0.43,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG802_LUXGEO_TO_WGS84RRAFGEO','NOUVELLE TRIANGULATION DU GRAND DUCHE DE LUXEMBOURG (LURES) vers WGS 84',NULL,'NATIONALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','LUXGEO','IGNF','WGS84RRAFGEO','IGNF','144',NULL,-192.986,13.673,-39.309,'EPSG','9001',-0.409900,-2.933200,2.688100,'EPSG','9104',0.43,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "other_transformation" VALUES('IGNF','TSG1240','NTF geographiques Paris (gr) vers NTF GEOGRAPHIQUES GREENWICH (DMS)',NULL,'NATIONALE','EPSG','9601','Longitude rotation','IGNF','NTFPGRAD','IGNF','NTFG','IGNF','143',0.0,'EPSG','8602','Longitude offset',2.5969213,'EPSG','9105',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0',0);
INSERT INTO "other_transformation" VALUES('IGNF','TSG1240_IGNF_NTFP_TO_IGNF_NTFG','NTF geographiques Paris (gr) vers NTF GEOGRAPHIQUES GREENWICH (DMS)',NULL,'NATIONALE','EPSG','9601','Longitude rotation','IGNF','NTFP','IGNF','NTFG','IGNF','143',0.0,'EPSG','8602','Longitude offset',2.5969213,'EPSG','9105',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0',0);
INSERT INTO "area" VALUES('IGNF','145','TERRE ADELIE - ILE DES PETRELS','TERRE ADELIE - ILE DES PETRELS',-68,-66.17,139.67,140.17,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG608','PETRELS-IGN 1972 vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','PETRELS72','IGNF','WGS84','IGNF','145',NULL,365,194,166,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG608_PETRELS72_RRAF91','PETRELS-IGN 1972 vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','PETRELS72','IGNF','RRAF91','IGNF','145',NULL,365,194,166,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG608_PETRELS72_4978','PETRELS-IGN 1972 vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','PETRELS72','EPSG','4978','IGNF','145',NULL,365,194,166,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG608_PETRELS72G_TO_WGS84GEODD','PETRELS-IGN 1972 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','PETRELS72G','IGNF','WGS84GEODD','IGNF','145',NULL,365,194,166,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG608_PETRELS72G_TO_WGS84GDD','PETRELS-IGN 1972 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','PETRELS72G','IGNF','WGS84GDD','IGNF','145',NULL,365,194,166,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG608_PETRELS72G_TO_WGS84G','PETRELS-IGN 1972 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','PETRELS72G','IGNF','WGS84G','IGNF','145',NULL,365,194,166,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG608_PETRELS72G_TO_4326','PETRELS-IGN 1972 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','PETRELS72G','EPSG','4326','IGNF','145',NULL,365,194,166,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG608_PETRELS72G_TO_WGS84GEO','PETRELS-IGN 1972 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','PETRELS72G','IGNF','WGS84GEO','IGNF','145',NULL,365,194,166,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG608_PETRELS72G_TO_WGS84RRAFGEO','PETRELS-IGN 1972 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','PETRELS72G','IGNF','WGS84RRAFGEO','IGNF','145',NULL,365,194,166,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG815','POINTE GEOLOGIE-PERROUD 1950 vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','PGP50','IGNF','RGTAAF07','IGNF','48',NULL,324.912,153.282,172.026,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG815_TERA50_RGTAAF07','POINTE GEOLOGIE-PERROUD 1950 vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TERA50','IGNF','RGTAAF07','IGNF','48',NULL,324.912,153.282,172.026,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG815_TERA50GEO_TO_RGTAAFGEODD','POINTE GEOLOGIE-PERROUD 1950 vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50GEO','IGNF','RGTAAFGEODD','IGNF','48',NULL,324.912,153.282,172.026,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG815_TERA50GEO_TO_RGTAAF07GDD','POINTE GEOLOGIE-PERROUD 1950 vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50GEO','IGNF','RGTAAF07GDD','IGNF','48',NULL,324.912,153.282,172.026,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG815_TERA50GEO_TO_RGTAAF07G','POINTE GEOLOGIE-PERROUD 1950 vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50GEO','IGNF','RGTAAF07G','IGNF','48',NULL,324.912,153.282,172.026,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG815_TERA50GEO_TO_RGTAAFGEO','POINTE GEOLOGIE-PERROUD 1950 vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50GEO','IGNF','RGTAAFGEO','IGNF','48',NULL,324.912,153.282,172.026,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG815_PGP50G_TO_RGTAAFGEODD','POINTE GEOLOGIE-PERROUD 1950 vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','PGP50G','IGNF','RGTAAFGEODD','IGNF','48',NULL,324.912,153.282,172.026,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG815_TERA50G_TO_RGTAAFGEODD','POINTE GEOLOGIE-PERROUD 1950 vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50G','IGNF','RGTAAFGEODD','IGNF','48',NULL,324.912,153.282,172.026,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG815_PGP50G_TO_RGTAAF07GDD','POINTE GEOLOGIE-PERROUD 1950 vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','PGP50G','IGNF','RGTAAF07GDD','IGNF','48',NULL,324.912,153.282,172.026,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG815_TERA50G_TO_RGTAAF07GDD','POINTE GEOLOGIE-PERROUD 1950 vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50G','IGNF','RGTAAF07GDD','IGNF','48',NULL,324.912,153.282,172.026,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG815_PGP50G_TO_RGTAAF07G','POINTE GEOLOGIE-PERROUD 1950 vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','PGP50G','IGNF','RGTAAF07G','IGNF','48',NULL,324.912,153.282,172.026,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG815_TERA50G_TO_RGTAAF07G','POINTE GEOLOGIE-PERROUD 1950 vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50G','IGNF','RGTAAF07G','IGNF','48',NULL,324.912,153.282,172.026,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG815_PGP50G_TO_RGTAAFGEO','POINTE GEOLOGIE-PERROUD 1950 vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','PGP50G','IGNF','RGTAAFGEO','IGNF','48',NULL,324.912,153.282,172.026,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG815_TERA50G_TO_RGTAAFGEO','POINTE GEOLOGIE-PERROUD 1950 vers RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007)',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50G','IGNF','RGTAAFGEO','IGNF','48',NULL,324.912,153.282,172.026,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','146','TERRE ADELIE','TERRE ADELIE',-66.72,-66.6,139.67,140.12,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','PGP50','IGNF','WGS84','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_PGP50_RRAF91','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','PGP50','IGNF','RRAF91','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_PGP50_4978','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','PGP50','EPSG','4978','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_TERA50_WGS84','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TERA50','IGNF','WGS84','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_TERA50_RRAF91','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TERA50','IGNF','RRAF91','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_TERA50_4978','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TERA50','EPSG','4978','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_TERA50GEO_TO_WGS84GEODD','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50GEO','IGNF','WGS84GEODD','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_TERA50GEO_TO_WGS84GDD','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50GEO','IGNF','WGS84GDD','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_TERA50GEO_TO_WGS84G','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50GEO','IGNF','WGS84G','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_TERA50GEO_TO_4326','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50GEO','EPSG','4326','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_TERA50GEO_TO_WGS84GEO','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50GEO','IGNF','WGS84GEO','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_TERA50GEO_TO_WGS84RRAFGEO','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50GEO','IGNF','WGS84RRAFGEO','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_PGP50G_TO_WGS84GEODD','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','PGP50G','IGNF','WGS84GEODD','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_TERA50G_TO_WGS84GEODD','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50G','IGNF','WGS84GEODD','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_PGP50G_TO_WGS84GDD','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','PGP50G','IGNF','WGS84GDD','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_TERA50G_TO_WGS84GDD','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50G','IGNF','WGS84GDD','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_PGP50G_TO_WGS84G','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','PGP50G','IGNF','WGS84G','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_PGP50G_TO_4326','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','PGP50G','EPSG','4326','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_TERA50G_TO_WGS84G','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50G','IGNF','WGS84G','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_TERA50G_TO_4326','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50G','EPSG','4326','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_PGP50G_TO_WGS84GEO','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','PGP50G','IGNF','WGS84GEO','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_PGP50G_TO_WGS84RRAFGEO','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','PGP50G','IGNF','WGS84RRAFGEO','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_TERA50G_TO_WGS84GEO','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50G','IGNF','WGS84GEO','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG586_TERA50G_TO_WGS84RRAFGEO','POINTE GEOLOGIE-PERROUD 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TERA50G','IGNF','WGS84RRAFGEO','IGNF','146',NULL,324.8,153.6,172.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','147','ILE DE RAIATEA','ILE DE RAIATEA',-17.0,-16.5,-151.75,-151.25,0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1140','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers RAIATEA_SAU 2001',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGPFGEO','IGNF','RAIA01','IGNF','147',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggpf02-Raiatea.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGNC','IGNF','WGS84','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNC_RRAF91','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGNC','IGNF','RRAF91','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNC_4978','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGNC','EPSG','4978','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNCGEODD_TO_WGS84GEODD','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGNCGEODD','IGNF','WGS84GEODD','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNCGEODD_TO_WGS84GDD','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGNCGEODD','IGNF','WGS84GDD','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNCGEODD_TO_WGS84G','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGNCGEODD','IGNF','WGS84G','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNCGEODD_TO_4326','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGNCGEODD','EPSG','4326','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNCGEODD_TO_WGS84GEO','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGNCGEODD','IGNF','WGS84GEO','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNCGEODD_TO_WGS84RRAFGEO','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGNCGEODD','IGNF','WGS84RRAFGEO','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNCGEO_TO_WGS84GEODD','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGNCGEO','IGNF','WGS84GEODD','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNCGEO_TO_WGS84GDD','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGNCGEO','IGNF','WGS84GDD','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNCGEO_TO_WGS84G','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGNCGEO','IGNF','WGS84G','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNCGEO_TO_4326','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGNCGEO','EPSG','4326','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNCGEO_TO_WGS84GEO','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGNCGEO','IGNF','WGS84GEO','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNCGEO_TO_WGS84RRAFGEO','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGNCGEO','IGNF','WGS84RRAFGEO','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNCG_TO_WGS84GEODD','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGNCG','IGNF','WGS84GEODD','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNCG_TO_WGS84GDD','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGNCG','IGNF','WGS84GDD','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNCG_TO_WGS84G','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGNCG','IGNF','WGS84G','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNCG_TO_4326','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGNCG','EPSG','4326','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNCG_TO_WGS84GEO','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGNCG','IGNF','WGS84GEO','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1212_RGNCG_TO_WGS84RRAFGEO','RESEAU GEODESIQUE DE NOUVELLE-CALEDONIE (RGNC 1991) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGNCG','IGNF','WGS84RRAFGEO','IGNF','57',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG601','REUNION-PITON DES NEIGES vers RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','REUN49','IGNF','RGR92','IGNF','55',NULL,789.524,-626.486,-89.904,'EPSG','9001',0.6006,76.7946,-10.5788,'EPSG','9104',-32.3241,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG601_REUN47_RGR92','REUNION-PITON DES NEIGES vers RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','REUN47','IGNF','RGR92','IGNF','55',NULL,789.524,-626.486,-89.904,'EPSG','9001',0.6006,76.7946,-10.5788,'EPSG','9104',-32.3241,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG601_REUN47GEO_TO_RGR92GEODD','REUNION-PITON DES NEIGES vers RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','REUN47GEO','IGNF','RGR92GEODD','IGNF','55',NULL,789.524,-626.486,-89.904,'EPSG','9001',0.6006,76.7946,-10.5788,'EPSG','9104',-32.3241,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG601_REUN47GEO_TO_RGR92GDD','REUNION-PITON DES NEIGES vers RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','REUN47GEO','IGNF','RGR92GDD','IGNF','55',NULL,789.524,-626.486,-89.904,'EPSG','9001',0.6006,76.7946,-10.5788,'EPSG','9104',-32.3241,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG601_REUN47GEO_TO_RGR92GEO','REUNION-PITON DES NEIGES vers RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','REUN47GEO','IGNF','RGR92GEO','IGNF','55',NULL,789.524,-626.486,-89.904,'EPSG','9001',0.6006,76.7946,-10.5788,'EPSG','9104',-32.3241,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG601_REUN47GEO_TO_RGR92G','REUNION-PITON DES NEIGES vers RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','REUN47GEO','IGNF','RGR92G','IGNF','55',NULL,789.524,-626.486,-89.904,'EPSG','9001',0.6006,76.7946,-10.5788,'EPSG','9104',-32.3241,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG601_REUN49G_TO_RGR92GEODD','REUNION-PITON DES NEIGES vers RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','REUN49G','IGNF','RGR92GEODD','IGNF','55',NULL,789.524,-626.486,-89.904,'EPSG','9001',0.6006,76.7946,-10.5788,'EPSG','9104',-32.3241,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG601_REUN47G_TO_RGR92GEODD','REUNION-PITON DES NEIGES vers RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','REUN47G','IGNF','RGR92GEODD','IGNF','55',NULL,789.524,-626.486,-89.904,'EPSG','9001',0.6006,76.7946,-10.5788,'EPSG','9104',-32.3241,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG601_REUN49G_TO_RGR92GDD','REUNION-PITON DES NEIGES vers RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','REUN49G','IGNF','RGR92GDD','IGNF','55',NULL,789.524,-626.486,-89.904,'EPSG','9001',0.6006,76.7946,-10.5788,'EPSG','9104',-32.3241,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG601_REUN47G_TO_RGR92GDD','REUNION-PITON DES NEIGES vers RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','REUN47G','IGNF','RGR92GDD','IGNF','55',NULL,789.524,-626.486,-89.904,'EPSG','9001',0.6006,76.7946,-10.5788,'EPSG','9104',-32.3241,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG601_REUN49G_TO_RGR92GEO','REUNION-PITON DES NEIGES vers RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','REUN49G','IGNF','RGR92GEO','IGNF','55',NULL,789.524,-626.486,-89.904,'EPSG','9001',0.6006,76.7946,-10.5788,'EPSG','9104',-32.3241,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG601_REUN47G_TO_RGR92GEO','REUNION-PITON DES NEIGES vers RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','REUN47G','IGNF','RGR92GEO','IGNF','55',NULL,789.524,-626.486,-89.904,'EPSG','9001',0.6006,76.7946,-10.5788,'EPSG','9104',-32.3241,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG601_REUN49G_TO_RGR92G','REUNION-PITON DES NEIGES vers RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','REUN49G','IGNF','RGR92G','IGNF','55',NULL,789.524,-626.486,-89.904,'EPSG','9001',0.6006,76.7946,-10.5788,'EPSG','9104',-32.3241,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG601_REUN47G_TO_RGR92G','REUNION-PITON DES NEIGES vers RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','REUN47G','IGNF','RGR92G','IGNF','55',NULL,789.524,-626.486,-89.904,'EPSG','9001',0.6006,76.7946,-10.5788,'EPSG','9104',-32.3241,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','REUN49','IGNF','WGS84','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN49_RRAF91','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','REUN49','IGNF','RRAF91','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN49_4978','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','REUN49','EPSG','4978','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN47_WGS84','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','REUN47','IGNF','WGS84','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN47_RRAF91','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','REUN47','IGNF','RRAF91','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN47_4978','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','REUN47','EPSG','4978','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN47GEO_TO_WGS84GEODD','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','REUN47GEO','IGNF','WGS84GEODD','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN47GEO_TO_WGS84GDD','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','REUN47GEO','IGNF','WGS84GDD','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN47GEO_TO_WGS84G','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','REUN47GEO','IGNF','WGS84G','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN47GEO_TO_4326','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','REUN47GEO','EPSG','4326','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN47GEO_TO_WGS84GEO','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','REUN47GEO','IGNF','WGS84GEO','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN47GEO_TO_WGS84RRAFGEO','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','REUN47GEO','IGNF','WGS84RRAFGEO','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN49G_TO_WGS84GEODD','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','REUN49G','IGNF','WGS84GEODD','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN47G_TO_WGS84GEODD','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','REUN47G','IGNF','WGS84GEODD','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN49G_TO_WGS84GDD','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','REUN49G','IGNF','WGS84GDD','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN47G_TO_WGS84GDD','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','REUN47G','IGNF','WGS84GDD','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN49G_TO_WGS84G','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','REUN49G','IGNF','WGS84G','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN49G_TO_4326','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','REUN49G','EPSG','4326','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN47G_TO_WGS84G','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','REUN47G','IGNF','WGS84G','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN47G_TO_4326','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','REUN47G','EPSG','4326','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN49G_TO_WGS84GEO','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','REUN49G','IGNF','WGS84GEO','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN49G_TO_WGS84RRAFGEO','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','REUN49G','IGNF','WGS84RRAFGEO','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN47G_TO_WGS84GEO','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','REUN47G','IGNF','WGS84GEO','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG587_REUN47G_TO_WGS84RRAFGEO','REUNION-PITON DES NEIGES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','REUN47G','IGNF','WGS84RRAFGEO','IGNF','55',NULL,94,-948,-1262,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGF93','IGNF','WGS84','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93_RRAF91','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGF93','IGNF','RRAF91','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93_4978','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGF93','EPSG','4978','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93GDD_TO_WGS84GEODD','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GDD','IGNF','WGS84GEODD','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93GDD_TO_WGS84GDD','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GDD','IGNF','WGS84GDD','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93GDD_TO_WGS84G','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GDD','IGNF','WGS84G','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93GDD_TO_4326','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GDD','EPSG','4326','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93GDD_TO_WGS84GEO','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GDD','IGNF','WGS84GEO','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93GDD_TO_WGS84RRAFGEO','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GDD','IGNF','WGS84RRAFGEO','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93GEODD_TO_WGS84GEODD','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GEODD','IGNF','WGS84GEODD','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93GEODD_TO_WGS84GDD','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GEODD','IGNF','WGS84GDD','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93GEODD_TO_WGS84G','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GEODD','IGNF','WGS84G','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93GEODD_TO_4326','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GEODD','EPSG','4326','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93GEODD_TO_WGS84GEO','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GEODD','IGNF','WGS84GEO','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93GEODD_TO_WGS84RRAFGEO','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GEODD','IGNF','WGS84RRAFGEO','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93G_TO_WGS84GEODD','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93G','IGNF','WGS84GEODD','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93G_TO_WGS84GDD','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93G','IGNF','WGS84GDD','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93G_TO_WGS84G','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93G','IGNF','WGS84G','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93G_TO_4326','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93G','EPSG','4326','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93G_TO_WGS84GEO','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93G','IGNF','WGS84GEO','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93G_TO_WGS84RRAFGEO','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93G','IGNF','WGS84RRAFGEO','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93GEO_TO_WGS84GEODD','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GEO','IGNF','WGS84GEODD','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93GEO_TO_WGS84GDD','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GEO','IGNF','WGS84GDD','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93GEO_TO_WGS84G','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GEO','IGNF','WGS84G','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93GEO_TO_4326','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GEO','EPSG','4326','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93GEO_TO_WGS84GEO','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GEO','IGNF','WGS84GEO','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1207_RGF93GEO_TO_WGS84RRAFGEO','RGF93 (ETRS89) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GEO','IGNF','WGS84RRAFGEO','IGNF','143',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGFG95','IGNF','WGS84','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95_RRAF91','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGFG95','IGNF','RRAF91','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95_4978','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGFG95','EPSG','4978','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95GEODD_TO_WGS84GEODD','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95GEODD','IGNF','WGS84GEODD','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95GEODD_TO_WGS84GDD','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95GEODD','IGNF','WGS84GDD','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95GEODD_TO_WGS84G','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95GEODD','IGNF','WGS84G','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95GEODD_TO_4326','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95GEODD','EPSG','4326','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95GEODD_TO_WGS84GEO','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95GEODD','IGNF','WGS84GEO','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95GEODD_TO_WGS84RRAFGEO','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95GEODD','IGNF','WGS84RRAFGEO','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95GDD_TO_WGS84GEODD','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95GDD','IGNF','WGS84GEODD','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95GDD_TO_WGS84GDD','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95GDD','IGNF','WGS84GDD','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95GDD_TO_WGS84G','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95GDD','IGNF','WGS84G','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95GDD_TO_4326','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95GDD','EPSG','4326','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95GDD_TO_WGS84GEO','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95GDD','IGNF','WGS84GEO','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95GDD_TO_WGS84RRAFGEO','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95GDD','IGNF','WGS84RRAFGEO','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95GEO_TO_WGS84GEODD','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95GEO','IGNF','WGS84GEODD','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95GEO_TO_WGS84GDD','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95GEO','IGNF','WGS84GDD','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95GEO_TO_WGS84G','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95GEO','IGNF','WGS84G','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95GEO_TO_4326','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95GEO','EPSG','4326','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95GEO_TO_WGS84GEO','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95GEO','IGNF','WGS84GEO','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95GEO_TO_WGS84RRAFGEO','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95GEO','IGNF','WGS84RRAFGEO','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95G_TO_WGS84GEODD','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95G','IGNF','WGS84GEODD','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95G_TO_WGS84GDD','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95G','IGNF','WGS84GDD','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95G_TO_WGS84G','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95G','IGNF','WGS84G','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95G_TO_4326','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95G','EPSG','4326','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95G_TO_WGS84GEO','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95G','IGNF','WGS84GEO','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1211_RGFG95G_TO_WGS84RRAFGEO','RGFG95 (RESEAU GEODESIQUE FRANCAIS DE GUYANE 1995) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGFG95G','IGNF','WGS84RRAFGEO','IGNF','10',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGM04','IGNF','WGS84','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04_RRAF91','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGM04','IGNF','RRAF91','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04_4978','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGM04','EPSG','4978','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04GEODD_TO_WGS84GEODD','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04GEODD','IGNF','WGS84GEODD','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04GEODD_TO_WGS84GDD','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04GEODD','IGNF','WGS84GDD','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04GEODD_TO_WGS84G','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04GEODD','IGNF','WGS84G','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04GEODD_TO_4326','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04GEODD','EPSG','4326','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04GEODD_TO_WGS84GEO','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04GEODD','IGNF','WGS84GEO','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04GEODD_TO_WGS84RRAFGEO','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04GEODD','IGNF','WGS84RRAFGEO','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04GDD_TO_WGS84GEODD','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04GDD','IGNF','WGS84GEODD','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04GDD_TO_WGS84GDD','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04GDD','IGNF','WGS84GDD','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04GDD_TO_WGS84G','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04GDD','IGNF','WGS84G','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04GDD_TO_4326','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04GDD','EPSG','4326','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04GDD_TO_WGS84GEO','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04GDD','IGNF','WGS84GEO','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04GDD_TO_WGS84RRAFGEO','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04GDD','IGNF','WGS84RRAFGEO','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04GEO_TO_WGS84GEODD','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04GEO','IGNF','WGS84GEODD','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04GEO_TO_WGS84GDD','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04GEO','IGNF','WGS84GDD','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04GEO_TO_WGS84G','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04GEO','IGNF','WGS84G','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04GEO_TO_4326','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04GEO','EPSG','4326','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04GEO_TO_WGS84GEO','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04GEO','IGNF','WGS84GEO','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04GEO_TO_WGS84RRAFGEO','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04GEO','IGNF','WGS84RRAFGEO','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04G_TO_WGS84GEODD','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04G','IGNF','WGS84GEODD','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04G_TO_WGS84GDD','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04G','IGNF','WGS84GDD','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04G_TO_WGS84G','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04G','IGNF','WGS84G','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04G_TO_4326','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04G','EPSG','4326','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04G_TO_WGS84GEO','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04G','IGNF','WGS84GEO','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1208_RGM04G_TO_WGS84RRAFGEO','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGM04G','IGNF','WGS84RRAFGEO','IGNF','89',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGPF','IGNF','WGS84','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPF_RRAF91','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGPF','IGNF','RRAF91','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPF_4978','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGPF','EPSG','4978','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPFGDD_TO_WGS84GEODD','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGPFGDD','IGNF','WGS84GEODD','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPFGDD_TO_WGS84GDD','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGPFGDD','IGNF','WGS84GDD','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPFGDD_TO_WGS84G','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGPFGDD','IGNF','WGS84G','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPFGDD_TO_4326','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGPFGDD','EPSG','4326','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPFGDD_TO_WGS84GEO','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGPFGDD','IGNF','WGS84GEO','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPFGDD_TO_WGS84RRAFGEO','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGPFGDD','IGNF','WGS84RRAFGEO','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPFGEO_TO_WGS84GEODD','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGPFGEO','IGNF','WGS84GEODD','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPFGEO_TO_WGS84GDD','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGPFGEO','IGNF','WGS84GDD','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPFGEO_TO_WGS84G','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGPFGEO','IGNF','WGS84G','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPFGEO_TO_4326','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGPFGEO','EPSG','4326','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPFGEO_TO_WGS84GEO','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGPFGEO','IGNF','WGS84GEO','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPFGEO_TO_WGS84RRAFGEO','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGPFGEO','IGNF','WGS84RRAFGEO','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPFG_TO_WGS84GEODD','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGPFG','IGNF','WGS84GEODD','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPFG_TO_WGS84GDD','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGPFG','IGNF','WGS84GDD','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPFG_TO_WGS84G','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGPFG','IGNF','WGS84G','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPFG_TO_4326','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGPFG','EPSG','4326','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPFG_TO_WGS84GEO','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGPFG','IGNF','WGS84GEO','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1213_RGPFG_TO_WGS84RRAFGEO','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGPFG','IGNF','WGS84RRAFGEO','IGNF','58',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG355','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers REUNION-PITON DES NEIGES',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','RGR92','IGNF','REUN49','IGNF','55',NULL,-789.990,627.333,89.685,'EPSG','9001',-0.6072,-76.8019,10.5680,'EPSG','9104',32.2083,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG355_RGR92_REUN47','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers REUNION-PITON DES NEIGES',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','RGR92','IGNF','REUN47','IGNF','55',NULL,-789.990,627.333,89.685,'EPSG','9001',-0.6072,-76.8019,10.5680,'EPSG','9104',32.2083,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG355_RGR92GEODD_TO_REUN47GEO','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers REUNION-PITON DES NEIGES',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RGR92GEODD','IGNF','REUN47GEO','IGNF','55',NULL,-789.990,627.333,89.685,'EPSG','9001',-0.6072,-76.8019,10.5680,'EPSG','9104',32.2083,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG355_RGR92GEODD_TO_REUN49G','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers REUNION-PITON DES NEIGES',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RGR92GEODD','IGNF','REUN49G','IGNF','55',NULL,-789.990,627.333,89.685,'EPSG','9001',-0.6072,-76.8019,10.5680,'EPSG','9104',32.2083,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG355_RGR92GEODD_TO_REUN47G','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers REUNION-PITON DES NEIGES',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RGR92GEODD','IGNF','REUN47G','IGNF','55',NULL,-789.990,627.333,89.685,'EPSG','9001',-0.6072,-76.8019,10.5680,'EPSG','9104',32.2083,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG355_RGR92GDD_TO_REUN47GEO','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers REUNION-PITON DES NEIGES',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RGR92GDD','IGNF','REUN47GEO','IGNF','55',NULL,-789.990,627.333,89.685,'EPSG','9001',-0.6072,-76.8019,10.5680,'EPSG','9104',32.2083,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG355_RGR92GDD_TO_REUN49G','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers REUNION-PITON DES NEIGES',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RGR92GDD','IGNF','REUN49G','IGNF','55',NULL,-789.990,627.333,89.685,'EPSG','9001',-0.6072,-76.8019,10.5680,'EPSG','9104',32.2083,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG355_RGR92GDD_TO_REUN47G','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers REUNION-PITON DES NEIGES',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RGR92GDD','IGNF','REUN47G','IGNF','55',NULL,-789.990,627.333,89.685,'EPSG','9001',-0.6072,-76.8019,10.5680,'EPSG','9104',32.2083,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG355_RGR92GEO_TO_REUN47GEO','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers REUNION-PITON DES NEIGES',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RGR92GEO','IGNF','REUN47GEO','IGNF','55',NULL,-789.990,627.333,89.685,'EPSG','9001',-0.6072,-76.8019,10.5680,'EPSG','9104',32.2083,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG355_RGR92GEO_TO_REUN49G','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers REUNION-PITON DES NEIGES',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RGR92GEO','IGNF','REUN49G','IGNF','55',NULL,-789.990,627.333,89.685,'EPSG','9001',-0.6072,-76.8019,10.5680,'EPSG','9104',32.2083,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG355_RGR92GEO_TO_REUN47G','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers REUNION-PITON DES NEIGES',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RGR92GEO','IGNF','REUN47G','IGNF','55',NULL,-789.990,627.333,89.685,'EPSG','9001',-0.6072,-76.8019,10.5680,'EPSG','9104',32.2083,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG355_RGR92G_TO_REUN47GEO','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers REUNION-PITON DES NEIGES',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RGR92G','IGNF','REUN47GEO','IGNF','55',NULL,-789.990,627.333,89.685,'EPSG','9001',-0.6072,-76.8019,10.5680,'EPSG','9104',32.2083,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG355_RGR92G_TO_REUN49G','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers REUNION-PITON DES NEIGES',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RGR92G','IGNF','REUN49G','IGNF','55',NULL,-789.990,627.333,89.685,'EPSG','9001',-0.6072,-76.8019,10.5680,'EPSG','9104',32.2083,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG355_RGR92G_TO_REUN47G','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers REUNION-PITON DES NEIGES',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RGR92G','IGNF','REUN47G','IGNF','55',NULL,-789.990,627.333,89.685,'EPSG','9001',-0.6072,-76.8019,10.5680,'EPSG','9104',32.2083,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','148','REUNION','REUNION',-21.42,-20.75,55.17,55.92,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGR92','IGNF','WGS84','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92_RRAF91','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGR92','IGNF','RRAF91','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92_4978','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGR92','EPSG','4978','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92GEODD_TO_WGS84GEODD','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92GEODD','IGNF','WGS84GEODD','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92GEODD_TO_WGS84GDD','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92GEODD','IGNF','WGS84GDD','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92GEODD_TO_WGS84G','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92GEODD','IGNF','WGS84G','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92GEODD_TO_4326','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92GEODD','EPSG','4326','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92GEODD_TO_WGS84GEO','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92GEODD','IGNF','WGS84GEO','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92GEODD_TO_WGS84RRAFGEO','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92GEODD','IGNF','WGS84RRAFGEO','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92GDD_TO_WGS84GEODD','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92GDD','IGNF','WGS84GEODD','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92GDD_TO_WGS84GDD','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92GDD','IGNF','WGS84GDD','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92GDD_TO_WGS84G','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92GDD','IGNF','WGS84G','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92GDD_TO_4326','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92GDD','EPSG','4326','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92GDD_TO_WGS84GEO','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92GDD','IGNF','WGS84GEO','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92GDD_TO_WGS84RRAFGEO','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92GDD','IGNF','WGS84RRAFGEO','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92GEO_TO_WGS84GEODD','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92GEO','IGNF','WGS84GEODD','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92GEO_TO_WGS84GDD','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92GEO','IGNF','WGS84GDD','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92GEO_TO_WGS84G','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92GEO','IGNF','WGS84G','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92GEO_TO_4326','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92GEO','EPSG','4326','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92GEO_TO_WGS84GEO','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92GEO','IGNF','WGS84GEO','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92GEO_TO_WGS84RRAFGEO','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92GEO','IGNF','WGS84RRAFGEO','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92G_TO_WGS84GEODD','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92G','IGNF','WGS84GEODD','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92G_TO_WGS84GDD','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92G','IGNF','WGS84GDD','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92G_TO_WGS84G','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92G','IGNF','WGS84G','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92G_TO_4326','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92G','EPSG','4326','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92G_TO_WGS84GEO','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92G','IGNF','WGS84GEO','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG731_RGR92G_TO_WGS84RRAFGEO','RGR92 (RESEAU GEODESIQUE DE LA REUNION 1992) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGR92G','IGNF','WGS84RRAFGEO','IGNF','148',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGSPM06','IGNF','WGS84','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06_RRAF91','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGSPM06','IGNF','RRAF91','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06_4978','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGSPM06','EPSG','4978','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06GEODD_TO_WGS84GEODD','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06GEODD','IGNF','WGS84GEODD','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06GEODD_TO_WGS84GDD','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06GEODD','IGNF','WGS84GDD','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06GEODD_TO_WGS84G','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06GEODD','IGNF','WGS84G','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06GEODD_TO_4326','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06GEODD','EPSG','4326','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06GEODD_TO_WGS84GEO','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06GEODD','IGNF','WGS84GEO','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06GEODD_TO_WGS84RRAFGEO','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06GEODD','IGNF','WGS84RRAFGEO','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06GDD_TO_WGS84GEODD','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06GDD','IGNF','WGS84GEODD','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06GDD_TO_WGS84GDD','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06GDD','IGNF','WGS84GDD','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06GDD_TO_WGS84G','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06GDD','IGNF','WGS84G','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06GDD_TO_4326','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06GDD','EPSG','4326','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06GDD_TO_WGS84GEO','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06GDD','IGNF','WGS84GEO','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06GDD_TO_WGS84RRAFGEO','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06GDD','IGNF','WGS84RRAFGEO','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06GEO_TO_WGS84GEODD','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06GEO','IGNF','WGS84GEODD','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06GEO_TO_WGS84GDD','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06GEO','IGNF','WGS84GDD','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06GEO_TO_WGS84G','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06GEO','IGNF','WGS84G','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06GEO_TO_4326','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06GEO','EPSG','4326','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06GEO_TO_WGS84GEO','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06GEO','IGNF','WGS84GEO','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06GEO_TO_WGS84RRAFGEO','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06GEO','IGNF','WGS84RRAFGEO','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06G_TO_WGS84GEODD','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06G','IGNF','WGS84GEODD','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06G_TO_WGS84GDD','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06G','IGNF','WGS84GDD','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06G_TO_WGS84G','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06G','IGNF','WGS84G','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06G_TO_4326','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06G','EPSG','4326','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06G_TO_WGS84GEO','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06G','IGNF','WGS84GEO','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1209_RGSPM06G_TO_WGS84RRAFGEO','RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGSPM06G','IGNF','WGS84RRAFGEO','IGNF','59',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','149','TAAF','TAAF',-90,-11,39,142,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGTAAF07','IGNF','WGS84','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAF07_RRAF91','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGTAAF07','IGNF','RRAF91','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAF07_4978','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGTAAF07','EPSG','4978','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAFGEODD_TO_WGS84GEODD','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAFGEODD','IGNF','WGS84GEODD','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAFGEODD_TO_WGS84GDD','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAFGEODD','IGNF','WGS84GDD','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAFGEODD_TO_WGS84G','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAFGEODD','IGNF','WGS84G','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAFGEODD_TO_4326','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAFGEODD','EPSG','4326','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAFGEODD_TO_WGS84GEO','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAFGEODD','IGNF','WGS84GEO','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAFGEODD_TO_WGS84RRAFGEO','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAFGEODD','IGNF','WGS84RRAFGEO','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAF07GDD_TO_WGS84GEODD','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAF07GDD','IGNF','WGS84GEODD','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAF07GDD_TO_WGS84GDD','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAF07GDD','IGNF','WGS84GDD','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAF07GDD_TO_WGS84G','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAF07GDD','IGNF','WGS84G','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAF07GDD_TO_4326','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAF07GDD','EPSG','4326','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAF07GDD_TO_WGS84GEO','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAF07GDD','IGNF','WGS84GEO','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAF07GDD_TO_WGS84RRAFGEO','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAF07GDD','IGNF','WGS84RRAFGEO','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAF07G_TO_WGS84GEODD','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAF07G','IGNF','WGS84GEODD','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAF07G_TO_WGS84GDD','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAF07G','IGNF','WGS84GDD','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAF07G_TO_WGS84G','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAF07G','IGNF','WGS84G','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAF07G_TO_4326','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAF07G','EPSG','4326','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAF07G_TO_WGS84GEO','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAF07G','IGNF','WGS84GEO','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAF07G_TO_WGS84RRAFGEO','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAF07G','IGNF','WGS84RRAFGEO','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAFGEO_TO_WGS84GEODD','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAFGEO','IGNF','WGS84GEODD','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAFGEO_TO_WGS84GDD','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAFGEO','IGNF','WGS84GDD','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAFGEO_TO_WGS84G','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAFGEO','IGNF','WGS84G','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAFGEO_TO_4326','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAFGEO','EPSG','4326','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAFGEO_TO_WGS84GEO','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAFGEO','IGNF','WGS84GEO','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1210_RGTAAFGEO_TO_WGS84RRAFGEO','RGTAAF07 (RESEAU GEODESIQUE DES TAAF 2007) vers WGS 84',NULL,'SYSTEMES GEODESIQUES ASSIMILABLES SUR LEUR ETENDUE COMMUNE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGTAAFGEO','IGNF','WGS84RRAFGEO','IGNF','149',NULL,0,0,0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','150','RURUTU - AUSTRALES','RURUTU - AUSTRALES',-22.58,-22.25,-151.5,-151.33,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG752','SAT84 (RURUTU) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RUSAT84','IGNF','WGS84','IGNF','150',NULL,202.13,174.60,-15.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG752_RUSAT84_RRAF91','SAT84 (RURUTU) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RUSAT84','IGNF','RRAF91','IGNF','150',NULL,202.13,174.60,-15.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG752_RUSAT84_4978','SAT84 (RURUTU) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RUSAT84','EPSG','4978','IGNF','150',NULL,202.13,174.60,-15.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG752_SAT84_WGS84','SAT84 (RURUTU) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','SAT84','IGNF','WGS84','IGNF','150',NULL,202.13,174.60,-15.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG752_SAT84_RRAF91','SAT84 (RURUTU) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','SAT84','IGNF','RRAF91','IGNF','150',NULL,202.13,174.60,-15.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG752_SAT84_4978','SAT84 (RURUTU) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','SAT84','EPSG','4978','IGNF','150',NULL,202.13,174.60,-15.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG752_RUSAT84G_TO_WGS84GEODD','SAT84 (RURUTU) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RUSAT84G','IGNF','WGS84GEODD','IGNF','150',NULL,202.13,174.60,-15.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG752_SAT84G_TO_WGS84GEODD','SAT84 (RURUTU) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','SAT84G','IGNF','WGS84GEODD','IGNF','150',NULL,202.13,174.60,-15.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG752_RUSAT84G_TO_WGS84GDD','SAT84 (RURUTU) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RUSAT84G','IGNF','WGS84GDD','IGNF','150',NULL,202.13,174.60,-15.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG752_SAT84G_TO_WGS84GDD','SAT84 (RURUTU) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','SAT84G','IGNF','WGS84GDD','IGNF','150',NULL,202.13,174.60,-15.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG752_RUSAT84G_TO_WGS84G','SAT84 (RURUTU) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RUSAT84G','IGNF','WGS84G','IGNF','150',NULL,202.13,174.60,-15.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG752_RUSAT84G_TO_4326','SAT84 (RURUTU) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RUSAT84G','EPSG','4326','IGNF','150',NULL,202.13,174.60,-15.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG752_SAT84G_TO_WGS84G','SAT84 (RURUTU) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','SAT84G','IGNF','WGS84G','IGNF','150',NULL,202.13,174.60,-15.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG752_SAT84G_TO_4326','SAT84 (RURUTU) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','SAT84G','EPSG','4326','IGNF','150',NULL,202.13,174.60,-15.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG752_RUSAT84G_TO_WGS84GEO','SAT84 (RURUTU) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RUSAT84G','IGNF','WGS84GEO','IGNF','150',NULL,202.13,174.60,-15.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG752_RUSAT84G_TO_WGS84RRAFGEO','SAT84 (RURUTU) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RUSAT84G','IGNF','WGS84RRAFGEO','IGNF','150',NULL,202.13,174.60,-15.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG752_SAT84G_TO_WGS84GEO','SAT84 (RURUTU) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','SAT84G','IGNF','WGS84GEO','IGNF','150',NULL,202.13,174.60,-15.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG752_SAT84G_TO_WGS84RRAFGEO','SAT84 (RURUTU) ILES AUSTRALES vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','SAT84G','IGNF','WGS84RRAFGEO','IGNF','150',NULL,202.13,174.60,-15.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1159','RGM04 (RESEAU GEODESIQUE DE MAYOTTE 2004) vers SHOM 1953 (MAYOTTE)',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGM04GEODD','IGNF','MAYO53','IGNF','89',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggm04v1.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG795','ST-PIERRE-ET-MIQUELON 1950 vers RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','STPM50','IGNF','RGSPM06','IGNF','59',NULL,-95.593,573.763,173.442,'EPSG','9001',-0.9602,1.2510,-1.3918,'EPSG','9104',42.6265,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG795_STPM50G_TO_RGSPM06GEODD','ST-PIERRE-ET-MIQUELON 1950 vers RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','STPM50G','IGNF','RGSPM06GEODD','IGNF','59',NULL,-95.593,573.763,173.442,'EPSG','9001',-0.9602,1.2510,-1.3918,'EPSG','9104',42.6265,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG795_STPM50G_TO_RGSPM06GDD','ST-PIERRE-ET-MIQUELON 1950 vers RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','STPM50G','IGNF','RGSPM06GDD','IGNF','59',NULL,-95.593,573.763,173.442,'EPSG','9001',-0.9602,1.2510,-1.3918,'EPSG','9104',42.6265,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG795_STPM50G_TO_RGSPM06GEO','ST-PIERRE-ET-MIQUELON 1950 vers RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','STPM50G','IGNF','RGSPM06GEO','IGNF','59',NULL,-95.593,573.763,173.442,'EPSG','9001',-0.9602,1.2510,-1.3918,'EPSG','9104',42.6265,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG795_STPM50G_TO_RGSPM06G','ST-PIERRE-ET-MIQUELON 1950 vers RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','STPM50G','IGNF','RGSPM06G','IGNF','59',NULL,-95.593,573.763,173.442,'EPSG','9001',-0.9602,1.2510,-1.3918,'EPSG','9104',42.6265,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG795_STPM50GEO_TO_RGSPM06GEODD','ST-PIERRE-ET-MIQUELON 1950 vers RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','STPM50GEO','IGNF','RGSPM06GEODD','IGNF','59',NULL,-95.593,573.763,173.442,'EPSG','9001',-0.9602,1.2510,-1.3918,'EPSG','9104',42.6265,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG795_STPM50GEO_TO_RGSPM06GDD','ST-PIERRE-ET-MIQUELON 1950 vers RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','STPM50GEO','IGNF','RGSPM06GDD','IGNF','59',NULL,-95.593,573.763,173.442,'EPSG','9001',-0.9602,1.2510,-1.3918,'EPSG','9104',42.6265,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG795_STPM50GEO_TO_RGSPM06GEO','ST-PIERRE-ET-MIQUELON 1950 vers RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','STPM50GEO','IGNF','RGSPM06GEO','IGNF','59',NULL,-95.593,573.763,173.442,'EPSG','9001',-0.9602,1.2510,-1.3918,'EPSG','9104',42.6265,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG795_STPM50GEO_TO_RGSPM06G','ST-PIERRE-ET-MIQUELON 1950 vers RGSPM06 (RESEAU GEODESIQUE DE SAINT-PIERRE-ET-MIQUELON 2006)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','STPM50GEO','IGNF','RGSPM06G','IGNF','59',NULL,-95.593,573.763,173.442,'EPSG','9001',-0.9602,1.2510,-1.3918,'EPSG','9104',42.6265,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','151','SAINT-PIERRE ET MIQUELON','SAINT-PIERRE ET MIQUELON',46.7,47.2,-56.49,-56.1,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG812','ST-PIERRE-ET-MIQUELON 1950 vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','STPM50','IGNF','WGS84','IGNF','151',NULL,11.363,424.148,373.130,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG812_STPM50_RRAF91','ST-PIERRE-ET-MIQUELON 1950 vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','STPM50','IGNF','RRAF91','IGNF','151',NULL,11.363,424.148,373.130,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG812_STPM50_4978','ST-PIERRE-ET-MIQUELON 1950 vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','STPM50','EPSG','4978','IGNF','151',NULL,11.363,424.148,373.130,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG812_STPM50G_TO_WGS84GEODD','ST-PIERRE-ET-MIQUELON 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','STPM50G','IGNF','WGS84GEODD','IGNF','151',NULL,11.363,424.148,373.130,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG812_STPM50G_TO_WGS84GDD','ST-PIERRE-ET-MIQUELON 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','STPM50G','IGNF','WGS84GDD','IGNF','151',NULL,11.363,424.148,373.130,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG812_STPM50G_TO_WGS84G','ST-PIERRE-ET-MIQUELON 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','STPM50G','IGNF','WGS84G','IGNF','151',NULL,11.363,424.148,373.130,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG812_STPM50G_TO_4326','ST-PIERRE-ET-MIQUELON 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','STPM50G','EPSG','4326','IGNF','151',NULL,11.363,424.148,373.130,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG812_STPM50G_TO_WGS84GEO','ST-PIERRE-ET-MIQUELON 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','STPM50G','IGNF','WGS84GEO','IGNF','151',NULL,11.363,424.148,373.130,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG812_STPM50G_TO_WGS84RRAFGEO','ST-PIERRE-ET-MIQUELON 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','STPM50G','IGNF','WGS84RRAFGEO','IGNF','151',NULL,11.363,424.148,373.130,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG812_STPM50GEO_TO_WGS84GEODD','ST-PIERRE-ET-MIQUELON 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','STPM50GEO','IGNF','WGS84GEODD','IGNF','151',NULL,11.363,424.148,373.130,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG812_STPM50GEO_TO_WGS84GDD','ST-PIERRE-ET-MIQUELON 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','STPM50GEO','IGNF','WGS84GDD','IGNF','151',NULL,11.363,424.148,373.130,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG812_STPM50GEO_TO_WGS84G','ST-PIERRE-ET-MIQUELON 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','STPM50GEO','IGNF','WGS84G','IGNF','151',NULL,11.363,424.148,373.130,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG812_STPM50GEO_TO_4326','ST-PIERRE-ET-MIQUELON 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','STPM50GEO','EPSG','4326','IGNF','151',NULL,11.363,424.148,373.130,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG812_STPM50GEO_TO_WGS84GEO','ST-PIERRE-ET-MIQUELON 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','STPM50GEO','IGNF','WGS84GEO','IGNF','151',NULL,11.363,424.148,373.130,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG812_STPM50GEO_TO_WGS84RRAFGEO','ST-PIERRE-ET-MIQUELON 1950 vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','STPM50GEO','IGNF','WGS84RRAFGEO','IGNF','151',NULL,11.363,424.148,373.130,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','152','BORA BORA, HUAHINE, RAIATEA, TAHAA','BORA BORA, HUAHINE, RAIATEA, TAHAA',-17,-16.25,-152,-150.75,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1004','TAHAA vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','TAHAA','IGNF','RGPF','IGNF','152',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1004_TAHAAGEO_TO_RGPFGDD','TAHAA vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHAAGEO','IGNF','RGPFGDD','IGNF','152',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1004_TAHAAGEO_TO_RGPFGEO','TAHAA vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHAAGEO','IGNF','RGPFGEO','IGNF','152',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1004_TAHAAGEO_TO_RGPFG','TAHAA vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHAAGEO','IGNF','RGPFG','IGNF','152',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1004_TAHAAG_TO_RGPFGDD','TAHAA vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHAAG','IGNF','RGPFGDD','IGNF','152',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1004_TAHAAG_TO_RGPFGEO','TAHAA vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHAAG','IGNF','RGPFGEO','IGNF','152',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG1004_TAHAAG_TO_RGPFG','TAHAA vers RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','TAHAAG','IGNF','RGPFG','IGNF','152',NULL,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','153','TAHAA-ILES DE LA SOCIETE','TAHAA-ILES DE LA SOCIETE',-16.7,-16.53,-151.58,-151.38,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG595','TAHAA vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TAHAA','IGNF','WGS84','IGNF','153',NULL,65,342,77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG595_TAHAA_RRAF91','TAHAA vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TAHAA','IGNF','RRAF91','IGNF','153',NULL,65,342,77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG595_TAHAA_4978','TAHAA vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TAHAA','EPSG','4978','IGNF','153',NULL,65,342,77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG595_TAHAAGEO_TO_WGS84GEODD','TAHAA vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHAAGEO','IGNF','WGS84GEODD','IGNF','153',NULL,65,342,77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG595_TAHAAGEO_TO_WGS84GDD','TAHAA vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHAAGEO','IGNF','WGS84GDD','IGNF','153',NULL,65,342,77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG595_TAHAAGEO_TO_WGS84G','TAHAA vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHAAGEO','IGNF','WGS84G','IGNF','153',NULL,65,342,77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG595_TAHAAGEO_TO_4326','TAHAA vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHAAGEO','EPSG','4326','IGNF','153',NULL,65,342,77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG595_TAHAAGEO_TO_WGS84GEO','TAHAA vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHAAGEO','IGNF','WGS84GEO','IGNF','153',NULL,65,342,77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG595_TAHAAGEO_TO_WGS84RRAFGEO','TAHAA vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHAAGEO','IGNF','WGS84RRAFGEO','IGNF','153',NULL,65,342,77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG595_TAHAAG_TO_WGS84GEODD','TAHAA vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHAAG','IGNF','WGS84GEODD','IGNF','153',NULL,65,342,77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG595_TAHAAG_TO_WGS84GDD','TAHAA vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHAAG','IGNF','WGS84GDD','IGNF','153',NULL,65,342,77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG595_TAHAAG_TO_WGS84G','TAHAA vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHAAG','IGNF','WGS84G','IGNF','153',NULL,65,342,77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG595_TAHAAG_TO_4326','TAHAA vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHAAG','EPSG','4326','IGNF','153',NULL,65,342,77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG595_TAHAAG_TO_WGS84GEO','TAHAA vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHAAG','IGNF','WGS84GEO','IGNF','153',NULL,65,342,77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG595_TAHAAG_TO_WGS84RRAFGEO','TAHAA vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHAAG','IGNF','WGS84RRAFGEO','IGNF','153',NULL,65,342,77,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','154','ILE DE TAHAA','ILE DE TAHAA',-16.75,-16.5,-151.75,-151.25,0);
INSERT INTO "grid_transformation" VALUES('IGNF','TSG1141','RGPF (RESEAU GEODESIQUE DE POLYNESIE FRANCAISE) vers TAHAA_SAU 2001',NULL,'LOCALE','EPSG','9664','Geographic3D to GravityRelatedHeight (IGN1997)','IGNF','RGPFGEO','IGNF','TAHAA01','IGNF','154',NULL,'EPSG','8666','Geoid (height correction) model file','http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggpf02-Tahaa.mnt',NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','155','TAHITI','TAHITI',-18,-17,-150,-149,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG594','TAHITI-TERME NORD vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TAHI51','IGNF','WGS84','IGNF','155',NULL,162,117,154,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG594_TAHI51_RRAF91','TAHITI-TERME NORD vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TAHI51','IGNF','RRAF91','IGNF','155',NULL,162,117,154,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG594_TAHI51_4978','TAHITI-TERME NORD vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TAHI51','EPSG','4978','IGNF','155',NULL,162,117,154,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG594_TAHI51G_TO_WGS84GEODD','TAHITI-TERME NORD vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHI51G','IGNF','WGS84GEODD','IGNF','155',NULL,162,117,154,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG594_TAHI51G_TO_WGS84GDD','TAHITI-TERME NORD vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHI51G','IGNF','WGS84GDD','IGNF','155',NULL,162,117,154,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG594_TAHI51G_TO_WGS84G','TAHITI-TERME NORD vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHI51G','IGNF','WGS84G','IGNF','155',NULL,162,117,154,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG594_TAHI51G_TO_4326','TAHITI-TERME NORD vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHI51G','EPSG','4326','IGNF','155',NULL,162,117,154,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG594_TAHI51G_TO_WGS84GEO','TAHITI-TERME NORD vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHI51G','IGNF','WGS84GEO','IGNF','155',NULL,162,117,154,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG594_TAHI51G_TO_WGS84RRAFGEO','TAHITI-TERME NORD vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TAHI51G','IGNF','WGS84RRAFGEO','IGNF','155',NULL,162,117,154,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','156','VANUATU - ILE TANNA','VANUATU - ILE TANNA',-19.67,-19.08,169.17,169.83,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG675','TANNA BLOC SUD vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TANNA','IGNF','WGS84','IGNF','156',NULL,-139,-967,436,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG675_TANNA_RRAF91','TANNA BLOC SUD vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TANNA','IGNF','RRAF91','IGNF','156',NULL,-139,-967,436,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG675_TANNA_4978','TANNA BLOC SUD vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','TANNA','EPSG','4978','IGNF','156',NULL,-139,-967,436,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG675_TANNAG_TO_WGS84GEODD','TANNA BLOC SUD vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TANNAG','IGNF','WGS84GEODD','IGNF','156',NULL,-139,-967,436,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG675_TANNAG_TO_WGS84GDD','TANNA BLOC SUD vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TANNAG','IGNF','WGS84GDD','IGNF','156',NULL,-139,-967,436,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG675_TANNAG_TO_WGS84G','TANNA BLOC SUD vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TANNAG','IGNF','WGS84G','IGNF','156',NULL,-139,-967,436,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG675_TANNAG_TO_4326','TANNA BLOC SUD vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TANNAG','EPSG','4326','IGNF','156',NULL,-139,-967,436,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG675_TANNAG_TO_WGS84GEO','TANNA BLOC SUD vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TANNAG','IGNF','WGS84GEO','IGNF','156',NULL,-139,-967,436,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG675_TANNAG_TO_WGS84RRAFGEO','TANNA BLOC SUD vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','TANNAG','IGNF','WGS84RRAFGEO','IGNF','156',NULL,-139,-967,436,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','157','WALLIS ET FUTUNA','WALLIS ET FUTUNA',-13.42,-13.17,-176.3,-176.1,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG609','WALLIS-UVEA SHOM 1978 (MOP1978) vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','WALL78','IGNF','WGS84','IGNF','157',NULL,253,-133,-127,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG609_WALL78_RRAF91','WALLIS-UVEA SHOM 1978 (MOP1978) vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','WALL78','IGNF','RRAF91','IGNF','157',NULL,253,-133,-127,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG609_WALL78_4978','WALLIS-UVEA SHOM 1978 (MOP1978) vers WGS 84',NULL,'LOCALE','EPSG','1031','Geocentric translations (geocentric domain)','IGNF','WALL78','EPSG','4978','IGNF','157',NULL,253,-133,-127,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG609_WALL78GEO_TO_WGS84GEODD','WALLIS-UVEA SHOM 1978 (MOP1978) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WALL78GEO','IGNF','WGS84GEODD','IGNF','157',NULL,253,-133,-127,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG609_WALL78GEO_TO_WGS84GDD','WALLIS-UVEA SHOM 1978 (MOP1978) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WALL78GEO','IGNF','WGS84GDD','IGNF','157',NULL,253,-133,-127,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG609_WALL78GEO_TO_WGS84G','WALLIS-UVEA SHOM 1978 (MOP1978) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WALL78GEO','IGNF','WGS84G','IGNF','157',NULL,253,-133,-127,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG609_WALL78GEO_TO_4326','WALLIS-UVEA SHOM 1978 (MOP1978) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WALL78GEO','EPSG','4326','IGNF','157',NULL,253,-133,-127,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG609_WALL78GEO_TO_WGS84GEO','WALLIS-UVEA SHOM 1978 (MOP1978) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WALL78GEO','IGNF','WGS84GEO','IGNF','157',NULL,253,-133,-127,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG609_WALL78GEO_TO_WGS84RRAFGEO','WALLIS-UVEA SHOM 1978 (MOP1978) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WALL78GEO','IGNF','WGS84RRAFGEO','IGNF','157',NULL,253,-133,-127,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG609_WALL78G_TO_WGS84GEODD','WALLIS-UVEA SHOM 1978 (MOP1978) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WALL78G','IGNF','WGS84GEODD','IGNF','157',NULL,253,-133,-127,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG609_WALL78G_TO_WGS84GDD','WALLIS-UVEA SHOM 1978 (MOP1978) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WALL78G','IGNF','WGS84GDD','IGNF','157',NULL,253,-133,-127,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG609_WALL78G_TO_WGS84G','WALLIS-UVEA SHOM 1978 (MOP1978) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WALL78G','IGNF','WGS84G','IGNF','157',NULL,253,-133,-127,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG609_WALL78G_TO_4326','WALLIS-UVEA SHOM 1978 (MOP1978) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WALL78G','EPSG','4326','IGNF','157',NULL,253,-133,-127,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG609_WALL78G_TO_WGS84GEO','WALLIS-UVEA SHOM 1978 (MOP1978) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WALL78G','IGNF','WGS84GEO','IGNF','157',NULL,253,-133,-127,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG609_WALL78G_TO_WGS84RRAFGEO','WALLIS-UVEA SHOM 1978 (MOP1978) vers WGS 84',NULL,'LOCALE','EPSG','9603','Geocentric translations (geog2D domain)','IGNF','WALL78G','IGNF','WGS84RRAFGEO','IGNF','157',NULL,253,-133,-127,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL, NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','RRAF','IGNF','RGAF09','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_WGS84GUAD_RGAF09','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','WGS84GUAD','IGNF','RGAF09','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_RRAFGDD_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGDD','IGNF','RGAF09GEODD','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_WGS84MARTGDD_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTGDD','IGNF','RGAF09GEODD','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_RRAFGDD_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGDD','IGNF','RGAF09GDD','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_WGS84MARTGDD_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTGDD','IGNF','RGAF09GDD','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_RRAFGDD_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGDD','IGNF','RGAF09GEO','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_WGS84MARTGDD_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTGDD','IGNF','RGAF09GEO','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_RRAFGDD_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGDD','IGNF','RGAF09G','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_WGS84MARTGDD_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTGDD','IGNF','RGAF09G','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_RRAFGEODD_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEODD','IGNF','RGAF09GEODD','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_W84MARTGEODD_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','W84MARTGEODD','IGNF','RGAF09GEODD','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_RRAFGEODD_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEODD','IGNF','RGAF09GDD','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_W84MARTGEODD_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','W84MARTGEODD','IGNF','RGAF09GDD','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_RRAFGEODD_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEODD','IGNF','RGAF09GEO','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_W84MARTGEODD_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','W84MARTGEODD','IGNF','RGAF09GEO','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_RRAFGEODD_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEODD','IGNF','RGAF09G','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_W84MARTGEODD_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','W84MARTGEODD','IGNF','RGAF09G','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_RRAFGEO_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEO','IGNF','RGAF09GEODD','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_WGS84GUADGEO_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84GUADGEO','IGNF','RGAF09GEODD','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_RRAFGEO_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEO','IGNF','RGAF09GDD','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_WGS84GUADGEO_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84GUADGEO','IGNF','RGAF09GDD','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_RRAFGEO_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEO','IGNF','RGAF09GEO','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_WGS84GUADGEO_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84GUADGEO','IGNF','RGAF09GEO','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_RRAFGEO_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEO','IGNF','RGAF09G','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_WGS84GUADGEO_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84GUADGEO','IGNF','RGAF09G','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_RRAFG_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFG','IGNF','RGAF09GEODD','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_WGS84MARTG_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTG','IGNF','RGAF09GEODD','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_RRAFG_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFG','IGNF','RGAF09GDD','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_WGS84MARTG_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTG','IGNF','RGAF09GDD','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_RRAFG_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFG','IGNF','RGAF09GEO','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_WGS84MARTG_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTG','IGNF','RGAF09GEO','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_RRAFG_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFG','IGNF','RGAF09G','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG818_WGS84MARTG_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTG','IGNF','RGAF09G','IGNF','39',NULL,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.02390,'EPSG','9104',0.2829,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','158','SAINT-MARTIN ET SAINT-BARTHELEMY','SAINT-MARTIN ET SAINT-BARTHELEMY',17.82,18.18,-63.18,-62.25,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','RRAF','IGNF','RGAF09','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_WGS84GUAD_RGAF09','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','WGS84GUAD','IGNF','RGAF09','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_RRAFGDD_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGDD','IGNF','RGAF09GEODD','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_WGS84MARTGDD_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTGDD','IGNF','RGAF09GEODD','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_RRAFGDD_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGDD','IGNF','RGAF09GDD','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_WGS84MARTGDD_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTGDD','IGNF','RGAF09GDD','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_RRAFGDD_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGDD','IGNF','RGAF09GEO','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_WGS84MARTGDD_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTGDD','IGNF','RGAF09GEO','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_RRAFGDD_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGDD','IGNF','RGAF09G','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_WGS84MARTGDD_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTGDD','IGNF','RGAF09G','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_RRAFGEODD_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEODD','IGNF','RGAF09GEODD','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_W84MARTGEODD_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','W84MARTGEODD','IGNF','RGAF09GEODD','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_RRAFGEODD_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEODD','IGNF','RGAF09GDD','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_W84MARTGEODD_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','W84MARTGEODD','IGNF','RGAF09GDD','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_RRAFGEODD_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEODD','IGNF','RGAF09GEO','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_W84MARTGEODD_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','W84MARTGEODD','IGNF','RGAF09GEO','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_RRAFGEODD_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEODD','IGNF','RGAF09G','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_W84MARTGEODD_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','W84MARTGEODD','IGNF','RGAF09G','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_RRAFGEO_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEO','IGNF','RGAF09GEODD','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_WGS84GUADGEO_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84GUADGEO','IGNF','RGAF09GEODD','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_RRAFGEO_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEO','IGNF','RGAF09GDD','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_WGS84GUADGEO_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84GUADGEO','IGNF','RGAF09GDD','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_RRAFGEO_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEO','IGNF','RGAF09GEO','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_WGS84GUADGEO_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84GUADGEO','IGNF','RGAF09GEO','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_RRAFGEO_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEO','IGNF','RGAF09G','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_WGS84GUADGEO_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84GUADGEO','IGNF','RGAF09G','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_RRAFG_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFG','IGNF','RGAF09GEODD','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_WGS84MARTG_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTG','IGNF','RGAF09GEODD','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_RRAFG_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFG','IGNF','RGAF09GDD','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_WGS84MARTG_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTG','IGNF','RGAF09GDD','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_RRAFG_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFG','IGNF','RGAF09GEO','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_WGS84MARTG_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTG','IGNF','RGAF09GEO','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_RRAFG_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFG','IGNF','RGAF09G','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG819_WGS84MARTG_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTG','IGNF','RGAF09G','IGNF','158',NULL,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "area" VALUES('IGNF','159','GUADELOUPE','GUADELOUPE',15.82,16.6,-61.83,-60.77,0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','RRAF','IGNF','RGAF09','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_WGS84GUAD_RGAF09','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','1033','Position Vector transformation (geocentric domain)','IGNF','WGS84GUAD','IGNF','RGAF09','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_RRAFGDD_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGDD','IGNF','RGAF09GEODD','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_WGS84MARTGDD_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTGDD','IGNF','RGAF09GEODD','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_RRAFGDD_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGDD','IGNF','RGAF09GDD','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_WGS84MARTGDD_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTGDD','IGNF','RGAF09GDD','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_RRAFGDD_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGDD','IGNF','RGAF09GEO','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_WGS84MARTGDD_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTGDD','IGNF','RGAF09GEO','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_RRAFGDD_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGDD','IGNF','RGAF09G','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_WGS84MARTGDD_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTGDD','IGNF','RGAF09G','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_RRAFGEODD_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEODD','IGNF','RGAF09GEODD','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_W84MARTGEODD_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','W84MARTGEODD','IGNF','RGAF09GEODD','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_RRAFGEODD_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEODD','IGNF','RGAF09GDD','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_W84MARTGEODD_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','W84MARTGEODD','IGNF','RGAF09GDD','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_RRAFGEODD_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEODD','IGNF','RGAF09GEO','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_W84MARTGEODD_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','W84MARTGEODD','IGNF','RGAF09GEO','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_RRAFGEODD_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEODD','IGNF','RGAF09G','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_W84MARTGEODD_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','W84MARTGEODD','IGNF','RGAF09G','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_RRAFGEO_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEO','IGNF','RGAF09GEODD','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_WGS84GUADGEO_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84GUADGEO','IGNF','RGAF09GEODD','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_RRAFGEO_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEO','IGNF','RGAF09GDD','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_WGS84GUADGEO_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84GUADGEO','IGNF','RGAF09GDD','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_RRAFGEO_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEO','IGNF','RGAF09GEO','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_WGS84GUADGEO_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84GUADGEO','IGNF','RGAF09GEO','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_RRAFGEO_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFGEO','IGNF','RGAF09G','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_WGS84GUADGEO_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84GUADGEO','IGNF','RGAF09G','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_RRAFG_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFG','IGNF','RGAF09GEODD','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_WGS84MARTG_TO_RGAF09GEODD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTG','IGNF','RGAF09GEODD','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_RRAFG_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFG','IGNF','RGAF09GDD','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_WGS84MARTG_TO_RGAF09GDD','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTG','IGNF','RGAF09GDD','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_RRAFG_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFG','IGNF','RGAF09GEO','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_WGS84MARTG_TO_RGAF09GEO','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTG','IGNF','RGAF09GEO','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_RRAFG_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','RRAFG','IGNF','RGAF09G','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "helmert_transformation" VALUES('IGNF','TSG820_WGS84MARTG_TO_RGAF09G','WGS 84 (RRAF) vers RGAF09 (RESEAU GEODESIQUE DES ANTILLES FRANCAISES 2009)',NULL,'LOCALE','EPSG','9606','Position Vector transformation (geog2D domain)','IGNF','WGS84MARTG','IGNF','RGAF09G','IGNF','159',NULL,1.2239,2.4156,-1.7598,'EPSG','9001',0.03800,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG', '9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'1.0.0',0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307248','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC034338','UTM SUD FUSEAU 43',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',75.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC9813548','EQUIRECTANGULAIRE AMSTERDAM SAINT-PAUL',NULL,NULL,'EPSG','1262','EPSG','1028','Equidistant Cylindrical','EPSG','8823','Latitude of 1st standard parallel',-38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0306336','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0306251','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC9814568','EQUIRECTANGULAIRE ANTILLES FRANCAISES',NULL,NULL,'EPSG','1262','EPSG','1028','Equidistant Cylindrical','EPSG','8823','Latitude of 1st standard parallel',15.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0306554','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC060623','BONNE FRANCE - ETAT MAJOR',NULL,NULL,'EPSG','1262','EPSG','9827','Bonne','EPSG','8801','Latitude of natural origin',50.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9105','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0338366','UTM SUD FUSEAU 38',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0212179','UTM NORD FUSEAU 12',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-111.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0338118','UTM SUD FUSEAU 38',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC033935','UTM SUD FUSEAU 39',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',51.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC9801422','EQUIRECTANGULAIRE CROZET',NULL,NULL,'EPSG','1262','EPSG','1028','Equidistant Cylindrical','EPSG','8823','Latitude of 1st standard parallel',-46.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0221400','UTM NORD FUSEAU 21',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-57.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0222401','UTM NORD FUSEAU 22',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-51.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0221137','UTM NORD FUSEAU 21',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-57.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0222138','UTM NORD FUSEAU 22',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-51.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC023086','UTM NORD FUSEAU 30',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC023288','UTM NORD FUSEAU 32',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC023187','UTM NORD FUSEAU 31',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0359176','UTM SUD FUSEAU 59',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',171.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC991495','ETRS89 LAMBERT AZIMUTHAL EQUAL AREA (LAEA)',NULL,NULL,'EPSG','1262','EPSG','9820','Lambert Azimuthal Equal Area','EPSG','8801','Latitude of natural origin',52.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',10.0,'EPSG','9102','EPSG','8806','False easting',4321000.0,'EPSG','9001','EPSG','8807','False northing',3210000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC813596','ETRS89 LAMBERT CONFORMAL CONIC',NULL,NULL,'EPSG','1262','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',52.0,'EPSG','9102','EPSG','8822','Longitude of false origin',10.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',35.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',65.0,'EPSG','9102','EPSG','8826','Easting at false origin',4000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC022697','UTM NORD FUSEAU 26',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC022798','UTM NORD FUSEAU 27',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC022899','UTM NORD FUSEAU 28',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0229100','UTM NORD FUSEAU 29',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0230101','UTM NORD FUSEAU 30',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0231102','UTM NORD FUSEAU 31',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0232103','UTM NORD FUSEAU 32',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0233104','UTM NORD FUSEAU 33',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0234105','UTM NORD FUSEAU 34',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0235106','UTM NORD FUSEAU 35',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0236107','UTM NORD FUSEAU 36',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0237108','UTM NORD FUSEAU 37',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',39.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0238109','UTM NORD FUSEAU 38',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0701121','MERCATOR DIRECTE',NULL,NULL,'EPSG','1262','EPSG','9804','Mercator (variant A)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',20000000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0337572','UTM SUD FUSEAU 37',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',39.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0306261','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307269','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307272','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307275','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307278','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307264','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC9802423','EQUIRECTANGULAIRE FRANCE',NULL,NULL,'EPSG','1262','EPSG','1028','Equidistant Cylindrical','EPSG','8823','Latitude of 1st standard parallel',46.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0701124','MERCATOR DIRECTE',NULL,NULL,'EPSG','1262','EPSG','9804','Mercator (variant A)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',20000000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0338125','UTM SUD FUSEAU 38',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0358566','UTM SUD FUSEAU 58',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0220150','UTM NORD FUSEAU 20',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-63.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0220147','UTM NORD FUSEAU 20',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-63.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC9805425','EQUIRECTANGULAIRE GUYANE',NULL,NULL,'EPSG','1262','EPSG','1028','Equidistant Cylindrical','EPSG','8823','Latitude of 1st standard parallel',4.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307283','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307286','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307289','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307292','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307235','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307238','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307241','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC030567','UTM SUD FUSEAU 5',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0149208','LAMBERT NOUVELLE-CALEDONIE',NULL,NULL,'EPSG','1262','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-21.5,'EPSG','9102','EPSG','8822','Longitude of false origin',166.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-20.6666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-22.3333333333,'EPSG','9102','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0358209','UTM SUD FUSEAU 58',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0338564','UTM SUD FUSEAU 38',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC030664','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC034219','UTM SUD FUSEAU 42',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',69.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC9812426','EQUIRECTANGULAIRE KERGUELEN',NULL,NULL,'EPSG','1262','EPSG','1028','Equidistant Cylindrical','EPSG','8823','Latitude of 1st standard parallel',-49.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC013591','LAMBERT NORD DE GUERRE',NULL,NULL,'EPSG','1262','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',55.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',6.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.99950908,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0358182','UTM SUD FUSEAU 58',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307295','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0308230','UTM SUD FUSEAU 8',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-135.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0358186','UTM SUD FUSEAU 58',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0220144','UTM NORD FUSEAU 20',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-63.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC030582','UTM SUD FUSEAU 5',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC9807428','EQUIRECTANGULAIRE MAYOTTE',NULL,NULL,'EPSG','1262','EPSG','1028','Equidistant Cylindrical','EPSG','8823','Latitude of 1st standard parallel',-12.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC030858','UTM SUD FUSEAU 8',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-135.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC030679','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307307','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307303','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307298','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC9203409','LAMBERT NOUMEA 2',NULL,NULL,'EPSG','1262','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-22.2697222222,'EPSG','9102','EPSG','8822','Longitude of false origin',166.4425,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-22.2447222222,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-22.2947222222,'EPSG','9102','EPSG','8826','Easting at false origin',8.313,'EPSG','9001','EPSG','8827','Northing at false origin',-2.354,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC9809429','EQUIRECTANGULAIRE N. CALEDONIE',NULL,NULL,'EPSG','1262','EPSG','1028','Equidistant Cylindrical','EPSG','8823','Latitude of 1st standard parallel',-22.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0406569','GAUSS-KRUGER (G-K) LUXEMBOURG',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.8333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',6.16666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',80000.0,'EPSG','9001','EPSG','8807','False northing',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC011814','LAMBERT GRAND CHAMP',NULL,NULL,'EPSG','1262','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9102','EPSG','8822','Longitude of false origin',0.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',49.0,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',600000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC01015','LAMBERT I NORD',NULL,NULL,'EPSG','1262','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',55.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.99987734,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC01316','LAMBERT I CARTO',NULL,NULL,'EPSG','1262','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',55.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.99987734,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',1200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC01027','LAMBERT II CENTRE',NULL,NULL,'EPSG','1262','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',52.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.99987742,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC01328','LAMBERT II CARTO',NULL,NULL,'EPSG','1262','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',52.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.99987742,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',2200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC012013','LAMBERT II ETENDU',NULL,NULL,'EPSG','1262','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',52.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.99987742,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',2200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC01039','LAMBERT III SUD',NULL,NULL,'EPSG','1262','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.9998775,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC013310','LAMBERT III CARTO',NULL,NULL,'EPSG','1262','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.9998775,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',3200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC010411','LAMBERT IV CORSE',NULL,NULL,'EPSG','1262','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.85,'EPSG','9105','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.99994471,'EPSG','9201','EPSG','8806','False easting',234.358,'EPSG','9001','EPSG','8807','False northing',185861.369,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC013412','LAMBERT IV CARTO',NULL,NULL,'EPSG','1262','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.85,'EPSG','9105','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.99994471,'EPSG','9201','EPSG','8806','False easting',234.358,'EPSG','9001','EPSG','8807','False northing',4185861.369,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307212','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0358195','UTM SUD FUSEAU 58',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0508542','GAUSS LABORDE REUNION',NULL,NULL,'EPSG','1262','PROJ','gstm','Gauss Schreiber Transverse Mercator','EPSG','8801','Latitude of natural origin',-21.1166666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',55.5333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',160000.0,'EPSG','9001','EPSG','8807','False northing',50000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0508546','GAUSS LABORDE REUNION',NULL,NULL,'EPSG','1262','PROJ','gstm','Gauss Schreiber Transverse Mercator','EPSG','8801','Latitude of natural origin',-21.1166666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',55.5333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',160000.0,'EPSG','9001','EPSG','8807','False northing',50000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC9811430','EQUIRECTANGULAIRE POLYNESIE',NULL,NULL,'EPSG','1262','EPSG','1028','Equidistant Cylindrical','EPSG','8823','Latitude of 1st standard parallel',-15.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0306215','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0306218','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0306311','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0306314','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0306317','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0301588','UTM SUD FUSEAU 1',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0508114','GAUSS LABORDE REUNION',NULL,NULL,'EPSG','1262','PROJ','gstm','Gauss Schreiber Transverse Mercator','EPSG','8801','Latitude of natural origin',-21.1166666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',55.5333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',160000.0,'EPSG','9001','EPSG','8807','False northing',50000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC9806431','EQUIRECTANGULAIRE LA REUNION',NULL,NULL,'EPSG','1262','EPSG','1028','Equidistant Cylindrical','EPSG','8823','Latitude of 1st standard parallel',-21.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0220527','UTM NORD FUSEAU 20',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-63.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC8142383','CC42 (CONIQUE CONFORME ZONE 1)',NULL,NULL,'EPSG','1262','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.0,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',41.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',42.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC8143384','CC43 (CONIQUE CONFORME ZONE 2)',NULL,NULL,'EPSG','1262','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.0,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC8144385','CC44 (CONIQUE CONFORME ZONE 3)',NULL,NULL,'EPSG','1262','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.0,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC8145386','CC45 (CONIQUE CONFORME ZONE 4)',NULL,NULL,'EPSG','1262','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.0,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC8146387','CC46 (CONIQUE CONFORME ZONE 5)',NULL,NULL,'EPSG','1262','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.0,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC8147388','CC47 (CONIQUE CONFORME ZONE 6)',NULL,NULL,'EPSG','1262','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',6200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC8148389','CC48 (CONIQUE CONFORME ZONE 7)',NULL,NULL,'EPSG','1262','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',48.0,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',7200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC8149390','CC49 (CONIQUE CONFORME ZONE 8)',NULL,NULL,'EPSG','1262','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',49.0,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',48.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',49.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',8200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC8150391','CC50 (CONIQUE CONFORME ZONE 9)',NULL,NULL,'EPSG','1262','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',50.0,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',49.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',50.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',9200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC014052','LAMBERT-93',NULL,NULL,'EPSG','1262','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.5,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',49.0,'EPSG','9102','EPSG','8826','Easting at false origin',700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',6600000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0231393','UTM NORD FUSEAU 31',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0232394','UTM NORD FUSEAU 32',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0230392','UTM NORD FUSEAU 30',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0221157','UTM NORD FUSEAU 21',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-57.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0222158','UTM NORD FUSEAU 22',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-51.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0338372','UTM SUD FUSEAU 38',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0149202','LAMBERT NOUVELLE-CALEDONIE',NULL,NULL,'EPSG','1262','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-21.5,'EPSG','9102','EPSG','8822','Longitude of false origin',166.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-20.6666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-22.3333333333,'EPSG','9102','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0357203','UTM SUD FUSEAU 57',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',159.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0358204','UTM SUD FUSEAU 58',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0359205','UTM SUD FUSEAU 59',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',171.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC030574','UTM SUD FUSEAU 5',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC030675','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC030776','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0308576','UTM SUD FUSEAU 8',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-135.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0340361','UTM SUD FUSEAU 40',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',57.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0221378','UTM NORD FUSEAU 21',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-57.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0337418','UTM SUD FUSEAU 37',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',39.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0339419','UTM SUD FUSEAU 39',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',51.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0342420','UTM SUD FUSEAU 42',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',69.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0343421','UTM SUD FUSEAU 43',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',75.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0353563','UTM SUD FUSEAU 53',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',135.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0220170','UTM NORD FUSEAU 20',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-63.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC030570','UTM SUD FUSEAU 5',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC034341','UTM SUD FUSEAU 43',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',75.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC9808432','EQUIRECTANGULAIRE SPM',NULL,NULL,'EPSG','1262','EPSG','1028','Equidistant Cylindrical','EPSG','8823','Latitude of 1st standard parallel',47.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0358407','UTM SUD FUSEAU 58',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0358405','UTM SUD FUSEAU 58',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',165.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0221141','UTM NORD FUSEAU 21',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-57.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0305187','UTM SUD FUSEAU 5',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC030655','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0306172','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0306320','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0359190','UTM SUD FUSEAU 59',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',171.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC090126','STEREOGRAPHIQUE POLAIRE SUD TERRE-ADELIE (TANGENTE)',NULL,NULL,'EPSG','1262','EPSG','9810','Polar Stereographic (variant A)','EPSG','8801','Latitude of natural origin',-90.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',140.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.960272946,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',-2299363.482,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC030661','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0306323','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0306585','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0306326','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0701131','MERCATOR DIRECTE',NULL,NULL,'EPSG','1262','EPSG','9804','Mercator (variant A)','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',20000000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0306330','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307331','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0306227','UTM SUD FUSEAU 6',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0307308','UTM SUD FUSEAU 7',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC9810433','EQUIRECTANGULAIRE WALLISFUTUNA',NULL,NULL,'EPSG','1262','EPSG','1028','Equidistant Cylindrical','EPSG','8823','Latitude of 1st standard parallel',-14.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC030144','UTM SUD FUSEAU 1',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC030147','UTM SUD FUSEAU 1',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0230345','UTM NORD FUSEAU 30',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0231346','UTM NORD FUSEAU 31',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0232348','UTM NORD FUSEAU 32',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0301545','UTM SUD FUSEAU 1',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC7001567','MILLER GEOPORTAIL',NULL,NULL,'EPSG','1262','PROJ','mill','PROJ mill',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0230353','UTM NORD FUSEAU 30',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0231354','UTM NORD FUSEAU 31',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',3.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0232355','UTM NORD FUSEAU 32',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0301550','UTM SUD FUSEAU 1',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-177.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0339578','UTM SUD FUSEAU 39',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',51.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0342579','UTM SUD FUSEAU 42',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',69.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC0343580','UTM SUD FUSEAU 43',NULL,NULL,'EPSG','1886','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',75.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',10000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "conversion" VALUES('IGNF','PRC9601581','PSEUDO MERCATOR (POPULAR VISUALISATION)',NULL,NULL,'EPSG','1262','EPSG','1024','Popular Visualisation Pseudo Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "area" VALUES('IGNF','160','AMANU (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 7','AMANU (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 7',-18,-17.58,-141,-140.58,0);
INSERT INTO "projected_crs" VALUES('IGNF','AMANU63UTM7S','Amanu (MHPF 1963) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','AMANU63G','IGNF','PRC0307248','IGNF','160',NULL,0);
INSERT INTO "area" VALUES('IGNF','161','ILE AMSTERDAM - UTM SUD FUSEAU 43','ILE AMSTERDAM - UTM SUD FUSEAU 43',-37.92,-37.75,77.45,77.63,0);
INSERT INTO "projected_crs" VALUES('IGNF','AMST63UTM43S','Amsterdam 1963 UTM Sud fuseau 43',NULL,NULL,'EPSG','4499','IGNF','AMST63G','IGNF','PRC034338','IGNF','161',NULL,0);
INSERT INTO "area" VALUES('IGNF','162','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - ILES AMSTERDAM ET SAINT-PAUL','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - ILES AMSTERDAM ET SAINT-PAUL',-38.77,-37.75,77.45,77.63,0);
INSERT INTO "projected_crs" VALUES('IGNF','WGS84EQGPASP','Amsterdam Saint-Paul projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC9813548','IGNF','162',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','GEOPORTALASP','Amsterdam Saint-Paul projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC9813548','IGNF','162',NULL,0);
INSERT INTO "area" VALUES('IGNF','163','ANAA (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 6','ANAA (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 6',-17.5,-17.32,-145.6,-145.37,0);
INSERT INTO "projected_crs" VALUES('IGNF','ANAA92UTM6S','Anaa (MOP92) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','ANAA92G','IGNF','PRC0306336','IGNF','163',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','ANAA47UTM6S','Anaa (SHM 1947) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','ANAA47G','IGNF','PRC0306251','IGNF','163',NULL,0);
INSERT INTO "area" VALUES('IGNF','164','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - ANTILLES FRANCAISES','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - ANTILLES FRANCAISES',14.25,18.2,-63.2,-60.73,0);
INSERT INTO "projected_crs" VALUES('IGNF','WGS84GPAF','ANTILLES FRANCAISES PROJECTION GEOPORTAIL',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC9814568','IGNF','164',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','GEOPORTALANF','ANTILLES FRANCAISES PROJECTION GEOPORTAIL',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC9814568','IGNF','164',NULL,0);
INSERT INTO "area" VALUES('IGNF','165','APATAKI (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 6','APATAKI (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 6',-15.63,-15.29,-146.46,-146.18,0);
INSERT INTO "projected_crs" VALUES('IGNF','APAT80UTM6S','Apataki (Cadastre 1980) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','APAT80G','IGNF','PRC0306554','IGNF','165',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','ATIGBONNE','ATIG Bonne France Etat Major',NULL,NULL,'EPSG','4499','IGNF','ATIGG','IGNF','PRC060623','IGNF','4',NULL,0);
INSERT INTO "area" VALUES('IGNF','166','ILE DE MAYOTTE - UTM SUD FUSEAU 38','ILE DE MAYOTTE - UTM SUD FUSEAU 38',-13.05,-12.5,44.95,45.4,0);
INSERT INTO "projected_crs" VALUES('IGNF','CAD97UTM38S','Cadastre 1997 UTM Sud fuseau 38',NULL,NULL,'EPSG','4499','IGNF','CAD97G','IGNF','PRC0338366','IGNF','166',NULL,0);
INSERT INTO "area" VALUES('IGNF','167','ILE CLIPPERTON - UTM NORD FUSEAU 12','ILE CLIPPERTON - UTM NORD FUSEAU 12',10.17,10.5,-109.5,-109,0);
INSERT INTO "projected_crs" VALUES('IGNF','CLIP67UTM12','Clipperton 1967 UTM Nord fuseau 12',NULL,NULL,'EPSG','4499','IGNF','CLIP67G','IGNF','PRC0212179','IGNF','167',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','CLIP57UTM12','Clipperton 1967 UTM Nord fuseau 12',NULL,NULL,'EPSG','4499','IGNF','CLIP67G','IGNF','PRC0212179','IGNF','167',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','MAYO50UTM38S','Combani UTM Sud fuseau 38',NULL,NULL,'EPSG','4499','IGNF','MAYO50G','IGNF','PRC0338118','IGNF','166',NULL,0);
INSERT INTO "area" VALUES('IGNF','168','ILES CROZET (ARCHIPEL) - UTM SUD FUSEAU 39','ILES CROZET (ARCHIPEL) - UTM SUD FUSEAU 39',-46.75,-45.75,50,52.5,0);
INSERT INTO "projected_crs" VALUES('IGNF','CROZ63UTM39S','CROZET POSSESSION 1963 UTM SUD FUSEAU 39',NULL,NULL,'EPSG','4499','IGNF','CROZ63G','IGNF','PRC033935','IGNF','168',NULL,0);
INSERT INTO "area" VALUES('IGNF','169','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - ILES CROZET (ARCHIPEL)','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - ILES CROZET (ARCHIPEL)',-46.75,-45.75,50,52.5,0);
INSERT INTO "projected_crs" VALUES('IGNF','WGS84EQGPCRZ','Crozet projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC9801422','IGNF','169',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','GEOPORTALCRZ','Crozet projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC9801422','IGNF','169',NULL,0);
INSERT INTO "area" VALUES('IGNF','170','GUYANE FRANCAISE - UTM NORD FUSEAU 21','GUYANE FRANCAISE - UTM NORD FUSEAU 21',2.05,5.95,-54.95,-54,0);
INSERT INTO "projected_crs" VALUES('IGNF','C67IG95UTM21','CSG67(IGN 1995) UTM Nord fuseau 21',NULL,NULL,'EPSG','4499','IGNF','C67IG95G','IGNF','PRC0221400','IGNF','170',NULL,0);
INSERT INTO "area" VALUES('IGNF','171','GUYANE FRANCAISE - UTM NORD FUSEAU 22','GUYANE FRANCAISE - UTM NORD FUSEAU 22',2.05,5.95,-54,-51.05,0);
INSERT INTO "projected_crs" VALUES('IGNF','C67IG95UTM22','CSG67 (IGN 1995) UTM Nord fuseau 22',NULL,NULL,'EPSG','4499','IGNF','C67IG95G','IGNF','PRC0222401','IGNF','171',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','CSG67UTM21','CSG67 UTM Nord fuseau 21',NULL,NULL,'EPSG','4499','IGNF','CSG67G','IGNF','PRC0221137','IGNF','170',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','CSG67UTM22','CSG67 UTM Nord fuseau 22',NULL,NULL,'EPSG','4499','IGNF','CSG67G','IGNF','PRC0222138','IGNF','171',NULL,0);
INSERT INTO "area" VALUES('IGNF','172','EUROPE DE L''OUEST ED50 - UTM NORD FUSEAU 30','EUROPE DE L''OUEST ED50 - UTM NORD FUSEAU 30',34,72,-6,0,0);
INSERT INTO "projected_crs" VALUES('IGNF','ED50UTM30','ED50 UTM fuseau 30',NULL,NULL,'EPSG','4499','IGNF','ED50G','IGNF','PRC023086','IGNF','172',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM30','ED50 UTM fuseau 30',NULL,NULL,'EPSG','4499','IGNF','ED50G','IGNF','PRC023086','IGNF','172',NULL,0);
INSERT INTO "area" VALUES('IGNF','173','EUROPE DE L''OUEST ED50 - UTM NORD FUSEAU 32','EUROPE DE L''OUEST ED50 - UTM NORD FUSEAU 32',34,72,6,12,0);
INSERT INTO "projected_crs" VALUES('IGNF','ED50UTM32','ED50 UTM fuseau 32',NULL,NULL,'EPSG','4499','IGNF','ED50G','IGNF','PRC023288','IGNF','173',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM32','ED50 UTM fuseau 32',NULL,NULL,'EPSG','4499','IGNF','ED50G','IGNF','PRC023288','IGNF','173',NULL,0);
INSERT INTO "area" VALUES('IGNF','174','EUROPE DE L''OUEST ED50 - UTM NORD FUSEAU 31','EUROPE DE L''OUEST ED50 - UTM NORD FUSEAU 31',34,72,0,6,0);
INSERT INTO "projected_crs" VALUES('IGNF','ED50UTM31','ED50 UTM NORD FUSEAU 31',NULL,NULL,'EPSG','4499','IGNF','ED50G','IGNF','PRC023187','IGNF','174',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM31','ED50 UTM NORD FUSEAU 31',NULL,NULL,'EPSG','4499','IGNF','ED50G','IGNF','PRC023187','IGNF','174',NULL,0);
INSERT INTO "area" VALUES('IGNF','175','EFATE (ARCHIPEL DU VANUATU) - UTM SUD FUSEAU 59','EFATE (ARCHIPEL DU VANUATU) - UTM SUD FUSEAU 59',-18,-17.25,168,168.67,0);
INSERT INTO "projected_crs" VALUES('IGNF','EFAT57UTM59S','Efate UTM Sud fuseau 59',NULL,NULL,'EPSG','4499','IGNF','EFATE57G','IGNF','PRC0359176','IGNF','175',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','EFATE57UT59S','Efate UTM Sud fuseau 59',NULL,NULL,'EPSG','4499','IGNF','EFATE57G','IGNF','PRC0359176','IGNF','175',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','ETRS89LAEA','ETRS89 Lambert Azimutal Equal Area',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC991495','IGNF','14',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','ETRS89LCC','ETRS89 Lambert Conformal Conic',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC813596','IGNF','14',NULL,0);
INSERT INTO "area" VALUES('IGNF','176','EUROPE (ETRS89) - UTM NORD FUSEAU 26','EUROPE (ETRS89) - UTM NORD FUSEAU 26',27.5,71.5,-25,-24,0);
INSERT INTO "projected_crs" VALUES('IGNF','ETRS89UTM26','ETRS89 UTM Nord fuseau 26',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC022697','IGNF','176',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM26ETRS89','ETRS89 UTM Nord fuseau 26',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC022697','IGNF','176',NULL,0);
INSERT INTO "area" VALUES('IGNF','177','EUROPE (ETRS89) - UTM NORD FUSEAU 27','EUROPE (ETRS89) - UTM NORD FUSEAU 27',27.5,71.5,-24,-18,0);
INSERT INTO "projected_crs" VALUES('IGNF','ETRS89UTM27','ETRS89 UTM Nord fuseau 27',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC022798','IGNF','177',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM27ETRS89','ETRS89 UTM Nord fuseau 27',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC022798','IGNF','177',NULL,0);
INSERT INTO "area" VALUES('IGNF','178','EUROPE (ETRS89) - UTM NORD FUSEAU 28','EUROPE (ETRS89) - UTM NORD FUSEAU 28',27.5,71.5,-18,-12,0);
INSERT INTO "projected_crs" VALUES('IGNF','ETRS89UTM28','ETRS89 UTM Nord fuseau 28',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC022899','IGNF','178',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM28ETRS89','ETRS89 UTM Nord fuseau 28',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC022899','IGNF','178',NULL,0);
INSERT INTO "area" VALUES('IGNF','179','EUROPE (ETRS89) - UTM NORD FUSEAU 29','EUROPE (ETRS89) - UTM NORD FUSEAU 29',27.5,71.5,-12,-6,0);
INSERT INTO "projected_crs" VALUES('IGNF','ETRS89UTM29','ETRS89 UTM Nord fuseau 29',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0229100','IGNF','179',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM29ETRS89','ETRS89 UTM Nord fuseau 29',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0229100','IGNF','179',NULL,0);
INSERT INTO "area" VALUES('IGNF','180','EUROPE (ETRS89) - UTM NORD FUSEAU 30','EUROPE (ETRS89) - UTM NORD FUSEAU 30',27.5,71.5,-6,0,0);
INSERT INTO "projected_crs" VALUES('IGNF','ETRS89UTM30','ETRS89 UTM Nord fuseau 30',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0230101','IGNF','180',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM30ETRS89','ETRS89 UTM Nord fuseau 30',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0230101','IGNF','180',NULL,0);
INSERT INTO "area" VALUES('IGNF','181','EUROPE (ETRS89) - UTM NORD FUSEAU 31','EUROPE (ETRS89) - UTM NORD FUSEAU 31',27.5,71.5,0,6,0);
INSERT INTO "projected_crs" VALUES('IGNF','ETRS89UTM31','ETRS89 UTM Nord fuseau 31',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0231102','IGNF','181',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM31ETRS89','ETRS89 UTM Nord fuseau 31',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0231102','IGNF','181',NULL,0);
INSERT INTO "area" VALUES('IGNF','182','EUROPE (ETRS89) - UTM NORD FUSEAU 32','EUROPE (ETRS89) - UTM NORD FUSEAU 32',27.5,71.5,6,12,0);
INSERT INTO "projected_crs" VALUES('IGNF','ETRS89UTM32','ETRS89 UTM Nord fuseau 32',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0232103','IGNF','182',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM32ETRS89','ETRS89 UTM Nord fuseau 32',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0232103','IGNF','182',NULL,0);
INSERT INTO "area" VALUES('IGNF','183','EUROPE (ETRS89) - UTM NORD FUSEAU 33','EUROPE (ETRS89) - UTM NORD FUSEAU 33',27.5,71.5,12,18,0);
INSERT INTO "projected_crs" VALUES('IGNF','ETRS89UTM33','ETRS89 UTM Nord fuseau 33',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0233104','IGNF','183',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM33ETRS89','ETRS89 UTM Nord fuseau 33',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0233104','IGNF','183',NULL,0);
INSERT INTO "area" VALUES('IGNF','184','EUROPE (ETRS89) - UTM NORD FUSEAU 34','EUROPE (ETRS89) - UTM NORD FUSEAU 34',27.5,71.5,18,24,0);
INSERT INTO "projected_crs" VALUES('IGNF','ETRS89UTM34','ETRS89 UTM Nord fuseau 34',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0234105','IGNF','184',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM34ETRS89','ETRS89 UTM Nord fuseau 34',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0234105','IGNF','184',NULL,0);
INSERT INTO "area" VALUES('IGNF','185','EUROPE (ETRS89) - UTM NORD FUSEAU 35','EUROPE (ETRS89) - UTM NORD FUSEAU 35',27.5,71.5,24,30,0);
INSERT INTO "projected_crs" VALUES('IGNF','ETRS89UTM35','ETRS89 UTM Nord fuseau 35',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0235106','IGNF','185',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM35ETRS89','ETRS89 UTM Nord fuseau 35',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0235106','IGNF','185',NULL,0);
INSERT INTO "area" VALUES('IGNF','186','EUROPE (ETRS89) - UTM NORD FUSEAU 36','EUROPE (ETRS89) - UTM NORD FUSEAU 36',27.5,71.5,30,36,0);
INSERT INTO "projected_crs" VALUES('IGNF','ETRS89UTM36','ETRS89 UTM Nord fuseau 36',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0236107','IGNF','186',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM36ETRS89','ETRS89 UTM Nord fuseau 36',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0236107','IGNF','186',NULL,0);
INSERT INTO "area" VALUES('IGNF','187','EUROPE (ETRS89) - UTM NORD FUSEAU 37','EUROPE (ETRS89) - UTM NORD FUSEAU 37',27.5,71.5,36,42,0);
INSERT INTO "projected_crs" VALUES('IGNF','ETRS89UTM37','ETRS89 UTM Nord fuseau 37',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0237108','IGNF','187',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM37ETRS89','ETRS89 UTM Nord fuseau 37',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0237108','IGNF','187',NULL,0);
INSERT INTO "area" VALUES('IGNF','188','EUROPE (ETRS89) - UTM NORD FUSEAU 38','EUROPE (ETRS89) - UTM NORD FUSEAU 38',27.5,71.5,42,45.5,0);
INSERT INTO "projected_crs" VALUES('IGNF','ETRS89UTM38','ETRS89 UTM Nord fuseau 38',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0238109','IGNF','188',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM38ETRS89','ETRS89 UTM Nord fuseau 38',NULL,NULL,'EPSG','4499','IGNF','ETRS89G','IGNF','PRC0238109','IGNF','188',NULL,0);
INSERT INTO "area" VALUES('IGNF','189','ILE EUROPA - MERCATOR DIRECTE','ILE EUROPA - MERCATOR DIRECTE',-22.33,-22,40.25,40.5,0);
INSERT INTO "projected_crs" VALUES('IGNF','EUROPA54MD','Europa Mercator directe',NULL,NULL,'EPSG','4499','IGNF','EUROPA54G','IGNF','PRC0701121','IGNF','189',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','EURO54UTM37S','EUROPA MHM 1954 UTM SUD FUSEAU 37',NULL,NULL,'EPSG','4499','IGNF','EUROPA54G','IGNF','PRC0337572','IGNF','15',NULL,0);
INSERT INTO "area" VALUES('IGNF','190','FAKARAVA (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 6','FAKARAVA (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 6',-16.58,-16,-146,-145.25,0);
INSERT INTO "projected_crs" VALUES('IGNF','FAKA50UTM6S','Fakarava (SHM 1947-1950) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','FAKA50G','IGNF','PRC0306261','IGNF','190',NULL,0);
INSERT INTO "area" VALUES('IGNF','191','FANGATAUFA (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 7','FANGATAUFA (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 7',-22.33,-22.15,-138.83,-138.58,0);
INSERT INTO "projected_crs" VALUES('IGNF','FANGA64UTM7S','Fangataufa (MHPF 1964) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','FANGA64G','IGNF','PRC0307269','IGNF','191',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','FANG651UTM7S','Fangataufa (MHPF 1965-1) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','FANG651G','IGNF','PRC0307272','IGNF','191',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','FANGA651U7S','Fangataufa (MHPF 1965-1) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','FANG651G','IGNF','PRC0307272','IGNF','191',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','FANG652UTM7S','Fangataufa (MHPF 1965-2) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','FANG652G','IGNF','PRC0307275','IGNF','191',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','FANGA652U7S','Fangataufa (MHPF 1965-2) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','FANG652G','IGNF','PRC0307275','IGNF','191',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','FANGA66UTM7S','Fangataufa (MHPF 1966) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','FANGA66G','IGNF','PRC0307278','IGNF','191',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','FANGA84UTM7S','Fangataufa (MOP84) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','FANGA84G','IGNF','PRC0307264','IGNF','191',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGF93EQGPFR','France Metropolitaine projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC9802423','IGNF','4',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','GEOPORTALFXX','France Metropolitaine projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC9802423','IGNF','4',NULL,0);
INSERT INTO "area" VALUES('IGNF','192','ILES GLORIEUSES - MERCATOR DIRECTE','ILES GLORIEUSES - MERCATOR DIRECTE',-11.62,-11.43,47.25,47.47,0);
INSERT INTO "projected_crs" VALUES('IGNF','GLOR77MD','Glorieuses Mercator directe',NULL,NULL,'EPSG','4499','IGNF','GLOR77G','IGNF','PRC0701124','IGNF','192',NULL,0);
INSERT INTO "area" VALUES('IGNF','193','ILES GLORIEUSES - UTM SUD FUSEAU 38','ILES GLORIEUSES - UTM SUD FUSEAU 38',-11.62,-11.43,47.25,47.47,0);
INSERT INTO "projected_crs" VALUES('IGNF','GLOR77UTM38S','GLORIEUSES MHG 1977 UTM SUD FUSEAU 38',NULL,NULL,'EPSG','4499','IGNF','GLOR77G','IGNF','PRC0338125','IGNF','193',NULL,0);
INSERT INTO "area" VALUES('IGNF','194','GRANDE TERRE (NOUVELLE-CALEDONIE) - UTM SUD FUSEAU 58','GRANDE TERRE (NOUVELLE-CALEDONIE) - UTM SUD FUSEAU 58',-22.75,-19.5,163.5,167.67,0);
INSERT INTO "projected_crs" VALUES('IGNF','GTN51UTM58S','GOMEN TERME NORD 1951 UTM SUD FUSEAU 58',NULL,NULL,'EPSG','4499','IGNF','GTN51G','IGNF','PRC0358566','IGNF','194',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','NC51UTM58S','GOMEN TERME NORD 1951 UTM SUD FUSEAU 58',NULL,NULL,'EPSG','4499','IGNF','GTN51G','IGNF','PRC0358566','IGNF','194',NULL,0);
INSERT INTO "area" VALUES('IGNF','195','ILES DE SAINT-MARTIN ET SAINT-BARTHELEMY (GUADELOUPE) - UTM NORD FUSEAU 20','ILES DE SAINT-MARTIN ET SAINT-BARTHELEMY (GUADELOUPE) - UTM NORD FUSEAU 20',17.82,18.18,-63.18,-62.25,0);
INSERT INTO "projected_crs" VALUES('IGNF','GUADFMUTM20','Guadeloupe Fort-Marigot UTM Nord fuseau 20',NULL,NULL,'EPSG','4499','IGNF','GUADFMG','IGNF','PRC0220150','IGNF','195',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','GUADFM49U20','Guadeloupe Fort-Marigot UTM Nord fuseau 20',NULL,NULL,'EPSG','4499','IGNF','GUADFMG','IGNF','PRC0220150','IGNF','195',NULL,0);
INSERT INTO "area" VALUES('IGNF','196','GRANDE-TERRE, BASSE-TERRE, MARIE-GALANTE, LA DESIRADE, LES SAINTES (GUADELOUPE) - UTM NORD FUSEAU 20','GRANDE-TERRE, BASSE-TERRE, MARIE-GALANTE, LA DESIRADE, LES SAINTES (GUADELOUPE) - UTM NORD FUSEAU 20',15.82,16.6,-61.83,-60.77,0);
INSERT INTO "projected_crs" VALUES('IGNF','GUADANNUTM20','Guadeloupe Ste Anne UTM Nord fuseau 20',NULL,NULL,'EPSG','4499','IGNF','GUADANNG','IGNF','PRC0220147','IGNF','196',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','GUAD48UTM20','Guadeloupe Ste Anne UTM Nord fuseau 20',NULL,NULL,'EPSG','4499','IGNF','GUADANNG','IGNF','PRC0220147','IGNF','196',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGFG95EQGPGU','Guyane Francaise projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','RGFG95G','IGNF','PRC9805425','IGNF','10',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','GEOPORTALGUF','Guyane Francaise projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','RGFG95G','IGNF','PRC9805425','IGNF','10',NULL,0);
INSERT INTO "area" VALUES('IGNF','197','HAO ET AMANU (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 7','HAO ET AMANU (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 7',-18.5,-17.58,-141.17,-140.58,0);
INSERT INTO "projected_crs" VALUES('IGNF','HAOAM67UTM7S','Hao Amanu (MHPF 1967) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','HAOAM67G','IGNF','PRC0307283','IGNF','197',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','HAO67UTM7S','Hao Amanu (MHPF 1967) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','HAOAM67G','IGNF','PRC0307283','IGNF','197',NULL,0);
INSERT INTO "area" VALUES('IGNF','198','HAO (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 7','HAO (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 7',-18.5,-18,-141.17,-140.58,0);
INSERT INTO "projected_crs" VALUES('IGNF','HAO58UTM7S','Hao (MHPF 1958) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','HAO58G','IGNF','PRC0307286','IGNF','198',NULL,0);
INSERT INTO "area" VALUES('IGNF','199','HARAIKI (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 7','HARAIKI (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 7',-17.58,-17.42,-143.58,-143.33,0);
INSERT INTO "projected_crs" VALUES('IGNF','HARA49UTM7S','Haraiki (SHM 1949) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','HARA49G','IGNF','PRC0307289','IGNF','199',NULL,0);
INSERT INTO "area" VALUES('IGNF','200','HIKUERU (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 7','HIKUERU (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 7',-17.83,-17.42,-142.83,-142.42,0);
INSERT INTO "projected_crs" VALUES('IGNF','HIKU50UTM7S','Hikueru (SHM 1947-1950) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','HIKU50G','IGNF','PRC0307292','IGNF','200',NULL,0);
INSERT INTO "area" VALUES('IGNF','201','HIVA OA (ARCHIPEL DES MARQUISES) - UTM SUD FUSEAU 7','HIVA OA (ARCHIPEL DES MARQUISES) - UTM SUD FUSEAU 7',-9.87,-9.6,-139.25,-138.58,0);
INSERT INTO "projected_crs" VALUES('IGNF','HIVA60UTM7S','Hiva Oa (MHPF 1960) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','HIVA60G','IGNF','PRC0307235','IGNF','201',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','HIVA67UTM7S','Hiva Oa (MHPF 1967) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','HIVA67G','IGNF','PRC0307238','IGNF','201',NULL,0);
INSERT INTO "area" VALUES('IGNF','202','HIVA OA, TAHUATA, MOHOTANI (ARCHIPEL DES MARQUISES) - UTM SUD FUSEAU 7','HIVA OA, TAHUATA, MOHOTANI (ARCHIPEL DES MARQUISES) - UTM SUD FUSEAU 7',-9.88,-9.65,-139.2,-138.75,0);
INSERT INTO "projected_crs" VALUES('IGNF','ATUO63UTM7S','IGN 1963 UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','ATUO63G','IGNF','PRC0307241','IGNF','202',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','IGN63UTM7S','IGN 1963 UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','ATUO63G','IGNF','PRC0307241','IGNF','202',NULL,0);
INSERT INTO "area" VALUES('IGNF','203','RAIATEA, TAHAA (ARCHIPEL DE LA SOCIETE) - UTM SUD FUSEAU 5','RAIATEA, TAHAA (ARCHIPEL DE LA SOCIETE) - UTM SUD FUSEAU 5',-17,-16.5,-151.67,-151.33,0);
INSERT INTO "projected_crs" VALUES('IGNF','TAHAA53UTM5S','IGN53 Societe UTM Sud fuseau 5',NULL,NULL,'EPSG','4499','IGNF','TAHAA53G','IGNF','PRC030567','IGNF','203',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RAIA53UTM5S','IGN53 Societe UTM Sud fuseau 5',NULL,NULL,'EPSG','4499','IGNF','TAHAA53G','IGNF','PRC030567','IGNF','203',NULL,0);
INSERT INTO "area" VALUES('IGNF','204','GRANDE TERRE (NOUVELLE-CALEDONIE) - NOUVELLE-CALEDONIE','GRANDE TERRE (NOUVELLE-CALEDONIE) - NOUVELLE-CALEDONIE',-22.75,-19.5,163.5,167.67,0);
INSERT INTO "projected_crs" VALUES('IGNF','IGN72LAMBNC','IGN72 Lambert Nouvelle-Caledonie',NULL,NULL,'EPSG','4400','IGNF','IGN72G','IGNF','PRC0149208','IGNF','204',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','IGN72LAM','IGN72 Lambert Nouvelle-Caledonie',NULL,NULL,'EPSG','4400','IGNF','IGN72G','IGNF','PRC0149208','IGNF','204',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','IGN72UTM58S','IGN72 UTM Sud fuseau 58',NULL,NULL,'EPSG','4499','IGNF','IGN72G','IGNF','PRC0358209','IGNF','194',NULL,0);
INSERT INTO "area" VALUES('IGNF','205','ILE JUAN DE NOVA - UTM SUD FUSEAU 38','ILE JUAN DE NOVA - UTM SUD FUSEAU 38',-17.17,-17,42.67,42.83,0);
INSERT INTO "projected_crs" VALUES('IGNF','NOVA53UTM38S','JUAN DE NOVA MHM 1953 UTM SUD FUSEAU 38',NULL,NULL,'EPSG','4499','IGNF','NOVA53G','IGNF','PRC0338564','IGNF','205',NULL,0);
INSERT INTO "area" VALUES('IGNF','206','KAUHEI (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 6','KAUHEI (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 6',-16,-15.67,-145.33,-145,0);
INSERT INTO "projected_crs" VALUES('IGNF','KAUE70UTM6S','Kauehi (MHPF70) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','KAUE70G','IGNF','PRC030664','IGNF','206',NULL,0);
INSERT INTO "area" VALUES('IGNF','207','KERGUELEN - UTM SUD FUSEAU 42','KERGUELEN - UTM SUD FUSEAU 42',-50.5,-48,67,71,0);
INSERT INTO "projected_crs" VALUES('IGNF','KERG62UTM42S','KERGUELEN K0 IGN 1962 UTM SUD FUSEAU 42',NULL,NULL,'EPSG','4499','IGNF','KERG62G','IGNF','PRC034219','IGNF','207',NULL,0);
INSERT INTO "area" VALUES('IGNF','208','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - KERGUELEN','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - KERGUELEN',-50.5,-48,67,71,0);
INSERT INTO "projected_crs" VALUES('IGNF','WGS84EQGPKER','Kerguelen projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC9812426','IGNF','208',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','GEOPORTALKER','Kerguelen projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC9812426','IGNF','208',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','LNGLNG','Lambert Nord de Guerre Lambert Nord de Guerre',NULL,NULL,'EPSG','4499','IGNF','LNGPGG','IGNF','PRC013591','EPSG','1262',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','SYSLN','Lambert Nord de Guerre Lambert Nord de Guerre',NULL,NULL,'EPSG','4499','IGNF','LNGPGG','IGNF','PRC013591','EPSG','1262',NULL,0);
INSERT INTO "area" VALUES('IGNF','209','LIFOU (ILES LOYAUTE) - UTM SUD FUSEAU 58','LIFOU (ILES LOYAUTE) - UTM SUD FUSEAU 58',-21.22,-20.65,166.96,167.51,0);
INSERT INTO "projected_crs" VALUES('IGNF','LIFOU56UT58S','Lifou IGN 56 UTM Sud fuseau 58',NULL,NULL,'EPSG','4499','IGNF','LIFOU56G','IGNF','PRC0358182','IGNF','209',NULL,0);
INSERT INTO "area" VALUES('IGNF','210','MAKEMO (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 7','MAKEMO (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 7',-16.83,-16.33,-144,-143.33,0);
INSERT INTO "projected_crs" VALUES('IGNF','MAKE50UTM7S','Makemo (SHM 1947-1950) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','MAKE50G','IGNF','PRC0307295','IGNF','210',NULL,0);
INSERT INTO "area" VALUES('IGNF','211','MANGAREVA (ILES GAMBIER) - UTM SUD FUSEAU 8','MANGAREVA (ILES GAMBIER) - UTM SUD FUSEAU 8',-23.45,-22.83,-135.33,-134.58,0);
INSERT INTO "projected_crs" VALUES('IGNF','MANGA51UTM8S','Mangareva 1951 UTM Sud fuseau 8',NULL,NULL,'EPSG','4499','IGNF','MANGA51G','IGNF','PRC0308230','IGNF','211',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','MANGA51U8S','Mangareva 1951 UTM Sud fuseau 8',NULL,NULL,'EPSG','4499','IGNF','MANGA51G','IGNF','PRC0308230','IGNF','211',NULL,0);
INSERT INTO "area" VALUES('IGNF','212','MARE (ILES LOYAUTE) - UTM SUD FUSEAU 58','MARE (ILES LOYAUTE) - UTM SUD FUSEAU 58',-21.69,-21.29,167.69,168,0);
INSERT INTO "projected_crs" VALUES('IGNF','MARE53UTM58S','Mare IGN53 UTM Sud fuseau 58',NULL,NULL,'EPSG','4499','IGNF','MARE53G','IGNF','PRC0358186','IGNF','212',NULL,0);
INSERT INTO "area" VALUES('IGNF','213','MARTINIQUE - UTM NORD FUSEAU 20','MARTINIQUE - UTM NORD FUSEAU 20',14.27,15,-61.25,-60.75,0);
INSERT INTO "projected_crs" VALUES('IGNF','MARTFDUTM20','Martinique Fort-Desaix UTM Nord fuseau 20',NULL,NULL,'EPSG','4499','IGNF','MARTFDG','IGNF','PRC0220144','IGNF','213',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','MART38UTM20','Martinique Fort-Desaix UTM Nord fuseau 20',NULL,NULL,'EPSG','4499','IGNF','MARTFDG','IGNF','PRC0220144','IGNF','213',NULL,0);
INSERT INTO "area" VALUES('IGNF','214','MAUPITI - UTM SUD FUSEAU 5','MAUPITI - UTM SUD FUSEAU 5',-16.75,-16.25,-152.5,-152,0);
INSERT INTO "projected_crs" VALUES('IGNF','MAUPITIUTM5S','Maupiti (MOP 1983) UTM Sud fuseau 5',NULL,NULL,'EPSG','4499','IGNF','MAUPITIG','IGNF','PRC030582','IGNF','214',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGM04EQGPMYT','Mayotte projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','RGM04G','IGNF','PRC9807428','IGNF','5',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','GEOPORTALMYT','Mayotte projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','RGM04G','IGNF','PRC9807428','IGNF','5',NULL,0);
INSERT INTO "area" VALUES('IGNF','215','MANGAREVA, AGAKAUITAI, AUKENA, MEKIRO (ILES GAMBIER) - UTM SUD FUSEAU 8','MANGAREVA, AGAKAUITAI, AUKENA, MEKIRO (ILES GAMBIER) - UTM SUD FUSEAU 8',-23.18,-23.07,-135.04,-134.89,0);
INSERT INTO "projected_crs" VALUES('IGNF','MHPF67UTM8S','MHPF 1967 UTM SUD FUSEAU 8',NULL,NULL,'EPSG','4499','IGNF','MHPF67G','IGNF','PRC030858','IGNF','215',NULL,0);
INSERT INTO "area" VALUES('IGNF','216','MOOREA (ARCHIPEL DE LA SOCIETE) - UTM SUD FUSEAU 6','MOOREA (ARCHIPEL DE LA SOCIETE) - UTM SUD FUSEAU 6',-17.75,-17.25,-150,-149.75,0);
INSERT INTO "projected_crs" VALUES('IGNF','MOORE87UTM6S','Moorea 1987 UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','MOOREA87G','IGNF','PRC030679','IGNF','216',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','MOOREA87U6S','Moorea 1987 UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','MOOREA87G','IGNF','PRC030679','IGNF','216',NULL,0);
INSERT INTO "area" VALUES('IGNF','217','MURUROA (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 7','MURUROA (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 7',-22,-21.67,-139.17,-138.58,0);
INSERT INTO "projected_crs" VALUES('IGNF','MURU78UTM7S','Mururoa (IGN 1978) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','MURU78G','IGNF','PRC0307307','IGNF','217',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','MURU62UTM7S','Mururoa (MHOI 1962) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','MURU62G','IGNF','PRC0307303','IGNF','217',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','MURU59UTM7S','Mururoa (MHPF 1959) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','MURU59G','IGNF','PRC0307298','IGNF','217',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','NEA74LBTNM2','NEA74 NOUMEA Lambert Noumea 2',NULL,NULL,'EPSG','4499','IGNF','NEA74G','IGNF','PRC9203409','IGNF','44',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGNC91EQGPNC','Nouvelle Caledonie projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','RGNCG','IGNF','PRC9809429','IGNF','57',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','GEOPORTALNCL','Nouvelle Caledonie projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','RGNCG','IGNF','PRC9809429','IGNF','57',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','LURESGKL','NOUVELLE TRIANGULATION DU DUCHE DU LUXEMBOURG GAUSS KRUGER LUXEMBOURG',NULL,NULL,'EPSG','4530','IGNF','LURESG','IGNF','PRC0406569','IGNF','45',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','LUXGAUSSK','NOUVELLE TRIANGULATION DU DUCHE DU LUXEMBOURG GAUSS KRUGER LUXEMBOURG',NULL,NULL,'EPSG','4530','IGNF','LURESG','IGNF','PRC0406569','IGNF','45',NULL,0);
INSERT INTO "area" VALUES('IGNF','218','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT GRAND CHAMP','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT GRAND CHAMP',41.310015543796,51.299958070717,-4.05379920354209,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','NTFLAMBGC','NTF Lambert Grand Champ',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC011814','IGNF','218',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','LAMBGC','NTF Lambert Grand Champ',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC011814','IGNF','218',NULL,0);
INSERT INTO "area" VALUES('IGNF','219','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT I NORD','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT I NORD',48.1498888194584,51.299958070717,-4.05379920354209,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','NTFLAMB1','NTF Lambert I',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC01015','IGNF','219',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','LAMB1','NTF Lambert I',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC01015','IGNF','219',NULL,0);
INSERT INTO "area" VALUES('IGNF','220','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT I CARTO','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT I CARTO',48.1498888194584,51.299958070717,-4.05379920354209,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','NTFLAMB1C','NTF Lambert I carto',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC01316','IGNF','220',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','LAMB1C','NTF Lambert I carto',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC01316','IGNF','220',NULL,0);
INSERT INTO "area" VALUES('IGNF','221','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT II CENTRE','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT II CENTRE',45.4499226513968,48.1499671938551,-4.05373473460064,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','NTFLAMB2','NTF Lambert II',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC01027','IGNF','221',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','LAMB2','NTF Lambert II',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC01027','IGNF','221',NULL,0);
INSERT INTO "area" VALUES('IGNF','222','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT II CARTO','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT II CARTO',45.4499226513968,48.1499671938551,-4.05373473460064,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','NTFLAMB2C','NTF Lambert II carto',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC01328','IGNF','222',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','LAMB2C','NTF Lambert II carto',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC01328','IGNF','222',NULL,0);
INSERT INTO "area" VALUES('IGNF','223','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT II ETENDU','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT II ETENDU',41.310015543796,50.8499576445959,-4.05378927743516,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','NTFLAMB2E','NTF Lambert II etendu',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC012013','IGNF','223',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','LAMBE','NTF Lambert II etendu',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC012013','IGNF','223',NULL,0);
INSERT INTO "area" VALUES('IGNF','224','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT III SUD','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT III SUD',42.2999888396489,45.4499976673229,-4.05368768512203,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','NTFLAMB3','NTF Lambert III',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC01039','IGNF','224',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','LAMB3','NTF Lambert III',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC01039','IGNF','224',NULL,0);
INSERT INTO "area" VALUES('IGNF','225','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT III CARTO','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT III CARTO',42.2999888396489,45.4499976673229,-4.05368768512203,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','NTFLAMB3C','NTF Lambert III carto',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC013310','IGNF','225',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','LAMB3C','NTF Lambert III carto',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC013310','IGNF','225',NULL,0);
INSERT INTO "area" VALUES('IGNF','226','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT IV CORSE','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT IV CORSE',41.3100821709321,43.0200472881681,7.7367772754414,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','NTFLAMB4','NTF Lambert IV',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC010411','IGNF','226',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','LAMB4','NTF Lambert IV',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC010411','IGNF','226',NULL,0);
INSERT INTO "area" VALUES('IGNF','227','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT IV CARTO','FRANCE METROPOLITAINE (CORSE COMPRISE) - LAMBERT IV CARTO',41.3100821709321,43.0200472881681,7.7367772754414,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','NTFLAMB4C','NTF Lambert IV carto',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC013412','IGNF','227',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','LAMB4C','NTF Lambert IV carto',NULL,NULL,'EPSG','4499','IGNF','NTFPGRAD','IGNF','PRC013412','IGNF','227',NULL,0);
INSERT INTO "area" VALUES('IGNF','228','NUKU HIVA, UA HUKA ET UA POU (ARCHIPEL DES MARQUISES) - UTM SUD FUSEAU 7','NUKU HIVA, UA HUKA ET UA POU (ARCHIPEL DES MARQUISES) - UTM SUD FUSEAU 7',-9.5,-8.77,-140.27,-139.48,0);
INSERT INTO "projected_crs" VALUES('IGNF','NUKU72UTM7S','Nuku Hiva UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','NUKU72G','IGNF','PRC0307212','IGNF','228',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','NUKU72U7S','Nuku Hiva UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','NUKU72G','IGNF','PRC0307212','IGNF','228',NULL,0);
INSERT INTO "area" VALUES('IGNF','229','OUVEA (ILES LOYAUTE) - UTM SUD FUSEAU 58','OUVEA (ILES LOYAUTE) - UTM SUD FUSEAU 58',-20.78,-20.25,166.11,166.71,0);
INSERT INTO "projected_crs" VALUES('IGNF','OUVE72UTM58S','Ouvea MHNC 1972 UTM Sud fuseau 58',NULL,NULL,'EPSG','4499','IGNF','OUVE72G','IGNF','PRC0358195','IGNF','229',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','OUVEA72U58S','Ouvea MHNC 1972 UTM Sud fuseau 58',NULL,NULL,'EPSG','4499','IGNF','OUVE72G','IGNF','PRC0358195','IGNF','229',NULL,0);
INSERT INTO "area" VALUES('IGNF','230','ILE DE LA REUNION - GAUSS LABORDE REUNION','ILE DE LA REUNION - GAUSS LABORDE REUNION',-21.42,-20.76,55.17,55.92,0);
INSERT INTO "projected_crs" VALUES('IGNF','PDN92GAUSSL','Piton des Neiges (1992) Gauss Laborde Reunion',NULL,NULL,'EPSG','4499','IGNF','PDN92G','IGNF','PRC0508542','IGNF','230',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','PDN08GAUSSL','Piton des Neiges (2008) Gauss Laborde Reunion',NULL,NULL,'EPSG','4499','IGNF','PDN08G','IGNF','PRC0508546','IGNF','230',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGPFEQGPPF','Polynesie Francaise projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','RGPFG','IGNF','PRC9811430','IGNF','58',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','GEOPORTALPYF','Polynesie Francaise projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','RGPFG','IGNF','PRC9811430','IGNF','58',NULL,0);
INSERT INTO "area" VALUES('IGNF','231','RAIVAVAE (ARCHIPEL DES AUSTRALES) - UTM SUD FUSEAU 6','RAIVAVAE (ARCHIPEL DES AUSTRALES) - UTM SUD FUSEAU 6',-23.92,-23.75,-147.75,-147.58,0);
INSERT INTO "projected_crs" VALUES('IGNF','RAIV54UTM6S','Raivavae (Cadastre) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','RAIV54G','IGNF','PRC0306215','IGNF','231',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RAIV66UTM6S','Raivavae (MHPF 1966) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','RAIV66G','IGNF','PRC0306218','IGNF','231',NULL,0);
INSERT INTO "area" VALUES('IGNF','232','RANGIROA (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 6','RANGIROA (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 6',-14.83,-14.42,-148,-147.15,0);
INSERT INTO "projected_crs" VALUES('IGNF','RANGI47UTM6S','Rangiroa (MGT 1947) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','RANGI47G','IGNF','PRC0306311','IGNF','232',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RANGI47U6S','Rangiroa (MGT 1947) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','RANGI47G','IGNF','PRC0306311','IGNF','232',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RANGI59UTM6S','Rangiroa (MHPF 1959) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','RANGI59G','IGNF','PRC0306314','IGNF','232',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RANGI59U6S','Rangiroa (MHPF 1959) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','RANGI59G','IGNF','PRC0306314','IGNF','232',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RANGI68UTM6S','Rangiroa (MHPF 1966-68) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','RANGI68G','IGNF','PRC0306317','IGNF','232',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RANGI68U6S','Rangiroa (MHPF 1966-68) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','RANGI68G','IGNF','PRC0306317','IGNF','232',NULL,0);
INSERT INTO "area" VALUES('IGNF','233','ILES WALLIS, FUTUNA ET ALOFI - UTM SUD FUSEAU 1','ILES WALLIS, FUTUNA ET ALOFI - UTM SUD FUSEAU 1',-14.39,-13.16,-179.98,-176.3,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGWF96UTM1S','RESEAU GEODESIQUE DE WALLIS ET FUTUNA 1996 UTM SUD FUSEAU 1',NULL,NULL,'EPSG','4499','IGNF','RGWF96GEO','IGNF','PRC0301588','IGNF','233',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','REUN49GAUSSL','Reunion Piton des Neiges Gauss Laborde',NULL,NULL,'EPSG','4499','IGNF','REUN49G','IGNF','PRC0508114','IGNF','230',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','REUN47GAUSSL','Reunion Piton des Neiges Gauss Laborde',NULL,NULL,'EPSG','4499','IGNF','REUN49G','IGNF','PRC0508114','IGNF','230',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGR92EQGPREU','Reunion projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','RGR92G','IGNF','PRC9806431','IGNF','55',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','GEOPORTALREU','Reunion projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','RGR92G','IGNF','PRC9806431','IGNF','55',NULL,0);
INSERT INTO "area" VALUES('IGNF','234','ANTILLES FRANCAISES - UTM NORD FUSEAU 20','ANTILLES FRANCAISES - UTM NORD FUSEAU 20',14.25,18.2,-63.2,-60.73,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGAF09UTM20','RGAF09 UTM Nord Fuseau 20',NULL,NULL,'EPSG','4499','IGNF','RGAF09G','IGNF','PRC0220527','IGNF','234',NULL,0);
INSERT INTO "area" VALUES('IGNF','235','FRANCE METROPOLITAINE (CORSE COMPRISE) - CC42 (CONIQUE CONFORME ZONE 1)','FRANCE METROPOLITAINE (CORSE COMPRISE) - CC42 (CONIQUE CONFORME ZONE 1)',41,43,-5.5,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGF93CC42','RGF93 CC42 zone 1',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC8142383','IGNF','235',NULL,0);
INSERT INTO "area" VALUES('IGNF','236','FRANCE METROPOLITAINE (CORSE COMPRISE) - CC43 (CONIQUE CONFORME ZONE 2)','FRANCE METROPOLITAINE (CORSE COMPRISE) - CC43 (CONIQUE CONFORME ZONE 2)',42,44,-5.5,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGF93CC43','RGF93 CC43 zone 2',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC8143384','IGNF','236',NULL,0);
INSERT INTO "area" VALUES('IGNF','237','FRANCE METROPOLITAINE (CORSE COMPRISE) - CC44 (CONIQUE CONFORME ZONE 3)','FRANCE METROPOLITAINE (CORSE COMPRISE) - CC44 (CONIQUE CONFORME ZONE 3)',43,45,-5.5,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGF93CC44','RGF93 CC44 zone 3',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC8144385','IGNF','237',NULL,0);
INSERT INTO "area" VALUES('IGNF','238','FRANCE METROPOLITAINE (CORSE COMPRISE) - CC45 (CONIQUE CONFORME ZONE 4)','FRANCE METROPOLITAINE (CORSE COMPRISE) - CC45 (CONIQUE CONFORME ZONE 4)',44,46,-5.5,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGF93CC45','RGF93 CC45 zone 4',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC8145386','IGNF','238',NULL,0);
INSERT INTO "area" VALUES('IGNF','239','FRANCE METROPOLITAINE (CORSE COMPRISE) - CC46 (CONIQUE CONFORME ZONE 5)','FRANCE METROPOLITAINE (CORSE COMPRISE) - CC46 (CONIQUE CONFORME ZONE 5)',45,47,-5.5,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGF93CC46','RGF93 CC46 zone 5',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC8146387','IGNF','239',NULL,0);
INSERT INTO "area" VALUES('IGNF','240','FRANCE METROPOLITAINE (CORSE COMPRISE) - CC47 (CONIQUE CONFORME ZONE 6)','FRANCE METROPOLITAINE (CORSE COMPRISE) - CC47 (CONIQUE CONFORME ZONE 6)',46,48,-5.5,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGF93CC47','RGF93 CC47 zone 6',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC8147388','IGNF','240',NULL,0);
INSERT INTO "area" VALUES('IGNF','241','FRANCE METROPOLITAINE (CORSE COMPRISE) - CC48 (CONIQUE CONFORME ZONE 7)','FRANCE METROPOLITAINE (CORSE COMPRISE) - CC48 (CONIQUE CONFORME ZONE 7)',47,49,-5.5,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGF93CC48','RGF93 CC48 zone 7',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC8148389','IGNF','241',NULL,0);
INSERT INTO "area" VALUES('IGNF','242','FRANCE METROPOLITAINE (CORSE COMPRISE) - CC49 (CONIQUE CONFORME ZONE 8)','FRANCE METROPOLITAINE (CORSE COMPRISE) - CC49 (CONIQUE CONFORME ZONE 8)',48,50,-5.5,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGF93CC49','RGF93 CC49 zone 8',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC8149390','IGNF','242',NULL,0);
INSERT INTO "area" VALUES('IGNF','243','FRANCE METROPOLITAINE (CORSE COMPRISE) - CC50 (CONIQUE CONFORME ZONE 9)','FRANCE METROPOLITAINE (CORSE COMPRISE) - CC50 (CONIQUE CONFORME ZONE 9)',49,51,-5.5,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGF93CC50','RGF93 CC50 zone 9',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC8150391','IGNF','243',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGF93LAMB93','RGF93 Lambert 93',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC014052','IGNF','4',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','LAMB93','RGF93 Lambert 93',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC014052','IGNF','4',NULL,0);
INSERT INTO "area" VALUES('IGNF','244','FRANCE METROPOLITAINE (CORSE COMPRISE) - UTM NORD FUSEAU 31','FRANCE METROPOLITAINE (CORSE COMPRISE) - UTM NORD FUSEAU 31',41,52,0,6,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGF93UTM31','RGF93 UTM fuseau 31',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC0231393','IGNF','244',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM31RGF93','RGF93 UTM fuseau 31',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC0231393','IGNF','244',NULL,0);
INSERT INTO "area" VALUES('IGNF','245','FRANCE METROPOLITAINE (CORSE COMPRISE) - UTM NORD FUSEAU 32','FRANCE METROPOLITAINE (CORSE COMPRISE) - UTM NORD FUSEAU 32',41,52,6,10,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGF93UTM32','RGF93 UTM fuseau 32',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC0232394','IGNF','245',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM32RGF93','RGF93 UTM fuseau 32',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC0232394','IGNF','245',NULL,0);
INSERT INTO "area" VALUES('IGNF','246','FRANCE METROPOLITAINE (CORSE COMPRISE) - UTM NORD FUSEAU 30','FRANCE METROPOLITAINE (CORSE COMPRISE) - UTM NORD FUSEAU 30',41,52,-5.5,0,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGF93UTM30','RGF93 UTM NORD FUSEAU 30',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC0230392','IGNF','246',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM30RGF93','RGF93 UTM NORD FUSEAU 30',NULL,NULL,'EPSG','4499','IGNF','RGF93G','IGNF','PRC0230392','IGNF','246',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGFG95UTM21','RGFG95 UTM Nord f.21',NULL,NULL,'EPSG','4499','IGNF','RGFG95G','IGNF','PRC0221157','IGNF','170',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM21RGFG95','RGFG95 UTM Nord f.21',NULL,NULL,'EPSG','4499','IGNF','RGFG95G','IGNF','PRC0221157','IGNF','170',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGFG95UTM22','RGFG95 UTM Nord f.22',NULL,NULL,'EPSG','4499','IGNF','RGFG95G','IGNF','PRC0222158','IGNF','171',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM22RGFG95','RGFG95 UTM Nord f.22',NULL,NULL,'EPSG','4499','IGNF','RGFG95G','IGNF','PRC0222158','IGNF','171',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGM04UTM38S','RGM04 UTM Sud fuseau 38',NULL,NULL,'EPSG','4499','IGNF','RGM04G','IGNF','PRC0338372','IGNF','166',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGNCLAMBNC','RGNC Lambert Nouvelle-Caledonie',NULL,NULL,'EPSG','4499','IGNF','RGNCG','IGNF','PRC0149202','IGNF','57',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGNCLAM','RGNC Lambert Nouvelle-Caledonie',NULL,NULL,'EPSG','4499','IGNF','RGNCG','IGNF','PRC0149202','IGNF','57',NULL,0);
INSERT INTO "area" VALUES('IGNF','247','NOUVELLE-CALEDONIE - UTM SUD FUSEAU 57','NOUVELLE-CALEDONIE - UTM SUD FUSEAU 57',-26.65,-14.6,156.1,162,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGNCUTM57S','RGNC UTM Sud fuseau 57',NULL,NULL,'EPSG','4499','IGNF','RGNCG','IGNF','PRC0357203','IGNF','247',NULL,0);
INSERT INTO "area" VALUES('IGNF','248','NOUVELLE-CALEDONIE - UTM SUD FUSEAU 58','NOUVELLE-CALEDONIE - UTM SUD FUSEAU 58',-26.65,-14.6,162,168,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGNCUTM58S','RGNC UTM Sud fuseau 58',NULL,NULL,'EPSG','4499','IGNF','RGNCG','IGNF','PRC0358204','IGNF','248',NULL,0);
INSERT INTO "area" VALUES('IGNF','249','NOUVELLE-CALEDONIE - UTM SUD FUSEAU 59','NOUVELLE-CALEDONIE - UTM SUD FUSEAU 59',-26.65,-14.6,168,174,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGNCUTM59S','RGNC UTM Sud fuseau 59',NULL,NULL,'EPSG','4499','IGNF','RGNCG','IGNF','PRC0359205','IGNF','249',NULL,0);
INSERT INTO "area" VALUES('IGNF','250','POLYNESIE FRANCAISE - UTM SUD FUSEAU 5','POLYNESIE FRANCAISE - UTM SUD FUSEAU 5',-28,-7,-156,-150,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGPFUTM5S','RGPF UTM Sud fuseau 5',NULL,NULL,'EPSG','4499','IGNF','RGPFG','IGNF','PRC030574','IGNF','250',NULL,0);
INSERT INTO "area" VALUES('IGNF','251','POLYNESIE FRANCAISE - UTM SUD FUSEAU 6','POLYNESIE FRANCAISE - UTM SUD FUSEAU 6',-28,-7,-150,-144,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGPFUTM6S','RGPF UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','RGPFG','IGNF','PRC030675','IGNF','251',NULL,0);
INSERT INTO "area" VALUES('IGNF','252','POLYNESIE FRANCAISE - UTM SUD FUSEAU 7','POLYNESIE FRANCAISE - UTM SUD FUSEAU 7',-28,-7,-144,-138,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGPFUTM7S','RGPF UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','RGPFG','IGNF','PRC030776','IGNF','252',NULL,0);
INSERT INTO "area" VALUES('IGNF','253','POLYNESIE FRANCAISE - UTM SUD FUSEAU 8','POLYNESIE FRANCAISE - UTM SUD FUSEAU 8',-28,-7,-138,-134,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGPFUTM8S','RGPF UTM SUD FUSEAU 8',NULL,NULL,'EPSG','4499','IGNF','RGPFG','IGNF','PRC0308576','IGNF','253',NULL,0);
INSERT INTO "area" VALUES('IGNF','254','ILE DE LA REUNION - UTM SUD FUSEAU 40','ILE DE LA REUNION - UTM SUD FUSEAU 40',-21.42,-20.75,55.17,55.92,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGR92UTM40S','RGR92 UTM 40 Sud',NULL,NULL,'EPSG','4499','IGNF','RGR92G','IGNF','PRC0340361','IGNF','254',NULL,0);
INSERT INTO "area" VALUES('IGNF','255','SAINT-PIERRE-ET-MIQUELON - UTM NORD FUSEAU 21','SAINT-PIERRE-ET-MIQUELON - UTM NORD FUSEAU 21',46.7,47.2,-56.49,-56.1,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGSPM06U21','RGSPM06 UTM Nord fuseau 21',NULL,NULL,'EPSG','4499','IGNF','RGSPM06G','IGNF','PRC0221378','IGNF','255',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGTAAFUTM37S','RGTAAF07 UTM Sud fuseau 37',NULL,NULL,'EPSG','4499','IGNF','RGTAAF07G','IGNF','PRC0337418','IGNF','60',NULL,0);
INSERT INTO "area" VALUES('IGNF','256','TERRES AUSTRALES ET ANTARCTIQUES FRANCAISES (TAAF) - UTM SUD FUSEAU 39','TERRES AUSTRALES ET ANTARCTIQUES FRANCAISES (TAAF) - UTM SUD FUSEAU 39',-80,-11,48,54,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGTAAFUTM39S','RGTAAF07 UTM Sud fuseau 39',NULL,NULL,'EPSG','4499','IGNF','RGTAAF07G','IGNF','PRC0339419','IGNF','256',NULL,0);
INSERT INTO "area" VALUES('IGNF','257','TERRES AUSTRALES ET ANTARCTIQUES FRANCAISES (TAAF) - UTM SUD FUSEAU 42','TERRES AUSTRALES ET ANTARCTIQUES FRANCAISES (TAAF) - UTM SUD FUSEAU 42',-80,-11,66,72,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGTAAFUTM42S','RGTAAF07 UTM Sud fuseau 42',NULL,NULL,'EPSG','4499','IGNF','RGTAAF07G','IGNF','PRC0342420','IGNF','257',NULL,0);
INSERT INTO "area" VALUES('IGNF','258','TERRES AUSTRALES ET ANTARCTIQUES FRANCAISES (TAAF) - UTM SUD FUSEAU 43','TERRES AUSTRALES ET ANTARCTIQUES FRANCAISES (TAAF) - UTM SUD FUSEAU 43',-80,-11,72,78,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGTAAFUTM43S','RGTAAF07 UTM Sud fuseau 43',NULL,NULL,'EPSG','4499','IGNF','RGTAAF07G','IGNF','PRC0343421','IGNF','258',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGTAAFUTM53S','RGTAAF07 UTM SUD FUSEAU 53',NULL,NULL,'EPSG','4499','IGNF','RGTAAF07G','IGNF','PRC0353563','IGNF','60',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RRAFUTM20','RRAF UTM Nord fuseau 20',NULL,NULL,'EPSG','4499','IGNF','RRAFG','IGNF','PRC0220170','IGNF','234',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM20W84MART','RRAF UTM Nord fuseau 20',NULL,NULL,'EPSG','4499','IGNF','RRAFG','IGNF','PRC0220170','IGNF','234',NULL,0);
INSERT INTO "area" VALUES('IGNF','259','RURUTU (ARCHIPEL DES AUSTRALES) - UTM SUD FUSEAU 5','RURUTU (ARCHIPEL DES AUSTRALES) - UTM SUD FUSEAU 5',-22.58,-22.25,-151.5,-151.33,0);
INSERT INTO "projected_crs" VALUES('IGNF','RUSAT84UTM5S','Rurutu (SAT84) UTM Sud fuseau 5',NULL,NULL,'EPSG','4499','IGNF','RUSAT84G','IGNF','PRC030570','IGNF','259',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','SAT84UTM5S','Rurutu (SAT84) UTM Sud fuseau 5',NULL,NULL,'EPSG','4499','IGNF','RUSAT84G','IGNF','PRC030570','IGNF','259',NULL,0);
INSERT INTO "area" VALUES('IGNF','260','ILE SAINT-PAUL - UTM SUD FUSEAU 43','ILE SAINT-PAUL - UTM SUD FUSEAU 43',-38.77,-38.67,77.48,77.58,0);
INSERT INTO "projected_crs" VALUES('IGNF','STPL69UTM43S','Saint-Paul UTM Sud fuseau 43',NULL,NULL,'EPSG','4499','IGNF','STPL69G','IGNF','PRC034341','IGNF','260',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','RGSPM06EQGP','Saint-Pierre-et-Miquelon Geoportail',NULL,NULL,'EPSG','4499','IGNF','RGSPM06G','IGNF','PRC9808432','IGNF','59',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','GEOPORTALSPM','Saint-Pierre-et-Miquelon Geoportail',NULL,NULL,'EPSG','4499','IGNF','RGSPM06G','IGNF','PRC9808432','IGNF','59',NULL,0);
INSERT INTO "area" VALUES('IGNF','261','ILE DES PINS (NOUVELLE-CALEDONIE) - UTM SUD FUSEAU 58','ILE DES PINS (NOUVELLE-CALEDONIE) - UTM SUD FUSEAU 58',-22.8,-22.44,167.29,167.62,0);
INSERT INTO "projected_crs" VALUES('IGNF','ST84UTM58S','ST 84 ILE DES PINS UTM Sud fuseau 58',NULL,NULL,'EPSG','4499','IGNF','ST84G','IGNF','PRC0358407','IGNF','261',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','ST87UTM58S','ST 87 OUVEA UTM Sud fuseau 58',NULL,NULL,'EPSG','4499','IGNF','ST87G','IGNF','PRC0358405','IGNF','229',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','STPM50UTM21','St-Pierre-et-Miquelon UTM Nord f.21',NULL,NULL,'EPSG','4499','IGNF','STPM50G','IGNF','PRC0221141','IGNF','255',NULL,0);
INSERT INTO "area" VALUES('IGNF','262','TAHAA (ARCHIPEL DE LA SOCIETE) - UTM SUD FUSEAU 5','TAHAA (ARCHIPEL DE LA SOCIETE) - UTM SUD FUSEAU 5',-16.7,-16.53,-151.58,-151.38,0);
INSERT INTO "projected_crs" VALUES('IGNF','TAHAAUTM5S','Tahaa UTM Sud fuseau 5',NULL,NULL,'EPSG','4499','IGNF','TAHAAG','IGNF','PRC0305187','IGNF','262',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','TAHAAUTM05S','Tahaa UTM Sud fuseau 5',NULL,NULL,'EPSG','4499','IGNF','TAHAAG','IGNF','PRC0305187','IGNF','262',NULL,0);
INSERT INTO "area" VALUES('IGNF','263','TAHITI (ARCHIPEL DE LA SOCIETE) - UTM SUD FUSEAU 6','TAHITI (ARCHIPEL DE LA SOCIETE) - UTM SUD FUSEAU 6',-18,-17,-150,-149,0);
INSERT INTO "projected_crs" VALUES('IGNF','TAHI79UTM6S','Tahiti (IGN79) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','TAHI79G','IGNF','PRC030655','IGNF','263',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','TAHI51UTM6S','TAHITI TERME NORD UTM SUD FUSEAU 6',NULL,NULL,'EPSG','4499','IGNF','TAHI51G','IGNF','PRC0306172','IGNF','263',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','TAHI51UTM06S','TAHITI TERME NORD UTM SUD FUSEAU 6',NULL,NULL,'EPSG','4499','IGNF','TAHI51G','IGNF','PRC0306172','IGNF','263',NULL,0);
INSERT INTO "area" VALUES('IGNF','264','TAKAROA ET TAKAPOTO (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 6','TAKAROA ET TAKAPOTO (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 6',-14.75,-14.25,-145.33,-144.75,0);
INSERT INTO "projected_crs" VALUES('IGNF','TAKA69UTM6S','Takaroa Takapoto (SHM 1969) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','TAKA69G','IGNF','PRC0306320','IGNF','264',NULL,0);
INSERT INTO "area" VALUES('IGNF','265','TANNA (ARCHIPEL DU VANUATU) - UTM SUD FUSEAU 59','TANNA (ARCHIPEL DU VANUATU) - UTM SUD FUSEAU 59',-19.67,-19.08,169.17,169.83,0);
INSERT INTO "projected_crs" VALUES('IGNF','TANNAUTM59S','Tanna UTM Sud fuseau 59',NULL,NULL,'EPSG','4499','IGNF','TANNAG','IGNF','PRC0359190','IGNF','265',NULL,0);
INSERT INTO "area" VALUES('IGNF','266','ARCHIPEL POINTE GEOLOGIE (TERRE ADELIE) - STEREOGRAPHIQUE POLAIRE SUD TERRE ADELIE','ARCHIPEL POINTE GEOLOGIE (TERRE ADELIE) - STEREOGRAPHIQUE POLAIRE SUD TERRE ADELIE',-66.72,-66.6,139.67,140.12,0);
INSERT INTO "projected_crs" VALUES('IGNF','PGP50STEREPS','TERRE ADELIE POINTE GEOLOGIE PERROUD STEREO POLAIRE SUD (TANGENTE)',NULL,NULL,'EPSG','4499','IGNF','PGP50G','IGNF','PRC090126','IGNF','266',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','TERA50STEREO','TERRE ADELIE POINTE GEOLOGIE PERROUD STEREO POLAIRE SUD (TANGENTE)',NULL,NULL,'EPSG','4499','IGNF','PGP50G','IGNF','PRC090126','IGNF','266',NULL,0);
INSERT INTO "area" VALUES('IGNF','267','TETIAROA (ARCHIPEL DE LA SOCIETE) - UTM SUD FUSEAU 6','TETIAROA (ARCHIPEL DE LA SOCIETE) - UTM SUD FUSEAU 6',-17.1,-17.02,-149.6,-149.53,0);
INSERT INTO "projected_crs" VALUES('IGNF','TETIA90UTM6S','Tetiaroa (MOP90) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','TETIA90G','IGNF','PRC030661','IGNF','267',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','MOP90UTM6S','Tetiaroa (MOP90) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','TETIA90G','IGNF','PRC030661','IGNF','267',NULL,0);
INSERT INTO "area" VALUES('IGNF','268','TIKEHAU (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 6','TIKEHAU (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 6',-15.2,-14.83,-148.5,-148,0);
INSERT INTO "projected_crs" VALUES('IGNF','TIKE60UTM6S','Tikehau (MHPF 1960) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','TIKE60G','IGNF','PRC0306323','IGNF','268',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','TIKE88UTM6S','TIKEHAU (MOP88) UTM SUD FUSEAU 6',NULL,NULL,'EPSG','4499','IGNF','TIKE88G','IGNF','PRC0306585','IGNF','268',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','TIKE50UTM6S','Tikehau (SHM 1947-1950) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','TIKE50G','IGNF','PRC0306326','IGNF','268',NULL,0);
INSERT INTO "area" VALUES('IGNF','269','ILE TROMELIN - MERCATOR DIRECTE','ILE TROMELIN - MERCATOR DIRECTE',-15.9,-15.87,54.51,54.53,0);
INSERT INTO "projected_crs" VALUES('IGNF','TROM56MD','TROMELIN SGM 1956 MERCATOR DIRECTE',NULL,NULL,'EPSG','4499','IGNF','TROM56G','IGNF','PRC0701131','IGNF','269',NULL,0);
INSERT INTO "area" VALUES('IGNF','270','APATAKI, RAPA et HAO - UTM SUD FUSEAU 6','APATAKI, RAPA et HAO - UTM SUD FUSEAU 6',-27.75,-15.293,-146.4644,-144,0);
INSERT INTO "projected_crs" VALUES('IGNF','TUAM86UTM6S','Tuamotu (MOP86) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','TUAM86G','IGNF','PRC0306330','IGNF','270',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','APAT86UTM6S','Tuamotu (MOP86) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','TUAM86G','IGNF','PRC0306330','IGNF','270',NULL,0);
INSERT INTO "area" VALUES('IGNF','271','APATAKI, RAPA et HAO - UTM SUD FUSEAU 7','APATAKI, RAPA et HAO - UTM SUD FUSEAU 7',-27.75,-15.293,-144,-140.5833,0);
INSERT INTO "projected_crs" VALUES('IGNF','TUAM86UTM7S','Tuamotu (MOP86) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','TUAM86G','IGNF','PRC0307331','IGNF','271',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','APAT86UTM7S','Tuamotu (MOP86) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','TUAM86G','IGNF','PRC0307331','IGNF','271',NULL,0);
INSERT INTO "area" VALUES('IGNF','272','TUBUAI (ARCHIPEL DES AUSTRALES) - UTM SUD FUSEAU 6','TUBUAI (ARCHIPEL DES AUSTRALES) - UTM SUD FUSEAU 6',-23.45,-23.25,-149.58,-149.33,0);
INSERT INTO "projected_crs" VALUES('IGNF','TUBU69UTM6S','Tubuai (MHPF 1969) UTM Sud fuseau 6',NULL,NULL,'EPSG','4499','IGNF','TUBU69G','IGNF','PRC0306227','IGNF','272',NULL,0);
INSERT INTO "area" VALUES('IGNF','273','TUREIA (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 7','TUREIA (ARCHIPEL DES TUAMOTU) - UTM SUD FUSEAU 7',-21,-20.67,-139.83,-138.83,0);
INSERT INTO "projected_crs" VALUES('IGNF','TURI69UTM7S','Tureia (SHM 1969) UTM Sud fuseau 7',NULL,NULL,'EPSG','4499','IGNF','TURI69G','IGNF','PRC0307308','IGNF','273',NULL,0);
INSERT INTO "area" VALUES('IGNF','274','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - ILES WALLIS, FUTUNA ET ALOFI','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - ILES WALLIS, FUTUNA ET ALOFI',-14.39,-13.16,-179.98,-176.3,0);
INSERT INTO "projected_crs" VALUES('IGNF','WGS84EQGPWF','Wallis et Futuna projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC9810433','IGNF','274',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','GEOPORTALWLF','Wallis et Futuna projection Geoportail',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC9810433','IGNF','274',NULL,0);
INSERT INTO "area" VALUES('IGNF','275','ILE D''UVEA (WALLIS) - UTM SUD FUSEAU 1','ILE D''UVEA (WALLIS) - UTM SUD FUSEAU 1',-13.42,-13.17,-176.3,-176.1,0);
INSERT INTO "projected_crs" VALUES('IGNF','WALL76UTM1S','Wallis (MOP 1976) UTM Sud fuseau 1',NULL,NULL,'EPSG','4499','IGNF','WALL76G','IGNF','PRC030144','IGNF','275',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','WALL78UTM1S','Wallis (MOP 1978) UTM Sud fuseau 1',NULL,NULL,'EPSG','4499','IGNF','WALL78G','IGNF','PRC030147','IGNF','275',NULL,0);
INSERT INTO "area" VALUES('IGNF','276','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - UTM NORD FUSEAU 30','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - UTM NORD FUSEAU 30',0,80,-6,0,0);
INSERT INTO "projected_crs" VALUES('IGNF','WGS72UTM30','WGS72 UTM fuseau 30',NULL,NULL,'EPSG','4499','IGNF','WGS72G','IGNF','PRC0230345','IGNF','276',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM30W72','WGS72 UTM fuseau 30',NULL,NULL,'EPSG','4499','IGNF','WGS72G','IGNF','PRC0230345','IGNF','276',NULL,0);
INSERT INTO "area" VALUES('IGNF','277','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - UTM NORD FUSEAU 31','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - UTM NORD FUSEAU 31',0,80,0,6,0);
INSERT INTO "projected_crs" VALUES('IGNF','WGS72UTM31','WGS72 UTM fuseau 31',NULL,NULL,'EPSG','4499','IGNF','WGS72G','IGNF','PRC0231346','IGNF','277',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM31W72','WGS72 UTM fuseau 31',NULL,NULL,'EPSG','4499','IGNF','WGS72G','IGNF','PRC0231346','IGNF','277',NULL,0);
INSERT INTO "area" VALUES('IGNF','278','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - UTM NORD FUSEAU 32','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - UTM NORD FUSEAU 32',0,80,6,12,0);
INSERT INTO "projected_crs" VALUES('IGNF','WGS72UTM32','WGS72 UTM fuseau 32',NULL,NULL,'EPSG','4499','IGNF','WGS72G','IGNF','PRC0232348','IGNF','278',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM32W72','WGS72 UTM fuseau 32',NULL,NULL,'EPSG','4499','IGNF','WGS72G','IGNF','PRC0232348','IGNF','278',NULL,0);
INSERT INTO "area" VALUES('IGNF','279','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - UTM SUD FUSEAU 1','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - UTM SUD FUSEAU 1',-80,0,-180,-174,0);
INSERT INTO "projected_crs" VALUES('IGNF','WGS72UTM1S','WGS72 UTM Sud Fuseau 1',NULL,NULL,'EPSG','4499','IGNF','WGS72G','IGNF','PRC0301545','IGNF','279',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','WGS84MILLGP','WGS84 PROJECTION MILLER GEOPORTAIL',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC7001567','IGNF','74',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','MILLER','WGS84 PROJECTION MILLER GEOPORTAIL',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC7001567','IGNF','74',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','WGS84UTM30','WGS84 UTM fuseau 30',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC0230353','IGNF','276',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM30W84','WGS84 UTM fuseau 30',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC0230353','IGNF','276',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','WGS84UTM31','WGS84 UTM fuseau 31',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC0231354','IGNF','277',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM31W84','WGS84 UTM fuseau 31',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC0231354','IGNF','277',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','WGS84UTM32','WGS84 UTM NORD FUSEAU 32',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC0232355','IGNF','278',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM32W84','WGS84 UTM NORD FUSEAU 32',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC0232355','IGNF','278',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','WGS84UTM1S','WGS84 UTM Sud Fuseau 1',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC0301550','IGNF','279',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM01SW84','WGS84 UTM Sud Fuseau 1',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC0301550','IGNF','279',NULL,0);
INSERT INTO "area" VALUES('IGNF','280','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - UTM SUD FUSEAU 39','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - UTM SUD FUSEAU 39',-80,0,48,54,0);
INSERT INTO "projected_crs" VALUES('IGNF','WGS84UTM39S','WGS84 UTM SUD FUSEAU 39',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC0339578','IGNF','280',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM39SW84','WGS84 UTM SUD FUSEAU 39',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC0339578','IGNF','280',NULL,0);
INSERT INTO "area" VALUES('IGNF','281','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - UTM SUD FUSEAU 42','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - UTM SUD FUSEAU 42',-80,0,66,72,0);
INSERT INTO "projected_crs" VALUES('IGNF','WGS84UTM42S','WGS84 UTM SUD FUSEAU 42',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC0342579','IGNF','281',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM42SW84','WGS84 UTM SUD FUSEAU 42',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC0342579','IGNF','281',NULL,0);
INSERT INTO "area" VALUES('IGNF','282','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - UTM SUD FUSEAU 43','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - UTM SUD FUSEAU 43',-80,0,72,78,0);
INSERT INTO "projected_crs" VALUES('IGNF','WGS84UTM43S','WGS84 UTM SUD FUSEAU 43',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC0343580','IGNF','282',NULL,0);
INSERT INTO "projected_crs" VALUES('IGNF','UTM43SW84','WGS84 UTM SUD FUSEAU 43',NULL,NULL,'EPSG','4499','IGNF','WGS84G','IGNF','PRC0343580','IGNF','282',NULL,0);
INSERT INTO "area" VALUES('IGNF','283','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - PSEUDO MERCATOR (POPULAR VISUALISATION)','PLANETE TERRE ET SON ENVIRONNEMENT PROCHE - PSEUDO MERCATOR (POPULAR VISUALISATION)',-85,85,-180,180,0);
INSERT INTO "projected_crs" VALUES('IGNF','WGS84WMSV','WGS84 WEB MERCATOR SPHERIQUE (VISUALISATION)',NULL,NULL,'EPSG','4400','IGNF','WGS84G','IGNF','PRC9601581','IGNF','283',NULL,0);
INSERT INTO "compound_crs" VALUES('IGNF','ATIGBONNE.BOURD','ATIG Bonne France Etat Major et NGF-BOURDALOUE',NULL,NULL,'IGNF','ATIGBONNE','IGNF','BOURD','IGNF','85',0);
INSERT INTO "compound_crs" VALUES('IGNF','ATIGBONNE.NGF84','ATIG Bonne France Etat Major et NGF-LALLEMAND',NULL,NULL,'IGNF','ATIGBONNE','IGNF','NGF84','IGNF','85',0);
INSERT INTO "compound_crs" VALUES('IGNF','ATIGG.BOURD','ATIG geographiques grades Paris (gr) et NGF-BOURDALOUE',NULL,NULL,'IGNF','ATIGG','IGNF','BOURD','IGNF','85',0);
INSERT INTO "compound_crs" VALUES('IGNF','ATIGG.NGF84','ATIG geographiques grades Paris (gr) et NGF-LALLEMAND',NULL,NULL,'IGNF','ATIGG','IGNF','NGF84','IGNF','85',0);
INSERT INTO "compound_crs" VALUES('IGNF','CAD97G.MAYO53','Cadastre 1997 geographiques (dms) et SHOM 1953 (MAYOTTE)',NULL,NULL,'IGNF','CAD97G','IGNF','MAYO53','IGNF','5',0);
INSERT INTO "compound_crs" VALUES('IGNF','CAD97UTM38S.MAYO53','Cadastre 1997 UTM Sud fuseau 38 et SHOM 1953 (MAYOTTE)',NULL,NULL,'IGNF','CAD97UTM38S','IGNF','MAYO53','IGNF','5',0);
INSERT INTO "compound_crs" VALUES('IGNF','MAYO50G.MAYO53','Combani triangulation IGN 1950 geographiques (dms) et SHOM 1953 (MAYOTTE)',NULL,NULL,'IGNF','MAYO50G','IGNF','MAYO53','IGNF','5',0);
INSERT INTO "compound_crs" VALUES('IGNF','MAYO50UTM38S.MAYO53','Combani UTM Sud fuseau 38 et SHOM 1953 (MAYOTTE)',NULL,NULL,'IGNF','MAYO50UTM38S','IGNF','MAYO53','IGNF','5',0);
INSERT INTO "compound_crs" VALUES('IGNF','CSG67G.GUYA77','CSG67 geographiques (dms) et NIVELLEMENT GENERAL DE GUYANE (NGG) 1977',NULL,NULL,'IGNF','CSG67G','IGNF','GUYA77','IGNF','10',0);
INSERT INTO "compound_crs" VALUES('IGNF','C67IG95G.GUYA77','CSG67 (IGN 1995) geographiques (dms) et NIVELLEMENT GENERAL DE GUYANE (NGG) 1977',NULL,NULL,'IGNF','C67IG95G','IGNF','GUYA77','IGNF','10',0);
INSERT INTO "compound_crs" VALUES('IGNF','C67IG95UTM21.GUYA77','CSG67(IGN 1995) UTM Nord fuseau 21 et NIVELLEMENT GENERAL DE GUYANE (NGG) 1977',NULL,NULL,'IGNF','C67IG95UTM21','IGNF','GUYA77','IGNF','170',0);
INSERT INTO "compound_crs" VALUES('IGNF','C67IG95UTM22.GUYA77','CSG67 (IGN 1995) UTM Nord fuseau 22 et NIVELLEMENT GENERAL DE GUYANE (NGG) 1977',NULL,NULL,'IGNF','C67IG95UTM22','IGNF','GUYA77','IGNF','171',0);
INSERT INTO "compound_crs" VALUES('IGNF','CSG67UTM21.GUYA77','CSG67 UTM Nord fuseau 21 et NIVELLEMENT GENERAL DE GUYANE (NGG) 1977',NULL,NULL,'IGNF','CSG67UTM21','IGNF','GUYA77','IGNF','170',0);
INSERT INTO "compound_crs" VALUES('IGNF','CSG67UTM22.GUYA77','CSG67 UTM Nord fuseau 22 et NIVELLEMENT GENERAL DE GUYANE (NGG) 1977',NULL,NULL,'IGNF','CSG67UTM22','IGNF','GUYA77','IGNF','171',0);
INSERT INTO "compound_crs" VALUES('IGNF','ED50G.IGN69','ED50 geographiques (dms) et NGF-IGN 1969',NULL,NULL,'IGNF','ED50G','IGNF','IGN69','IGNF','85',0);
INSERT INTO "compound_crs" VALUES('IGNF','ED50G.IGN78C','ED50 geographiques (dms) et NGF-IGN 1978',NULL,NULL,'IGNF','ED50G','IGNF','IGN78C','IGNF','86',0);
INSERT INTO "compound_crs" VALUES('IGNF','ED50G.NGF84','ED50 geographiques (dms) et NGF-LALLEMAND',NULL,NULL,'IGNF','ED50G','IGNF','NGF84','IGNF','85',0);
INSERT INTO "compound_crs" VALUES('IGNF','ED50G.NGC48','ED50 geographiques (dms) et NIVELLEMENT GENERAL DE LA CORSE (NGC)',NULL,NULL,'IGNF','ED50G','IGNF','NGC48','IGNF','86',0);
INSERT INTO "area" VALUES('IGNF','284','FRANCE CONTINENTALE (CORSE EXCLUE) - UTM NORD FUSEAU 30','FRANCE CONTINENTALE (CORSE EXCLUE) - UTM NORD FUSEAU 30',42,51.5,-5.5,0,0);
INSERT INTO "compound_crs" VALUES('IGNF','ED50UTM30.IGN69','ED50 UTM fuseau 30 et NGF-IGN 1969',NULL,NULL,'IGNF','ED50UTM30','IGNF','IGN69','IGNF','284',0);
INSERT INTO "compound_crs" VALUES('IGNF','ED50UTM30.NGF84','ED50 UTM fuseau 30 et NGF-LALLEMAND',NULL,NULL,'IGNF','ED50UTM30','IGNF','NGF84','IGNF','284',0);
INSERT INTO "area" VALUES('IGNF','285','FRANCE CONTINENTALE (CORSE EXCLUE) - UTM NORD FUSEAU 32','FRANCE CONTINENTALE (CORSE EXCLUE) - UTM NORD FUSEAU 32',42,51.5,6,8.5,0);
INSERT INTO "compound_crs" VALUES('IGNF','ED50UTM32.IGN69','ED50 UTM fuseau 32 et NGF-IGN 1969',NULL,NULL,'IGNF','ED50UTM32','IGNF','IGN69','IGNF','285',0);
INSERT INTO "compound_crs" VALUES('IGNF','ED50UTM32.IGN78C','ED50 UTM fuseau 32 et NGF-IGN 1978',NULL,NULL,'IGNF','ED50UTM32','IGNF','IGN78C','IGNF','86',0);
INSERT INTO "compound_crs" VALUES('IGNF','ED50UTM32.NGF84','ED50 UTM fuseau 32 et NGF-LALLEMAND',NULL,NULL,'IGNF','ED50UTM32','IGNF','NGF84','IGNF','285',0);
INSERT INTO "compound_crs" VALUES('IGNF','ED50UTM32.NGC48','ED50 UTM fuseau 32 et NIVELLEMENT GENERAL DE LA CORSE (NGC)',NULL,NULL,'IGNF','ED50UTM32','IGNF','NGC48','IGNF','86',0);
INSERT INTO "area" VALUES('IGNF','286','FRANCE CONTINENTALE (CORSE EXCLUE) - UTM NORD FUSEAU 31','FRANCE CONTINENTALE (CORSE EXCLUE) - UTM NORD FUSEAU 31',42,51.5,0,6,0);
INSERT INTO "compound_crs" VALUES('IGNF','ED50UTM31.IGN69','ED50 UTM NORD FUSEAU 31 et NGF-IGN 1969',NULL,NULL,'IGNF','ED50UTM31','IGNF','IGN69','IGNF','286',0);
INSERT INTO "compound_crs" VALUES('IGNF','ED50UTM31.NGF84','ED50 UTM NORD FUSEAU 31 et NGF-LALLEMAND',NULL,NULL,'IGNF','ED50UTM31','IGNF','NGF84','IGNF','286',0);
INSERT INTO "compound_crs" VALUES('IGNF','ETRS89G.EVRF2000','ETRS89 geographiques (dms) et EVRF2000 (UELN-95/98)(EUROPEAN VERTICAL REFERENCE FRAME)',NULL,NULL,'IGNF','ETRS89G','IGNF','EVRF2000','IGNF','77',0);
INSERT INTO "compound_crs" VALUES('IGNF','ETRS89LAEA.EVRF2000','ETRS89 Lambert Azimutal Equal Area et EVRF2000 (UELN-95/98)(EUROPEAN VERTICAL REFERENCE FRAME)',NULL,NULL,'IGNF','ETRS89LAEA','IGNF','EVRF2000','IGNF','77',0);
INSERT INTO "compound_crs" VALUES('IGNF','ETRS89LCC.EVRF2000','ETRS89 Lambert Conformal Conic et EVRF2000 (UELN-95/98)(EUROPEAN VERTICAL REFERENCE FRAME)',NULL,NULL,'IGNF','ETRS89LCC','IGNF','EVRF2000','IGNF','77',0);
INSERT INTO "area" VALUES('IGNF','287','EUROPE (RESEAU VERTICAL UNIFIE) - UTM NORD FUSEAU 29','EUROPE (RESEAU VERTICAL UNIFIE) - UTM NORD FUSEAU 29',36,71.2,-10,-6,0);
INSERT INTO "compound_crs" VALUES('IGNF','ETRS89UTM29.EVRF2000','ETRS89 UTM Nord fuseau 29 et EVRF2000 (UELN-95/98)(EUROPEAN VERTICAL REFERENCE FRAME)',NULL,NULL,'IGNF','ETRS89UTM29','IGNF','EVRF2000','IGNF','287',0);
INSERT INTO "area" VALUES('IGNF','288','EUROPE (RESEAU VERTICAL UNIFIE) - UTM NORD FUSEAU 30','EUROPE (RESEAU VERTICAL UNIFIE) - UTM NORD FUSEAU 30',36,71.2,-6,0,0);
INSERT INTO "compound_crs" VALUES('IGNF','ETRS89UTM30.EVRF2000','ETRS89 UTM Nord fuseau 30 et EVRF2000 (UELN-95/98)(EUROPEAN VERTICAL REFERENCE FRAME)',NULL,NULL,'IGNF','ETRS89UTM30','IGNF','EVRF2000','IGNF','288',0);
INSERT INTO "area" VALUES('IGNF','289','EUROPE (RESEAU VERTICAL UNIFIE) - UTM NORD FUSEAU 31','EUROPE (RESEAU VERTICAL UNIFIE) - UTM NORD FUSEAU 31',36,71.2,0,6,0);
INSERT INTO "compound_crs" VALUES('IGNF','ETRS89UTM31.EVRF2000','ETRS89 UTM Nord fuseau 31 et EVRF2000 (UELN-95/98)(EUROPEAN VERTICAL REFERENCE FRAME)',NULL,NULL,'IGNF','ETRS89UTM31','IGNF','EVRF2000','IGNF','289',0);
INSERT INTO "area" VALUES('IGNF','290','EUROPE (RESEAU VERTICAL UNIFIE) - UTM NORD FUSEAU 32','EUROPE (RESEAU VERTICAL UNIFIE) - UTM NORD FUSEAU 32',36,71.2,6,12,0);
INSERT INTO "compound_crs" VALUES('IGNF','ETRS89UTM32.EVRF2000','ETRS89 UTM Nord fuseau 32 et EVRF2000 (UELN-95/98)(EUROPEAN VERTICAL REFERENCE FRAME)',NULL,NULL,'IGNF','ETRS89UTM32','IGNF','EVRF2000','IGNF','290',0);
INSERT INTO "area" VALUES('IGNF','291','EUROPE (RESEAU VERTICAL UNIFIE) - UTM NORD FUSEAU 33','EUROPE (RESEAU VERTICAL UNIFIE) - UTM NORD FUSEAU 33',36,71.2,12,18,0);
INSERT INTO "compound_crs" VALUES('IGNF','ETRS89UTM33.EVRF2000','ETRS89 UTM Nord fuseau 33 et EVRF2000 (UELN-95/98)(EUROPEAN VERTICAL REFERENCE FRAME)',NULL,NULL,'IGNF','ETRS89UTM33','IGNF','EVRF2000','IGNF','291',0);
INSERT INTO "area" VALUES('IGNF','292','EUROPE (RESEAU VERTICAL UNIFIE) - UTM NORD FUSEAU 34','EUROPE (RESEAU VERTICAL UNIFIE) - UTM NORD FUSEAU 34',36,71.2,18,24,0);
INSERT INTO "compound_crs" VALUES('IGNF','ETRS89UTM34.EVRF2000','ETRS89 UTM Nord fuseau 34 et EVRF2000 (UELN-95/98)(EUROPEAN VERTICAL REFERENCE FRAME)',NULL,NULL,'IGNF','ETRS89UTM34','IGNF','EVRF2000','IGNF','292',0);
INSERT INTO "area" VALUES('IGNF','293','EUROPE (RESEAU VERTICAL UNIFIE) - UTM NORD FUSEAU 35','EUROPE (RESEAU VERTICAL UNIFIE) - UTM NORD FUSEAU 35',36,71.2,24,30,0);
INSERT INTO "compound_crs" VALUES('IGNF','ETRS89UTM35.EVRF2000','ETRS89 UTM Nord fuseau 35 et EVRF2000 (UELN-95/98)(EUROPEAN VERTICAL REFERENCE FRAME)',NULL,NULL,'IGNF','ETRS89UTM35','IGNF','EVRF2000','IGNF','293',0);
INSERT INTO "area" VALUES('IGNF','294','EUROPE (RESEAU VERTICAL UNIFIE) - UTM NORD FUSEAU 36','EUROPE (RESEAU VERTICAL UNIFIE) - UTM NORD FUSEAU 36',36,71.2,30,32,0);
INSERT INTO "compound_crs" VALUES('IGNF','ETRS89UTM36.EVRF2000','ETRS89 UTM Nord fuseau 36 et EVRF2000 (UELN-95/98)(EUROPEAN VERTICAL REFERENCE FRAME)',NULL,NULL,'IGNF','ETRS89UTM36','IGNF','EVRF2000','IGNF','294',0);
INSERT INTO "compound_crs" VALUES('IGNF','GLOR77G.GLOR77','Glorieuses geographiques (dms) et SHOM 1977 (ILES GLORIEUSES - CANAL DE MOZAMBIQUE)',NULL,NULL,'IGNF','GLOR77G','IGNF','GLOR77','IGNF','20',0);
INSERT INTO "compound_crs" VALUES('IGNF','GLOR77MD.GLOR77','Glorieuses Mercator directe et SHOM 1977 (ILES GLORIEUSES - CANAL DE MOZAMBIQUE)',NULL,NULL,'IGNF','GLOR77MD','IGNF','GLOR77','IGNF','20',0);
INSERT INTO "compound_crs" VALUES('IGNF','GLOR77UTM38S.GLOR77','GLORIEUSES MHG 1977 UTM SUD FUSEAU 38 et SHOM 1977 (ILES GLORIEUSES - CANAL DE MOZAMBIQUE)',NULL,NULL,'IGNF','GLOR77UTM38S','IGNF','GLOR77','IGNF','20',0);
INSERT INTO "compound_crs" VALUES('IGNF','GUADFMG.GUAD88SB','Guadeloupe Fort-Marigot geographiques (dms) et IGN 1988 SB (GUADELOUPE / SAINT-BARTHELEMY)',NULL,NULL,'IGNF','GUADFMG','IGNF','GUAD88SB','IGNF','82',0);
INSERT INTO "compound_crs" VALUES('IGNF','GUADFMG.GUAD88SM','Guadeloupe Fort-Marigot geographiques (dms) et IGN 1988 SM (GUADELOUPE / SAINT-MARTIN)',NULL,NULL,'IGNF','GUADFMG','IGNF','GUAD88SM','IGNF','83',0);
INSERT INTO "compound_crs" VALUES('IGNF','GUADFMUTM20.GUAD88SB','Guadeloupe Fort-Marigot UTM Nord fuseau 20 et IGN 1988 SB (GUADELOUPE / SAINT-BARTHELEMY)',NULL,NULL,'IGNF','GUADFMUTM20','IGNF','GUAD88SB','IGNF','82',0);
INSERT INTO "compound_crs" VALUES('IGNF','GUADFMUTM20.GUAD88SM','Guadeloupe Fort-Marigot UTM Nord fuseau 20 et IGN 1988 SM (GUADELOUPE / SAINT-MARTIN)',NULL,NULL,'IGNF','GUADFMUTM20','IGNF','GUAD88SM','IGNF','83',0);
INSERT INTO "compound_crs" VALUES('IGNF','GUADANNG.GUAD88','Guadeloupe Sainte-Anne geographiques (dms) et IGN 1988 (GUADELOUPE)',NULL,NULL,'IGNF','GUADANNG','IGNF','GUAD88','IGNF','79',0);
INSERT INTO "compound_crs" VALUES('IGNF','GUADANNG.GUAD88LS','Guadeloupe Sainte-Anne geographiques (dms) et IGN 1988 LS (GUADELOUPE / LES SAINTES)',NULL,NULL,'IGNF','GUADANNG','IGNF','GUAD88LS','IGNF','80',0);
INSERT INTO "compound_crs" VALUES('IGNF','GUADANNG.GUAD88MG','Guadeloupe Sainte-Anne geographiques (dms) et IGN 1988 MG (GUADELOUPE / MARIE-GALANTE)',NULL,NULL,'IGNF','GUADANNG','IGNF','GUAD88MG','IGNF','81',0);
INSERT INTO "compound_crs" VALUES('IGNF','GUADANNG.GUAD92LD','Guadeloupe Sainte-Anne geographiques (dms) et IGN 1992 LD (GUADELOUPE / LA DESIRADE)',NULL,NULL,'IGNF','GUADANNG','IGNF','GUAD92LD','IGNF','84',0);
INSERT INTO "compound_crs" VALUES('IGNF','GUADANNUTM20.GUAD88','Guadeloupe Ste Anne UTM Nord fuseau 20 et IGN 1988 (GUADELOUPE)',NULL,NULL,'IGNF','GUADANNUTM20','IGNF','GUAD88','IGNF','79',0);
INSERT INTO "compound_crs" VALUES('IGNF','GUADANNUTM20.GUAD88LS','Guadeloupe Ste Anne UTM Nord fuseau 20 et IGN 1988 LS (GUADELOUPE / LES SAINTES)',NULL,NULL,'IGNF','GUADANNUTM20','IGNF','GUAD88LS','IGNF','80',0);
INSERT INTO "compound_crs" VALUES('IGNF','GUADANNUTM20.GUAD88MG','Guadeloupe Ste Anne UTM Nord fuseau 20 et IGN 1988 MG (GUADELOUPE / MARIE-GALANTE)',NULL,NULL,'IGNF','GUADANNUTM20','IGNF','GUAD88MG','IGNF','81',0);
INSERT INTO "compound_crs" VALUES('IGNF','GUADANNUTM20.GUAD92LD','Guadeloupe Ste Anne UTM Nord fuseau 20 et IGN 1992 LD (GUADELOUPE / LA DESIRADE)',NULL,NULL,'IGNF','GUADANNUTM20','IGNF','GUAD92LD','IGNF','84',0);
INSERT INTO "compound_crs" VALUES('IGNF','TAHAA53G.BORA01','IGN53 Societe geographiques (dms) et BORA_SAU 2001',NULL,NULL,'IGNF','TAHAA53G','IGNF','BORA01','IGNF','76',0);
INSERT INTO "compound_crs" VALUES('IGNF','TAHAA53G.HUAH01','IGN53 Societe geographiques (dms) et HUAHINE_SAU 2001',NULL,NULL,'IGNF','TAHAA53G','IGNF','HUAH01','IGNF','51',0);
INSERT INTO "compound_crs" VALUES('IGNF','TAHAA53G.RAIA01','IGN53 Societe geographiques (dms) et RAIATEA_SAU 2001',NULL,NULL,'IGNF','TAHAA53G','IGNF','RAIA01','IGNF','51',0);
INSERT INTO "compound_crs" VALUES('IGNF','TAHAA53UTM5S.BORA01','IGN53 Societe UTM Sud fuseau 5 et BORA_SAU 2001',NULL,NULL,'IGNF','TAHAA53UTM5S','IGNF','BORA01','IGNF','76',0);
INSERT INTO "compound_crs" VALUES('IGNF','TAHAA53UTM5S.HUAH01','IGN53 Societe UTM Sud fuseau 5 et HUAHINE_SAU 2001',NULL,NULL,'IGNF','TAHAA53UTM5S','IGNF','HUAH01','IGNF','51',0);
INSERT INTO "compound_crs" VALUES('IGNF','TAHAA53UTM5S.RAIA01','IGN53 Societe UTM Sud fuseau 5 et RAIATEA_SAU 2001',NULL,NULL,'IGNF','TAHAA53UTM5S','IGNF','RAIA01','IGNF','51',0);
INSERT INTO "compound_crs" VALUES('IGNF','IGN72G.NCAL69','IGN72 geographiques (dms) et NIVELLEMENT GENERAL DE NOUVELLE-CALEDONIE (NGNC)',NULL,NULL,'IGNF','IGN72G','IGNF','NCAL69','IGNF','21',0);
INSERT INTO "compound_crs" VALUES('IGNF','IGN72UTM58S.NCAL69','IGN72 UTM Sud fuseau 58 et NIVELLEMENT GENERAL DE NOUVELLE-CALEDONIE (NGNC)',NULL,NULL,'IGNF','IGN72UTM58S','IGNF','NCAL69','IGNF','21',0);
INSERT INTO "compound_crs" VALUES('IGNF','KERG62G.KERG62','Kerguelen geographiques (dms) et IGN 1962 (KERGUELEN)',NULL,NULL,'IGNF','KERG62G','IGNF','KERG62','IGNF','34',0);
INSERT INTO "compound_crs" VALUES('IGNF','KERG62UTM42S.KERG62','KERGUELEN K0 IGN 1962 UTM SUD FUSEAU 42 et IGN 1962 (KERGUELEN)',NULL,NULL,'IGNF','KERG62UTM42S','IGNF','KERG62','IGNF','34',0);
INSERT INTO "compound_crs" VALUES('IGNF','LIFOU56G.LIFOU91','Lifou IGN 56 geographiques (dms) et NIVELLEMENT GENERAL DE LIFOU (IGN 1991 LF)',NULL,NULL,'IGNF','LIFOU56G','IGNF','LIFOU91','IGNF','35',0);
INSERT INTO "compound_crs" VALUES('IGNF','LIFOU56UT58S.LIFOU91','Lifou IGN 56 UTM Sud fuseau 58 et NIVELLEMENT GENERAL DE LIFOU (IGN 1991 LF)',NULL,NULL,'IGNF','LIFOU56UT58S','IGNF','LIFOU91','IGNF','35',0);
INSERT INTO "compound_crs" VALUES('IGNF','MARE53G.MARE91','Mare IGN53 geographiques (dms) et NIVELLEMENT GENERAL DE MARE (IGN 1991 MR)',NULL,NULL,'IGNF','MARE53G','IGNF','MARE91','IGNF','38',0);
INSERT INTO "compound_crs" VALUES('IGNF','MARE53UTM58S.MARE91','Mare IGN53 UTM Sud fuseau 58 et NIVELLEMENT GENERAL DE MARE (IGN 1991 MR)',NULL,NULL,'IGNF','MARE53UTM58S','IGNF','MARE91','IGNF','212',0);
INSERT INTO "compound_crs" VALUES('IGNF','MARTFDG.MART87','Martinique Fort-Desaix geographiques (dms) et IGN 1987 (MARTINIQUE)',NULL,NULL,'IGNF','MARTFDG','IGNF','MART87','IGNF','39',0);
INSERT INTO "compound_crs" VALUES('IGNF','MARTFDUTM20.MART87','Martinique Fort-Desaix UTM Nord fuseau 20 et IGN 1987 (MARTINIQUE)',NULL,NULL,'IGNF','MARTFDUTM20','IGNF','MART87','IGNF','39',0);
INSERT INTO "compound_crs" VALUES('IGNF','MAUPITIG.MAUPITI01','Maupiti (MOP 1983) geographiques (dms) et MAUPITI_SAU 2001',NULL,NULL,'IGNF','MAUPITIG','IGNF','MAUPITI01','IGNF','40',0);
INSERT INTO "compound_crs" VALUES('IGNF','MAUPITIUTM5S.MAUPITI01','Maupiti (MOP 1983) UTM Sud fuseau 5 et MAUPITI_SAU 2001',NULL,NULL,'IGNF','MAUPITIUTM5S','IGNF','MAUPITI01','IGNF','40',0);
INSERT INTO "compound_crs" VALUES('IGNF','MOOREA87G.MOOREA81','Moorea 1987 geographiques (dms) et MOOREA 1981 (MOOREA_SAU 2001)',NULL,NULL,'IGNF','MOOREA87G','IGNF','MOOREA81','IGNF','42',0);
INSERT INTO "compound_crs" VALUES('IGNF','MOORE87UTM6S.MOOREA81','Moorea 1987 UTM Sud fuseau 6 et MOOREA 1981 (MOOREA_SAU 2001)',NULL,NULL,'IGNF','MOORE87UTM6S','IGNF','MOOREA81','IGNF','42',0);
INSERT INTO "compound_crs" VALUES('IGNF','NEA74G.NCAL69','NEA74 NOUMEA geographiques (dms) et NIVELLEMENT GENERAL DE NOUVELLE-CALEDONIE (NGNC)',NULL,NULL,'IGNF','NEA74G','IGNF','NCAL69','IGNF','44',0);
INSERT INTO "compound_crs" VALUES('IGNF','NEA74LBTNM2.NCAL69','NEA74 NOUMEA Lambert Noumea 2 et NIVELLEMENT GENERAL DE NOUVELLE-CALEDONIE (NGNC)',NULL,NULL,'IGNF','NEA74LBTNM2','IGNF','NCAL69','IGNF','44',0);
INSERT INTO "compound_crs" VALUES('IGNF','LURESGKL.NNLUX','NOUVELLE TRIANGULATION DU DUCHE DU LUXEMBOURG GAUSS KRUGER LUXEMBOURG et NIVELLEMENT GENERAL DU LUXEMBOURG',NULL,NULL,'IGNF','LURESGKL','IGNF','NNLUX','IGNF','45',0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFPGRAD.BOURD','NTF geographiques Paris (gr) et NGF-BOURDALOUE',NULL,NULL,'IGNF','NTFPGRAD','IGNF','BOURD','IGNF','85',0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFPGRAD.IGN69','NTF geographiques Paris (gr) et NGF-IGN 1969',NULL,NULL,'IGNF','NTFPGRAD','IGNF','IGN69','IGNF','85',0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFPGRAD.IGN78C','NTF geographiques Paris (gr) et NGF-IGN 1978',NULL,NULL,'IGNF','NTFPGRAD','IGNF','IGN78C','IGNF','86',0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFPGRAD.NGF84','NTF geographiques Paris (gr) et NGF-LALLEMAND',NULL,NULL,'IGNF','NTFPGRAD','IGNF','NGF84','IGNF','85',0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFPGRAD.NGC48','NTF geographiques Paris (gr) et NIVELLEMENT GENERAL DE LA CORSE (NGC)',NULL,NULL,'IGNF','NTFPGRAD','IGNF','NGC48','IGNF','86',0);
INSERT INTO "area" VALUES('IGNF','295','FRANCE CONTINENTALE (CORSE EXCLUE) - LAMBERT I CARTO','FRANCE CONTINENTALE (CORSE EXCLUE) - LAMBERT I CARTO',48.1498888194584,51.2999493112821,-4.05379920354209,8.5,0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB1C.IGN69','NTF Lambert I carto et NGF-IGN 1969',NULL,NULL,'IGNF','NTFLAMB1C','IGNF','IGN69','IGNF','295',0);
INSERT INTO "area" VALUES('IGNF','296','FRANCE CONTINENTALE (CORSE EXCLUE) - LAMBERT I NORD','FRANCE CONTINENTALE (CORSE EXCLUE) - LAMBERT I NORD',48.1498888194584,51.2999493112821,-4.05379920354209,8.5,0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB1.BOURD','NTF Lambert I et NGF-BOURDALOUE',NULL,NULL,'IGNF','NTFLAMB1','IGNF','BOURD','IGNF','296',0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB1.IGN69','NTF Lambert I et NGF-IGN 1969',NULL,NULL,'IGNF','NTFLAMB1','IGNF','IGN69','IGNF','296',0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB1.NGF84','NTF Lambert I et NGF-LALLEMAND',NULL,NULL,'IGNF','NTFLAMB1','IGNF','NGF84','IGNF','296',0);
INSERT INTO "area" VALUES('IGNF','297','FRANCE CONTINENTALE (CORSE EXCLUE) - LAMBERT II CARTO','FRANCE CONTINENTALE (CORSE EXCLUE) - LAMBERT II CARTO',45.4499226513968,48.1499588287054,-4.05373473460064,8.5,0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB2C.IGN69','NTF Lambert II carto et NGF-IGN 1969',NULL,NULL,'IGNF','NTFLAMB2C','IGNF','IGN69','IGNF','297',0);
INSERT INTO "area" VALUES('IGNF','298','FRANCE CONTINENTALE (CORSE EXCLUE) - LAMBERT II ETENDU','FRANCE CONTINENTALE (CORSE EXCLUE) - LAMBERT II ETENDU',42,50.8499489398734,-4.05378927743516,8.5,0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB2E.BOURD','NTF Lambert II etendu et NGF-BOURDALOUE',NULL,NULL,'IGNF','NTFLAMB2E','IGNF','BOURD','IGNF','298',0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB2E.IGN69','NTF Lambert II etendu et NGF-IGN 1969',NULL,NULL,'IGNF','NTFLAMB2E','IGNF','IGN69','IGNF','298',0);
INSERT INTO "area" VALUES('IGNF','299','CORSE - LAMBERT II ETENDU','CORSE - LAMBERT II ETENDU',41.3100751867312,43.5,8,10,0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB2E.IGN78C','NTF Lambert II etendu et NGF-IGN 1978',NULL,NULL,'IGNF','NTFLAMB2E','IGNF','IGN78C','IGNF','299',0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB2E.NGF84','NTF Lambert II etendu et NGF-LALLEMAND',NULL,NULL,'IGNF','NTFLAMB2E','IGNF','NGF84','IGNF','298',0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB2E.NGC48','NTF Lambert II etendu et NIVELLEMENT GENERAL DE LA CORSE (NGC)',NULL,NULL,'IGNF','NTFLAMB2E','IGNF','NGC48','IGNF','299',0);
INSERT INTO "area" VALUES('IGNF','300','FRANCE CONTINENTALE (CORSE EXCLUE) - LAMBERT II CENTRE','FRANCE CONTINENTALE (CORSE EXCLUE) - LAMBERT II CENTRE',45.4499226513968,48.1499588287054,-4.05373473460064,8.5,0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB2.BOURD','NTF Lambert II et NGF-BOURDALOUE',NULL,NULL,'IGNF','NTFLAMB2','IGNF','BOURD','IGNF','300',0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB2.IGN69','NTF Lambert II et NGF-IGN 1969',NULL,NULL,'IGNF','NTFLAMB2','IGNF','IGN69','IGNF','300',0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB2.NGF84','NTF Lambert II et NGF-LALLEMAND',NULL,NULL,'IGNF','NTFLAMB2','IGNF','NGF84','IGNF','300',0);
INSERT INTO "area" VALUES('IGNF','301','FRANCE CONTINENTALE (CORSE EXCLUE) - LAMBERT III CARTO','FRANCE CONTINENTALE (CORSE EXCLUE) - LAMBERT III CARTO',42.2999888396489,45.4499896606067,-4.05368768512203,8.5,0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB3C.IGN69','NTF Lambert III carto et NGF-IGN 1969',NULL,NULL,'IGNF','NTFLAMB3C','IGNF','IGN69','IGNF','301',0);
INSERT INTO "area" VALUES('IGNF','302','FRANCE CONTINENTALE (CORSE EXCLUE) - LAMBERT III SUD','FRANCE CONTINENTALE (CORSE EXCLUE) - LAMBERT III SUD',42.2999888396489,45.4499896606067,-4.05368768512203,8.5,0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB3.BOURD','NTF Lambert III et NGF-BOURDALOUE',NULL,NULL,'IGNF','NTFLAMB3','IGNF','BOURD','IGNF','302',0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB3.IGN69','NTF Lambert III et NGF-IGN 1969',NULL,NULL,'IGNF','NTFLAMB3','IGNF','IGN69','IGNF','302',0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB3.NGF84','NTF Lambert III et NGF-LALLEMAND',NULL,NULL,'IGNF','NTFLAMB3','IGNF','NGF84','IGNF','302',0);
INSERT INTO "area" VALUES('IGNF','303','CORSE - LAMBERT IV CARTO','CORSE - LAMBERT IV CARTO',41.3100829886572,43.0200472881681,8,10,0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB4C.IGN78C','NTF Lambert IV carto et NGF-IGN 1978',NULL,NULL,'IGNF','NTFLAMB4C','IGNF','IGN78C','IGNF','303',0);
INSERT INTO "area" VALUES('IGNF','304','CORSE - LAMBERT IV CORSE','CORSE - LAMBERT IV CORSE',41.3100829886572,43.0200472881681,8,10,0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB4.IGN78C','NTF Lambert IV et NGF-IGN 1978',NULL,NULL,'IGNF','NTFLAMB4','IGNF','IGN78C','IGNF','304',0);
INSERT INTO "compound_crs" VALUES('IGNF','NTFLAMB4.NGC48','NTF Lambert IV et NIVELLEMENT GENERAL DE LA CORSE (NGC)',NULL,NULL,'IGNF','NTFLAMB4','IGNF','NGC48','IGNF','304',0);
INSERT INTO "compound_crs" VALUES('IGNF','PDN92GAUSSL.REUN89','Piton des Neiges (1992) Gauss Laborde Reunion et IGN 1989 (REUNION)',NULL,NULL,'IGNF','PDN92GAUSSL','IGNF','REUN89','IGNF','230',0);
INSERT INTO "compound_crs" VALUES('IGNF','PDN08GAUSSL.REUN89','Piton des Neiges (2008) Gauss Laborde Reunion et IGN 1989 (REUNION)',NULL,NULL,'IGNF','PDN08GAUSSL','IGNF','REUN89','IGNF','230',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGWF96GEO.FUTUNA1997','RESEAU GEODESIQUE DE WALLIS ET FUTUNA 1996 GEOGRAPHIQUE DMS et NGWF ILES HORN (FUTUNA ET ALOFI)',NULL,NULL,'IGNF','RGWF96G','IGNF','FUTUNA1997','IGNF','87',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGWF96GEO.WALLIS96','RESEAU GEODESIQUE DE WALLIS ET FUTUNA 1996 GEOGRAPHIQUE DMS et NGWF WALLIS (MOP 1996)',NULL,NULL,'IGNF','RGWF96G','IGNF','WALLIS96','IGNF','73',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGWF96UTM1S.FUTUNA1997','RESEAU GEODESIQUE DE WALLIS ET FUTUNA 1996 UTM SUD FUSEAU 1 et NGWF ILES HORN (FUTUNA ET ALOFI)',NULL,NULL,'IGNF','RGWF96UTM1S','IGNF','FUTUNA1997','IGNF','87',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGWF96UTM1S.WALLIS96','RESEAU GEODESIQUE DE WALLIS ET FUTUNA 1996 UTM SUD FUSEAU 1 et NGWF WALLIS (MOP 1996)',NULL,NULL,'IGNF','RGWF96UTM1S','IGNF','WALLIS96','IGNF','73',0);
INSERT INTO "compound_crs" VALUES('IGNF','REUN49GAUSSL.REUN89','Reunion Piton des Neiges Gauss Laborde et IGN 1989 (REUNION)',NULL,NULL,'IGNF','REUN49GAUSSL','IGNF','REUN89','IGNF','230',0);
INSERT INTO "compound_crs" VALUES('IGNF','REUN49G.REUN89','Reunion Piton des Neiges geographiques (dms) et IGN 1989 (REUNION)',NULL,NULL,'IGNF','REUN49G','IGNF','REUN89','IGNF','55',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09GDD.MART87','RGAF09 geographiques (dd) et IGN 1987 (MARTINIQUE)',NULL,NULL,'IGNF','RGAF09GDD','IGNF','MART87','IGNF','39',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09GDD.GUAD88','RGAF09 geographiques (dd) et IGN 1988 (GUADELOUPE)',NULL,NULL,'IGNF','RGAF09GDD','IGNF','GUAD88','IGNF','79',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09GDD.GUAD88LS','RGAF09 geographiques (dd) et IGN 1988 LS (GUADELOUPE / LES SAINTES)',NULL,NULL,'IGNF','RGAF09GDD','IGNF','GUAD88LS','IGNF','80',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09GDD.GUAD88MG','RGAF09 geographiques (dd) et IGN 1988 MG (GUADELOUPE / MARIE-GALANTE)',NULL,NULL,'IGNF','RGAF09GDD','IGNF','GUAD88MG','IGNF','81',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09GDD.GUAD88SB','RGAF09 geographiques (dd) et IGN 1988 SB (GUADELOUPE / SAINT-BARTHELEMY)',NULL,NULL,'IGNF','RGAF09GDD','IGNF','GUAD88SB','IGNF','82',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09GDD.GUAD88SM','RGAF09 geographiques (dd) et IGN 1988 SM (GUADELOUPE / SAINT-MARTIN)',NULL,NULL,'IGNF','RGAF09GDD','IGNF','GUAD88SM','IGNF','83',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09GDD.GUAD92LD','RGAF09 geographiques (dd) et IGN 1992 LD (GUADELOUPE / LA DESIRADE)',NULL,NULL,'IGNF','RGAF09GDD','IGNF','GUAD92LD','IGNF','84',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09GDD.GUAD2008LD','RGAF09 geographiques (dd) et IGN 2008 LD (GUADELOUPE / LA DESIRADE)',NULL,NULL,'IGNF','RGAF09GDD','IGNF','GUAD2008LD','IGNF','84',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09G.MART87','RGAF09 geographiques (dms) et IGN 1987 (MARTINIQUE)',NULL,NULL,'IGNF','RGAF09G','IGNF','MART87','IGNF','39',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09G.GUAD88','RGAF09 geographiques (dms) et IGN 1988 (GUADELOUPE)',NULL,NULL,'IGNF','RGAF09G','IGNF','GUAD88','IGNF','79',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09G.GUAD88LS','RGAF09 geographiques (dms) et IGN 1988 LS (GUADELOUPE / LES SAINTES)',NULL,NULL,'IGNF','RGAF09G','IGNF','GUAD88LS','IGNF','80',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09G.GUAD88MG','RGAF09 geographiques (dms) et IGN 1988 MG (GUADELOUPE / MARIE-GALANTE)',NULL,NULL,'IGNF','RGAF09G','IGNF','GUAD88MG','IGNF','81',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09G.GUAD88SB','RGAF09 geographiques (dms) et IGN 1988 SB (GUADELOUPE / SAINT-BARTHELEMY)',NULL,NULL,'IGNF','RGAF09G','IGNF','GUAD88SB','IGNF','82',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09G.GUAD88SM','RGAF09 geographiques (dms) et IGN 1988 SM (GUADELOUPE / SAINT-MARTIN)',NULL,NULL,'IGNF','RGAF09G','IGNF','GUAD88SM','IGNF','83',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09G.GUAD92LD','RGAF09 geographiques (dms) et IGN 1992 LD (GUADELOUPE / LA DESIRADE)',NULL,NULL,'IGNF','RGAF09G','IGNF','GUAD92LD','IGNF','84',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09G.GUAD2008LD','RGAF09 geographiques (dms) et IGN 2008 LD (GUADELOUPE / LA DESIRADE)',NULL,NULL,'IGNF','RGAF09G','IGNF','GUAD2008LD','IGNF','84',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09UTM20.MART87','RGAF09 UTM Nord Fuseau 20 et IGN 1987 (MARTINIQUE)',NULL,NULL,'IGNF','RGAF09UTM20','IGNF','MART87','IGNF','39',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09UTM20.GUAD88','RGAF09 UTM Nord Fuseau 20 et IGN 1988 (GUADELOUPE)',NULL,NULL,'IGNF','RGAF09UTM20','IGNF','GUAD88','IGNF','79',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09UTM20.GUAD88LS','RGAF09 UTM Nord Fuseau 20 et IGN 1988 LS (GUADELOUPE / LES SAINTES)',NULL,NULL,'IGNF','RGAF09UTM20','IGNF','GUAD88LS','IGNF','80',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09UTM20.GUAD88MG','RGAF09 UTM Nord Fuseau 20 et IGN 1988 MG (GUADELOUPE / MARIE-GALANTE)',NULL,NULL,'IGNF','RGAF09UTM20','IGNF','GUAD88MG','IGNF','81',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09UTM20.GUAD88SB','RGAF09 UTM Nord Fuseau 20 et IGN 1988 SB (GUADELOUPE / SAINT-BARTHELEMY)',NULL,NULL,'IGNF','RGAF09UTM20','IGNF','GUAD88SB','IGNF','82',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09UTM20.GUAD88SM','RGAF09 UTM Nord Fuseau 20 et IGN 1988 SM (GUADELOUPE / SAINT-MARTIN)',NULL,NULL,'IGNF','RGAF09UTM20','IGNF','GUAD88SM','IGNF','83',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09UTM20.GUAD92LD','RGAF09 UTM Nord Fuseau 20 et IGN 1992 LD (GUADELOUPE / LA DESIRADE)',NULL,NULL,'IGNF','RGAF09UTM20','IGNF','GUAD92LD','IGNF','84',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGAF09UTM20.GUAD2008LD','RGAF09 UTM Nord Fuseau 20 et IGN 2008 LD (GUADELOUPE / LA DESIRADE)',NULL,NULL,'IGNF','RGAF09UTM20','IGNF','GUAD2008LD','IGNF','84',0);
INSERT INTO "area" VALUES('IGNF','305','FRANCE CONTINENTALE (CORSE EXCLUE) - CC42 (CONIQUE CONFORME ZONE 1)','FRANCE CONTINENTALE (CORSE EXCLUE) - CC42 (CONIQUE CONFORME ZONE 1)',42,43,-5.5,8.5,0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93CC42.IGN69','RGF93 CC42 zone 1 et NGF-IGN 1969',NULL,NULL,'IGNF','RGF93CC42','IGNF','IGN69','IGNF','305',0);
INSERT INTO "area" VALUES('IGNF','306','CORSE - CC42 (CONIQUE CONFORME ZONE 1)','CORSE - CC42 (CONIQUE CONFORME ZONE 1)',41.2,43,8,10,0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93CC42.IGN78C','RGF93 CC42 zone 1 et NGF-IGN 1978',NULL,NULL,'IGNF','RGF93CC42','IGNF','IGN78C','IGNF','306',0);
INSERT INTO "area" VALUES('IGNF','307','FRANCE CONTINENTALE (CORSE EXCLUE) - CC43 (CONIQUE CONFORME ZONE 2)','FRANCE CONTINENTALE (CORSE EXCLUE) - CC43 (CONIQUE CONFORME ZONE 2)',42,44,-5.5,8.5,0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93CC43.IGN69','RGF93 CC43 zone 2 et NGF-IGN 1969',NULL,NULL,'IGNF','RGF93CC43','IGNF','IGN69','IGNF','307',0);
INSERT INTO "area" VALUES('IGNF','308','CORSE - CC43 (CONIQUE CONFORME ZONE 2)','CORSE - CC43 (CONIQUE CONFORME ZONE 2)',42,43.5,8,10,0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93CC43.IGN78C','RGF93 CC43 zone 2 et NGF-IGN 1978',NULL,NULL,'IGNF','RGF93CC43','IGNF','IGN78C','IGNF','308',0);
INSERT INTO "area" VALUES('IGNF','309','FRANCE CONTINENTALE (CORSE EXCLUE) - CC44 (CONIQUE CONFORME ZONE 3)','FRANCE CONTINENTALE (CORSE EXCLUE) - CC44 (CONIQUE CONFORME ZONE 3)',43,45,-5.5,8.5,0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93CC44.IGN69','RGF93 CC44 zone 3 et NGF-IGN 1969',NULL,NULL,'IGNF','RGF93CC44','IGNF','IGN69','IGNF','309',0);
INSERT INTO "area" VALUES('IGNF','310','FRANCE CONTINENTALE (CORSE EXCLUE) - CC45 (CONIQUE CONFORME ZONE 4)','FRANCE CONTINENTALE (CORSE EXCLUE) - CC45 (CONIQUE CONFORME ZONE 4)',44,46,-5.5,8.5,0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93CC45.IGN69','RGF93 CC45 zone 4 et NGF-IGN 1969',NULL,NULL,'IGNF','RGF93CC45','IGNF','IGN69','IGNF','310',0);
INSERT INTO "area" VALUES('IGNF','311','FRANCE CONTINENTALE (CORSE EXCLUE) - CC46 (CONIQUE CONFORME ZONE 5)','FRANCE CONTINENTALE (CORSE EXCLUE) - CC46 (CONIQUE CONFORME ZONE 5)',45,47,-5.5,8.5,0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93CC46.IGN69','RGF93 CC46 zone 5 et NGF-IGN 1969',NULL,NULL,'IGNF','RGF93CC46','IGNF','IGN69','IGNF','311',0);
INSERT INTO "area" VALUES('IGNF','312','FRANCE CONTINENTALE (CORSE EXCLUE) - CC47 (CONIQUE CONFORME ZONE 6)','FRANCE CONTINENTALE (CORSE EXCLUE) - CC47 (CONIQUE CONFORME ZONE 6)',46,48,-5.5,8.5,0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93CC47.IGN69','RGF93 CC47 zone 6 et NGF-IGN 1969',NULL,NULL,'IGNF','RGF93CC47','IGNF','IGN69','IGNF','312',0);
INSERT INTO "area" VALUES('IGNF','313','FRANCE CONTINENTALE (CORSE EXCLUE) - CC48 (CONIQUE CONFORME ZONE 7)','FRANCE CONTINENTALE (CORSE EXCLUE) - CC48 (CONIQUE CONFORME ZONE 7)',47,49,-5.5,8.5,0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93CC48.IGN69','RGF93 CC48 zone 7 et NGF-IGN 1969',NULL,NULL,'IGNF','RGF93CC48','IGNF','IGN69','IGNF','313',0);
INSERT INTO "area" VALUES('IGNF','314','FRANCE CONTINENTALE (CORSE EXCLUE) - CC49 (CONIQUE CONFORME ZONE 8)','FRANCE CONTINENTALE (CORSE EXCLUE) - CC49 (CONIQUE CONFORME ZONE 8)',48,50,-5.5,8.5,0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93CC49.IGN69','RGF93 CC49 zone 8 et NGF-IGN 1969',NULL,NULL,'IGNF','RGF93CC49','IGNF','IGN69','IGNF','314',0);
INSERT INTO "area" VALUES('IGNF','315','FRANCE CONTINENTALE (CORSE EXCLUE) - CC50 (CONIQUE CONFORME ZONE 9)','FRANCE CONTINENTALE (CORSE EXCLUE) - CC50 (CONIQUE CONFORME ZONE 9)',49,51,-5.5,8.5,0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93CC50.IGN69','RGF93 CC50 zone 9 et NGF-IGN 1969',NULL,NULL,'IGNF','RGF93CC50','IGNF','IGN69','IGNF','315',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93G.IGN69','RGF93 geographiques (dms) et NGF-IGN 1969',NULL,NULL,'IGNF','RGF93G','IGNF','IGN69','IGNF','85',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93G.IGN78C','RGF93 geographiques (dms) et NGF-IGN 1978',NULL,NULL,'IGNF','RGF93G','IGNF','IGN78C','IGNF','86',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93LAMB93.IGN69','RGF93 Lambert 93 et NGF-IGN 1969',NULL,NULL,'IGNF','RGF93LAMB93','IGNF','IGN69','IGNF','85',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93LAMB93.IGN78C','RGF93 Lambert 93 et NGF-IGN 1978',NULL,NULL,'IGNF','RGF93LAMB93','IGNF','IGN78C','IGNF','86',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93UTM31.IGN69','RGF93 UTM fuseau 31 et NGF-IGN 1969',NULL,NULL,'IGNF','RGF93UTM31','IGNF','IGN69','IGNF','286',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93UTM32.IGN69','RGF93 UTM fuseau 32 et NGF-IGN 1969',NULL,NULL,'IGNF','RGF93UTM32','IGNF','IGN69','IGNF','285',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93UTM32.IGN78C','RGF93 UTM fuseau 32 et NGF-IGN 1978',NULL,NULL,'IGNF','RGF93UTM32','IGNF','IGN78C','IGNF','86',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGF93UTM30.IGN69','RGF93 UTM NORD FUSEAU 30 et NGF-IGN 1969',NULL,NULL,'IGNF','RGF93UTM30','IGNF','IGN69','IGNF','284',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGFG95G.GUYA77','RGFG95 geographiques (dms) et NIVELLEMENT GENERAL DE GUYANE (NGG) 1977',NULL,NULL,'IGNF','RGFG95G','IGNF','GUYA77','IGNF','10',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGFG95UTM21.GUYA77','RGFG95 UTM Nord f.21 et NIVELLEMENT GENERAL DE GUYANE (NGG) 1977',NULL,NULL,'IGNF','RGFG95UTM21','IGNF','GUYA77','IGNF','170',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGFG95UTM22.GUYA77','RGFG95 UTM Nord f.22 et NIVELLEMENT GENERAL DE GUYANE (NGG) 1977',NULL,NULL,'IGNF','RGFG95UTM22','IGNF','GUYA77','IGNF','171',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGM04GDD.MAYO53','RGM04 geographiques (dd) et SHOM 1953 (MAYOTTE)',NULL,NULL,'IGNF','RGM04GDD','IGNF','MAYO53','IGNF','5',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGM04G.MAYO53','RGM04 geographiques (dms) et SHOM 1953 (MAYOTTE)',NULL,NULL,'IGNF','RGM04G','IGNF','MAYO53','IGNF','5',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGM04UTM38S.MAYO53','RGM04 UTM Sud fuseau 38 et SHOM 1953 (MAYOTTE)',NULL,NULL,'IGNF','RGM04UTM38S','IGNF','MAYO53','IGNF','5',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGNCG.LIFOU91','RGNC geographiques (dms) et NIVELLEMENT GENERAL DE LIFOU (IGN 1991 LF)',NULL,NULL,'IGNF','RGNCG','IGNF','LIFOU91','IGNF','35',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGNCG.MARE91','RGNC geographiques (dms) et NIVELLEMENT GENERAL DE MARE (IGN 1991 MR)',NULL,NULL,'IGNF','RGNCG','IGNF','MARE91','IGNF','38',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGNCG.NCAL69','RGNC geographiques (dms) et NIVELLEMENT GENERAL DE NOUVELLE-CALEDONIE (NGNC)',NULL,NULL,'IGNF','RGNCG','IGNF','NCAL69','IGNF','21',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGNCG.PINS78','RGNC geographiques (dms) et SHOM 1978 (ILE DES PINS)',NULL,NULL,'IGNF','RGNCG','IGNF','PINS78','IGNF','31',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGNCLAMBNC.LIFOU91','RGNC Lambert Nouvelle-Caledonie et NIVELLEMENT GENERAL DE LIFOU (IGN 1991 LF)',NULL,NULL,'IGNF','RGNCLAMBNC','IGNF','LIFOU91','IGNF','35',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGNCLAMBNC.MARE91','RGNC Lambert Nouvelle-Caledonie et NIVELLEMENT GENERAL DE MARE (IGN 1991 MR)',NULL,NULL,'IGNF','RGNCLAMBNC','IGNF','MARE91','IGNF','38',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGNCLAMBNC.NCAL69','RGNC Lambert Nouvelle-Caledonie et NIVELLEMENT GENERAL DE NOUVELLE-CALEDONIE (NGNC)',NULL,NULL,'IGNF','RGNCLAMBNC','IGNF','NCAL69','IGNF','21',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGNCLAMBNC.PINS78','RGNC Lambert Nouvelle-Caledonie et SHOM 1978 (ILE DES PINS)',NULL,NULL,'IGNF','RGNCLAMBNC','IGNF','PINS78','IGNF','31',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGPFG.BORA01','RGPF geographiques (dms) et BORA_SAU 2001',NULL,NULL,'IGNF','RGPFG','IGNF','BORA01','IGNF','76',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGPFG.HUAH01','RGPF geographiques (dms) et HUAHINE_SAU 2001',NULL,NULL,'IGNF','RGPFG','IGNF','HUAH01','IGNF','78',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGPFG.MAUPITI01','RGPF geographiques (dms) et MAUPITI_SAU 2001',NULL,NULL,'IGNF','RGPFG','IGNF','MAUPITI01','IGNF','40',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGPFG.MOOREA81','RGPF geographiques (dms) et MOOREA 1981 (MOOREA_SAU 2001)',NULL,NULL,'IGNF','RGPFG','IGNF','MOOREA81','IGNF','42',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGPFG.RAIA01','RGPF geographiques (dms) et RAIATEA_SAU 2001',NULL,NULL,'IGNF','RGPFG','IGNF','RAIA01','IGNF','51',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGPFG.TAHAA01','RGPF geographiques (dms) et TAHAA_SAU 2001',NULL,NULL,'IGNF','RGPFG','IGNF','TAHAA01','IGNF','63',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGPFUTM5S.BORA01','RGPF UTM Sud fuseau 5 et BORA_SAU 2001',NULL,NULL,'IGNF','RGPFUTM5S','IGNF','BORA01','IGNF','76',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGPFUTM5S.HUAH01','RGPF UTM Sud fuseau 5 et HUAHINE_SAU 2001',NULL,NULL,'IGNF','RGPFUTM5S','IGNF','HUAH01','IGNF','78',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGPFUTM5S.MAUPITI01','RGPF UTM Sud fuseau 5 et MAUPITI_SAU 2001',NULL,NULL,'IGNF','RGPFUTM5S','IGNF','MAUPITI01','IGNF','40',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGPFUTM5S.RAIA01','RGPF UTM Sud fuseau 5 et RAIATEA_SAU 2001',NULL,NULL,'IGNF','RGPFUTM5S','IGNF','RAIA01','IGNF','51',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGPFUTM5S.TAHAA01','RGPF UTM Sud fuseau 5 et TAHAA_SAU 2001',NULL,NULL,'IGNF','RGPFUTM5S','IGNF','TAHAA01','IGNF','63',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGPFUTM6S.MOOREA81','RGPF UTM Sud fuseau 6 et MOOREA 1981 (MOOREA_SAU 2001)',NULL,NULL,'IGNF','RGPFUTM6S','IGNF','MOOREA81','IGNF','42',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGR92G.REUN89','RGR92 geographiques (dms) et IGN 1989 (REUNION)',NULL,NULL,'IGNF','RGR92G','IGNF','REUN89','IGNF','55',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGR92UTM40S.REUN89','RGR92 UTM 40 Sud et IGN 1989 (REUNION)',NULL,NULL,'IGNF','RGR92UTM40S','IGNF','REUN89','IGNF','55',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGSPM06G.STPM50','RGSPM06 geographiques (dms) et DANGER 1950 (SAINT-PIERRE-ET-MIQUELON)',NULL,NULL,'IGNF','RGSPM06G','IGNF','STPM50_V','IGNF','59',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGSPM06U21.STPM50','RGSPM06 UTM Nord fuseau 21 et DANGER 1950 (SAINT-PIERRE-ET-MIQUELON)',NULL,NULL,'IGNF','RGSPM06U21','IGNF','STPM50_V','IGNF','59',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGTAAF07GDD.KERG62','RGTAAF07 geographiques (dd) et IGN 1962 (KERGUELEN)',NULL,NULL,'IGNF','RGTAAF07GDD','IGNF','KERG62','IGNF','34',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGTAAF07G.KERG62','RGTAAF07 geographiques (dms) et IGN 1962 (KERGUELEN)',NULL,NULL,'IGNF','RGTAAF07G','IGNF','KERG62','IGNF','34',0);
INSERT INTO "compound_crs" VALUES('IGNF','RGTAAFUTM42S.KERG62','RGTAAF07 UTM Sud fuseau 42 et IGN 1962 (KERGUELEN)',NULL,NULL,'IGNF','RGTAAFUTM42S','IGNF','KERG62','IGNF','34',0);
INSERT INTO "compound_crs" VALUES('IGNF','RRAFG.MART87','RRAF geographiques (dms) et IGN 1987 (MARTINIQUE)',NULL,NULL,'IGNF','RRAFG','IGNF','MART87','IGNF','39',0);
INSERT INTO "compound_crs" VALUES('IGNF','RRAFG.GUAD88','RRAF geographiques (dms) et IGN 1988 (GUADELOUPE)',NULL,NULL,'IGNF','RRAFG','IGNF','GUAD88','IGNF','79',0);
INSERT INTO "compound_crs" VALUES('IGNF','RRAFG.GUAD88LS','RRAF geographiques (dms) et IGN 1988 LS (GUADELOUPE / LES SAINTES)',NULL,NULL,'IGNF','RRAFG','IGNF','GUAD88LS','IGNF','80',0);
INSERT INTO "compound_crs" VALUES('IGNF','RRAFG.GUAD88MG','RRAF geographiques (dms) et IGN 1988 MG (GUADELOUPE / MARIE-GALANTE)',NULL,NULL,'IGNF','RRAFG','IGNF','GUAD88MG','IGNF','81',0);
INSERT INTO "compound_crs" VALUES('IGNF','RRAFG.GUAD88SB','RRAF geographiques (dms) et IGN 1988 SB (GUADELOUPE / SAINT-BARTHELEMY)',NULL,NULL,'IGNF','RRAFG','IGNF','GUAD88SB','IGNF','82',0);
INSERT INTO "compound_crs" VALUES('IGNF','RRAFG.GUAD88SM','RRAF geographiques (dms) et IGN 1988 SM (GUADELOUPE / SAINT-MARTIN)',NULL,NULL,'IGNF','RRAFG','IGNF','GUAD88SM','IGNF','83',0);
INSERT INTO "compound_crs" VALUES('IGNF','RRAFG.GUAD92LD','RRAF geographiques (dms) et IGN 1992 LD (GUADELOUPE / LA DESIRADE)',NULL,NULL,'IGNF','RRAFG','IGNF','GUAD92LD','IGNF','84',0);
INSERT INTO "compound_crs" VALUES('IGNF','RRAFUTM20.MART87','RRAF UTM Nord fuseau 20 et IGN 1987 (MARTINIQUE)',NULL,NULL,'IGNF','RRAFUTM20','IGNF','MART87','IGNF','39',0);
INSERT INTO "compound_crs" VALUES('IGNF','RRAFUTM20.GUAD88','RRAF UTM Nord fuseau 20 et IGN 1988 (GUADELOUPE)',NULL,NULL,'IGNF','RRAFUTM20','IGNF','GUAD88','IGNF','79',0);
INSERT INTO "compound_crs" VALUES('IGNF','RRAFUTM20.GUAD88LS','RRAF UTM Nord fuseau 20 et IGN 1988 LS (GUADELOUPE / LES SAINTES)',NULL,NULL,'IGNF','RRAFUTM20','IGNF','GUAD88LS','IGNF','80',0);
INSERT INTO "compound_crs" VALUES('IGNF','RRAFUTM20.GUAD88MG','RRAF UTM Nord fuseau 20 et IGN 1988 MG (GUADELOUPE / MARIE-GALANTE)',NULL,NULL,'IGNF','RRAFUTM20','IGNF','GUAD88MG','IGNF','81',0);
INSERT INTO "compound_crs" VALUES('IGNF','RRAFUTM20.GUAD88SB','RRAF UTM Nord fuseau 20 et IGN 1988 SB (GUADELOUPE / SAINT-BARTHELEMY)',NULL,NULL,'IGNF','RRAFUTM20','IGNF','GUAD88SB','IGNF','82',0);
INSERT INTO "compound_crs" VALUES('IGNF','RRAFUTM20.GUAD88SM','RRAF UTM Nord fuseau 20 et IGN 1988 SM (GUADELOUPE / SAINT-MARTIN)',NULL,NULL,'IGNF','RRAFUTM20','IGNF','GUAD88SM','IGNF','83',0);
INSERT INTO "compound_crs" VALUES('IGNF','RRAFUTM20.GUAD92LD','RRAF UTM Nord fuseau 20 et IGN 1992 LD (GUADELOUPE / LA DESIRADE)',NULL,NULL,'IGNF','RRAFUTM20','IGNF','GUAD92LD','IGNF','84',0);
INSERT INTO "compound_crs" VALUES('IGNF','ST84G.PINS78','ST 84 ILE DES PINS geographiques (dms) et SHOM 1978 (ILE DES PINS)',NULL,NULL,'IGNF','ST84G','IGNF','PINS78','IGNF','31',0);
INSERT INTO "compound_crs" VALUES('IGNF','ST84UTM58S.PINS78','ST 84 ILE DES PINS UTM Sud fuseau 58 et SHOM 1978 (ILE DES PINS)',NULL,NULL,'IGNF','ST84UTM58S','IGNF','PINS78','IGNF','31',0);
INSERT INTO "compound_crs" VALUES('IGNF','STPM50UTM21.STPM50','St-Pierre-et-Miquelon UTM Nord f.21 et DANGER 1950 (SAINT-PIERRE-ET-MIQUELON)',NULL,NULL,'IGNF','STPM50UTM21','IGNF','STPM50_V','IGNF','59',0);
INSERT INTO "compound_crs" VALUES('IGNF','STPM50G.STPM50','St Pierre Miquelon 1950 geographiques (dms) et DANGER 1950 (SAINT-PIERRE-ET-MIQUELON)',NULL,NULL,'IGNF','STPM50G','IGNF','STPM50_V','IGNF','59',0);
INSERT INTO "compound_crs" VALUES('IGNF','TAHAAG.TAHAA01','Tahaa geographiques (dms) et TAHAA_SAU 2001',NULL,NULL,'IGNF','TAHAAG','IGNF','TAHAA01','IGNF','63',0);
INSERT INTO "compound_crs" VALUES('IGNF','TAHAAUTM5S.TAHAA01','Tahaa UTM Sud fuseau 5 et TAHAA_SAU 2001',NULL,NULL,'IGNF','TAHAAUTM5S','IGNF','TAHAA01','IGNF','63',0);
INSERT INTO "compound_crs" VALUES('IGNF','TAHI79G.TAHITI66','Tahiti (IGN79) geographiques (dms) et IGN 1966 (TAHITI)',NULL,NULL,'IGNF','TAHI79G','IGNF','TAHITI66','IGNF','64',0);
INSERT INTO "compound_crs" VALUES('IGNF','TAHI79UTM6S.TAHITI66','Tahiti (IGN79) UTM Sud fuseau 6 et IGN 1966 (TAHITI)',NULL,NULL,'IGNF','TAHI79UTM6S','IGNF','TAHITI66','IGNF','64',0);
INSERT INTO "compound_crs" VALUES('IGNF','TAHI51UTM6S.TAHITI66','TAHITI TERME NORD UTM SUD FUSEAU 6 et IGN 1966 (TAHITI)',NULL,NULL,'IGNF','TAHI51UTM6S','IGNF','TAHITI66','IGNF','64',0);
INSERT INTO "compound_crs" VALUES('IGNF','WALL76G.WALLIS96','Wallis (MOP 1976) geographiques (dms) et NGWF WALLIS (MOP 1996)',NULL,NULL,'IGNF','WALL76G','IGNF','WALLIS96','IGNF','73',0);
INSERT INTO "compound_crs" VALUES('IGNF','WALL76UTM1S.WALLIS96','Wallis (MOP 1976) UTM Sud fuseau 1 et NGWF WALLIS (MOP 1996)',NULL,NULL,'IGNF','WALL76UTM1S','IGNF','WALLIS96','IGNF','73',0);
INSERT INTO "compound_crs" VALUES('IGNF','WALL78G.WALLIS96','Wallis (MOP 1978) geographiques (dms) et NGWF WALLIS (MOP 1996)',NULL,NULL,'IGNF','WALL78G','IGNF','WALLIS96','IGNF','73',0);
INSERT INTO "compound_crs" VALUES('IGNF','WALL78UTM1S.WALLIS96','Wallis (MOP 1978) UTM Sud fuseau 1 et NGWF WALLIS (MOP 1996)',NULL,NULL,'IGNF','WALL78UTM1S','IGNF','WALLIS96','IGNF','73',0);
INSERT INTO "compound_crs" VALUES('IGNF','WGS72G.IGN69','WGS72 geographiques (dms) et NGF-IGN 1969',NULL,NULL,'IGNF','WGS72G','IGNF','IGN69','IGNF','85',0);
INSERT INTO "compound_crs" VALUES('IGNF','WGS72G.IGN78C','WGS72 geographiques (dms) et NGF-IGN 1978',NULL,NULL,'IGNF','WGS72G','IGNF','IGN78C','IGNF','86',0);
INSERT INTO "compound_crs" VALUES('IGNF','WGS72G.NGC48','WGS72 geographiques (dms) et NIVELLEMENT GENERAL DE LA CORSE (NGC)',NULL,NULL,'IGNF','WGS72G','IGNF','NGC48','IGNF','86',0);
INSERT INTO "compound_crs" VALUES('IGNF','WGS72UTM30.IGN69','WGS72 UTM fuseau 30 et NGF-IGN 1969',NULL,NULL,'IGNF','WGS72UTM30','IGNF','IGN69','IGNF','284',0);
INSERT INTO "compound_crs" VALUES('IGNF','WGS72UTM31.IGN69','WGS72 UTM fuseau 31 et NGF-IGN 1969',NULL,NULL,'IGNF','WGS72UTM31','IGNF','IGN69','IGNF','286',0);
INSERT INTO "compound_crs" VALUES('IGNF','WGS72UTM32.IGN69','WGS72 UTM fuseau 32 et NGF-IGN 1969',NULL,NULL,'IGNF','WGS72UTM32','IGNF','IGN69','IGNF','285',0);
INSERT INTO "compound_crs" VALUES('IGNF','WGS72UTM32.IGN78C','WGS72 UTM fuseau 32 et NGF-IGN 1978',NULL,NULL,'IGNF','WGS72UTM32','IGNF','IGN78C','IGNF','86',0);
INSERT INTO "compound_crs" VALUES('IGNF','WGS72UTM32.NGC48','WGS72 UTM fuseau 32 et NIVELLEMENT GENERAL DE LA CORSE (NGC)',NULL,NULL,'IGNF','WGS72UTM32','IGNF','NGC48','IGNF','86',0);
INSERT INTO "compound_crs" VALUES('IGNF','WGS84GDD.IGN69','WGS84 geographiques (dd) et NGF-IGN 1969',NULL,NULL,'IGNF','WGS84GDD','IGNF','IGN69','IGNF','85',0);
INSERT INTO "compound_crs" VALUES('IGNF','WGS84GDD.IGN78C','WGS84 geographiques (dd) et NGF-IGN 1978',NULL,NULL,'IGNF','WGS84GDD','IGNF','IGN78C','IGNF','86',0);
INSERT INTO "compound_crs" VALUES('IGNF','WGS84G.IGN69','WGS84 geographiques (dms) et NGF-IGN 1969',NULL,NULL,'IGNF','WGS84G','IGNF','IGN69','IGNF','85',0);
INSERT INTO "compound_crs" VALUES('IGNF','WGS84G.IGN78C','WGS84 geographiques (dms) et NGF-IGN 1978',NULL,NULL,'IGNF','WGS84G','IGNF','IGN78C','IGNF','86',0);
INSERT INTO "compound_crs" VALUES('IGNF','WGS84UTM30.IGN69','WGS84 UTM fuseau 30 et NGF-IGN 1969',NULL,NULL,'IGNF','WGS84UTM30','IGNF','IGN69','IGNF','284',0);
INSERT INTO "compound_crs" VALUES('IGNF','WGS84UTM31.IGN69','WGS84 UTM fuseau 31 et NGF-IGN 1969',NULL,NULL,'IGNF','WGS84UTM31','IGNF','IGN69','IGNF','286',0);
INSERT INTO "compound_crs" VALUES('IGNF','WGS84UTM32.IGN69','WGS84 UTM NORD FUSEAU 32 et NGF-IGN 1969',NULL,NULL,'IGNF','WGS84UTM32','IGNF','IGN69','IGNF','285',0);
INSERT INTO "compound_crs" VALUES('IGNF','WGS84UTM32.IGN78C','WGS84 UTM NORD FUSEAU 32 et NGF-IGN 1978',NULL,NULL,'IGNF','WGS84UTM32','IGNF','IGN78C','IGNF','86',0);

--- Grid alternatives

INSERT INTO grid_alternatives(original_grid_name,
                              proj_grid_name,
                              proj_grid_format,
                              proj_method,
                              inverse_direction,
                              package_name,
                              url, direct_download, open_license, directory)
                      VALUES ('ntf_r93.gsb',    -- as referenced by the IGNF registry
                              'ntf_r93.gsb',
                              'NTv2',
                              'hgridshift',
                              0,
                              'proj-datumgrid',
                              NULL, NULL, NULL, NULL);

INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggpf02-Huahine.mnt',    -- as referenced by the IGNF registry
                            'ggpf02-Huahine.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggg00v2.mnt',    -- as referenced by the IGNF registry
                            'ggg00v2.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggpf10-Tahiti.mnt',    -- as referenced by the IGNF registry
                            'ggpf10-Tahiti.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggpf02-Raiatea.mnt',    -- as referenced by the IGNF registry
                            'ggpf02-Raiatea.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggg00_sbv2.mnt',    -- as referenced by the IGNF registry
                            'ggg00_sbv2.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/gg10_smv2.mnt',    -- as referenced by the IGNF registry
                            'gg10_smv2.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RAMG2016.mnt',    -- as referenced by the IGNF registry
                            'RAMG2016.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggker08v2.mnt',    -- as referenced by the IGNF registry
                            'ggker08v2.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggspm06v1.mnt',    -- as referenced by the IGNF registry
                            'ggspm06v1.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/gg10_sbv2.mnt',    -- as referenced by the IGNF registry
                            'gg10_sbv2.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggguy15.mnt',    -- as referenced by the IGNF registry
                            'ggguy15.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/metropole/RAF09.mnt',    -- as referenced by the IGNF registry
                            'RAF09.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggpf08-Fakarava.mnt',    -- as referenced by the IGNF registry
                            'ggpf08-Fakarava.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggm00v2.mnt',    -- as referenced by the IGNF registry
                            'ggm00v2.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggpf10-Moorea.mnt',    -- as referenced by the IGNF registry
                            'ggpf10-Moorea.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggpf02-Maupiti.mnt',    -- as referenced by the IGNF registry
                            'ggpf02-Maupiti.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggg00_lsv2.mnt',    -- as referenced by the IGNF registry
                            'ggg00_lsv2.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggm04v1.mnt',    -- as referenced by the IGNF registry
                            'ggm04v1.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggg00_smv2.mnt',    -- as referenced by the IGNF registry
                            'ggg00_smv2.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RALD2016.mnt',    -- as referenced by the IGNF registry
                            'RALD2016.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RAR07_bl.gra',    -- as referenced by the IGNF registry
                            'RAR07_bl.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RALS2016.mnt',    -- as referenced by the IGNF registry
                            'RALS2016.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RALDW842016.mnt',    -- as referenced by the IGNF registry
                            'RALDW842016.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggpf02-Tahaa.mnt',    -- as referenced by the IGNF registry
                            'ggpf02-Tahaa.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RAGTBT2016.mnt',    -- as referenced by the IGNF registry
                            'RAGTBT2016.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/metropole/RAC09.mnt',    -- as referenced by the IGNF registry
                            'RAC09.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/RAMART2016.mnt',    -- as referenced by the IGNF registry
                            'RAMART2016.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('https://geodesie.ign.fr/contenu/fichiers/documentation/grilles/metropole/RAF18.mnt',    -- as referenced by the IGNF registry
                            'RAF18.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);
INSERT INTO grid_alternatives(original_grid_name,
                            proj_grid_name,
                            proj_grid_format,
                            proj_method,
                            inverse_direction,
                            package_name,
                            url, direct_download, open_license, directory)
                    VALUES ('http://geodesie.ign.fr/contenu/fichiers/documentation/grilles/outremer/ggpf02-Bora.mnt',    -- as referenced by the IGNF registry
                            'ggpf02-Bora.gtx',
                            'GTX',
                            'vgridshift',
                            1,
                            'proj-datumgrid-europe',
                            NULL, NULL, NULL, NULL);

--- Null transformations between RRAF and WGS84 adapted from EPSG

INSERT INTO "helmert_transformation" VALUES('PROJ','IGNF_RRAF_TO_EPSG_4978','RRAF to WGS 84',NULL,NULL,'EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RRAF','EPSG','4978','IGNF','56',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('PROJ','IGNF_RRAFG_TO_EPSG_4326','RRAFG to WGS 84',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RRAFG','EPSG','4326','IGNF','56',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('PROJ','IGNF_RRAFGDD_TO_EPSG_4326','RRAFGDD to WGS 84',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RRAFGDD','EPSG','4326','IGNF','56',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);

--- Null transformations between RGF93 and WGS84 adapted from EPSG

INSERT INTO "helmert_transformation" VALUES('PROJ','IGNF_RGF93_TO_EPSG_4978','RGF93 to WGS 84',NULL,NULL,'EPSG','1031','Geocentric translations (geocentric domain)','IGNF','RGF93','EPSG','4978','IGNF','4',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('PROJ','IGNF_RGF93G_TO_EPSG_4326','RGF93G to WGS 84',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93G','EPSG','4326','IGNF','4',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('PROJ','IGNF_RGF93GDD_TO_EPSG_4326','RGF93GDD to WGS 84',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','IGNF','RGF93GDD','EPSG','4326','IGNF','4',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);

--- Concatenated operations

INSERT INTO "concatenated_operation" VALUES('IGNF','TSG62_NTFPGRAD_TO_ED50G','Nouvelle Triangulation Francaise Paris grades to ED50G',NULL,'NATIONALE','IGNF','NTFPGRAD','IGNF','ED50G','IGNF','91',NULL,'IGNF','TSG1240','IGNF','TSG62_NTFG_TO_ED50G',NULL,NULL,'1.0.0',0);
INSERT INTO "concatenated_operation" VALUES('IGNF','TSG62_NTFP_TO_ED50G','Nouvelle Triangulation Francaise Paris grades to ED50G',NULL,'NATIONALE','IGNF','NTFP','IGNF','ED50G','IGNF','91',NULL,'IGNF','TSG1240_IGNF_NTFP_TO_IGNF_NTFG','IGNF','TSG62_NTFG_TO_ED50G',NULL,NULL,'1.0.0',0);
INSERT INTO "concatenated_operation" VALUES('IGNF','TSG62_NTFPGRAD_TO_ED50GEO','Nouvelle Triangulation Francaise Paris grades to ED50GEO',NULL,'NATIONALE','IGNF','NTFPGRAD','IGNF','ED50GEO','IGNF','91',NULL,'IGNF','TSG1240','IGNF','TSG62_NTFG_TO_ED50GEO',NULL,NULL,'1.0.0',0);
INSERT INTO "concatenated_operation" VALUES('IGNF','TSG62_NTFP_TO_ED50GEO','Nouvelle Triangulation Francaise Paris grades to ED50GEO',NULL,'NATIONALE','IGNF','NTFP','IGNF','ED50GEO','IGNF','91',NULL,'IGNF','TSG1240_IGNF_NTFP_TO_IGNF_NTFG','IGNF','TSG62_NTFG_TO_ED50GEO',NULL,NULL,'1.0.0',0);
INSERT INTO "concatenated_operation" VALUES('IGNF','TSG399_NTFPGRAD_TO_WGS84GEODD','Nouvelle Triangulation Francaise Paris grades to WGS84GEODD',NULL,'NATIONALE','IGNF','NTFPGRAD','IGNF','WGS84GEODD','IGNF','91',NULL,'IGNF','TSG1240','IGNF','TSG399_NTFG_TO_WGS84GEODD',NULL,NULL,'1.0.0',0);
INSERT INTO "concatenated_operation" VALUES('IGNF','TSG399_NTFP_TO_WGS84GEODD','Nouvelle Triangulation Francaise Paris grades to WGS84GEODD',NULL,'NATIONALE','IGNF','NTFP','IGNF','WGS84GEODD','IGNF','91',NULL,'IGNF','TSG1240_IGNF_NTFP_TO_IGNF_NTFG','IGNF','TSG399_NTFG_TO_WGS84GEODD',NULL,NULL,'1.0.0',0);
INSERT INTO "concatenated_operation" VALUES('IGNF','TSG399_NTFPGRAD_TO_WGS84GDD','Nouvelle Triangulation Francaise Paris grades to WGS84GDD',NULL,'NATIONALE','IGNF','NTFPGRAD','IGNF','WGS84GDD','IGNF','91',NULL,'IGNF','TSG1240','IGNF','TSG399_NTFG_TO_WGS84GDD',NULL,NULL,'1.0.0',0);
INSERT INTO "concatenated_operation" VALUES('IGNF','TSG399_NTFP_TO_WGS84GDD','Nouvelle Triangulation Francaise Paris grades to WGS84GDD',NULL,'NATIONALE','IGNF','NTFP','IGNF','WGS84GDD','IGNF','91',NULL,'IGNF','TSG1240_IGNF_NTFP_TO_IGNF_NTFG','IGNF','TSG399_NTFG_TO_WGS84GDD',NULL,NULL,'1.0.0',0);
INSERT INTO "concatenated_operation" VALUES('IGNF','TSG399_NTFPGRAD_TO_WGS84G','Nouvelle Triangulation Francaise Paris grades to WGS84G',NULL,'NATIONALE','IGNF','NTFPGRAD','IGNF','WGS84G','IGNF','91',NULL,'IGNF','TSG1240','IGNF','TSG399_NTFG_TO_WGS84G',NULL,NULL,'1.0.0',0);
INSERT INTO "concatenated_operation" VALUES('IGNF','TSG399_NTFP_TO_WGS84G','Nouvelle Triangulation Francaise Paris grades to WGS84G',NULL,'NATIONALE','IGNF','NTFP','IGNF','WGS84G','IGNF','91',NULL,'IGNF','TSG1240_IGNF_NTFP_TO_IGNF_NTFG','IGNF','TSG399_NTFG_TO_WGS84G',NULL,NULL,'1.0.0',0);
INSERT INTO "concatenated_operation" VALUES('IGNF','TSG399_NTFPGRAD_TO_4326','Nouvelle Triangulation Francaise Paris grades to 4326',NULL,'NATIONALE','IGNF','NTFPGRAD','EPSG','4326','IGNF','91',NULL,'IGNF','TSG1240','IGNF','TSG399_NTFG_TO_4326',NULL,NULL,'1.0.0',0);
INSERT INTO "concatenated_operation" VALUES('IGNF','TSG399_NTFP_TO_4326','Nouvelle Triangulation Francaise Paris grades to 4326',NULL,'NATIONALE','IGNF','NTFP','EPSG','4326','IGNF','91',NULL,'IGNF','TSG1240_IGNF_NTFP_TO_IGNF_NTFG','IGNF','TSG399_NTFG_TO_4326',NULL,NULL,'1.0.0',0);
INSERT INTO "concatenated_operation" VALUES('IGNF','TSG399_NTFPGRAD_TO_WGS84GEO','Nouvelle Triangulation Francaise Paris grades to WGS84GEO',NULL,'NATIONALE','IGNF','NTFPGRAD','IGNF','WGS84GEO','IGNF','91',NULL,'IGNF','TSG1240','IGNF','TSG399_NTFG_TO_WGS84GEO',NULL,NULL,'1.0.0',0);
INSERT INTO "concatenated_operation" VALUES('IGNF','TSG399_NTFP_TO_WGS84GEO','Nouvelle Triangulation Francaise Paris grades to WGS84GEO',NULL,'NATIONALE','IGNF','NTFP','IGNF','WGS84GEO','IGNF','91',NULL,'IGNF','TSG1240_IGNF_NTFP_TO_IGNF_NTFG','IGNF','TSG399_NTFG_TO_WGS84GEO',NULL,NULL,'1.0.0',0);
INSERT INTO "concatenated_operation" VALUES('IGNF','TSG399_NTFPGRAD_TO_WGS84RRAFGEO','Nouvelle Triangulation Francaise Paris grades to WGS84RRAFGEO',NULL,'NATIONALE','IGNF','NTFPGRAD','IGNF','WGS84RRAFGEO','IGNF','91',NULL,'IGNF','TSG1240','IGNF','TSG399_NTFG_TO_WGS84RRAFGEO',NULL,NULL,'1.0.0',0);
INSERT INTO "concatenated_operation" VALUES('IGNF','TSG399_NTFP_TO_WGS84RRAFGEO','Nouvelle Triangulation Francaise Paris grades to WGS84RRAFGEO',NULL,'NATIONALE','IGNF','NTFP','IGNF','WGS84RRAFGEO','IGNF','91',NULL,'IGNF','TSG1240_IGNF_NTFP_TO_IGNF_NTFG','IGNF','TSG399_NTFG_TO_WGS84RRAFGEO',NULL,NULL,'1.0.0',0);
