--- This file has been generated by scripts/build_db.py. DO NOT EDIT !

INSERT INTO "helmert_transformation" VALUES('EPSG','1024','MGI to ETRS89 (4)','Parameter values from MGI to WGS 84 (8) (tfm code 1194). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation. Information source gives scale as -2.388739 ppm.','For applications to an accuracy of 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4312','EPSG','4258','EPSG','1543',1.0,601.705,84.263,485.227,'EPSG','9001',-4.7354,-1.3145,-5.393,'EPSG','9104',-2.3887,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'LBD-Aut Sty',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1055','Ain el Abd to WGS 84 (3)','Derived at station K1.','1 metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4204','EPSG','4326','EPSG','3267',1.0,-145.7,-249.1,1.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'WGC-Kwt',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1056','Ain el Abd to WGS 84 (4)','Derivation is more precise, but no evidence that accuracy is better than Ain el Abd to WGS 84 (3). OGP recommends using Ain el Abd to WGS 84 (3).','1 metre accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4204','EPSG','4326','EPSG','3267',1.0,-85.645,-273.077,-79.708,'EPSG','9001',-2.289,1.421,-2.532,'EPSG','9104',3.194,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Par-Kwt',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1057','Ain el Abd to WGS 84 (5)','.','1 metre accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4204','EPSG','4326','EPSG','2956',1.0,-202.234,-168.351,-63.51,'EPSG','9001',-3.545,-0.659,1.945,'EPSG','9104',2.1,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Par-Kwt N',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1058','Ain el Abd to WGS 84 (6)','','1 metre accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4204','EPSG','4326','EPSG','2957',1.0,-18.944,-379.364,-24.063,'EPSG','9001',-0.04,0.764,-6.431,'EPSG','9104',3.657,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Par-Kwt S',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1059','KOC to WGS 84 (1)','','1 metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4246','EPSG','4326','EPSG','3267',1.0,-294.7,-200.1,525.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'WGC-Kwt',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1060','NGN to WGS 84 (1)','','1 metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4318','EPSG','4326','EPSG','3267',1.0,-3.2,-5.7,2.8,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Mun-Kwt',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1061','Kudams to WGS 84 (1)','','For applications requiring an accuracy of better than 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4319','EPSG','4326','EPSG','1310',1.0,-20.8,11.3,2.4,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Mun-Kwt',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1062','Kudams to WGS 84 (2)','','For applications requiring an accuracy of better than 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4319','EPSG','4326','EPSG','1310',1.0,226.702,-193.337,-35.371,'EPSG','9001',2.229,4.391,-9.238,'EPSG','9104',0.9798,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Par-Kwt',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1063','Vientiane 1982 to Lao 1997 (1)','Derived at 8 stations.','Accuracy 2m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4676','EPSG','4678','EPSG','1138',2.0,-2.227,6.524,2.178,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGD-Lao',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1064','Lao 1993 to Lao 1997 (1)','Derived at 25 stations.','Accuracy 0.15m','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4677','EPSG','4678','EPSG','1138',0.15,-0.652,1.619,0.213,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGD-Lao',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1065','Lao 1997 to WGS 84 (1)','Derived at 25 stations.','Accuracy 5m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4678','EPSG','4326','EPSG','1138',5.0,44.585,-131.212,-39.544,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGD-Lao',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1066','Amersfoort to ETRS89 (2)','Replaced by Amersfoort to ETRS89 (4) (tfm code 15740). Dutch sources also quote an equivalent transformation using the Coordinate Frame 7-parameter method - see tfm code 1751.','Accuracy 0.5m','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4289','EPSG','4258','EPSG','1275',0.5,593.032,26.0,478.741,'EPSG','9001',1.9848,-1.7439,9.0587,'EPSG','9109',4.0772,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,3903453.148,368135.313,5012970.306,'EPSG','9001','NCG-Nld 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1067','Minna to WGS 84 (11)','Used by Statoil for deep water blocks 210, 213, 217 and 218. Parameter values interpolated from Racal Survey geocentric translation contour charts for each of these four blocks and then meaned.','Oil industry exploration and production.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4263','EPSG','4326','EPSG','3817',8.0,-92.1,-89.9,114.9,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Stat-Nga',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1070','Guam 1963 to WGS 84 (1)','Derived at 5 stations.','For military purposes only. Accuracy 3m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4675','EPSG','4326','EPSG','3255',6.0,-100.0,-248.0,259.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Gum',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1071','Palestine 1923 to Israel (1)','For more accurate transformation contact Survey of Israel.','Accuracy: 1.5m','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4281','EPSG','4141','EPSG','2603',1.5,-181.0,-122.0,225.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SoI-Isr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1073','Israel to WGS 84 (1)','For more accurate transformation contact Survey of Israel.','Accuracy: 2m','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4141','EPSG','4326','EPSG','2603',2.0,-48.0,55.0,52.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SoI-Isr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1074','Palestine 1923 to WGS 84 (1)','Not recognised by Survey of Israel. See Palestine 1923 to WGS 84 (2) (code 8650).','Oil Exploration. Accuracy: 1m to north and 5m to south of east-west line through Beersheba (31°15''N).','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4281','EPSG','4326','EPSG','2603',2.0,-275.7224,94.7824,340.8944,'EPSG','9001',-8.001,-4.42,-11.821,'EPSG','9104',1.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Isr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1075','ED50 to WGS 84 (38)','Derived in 1987 by Geodetic for TPAO. Used on BP 1991/92 2D seismic surveys in central and eastern Turkish sector of Black Sea. In Turkey, replaced by tfm code 1784. Also adopted for use offshore Israel.','Oil Exploration','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2896',10.0,-89.05,-87.03,-124.56,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TPAO-Tur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1078','Luxembourg 1930 to ETRS89 (2)','May be taken as approximate transformation Luxembourg 1930 to WGS 84 - see code 1079. Replaced by Luxembourg 1930 to ETRS89 (3) (code 5483).','For applications to an accuracy of 0.1 metre.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4181','EPSG','4258','EPSG','1146',0.1,-265.983,76.918,20.182,'EPSG','9001',0.4099,2.9332,-2.6881,'EPSG','9104',0.43,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,4098647.674,442843.139,4851251.093,'EPSG','9001','ACT-Lux 0.1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1079','Luxembourg 1930 to WGS 84 (2)','Parameter values from Luxembourg 1930 to ETRS89 (2) (code 1078). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 0.5 metre.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4181','EPSG','4326','EPSG','1146',0.5,-265.983,76.918,20.182,'EPSG','9001',0.4099,2.9332,-2.6881,'EPSG','9104',0.43,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,4098647.674,442843.139,4851251.093,'EPSG','9001','EPSG-Lux 0.5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1080','CI1971 to WGS 84 (1)','Derived at 4 stations.','For military purposes. Accuracy 15m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4672','EPSG','4326','EPSG','2889',26.0,175.0,-38.0,113.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Nzl CI',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1081','CI1979 to WGS 84 (1)','Derived at 4 stations using concatenation through WGS72. Parameter vales are also used to transform CI1979 to NZGD2000 - see tfm code 1082.','For applications requiring 2m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4673','EPSG','4326','EPSG','2889',2.0,174.05,-25.49,112.57,'EPSG','9001',0.0,0.0,-0.554,'EPSG','9104',0.2263,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OSG-Nzl CI',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1082','CI1979 to NZGD2000 (1)','Parameter vales are from CI1979 to WGS 84 (1) (code 1081) assuming that WGS 84 is equivalent to NZGD2000 within the accuracy of the transformation.','For applications requiring 2m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4673','EPSG','4167','EPSG','2889',2.0,174.05,-25.49,112.57,'EPSG','9001',0.0,0.0,-0.554,'EPSG','9104',0.2263,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OSG-Nzl CI',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1083','JAD69 to WGS 72 (2)','Derived in 1981 through Transit observations at 4 stations by Geodetic Survey for Petroleum Corporation of Jamaica.','For oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4242','EPSG','4322','EPSG','3342',10.0,50.0,212.0,381.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PC-Jam',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1084','JAD69 to WGS 84 (1)','Derived via NAD27 and WGS 72. Preliminary values derived by Survey Department but not officially promulgated.','For applications requiring 5m accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4242','EPSG','4326','EPSG','3342',5.0,70.0,207.0,389.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UT-Jam 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1085','JAD69 to WGS 84 (2)','Derived at 4 stations, tested at a further 9.','For applications requiring 2m accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4242','EPSG','4326','EPSG','3342',2.0,65.334,212.46,387.63,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UT-Jam 2m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1086','JAD69 to WGS 84 (3)','Derived at 4 stations, tested at a further 9.','For applications requiring 1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4242','EPSG','4326','EPSG','3342',1.0,-33.722,153.789,94.959,'EPSG','9001',8.581,4.478,-4.54,'EPSG','9104',-8.95,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UT-Jam 1m',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1087','ED50 to WGS 84 (37)','','Topographic mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','1130',2.5,-112.0,-110.3,-140.2,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'RJGC-Jor',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1088','Monte Mario to WGS 84 (5)','','Oil exploration and production','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4265','EPSG','4326','EPSG','2882',10.0,-223.7,-67.38,1.34,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ENI-Ita Adr N Anc',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1089','Monte Mario to WGS 84 (6)','','Oil exploration and production','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4265','EPSG','4326','EPSG','2883',10.0,-225.4,-67.7,7.85,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ENI-Ita Adr Anc-Gar',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1090','Monte Mario to WGS 84 (7)','','Oil exploration and production','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4265','EPSG','4326','EPSG','2884',10.0,-227.1,-68.1,14.4,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ENI-Ita Adr S Gar',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1091','Monte Mario to WGS 84 (8)','','Marine navigation','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4265','EPSG','4326','EPSG','2885',10.0,-231.61,-68.21,13.93,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ENI-Ita Otr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1092','Monte Mario to WGS 84 (9)','','Marine navigation','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4265','EPSG','4326','EPSG','2886',10.0,-225.06,-67.37,14.61,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ENI-Ita N Jon',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1093','Monte Mario to WGS 84 (10)','','Marine navigation','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4265','EPSG','4326','EPSG','2887',10.0,-229.08,-65.73,20.21,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ENI-Ita E Sic',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1094','Monte Mario to WGS 84 (11)','','Marine navigation','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4265','EPSG','4326','EPSG','2888',10.0,-230.47,-56.08,22.43,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ENI-Ita W Sic',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1095','PSAD56 to WGS 84 (13)','Parameter values are from PSAD56 to REGVEN (1) (code 1769) assuming that REGVEN is equivalent to WGS 84 within the accuracy of the transformation.','Spatial referencing.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4248','EPSG','4326','EPSG','3327',15.0,-270.933,115.599,-360.226,'EPSG','9001',-5.266,-1.238,2.381,'EPSG','9104',-5.109,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2464351.59,-5783466.61,974809.81,'EPSG','9001','EPSG-Ven',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1096','La Canoa to WGS 84 (13)','Parameter values are from La Canoa to REGVEN (1) (code 1771) assuming that REGVEN is equivalent to WGS 84 within the accuracy of the transformation.','Spatial referencing.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4247','EPSG','4326','EPSG','3327',15.0,-270.933,115.599,-360.226,'EPSG','9001',-5.266,-1.238,2.381,'EPSG','9104',-5.109,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2464351.59,-5783466.61,974809.81,'EPSG','9001','EPSG-Ven',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1097','Dealul Piscului 1970 to WGS 84 (2)','Parameter values taken from Pulkovo 1942 to WGS 84 (9) (code 1293) assuming that Pulkovo 1942 in Romania is equivalent to Dealul Piscului 1970.','Accuracy 3m, 5m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4317','EPSG','4326','EPSG','1197',7.0,28.0,-121.0,-77.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Rom',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1098','IGM95 to ETRS89 (1)','May be taken as approximate transformation IGM95 to WGS 84 - see code 1099.','IGM95 is a realization of ETRS89.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4670','EPSG','4258','EPSG','3343',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Ita',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1099','IGM95 to WGS 84 (1)','Parameter values taken from IGM95 to ETRS89 (1) (code 1098) assuming that ETRS89 is coincident with WGS 84 within the accuracy of the transformation.','Approximation at the 1m level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4670','EPSG','4326','EPSG','3343',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Ita',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1100','Adindan to WGS 84 (1)','Derived at 22 stations.','For military purposes only. Accuracy 5m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4201','EPSG','4326','EPSG','1271',9.0,-166.0,-15.0,204.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Eth Sud',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1101','Adindan to WGS 84 (2)','Derived at 1 station connected to the Adindan (Blue Nile 1958) network through the 1968-69 12th parallel traverse. Note: the Adindan (Blue Nile 1958) CRS is used in Ethiopia and Sudan, not Burkino Faso.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4201','EPSG','4326','EPSG','1057',44.0,-118.0,-14.0,218.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Bfa',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1102','Adindan to WGS 84 (3)','Derived at 1 station connected to the Adindan (Blue Nile 1958) network through the 1968-69 12th parallel traverse. Note: the Adindan (Blue Nile 1958) CRS is used in Ethiopia and Sudan, not Cameroon.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4201','EPSG','4326','EPSG','3226',44.0,-134.0,-2.0,210.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Cmr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1103','Adindan to WGS 84 (4)','Derived at 8 stations.','For military purposes. Accuracy 3m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4201','EPSG','4326','EPSG','1091',6.0,-165.0,-11.0,206.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Eth',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1104','Adindan to WGS 84 (5)','Derived at 1 station connected to the Adindan (Blue Nile 1958) network through the 1968-69 12th parallel traverse. Note: the Adindan (Blue Nile 1958) CRS is used in Ethiopia and Sudan, not Mali.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4201','EPSG','4326','EPSG','1153',44.0,-123.0,-20.0,220.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Mli',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1105','Adindan to WGS 84 (6)','Derived at 2 stations connected to the Adindan (Blue Nile 1958) network through the 1968-69 12th parallel traverse. Note: The Adindan (Blue Nile 1958) CRS is used in Ethiopia and Sudan, not Senegal.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4201','EPSG','4326','EPSG','3304',44.0,-128.0,-18.0,224.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Sen',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1106','Adindan to WGS 84 (7)','Derived at 14 stations.','For military purposes. Accuracy 3m, 5m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4201','EPSG','4326','EPSG','3311',7.0,-161.0,-14.0,205.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Sud',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1107','Afgooye to WGS 84 (1)','Derived at 1 station.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4205','EPSG','4326','EPSG','3308',44.0,-43.0,-163.0,45.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Som',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1108','AGD66 to WGS 84 (1)','Derived at 105 stations. Replaced by AGD66 to WGS 84 (20) (code 6905).','For military purposes only. Accuracy 3m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4202','EPSG','4326','EPSG','2575',6.0,-133.0,-48.0,148.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Aus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1109','AGD84 to WGS 84 (1)','Derived at 90 stations. Note: AGD84 officially adopted only in Queensland, South Australia and Western Australia.','For military purposes only. Accuracy 2m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4203','EPSG','4326','EPSG','2576',4.0,-134.0,-48.0,149.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Aus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1110','Ain el Abd to WGS 84 (1)','Derived at 2 stations.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4204','EPSG','4326','EPSG','3943',44.0,-150.0,-250.0,-1.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Bhr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1111','Ain el Abd to WGS 84 (2)','Derived at 9 stations.','For military purposes. Accuracy 10m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4204','EPSG','4326','EPSG','3303',18.0,-143.0,-236.0,7.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Sau',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1112','Amersfoort to WGS 84 (1)','Replaced by Amersfoort to WGS 84 (2) (code 1672).','Not known.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4289','EPSG','4326','EPSG','1275',1.0,593.16,26.15,478.54,'EPSG','9001',-6.3239,-0.5008,-5.5487,'EPSG','9109',4.0775,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NCG-Nld 93',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1113','Arc 1950 to WGS 84 (1)','Derived at 41 stations.','For military purposes only. Accuracy 20m, 33m and 20m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4209','EPSG','4326','EPSG','2312',44.0,-143.0,-90.0,-294.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-mean',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1114','Arc 1950 to WGS 84 (2)','Derived at 9 stations.','For military purposes. Accuracy 3m, 5m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4209','EPSG','4326','EPSG','1051',7.0,-138.0,-105.0,-289.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Bwa',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1115','Arc 1950 to WGS 84 (3)','Derived at 3 stations.','For military purposes. Accuracy 20m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4209','EPSG','4326','EPSG','1058',35.0,-153.0,-5.0,-292.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Bdi',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1116','Arc 1950 to WGS 84 (4)','Derived at 5 stations.','For military purposes. Accuracy 3m, 3m and 8m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4209','EPSG','4326','EPSG','1141',10.0,-125.0,-108.0,-295.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Lso',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1117','Arc 1950 to WGS 84 (5)','Derived at 6 stations.','For military purposes. Accuracy 9m, 24m and 8m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4209','EPSG','4326','EPSG','1150',27.0,-161.0,-73.0,-317.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Mwi',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1118','Arc 1950 to WGS 84 (6)','Derived at 4 stations.','For military purposes. Accuracy 15m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4209','EPSG','4326','EPSG','1224',26.0,-134.0,-105.0,-295.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Swz',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1119','Arc 1950 to WGS 84 (7)','Derived at 2 stations.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4209','EPSG','4326','EPSG','1259',25.0,-169.0,-19.0,-278.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Cod',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1120','Arc 1950 to WGS 84 (8)','Derived at 5 stations.','For military purposes. Accuracy 21m, 21m and 27m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4209','EPSG','4326','EPSG','1260',41.0,-147.0,-74.0,-283.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Zmb',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1121','Arc 1950 to WGS 84 (9)','Derived at 10 stations. Replaced by Arc 1950 to WGS 84 (10), tfm code 6906.','For military purposes. Accuracy 5m, 8m and 11m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4209','EPSG','4326','EPSG','1261',15.0,-142.0,-96.0,-293.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Zwe',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1122','Arc 1960 to WGS 84 (1)','Derived at 25 stations.','For military purposes only. Accuracy 20m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4210','EPSG','4326','EPSG','2311',35.0,-160.0,-6.0,-302.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Ken Tza',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1123','Batavia to WGS 84 (1)','Note: The area of use cited for this transformation (Sumatra) is not consistent with the area of use (Java) for the Batavia (Genuk) coordinate reference system. Derived at 5 stations.','For military purposes. Accuracy 3m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4211','EPSG','4326','EPSG','1355',6.0,-377.0,681.0,-50.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Idn Sumatra',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1124','Bermuda 1957 to WGS 84 (1)','Derived at 3 stations.','For military purposes. Accuracy 20m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4216','EPSG','4326','EPSG','3221',35.0,-73.0,213.0,296.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Bmu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1125','Bogota 1975 to WGS 84 (1)','Derived in 1987 at 7 stations.','For military purposes. Accuracy 6m, 5m and 6m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4218','EPSG','4326','EPSG','3686',10.0,307.0,304.0,-318.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Col',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1126','Bukit Rimpah to WGS 84 (1)','Accuracy estimate not available.','For military purposes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4219','EPSG','4326','EPSG','1287',999.0,-384.0,664.0,-48.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Idn BBI',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1127','Campo Inchauspe to WGS 84 (1)','Derived at 20 stations.','For military purposes. Accuracy 5m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4221','EPSG','4326','EPSG','3843',9.0,-148.0,136.0,90.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Arg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1128','Cape to WGS 84 (1)','Derived at 5 stations.','For military purposes. Accuracy 3m, 6m and 6m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4222','EPSG','4326','EPSG','3309',9.0,-136.0,-108.0,-292.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Zaf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1129','Cape to WGS 84 (2)','Parameter values are from Cape to Hartebeesthoek94 (1) (code 1504) assuming that Hartebeesthoek94 and WGS 84 are equivalent within the accuracy of the transformation. Residuals should not exceed 15 metres.','Accuracy 15m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4222','EPSG','4326','EPSG','3309',15.0,-134.73,-110.92,-292.66,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DSLI-Zaf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1130','Carthage to WGS 84 (1)','Derived at 5 stations.','For military purposes. Accuracy 6m, 9m and 8m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4223','EPSG','4326','EPSG','1236',14.0,-263.0,6.0,431.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Tun',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1131','Chua to WGS 84 (1)','Derived at 6 stations.','For military purposes. Accuracy 6m, 9m and 5m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4224','EPSG','4326','EPSG','3675',12.0,-134.0,229.0,-29.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Pry',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1132','Corrego Alegre 1970-72 to WGS 84 (1)','Derived at 17 stations.','For military purposes. Accuracy 5m, 3m and 5m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4225','EPSG','4326','EPSG','1293',8.0,-206.0,172.0,-6.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Bra',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1133','ED50 to WGS 84 (1)','Derived at 85 stations. In Germany will be accepted by LBA for minerals management purposes as alternative to tfm 1052 or 1998.','For military purposes. Accepted for minerals management in Germany. Accuracy 3m, 8m and 5m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2420',10.0,-87.0,-98.0,-121.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-mean',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1134','ED50 to WGS 84 (2)','Derived at 52 stations.','For military purposes only. Accuracy 3m each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2421',6.0,-87.0,-96.0,-120.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-cenEur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1135','ED50 to WGS 84 (3)','Accuracy estimate not available. Note: ED50 is not used in Israel, Lebanon, Kuwait, Saudi Arabia or Syria.','For military purposes only.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2345',999.0,-103.0,-106.0,-141.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-midEast',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1136','ED50 to WGS 84 (4)','Derived at 4 stations.','For military purposes only. Accuracy 15m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','1078',26.0,-104.0,-101.0,-140.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Cyp',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1137','ED50 to WGS 84 (5)','Derived at 14 stations.','For military purposes. Accuracy 6m, 8m and 8m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2595',13.0,-130.0,-117.0,-151.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Egy',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1138','ED50 to WGS 84 (6)','Derived at 40 stations.','For military purposes only. Accuracy 3m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2343',6.0,-86.0,-96.0,-120.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Irl Gbr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1139','ED50 to WGS 84 (7)','Derived at 20 stations.','For military purposes. Accuracy 3m, 5m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2344',7.0,-87.0,-95.0,-120.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Fin Nor',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1140','ED50 to WGS 84 (8)','Derived at 2 stations.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','3254',44.0,-84.0,-95.0,-130.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Grc',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1141','ED50(ED77) to WGS 84 (2)','Given by DMA as from ED50. OGP interpret that as ED50(ED77) in Iran. Derived at 27 stations.','For military purposes. Accuracy 9m, 12m and 11m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4154','EPSG','4326','EPSG','1123',19.0,-117.0,-132.0,-164.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Irn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1142','ED50 to WGS 84 (10)','Derived at 2 stations.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2339',44.0,-97.0,-103.0,-120.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Ita Sard',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1143','ED50 to WGS 84 (11)','Derived at 3 stations.','For military purposes only. Accuracy 20m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2340',35.0,-97.0,-88.0,-135.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Ita Sic',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1144','ED50 to WGS 84 (12)','Derived at 1 station.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','3275',44.0,-107.0,-88.0,-149.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Mlt',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1145','ED50 to WGS 84 (13)','Derived at 18 stations.','For military purposes only. Accuracy 5m, 6m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2338',9.0,-84.0,-107.0,-120.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Prt Esp',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1146','ED87 to WGS 84 (1)','','Not known.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4231','EPSG','4326','EPSG','2330',0.8,-82.981,-99.719,-110.709,'EPSG','9001',-0.5076,0.1503,0.3898,'EPSG','9109',-0.3143,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'5Nat-NSea-90',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1147','ED50 to ED87 (2)','','Geodetic purposes.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4231','EPSG','2332',1.0,-1.51,-0.84,-3.5,'EPSG','9001',-1.893,-0.687,-2.764,'EPSG','9109',0.609,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NMA-Nor N65',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1148','Egypt 1907 to WGS 84 (1)','Derived at 14 stations.','For military purposes. Accuracy 3m, 6m and 8m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4229','EPSG','4326','EPSG','1086',11.0,-130.0,110.0,-13.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Egy',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1149','ETRS89 to WGS 84 (1)','','ETRS89 and WGS 84 are realizations of ITRS coincident to within 1 metre. This transformation has an accuracy equal to the coincidence figure.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4258','EPSG','4326','EPSG','1298',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-eur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1150','GDA94 to WGS 84 (1)','Approximation at the +/- 3m level using inappropriate assumption that GDA94 is equivalent to WGS 84. Accuracy changed from 1m to 3m due to tectonic plate motion over more than 15 years.','Spatial referencing with 3-metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4283','EPSG','4326','EPSG','4177',3.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Aus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1151','NZGD49 to WGS 84 (1)','Derived at 14 stations.','For military purposes only. Accuracy 5m, 3m and 5m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4272','EPSG','4326','EPSG','3285',8.0,84.0,-22.0,209.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Nzl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1152','Hu Tzu Shan 1950 to WGS 84 (1)','Derived at 4 stations.','For military purposes. Accuracy 15m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4236','EPSG','4326','EPSG','3315',26.0,-637.0,-549.0,-203.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Twn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1153','Indian 1954 to WGS 84 (1)','Derived at 11 stations.','For military purposes. Accuracy 15m, 6m and 12m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4239','EPSG','4326','EPSG','3317',21.0,217.0,823.0,299.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Tha',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1154','Indian 1975 to WGS 84 (1)','Derived at 62 stations. Replaced by Indian 1975 to WGS 84 (2) (code 1304).','For military purposes. Accuracy 3m, 2m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4240','EPSG','4326','EPSG','3741',5.0,209.0,818.0,290.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Tha',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1155','Kalianpur 1937 to WGS 84 (1)','Derived at 6 stations.','For military purposes. Accuracy 10m, 8m and 12m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4144','EPSG','4326','EPSG','3217',18.0,282.0,726.0,254.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Bgd',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1156','Kalianpur 1975 to WGS 84 (1)','Care! DMA ellipsoid is inconsistent with EPSG ellipsoid - transformation parameter values may not be appropriate. Also source CRS may not apply to Nepal. Derived at 7 stations.','For military purposes. Accuracy 12m, 10m and 15m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4146','EPSG','4326','EPSG','2411',22.0,295.0,736.0,257.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Ind Npl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1157','Kandawala to WGS 84 (1)','Derived at 3 stations.','For military purposes. Accuracy 20m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4244','EPSG','4326','EPSG','3310',35.0,-97.0,787.0,86.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Lka',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1158','Kertau 1968 to WGS 84 (1)','Derived at 6 stations.','For military purposes. Accuracy 10m, 8m and 6m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4245','EPSG','4326','EPSG','4223',15.0,-11.0,851.0,5.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Mys Sgp',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1159','Leigon to WGS 84 (1)','Derived at 8 stations.','For military purposes. Accuracy 2m, 3m and 2m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4250','EPSG','4326','EPSG','1104',5.0,-130.0,29.0,364.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Gha',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1160','Liberia 1964 to WGS 84 (1)','Derived at 4 stations.','For military purposes only. Accuracy 15m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4251','EPSG','4326','EPSG','3270',26.0,-90.0,40.0,88.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Lbr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1161','Luzon 1911 to WGS 84 (1)','Derived at 6 stations.','For military purposes. Accuracy 8m, 11m and 9m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4253','EPSG','4326','EPSG','2364',17.0,-133.0,-77.0,-51.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Phl N',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1162','Luzon 1911 to WGS 84 (2)','Derived at 1 station.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4253','EPSG','4326','EPSG','2365',44.0,-133.0,-79.0,-72.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Phl Min',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1163','M''poraloko to WGS 84 (1)','Derived at 1 station.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4266','EPSG','4326','EPSG','1100',44.0,-74.0,-130.0,42.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Gab',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1164','Mahe 1971 to WGS 84 (1)','Derived at 1 station.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4256','EPSG','4326','EPSG','2369',44.0,41.0,-220.0,-134.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Syc',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1165','Massawa to WGS 84 (1)','Derived at 1 station.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4262','EPSG','4326','EPSG','1089',44.0,639.0,405.0,60.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Eth',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1166','Merchich to WGS 84 (1)','Derived at 9 stations.','For military purposes. Accuracy 5m, 3m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4261','EPSG','4326','EPSG','3280',7.0,31.0,146.0,47.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Mar',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1167','Minna to WGS 84 (1)','Derived at 2 stations. Note: Minna is used in Nigeria, not Cameroon.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4263','EPSG','4326','EPSG','3226',44.0,-81.0,-84.0,115.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Cmr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1168','Minna to WGS 84 (2)','Derived at 6 stations.','For military purposes. Accuracy 3m, 6m and 5m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4263','EPSG','4326','EPSG','1178',15.0,-92.0,-93.0,122.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Nga',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1169','Monte Mario to WGS 84 (1)','Derived at 1 station.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4265','EPSG','4326','EPSG','2339',44.0,-225.0,-65.0,9.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Ita Sar',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1170','NAD27 to WGS 84 (1)','Derived at 15 stations.','For military purposes. Accuracy 3m, 9m and 12m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','2418',16.0,-3.0,142.0,183.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Carib',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1171','NAD27 to WGS 84 (2)','Derived at 19 stations.','For military purposes only. Accuracy 8m, 3m and 5m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','2419',10.0,0.0,125.0,194.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Cen Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1172','NAD27 to WGS 84 (3)','Derived at 112 stations.','For military purposes only. Accuracy 15m, 11m and 6m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','4517',20.0,-10.0,158.0,187.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Can',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1173','NAD27 to WGS 84 (4)','Derived at 405 stations.','For military purposes only. Accuracy 5m, 5m and 6m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','1323',10.0,-8.0,160.0,176.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Conus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1174','NAD27 to WGS 84 (5)','Derived at 129 stations.','For military purposes only. Accuracy 5m, 5m and 8m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','2389',11.0,-9.0,161.0,179.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-ConusE',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1175','NAD27 to WGS 84 (6)','Derived at 276 stations.','For military purposes only. Accuracy 5m, 3m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','2390',7.0,-8.0,159.0,175.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-ConusW',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1176','NAD27 to WGS 84 (7)','Derived at 47 stations.','For military purposes only. Accuracy 5m, 9m and 5m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','2412',12.0,-5.0,135.0,172.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-USA AK',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1177','NAD27 to WGS 84 (8)','Derived at 11 stations.','For military purposes. Accuracy 5m, 3m and 5m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','2413',8.0,-4.0,154.0,178.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Bha xSalv',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1178','NAD27 to WGS 84 (9)','Derived at 1 station.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','2414',44.0,1.0,140.0,165.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Bha Salv',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1179','NAD27 to WGS 84 (10)','Derived at 25 stations.','For military purposes only. Accuracy 8m, 8m and 6m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','2384',13.0,-7.0,162.0,188.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Can AB BC',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1180','NAD27 to WGS 84 (11)','Derived at 25 stations.','For military purposes only. Accuracy 9m, 5m and 5m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','2415',12.0,-9.0,157.0,184.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Can MN ON',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1181','NAD27 to WGS 84 (12)','Derived at 37 stations.','For military purposes only. Accuracy 6m, 6m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','2416',9.0,-22.0,160.0,190.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Can E',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1182','NAD27 to WGS 84 (13)','Derived at 17 stations.','For military purposes only. Accuracy 5m, 5m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','2410',8.0,4.0,159.0,188.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Can NWT',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1183','NAD27 to WGS 84 (14)','Derived at 8 stations.','For military purposes only. Accuracy 5m, 8m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','2417',10.0,-7.0,139.0,181.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Can Yuk',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1184','NAD27 to WGS 84 (15)','Derived at 3 stations.','For military purposes. Accuracy 20m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','2385',35.0,0.0,125.0,201.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Pan',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1185','NAD27 to WGS 84 (16)','Derived at 1 station.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','3235',44.0,-9.0,152.0,178.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Cuba',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1186','NAD27 to WGS 84 (17)','Derived at 2 stations. Note: NAD27 is not used in Greenland.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','2386',44.0,11.0,114.0,195.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Grl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1187','NAD27 to WGS 84 (18)','Derived at 22 stations.','For military purposes only. Accuracy 8m, 6m and 6m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','3278',12.0,-12.0,130.0,190.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Mex',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1188','NAD83 to WGS 84 (1)','Derived at 354 stations.','Accuracy 2m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4269','EPSG','4326','EPSG','1325',4.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-N Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1189','Nahrwan 1967 to WGS 84 (1)','Derived at 2 stations.  Note: Nahrwan 1967 is not used in Oman.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4270','EPSG','4326','EPSG','2391',44.0,-247.0,-148.0,369.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Omn Mas',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1190','Nahrwan 1967 to WGS 84 (2)','Derived at 3 stations.','For military purposes. Accuracy 20m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4270','EPSG','4326','EPSG','3968',35.0,-243.0,-192.0,477.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Sau',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1191','Nahrwan 1967 to WGS 84 (3)','Derived at 2 stations.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4270','EPSG','4326','EPSG','1243',44.0,-249.0,-156.0,381.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-UAE',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1192','Naparima 1972 to WGS 84 (1)','CAUTION: IOGP believes that the coordinates used to derive these parameter values include a blunder, leading to an error in the value of tX. If a transformation from DMA is required IOGP recommends use of the 1987 version (EPSG codes 1307 and 1556).','For military purposes only. Accuracy given by DMA 15m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4271','EPSG','4326','EPSG','1322',33.0,-10.0,375.0,165.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Tto',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1193','NTF to WGS 84 (1)','These same parameter values are used to transform to ETRS89. See NTF to ETRS89 (1) (code 1651).','For applications to an accuracy of 2 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4275','EPSG','4326','EPSG','3694',2.0,-168.0,-60.0,320.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Fra',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1194','MGI to WGS 84 (8)','May be taken as approximate transformation MGI to ETRS89 assuming ETRS89 is equivalent to WGS 84 within the accuracy of the transformation - see tfm code 1024. Information source gives scale as -2.388739 ppm.','Provincial GIS and other applications to an accuracy of 0.5 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4312','EPSG','4326','EPSG','1543',0.5,601.705,84.263,485.227,'EPSG','9001',-4.7354,-1.3145,-5.393,'EPSG','9104',-2.3887,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'LBD-Aut Sty',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1195','OSGB 1936 to WGS 84 (1)','Derived at 38 stations.','For military purposes only. Accuracy 10m, 10m and 15m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4277','EPSG','4326','EPSG','1264',21.0,375.0,-111.0,431.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Gbr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1196','OSGB 1936 to WGS 84 (2)','Derived at 24 stations.','For military purposes only. Accuracy 5m, 5m and 6m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4277','EPSG','4326','EPSG','2395',10.0,371.0,-112.0,434.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Gbr Eng',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1197','OSGB 1936 to WGS 84 (3)','Derived at 25 stations.','For military purposes only. Accuracy 10m, 10m and 15m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4277','EPSG','4326','EPSG','2396',21.0,371.0,-111.0,434.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Gbr E&W',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1198','OSGB 1936 to WGS 84 (4)','Derived at 13 stations.','For military purposes only. Accuracy 10m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4277','EPSG','4326','EPSG','2397',18.0,384.0,-111.0,425.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Gbr Sco',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1199','OSGB 1936 to WGS 84 (5)','Derived at 3 stations.','For military purposes only. Accuracy 20m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4277','EPSG','4326','EPSG','2398',35.0,370.0,-108.0,434.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Gbr Wal',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1200','Pointe Noire to WGS 84 (1)','Derived at 1 station.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4282','EPSG','4326','EPSG','1072',44.0,-148.0,51.0,-291.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Cog',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1201','PSAD56 to WGS 84 (1)','Derived at 63 stations. DMA also lists Colombia as area of applicability but PSAD56 is not used in that country.','For military purposes only. Accuracy 17m, 27m and 27m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4248','EPSG','4326','EPSG','2399',42.0,-288.0,175.0,-376.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-mean',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1202','PSAD56 to WGS 84 (2)','Derived at 5 stations.','For military purposes only. Accuracy 5m, 11m and 14m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4248','EPSG','4326','EPSG','1049',19.0,-270.0,188.0,-388.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Bol',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1203','PSAD56 to WGS 84 (3)','Derived at 1 station. Replaced by PSAD56 to WGS 84 (15) (code 6971).','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4248','EPSG','4326','EPSG','2402',44.0,-270.0,183.0,-390.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Chl N',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1204','PSAD56 to WGS 84 (4)','Derived at 3 stations. Replaced by PSAD56 to WGS 84 (17) (code 6973).','For military purposes. Accuracy 20m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4248','EPSG','4326','EPSG','2403',35.0,-305.0,243.0,-442.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Chl S',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1205','PSAD56 to WGS 84 (5)','Derived at 4 stations. Note that although the PSAD56 network included Colombia the CRS is not used there: see Bogota 1975 (CRS code 4218).','For military purposes. Accuracy 15m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4248','EPSG','4326','EPSG','3229',26.0,-282.0,169.0,-371.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Col',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1206','PSAD56 to WGS 84 (6)','Derived at 11 stations.','For military purposes. Accuracy 3m, 5m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4248','EPSG','4326','EPSG','3241',7.0,-278.0,171.0,-367.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Ecu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1207','PSAD56 to WGS 84 (7)','Derived at 9 stations.','For military purposes. Accuracy 6m, 14m and 5m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4248','EPSG','4326','EPSG','1114',17.0,-298.0,159.0,-369.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Guy',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1208','PSAD56 to WGS 84 (8)','Derived at 6 stations.','For military purposes only. Accuracy 6m, 8m and 12m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4248','EPSG','4326','EPSG','3292',16.0,-279.0,175.0,-379.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Per',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1209','PSAD56 to WGS 84 (9)','Derived at 24 stations.','For military purposes only. Accuracy 9m, 14m and 15m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4248','EPSG','4326','EPSG','3327',23.0,-295.0,173.0,-371.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Ven',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1210','POSGAR 94 to WGS 84 (1)','','Transformation with 1-metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4694','EPSG','4326','EPSG','1033',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Arg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1211','Qornoq to WGS 84 (1)','Derived at 2 stations.','For military purposes. Accuracy 25m, 25m and 32m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4287','EPSG','4326','EPSG','2407',NULL,164.0,138.0,-189.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Grl S',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1212','SAD69 to WGS 84 (1)','Derived at 84 stations.','For military purposes only. Accuracy 15m, 6m and 9m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4291','EPSG','4326','EPSG','1341',NULL,-57.0,1.0,-41.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-mean',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1213','SAD69 to WGS 84 (2)','Derived at 10 stations.','For military purposes only. Accuracy 5m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4291','EPSG','4326','EPSG','1033',NULL,-62.0,-1.0,-37.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Arg',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1214','SAD69 to WGS 84 (3)','Derived at 4 stations.','For military purposes. Accuracy 15m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4291','EPSG','4326','EPSG','1049',NULL,-61.0,2.0,-48.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Bol',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1215','SAD69 to WGS 84 (4)','Derived at 22 stations.','For military purposes only. Accuracy 3m, 5m and 5m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4291','EPSG','4326','EPSG','1053',NULL,-60.0,-2.0,-41.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Bra',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1216','SAD69 to WGS 84 (5)','Derived at 9 stations.','For military purposes only. Accuracy 15m, 8m and 11m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4291','EPSG','4326','EPSG','1066',NULL,-75.0,-1.0,-44.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Chile',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1217','SAD69 to WGS 84 (6)','Derived at 7 stations.','For military purposes only. Accuracy 6m, 6m and 5m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4291','EPSG','4326','EPSG','1070',NULL,-44.0,6.0,-36.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Col',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1218','SAD69 to WGS 84 (7)','Derived at 11 stations.','For military purposes. Accuracy 3m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4291','EPSG','4326','EPSG','1085',NULL,-48.0,3.0,-44.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Ecu',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1219','SAD69 to WGS 84 (8)','Derived at 1 station.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4291','EPSG','4326','EPSG','2356',NULL,-47.0,26.0,-42.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Ecu Gal',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1220','SAD69 to WGS 84 (9)','Derived at 5 stations.','For military purposes only. Accuracy 9m, 5m and 5m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4291','EPSG','4326','EPSG','1114',NULL,-53.0,3.0,-47.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Guy',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1221','SAD69 to WGS 84 (10)','Derived at 4 stations.','For military purposes. Accuracy 15m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4291','EPSG','4326','EPSG','1188',NULL,-61.0,2.0,-33.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Pgy',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1222','SAD69 to WGS 84 (11)','Derived at 6 stations.','For military purposes. Accuracy 5m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4291','EPSG','4326','EPSG','1189',NULL,-58.0,0.0,-44.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Peru',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1223','SAD69 to WGS 84 (12)','Derived at 1 station.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4291','EPSG','4326','EPSG','1235',NULL,-45.0,12.0,-33.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Tto',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1224','SAD69 to WGS 84 (13)','Derived at 5 stations.','For military purposes only. Accuracy 3m, 6m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4291','EPSG','4326','EPSG','1251',NULL,-45.0,8.0,-33.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Ven',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1225','Sapper Hill 1943 to WGS 84 (1)','Derived at 5 stations.','For military purposes. Accuracy 1m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4292','EPSG','4326','EPSG','2355',2.0,-355.0,21.0,72.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Flk E',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1226','Schwarzeck to WGS 84 (1)','Derived at 3 stations. ¶Beware!  Source CRS uses German legal metres, transformation parameter values are in (International) metres. See tfm code 1271 for example.','For military purposes only. Accuracy 20m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4293','EPSG','4326','EPSG','1169',35.0,616.0,97.0,-251.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Nam',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1227','Tananarive to WGS 84 (1)','Accuracy estimate not available.','For military purposes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4297','EPSG','4326','EPSG','1149',999.0,-189.0,-242.0,-91.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Mdg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1228','Timbalai 1948 to WGS 84 (1)','Derived at 8 stations.','For military purposes. Accuracy 10m, 10m and 12m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4298','EPSG','4326','EPSG','1362',19.0,-679.0,669.0,-48.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Borneo',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1229','TM65 to WGS 84 (1)','Derived at 7 stations.','For military purposes only. Accuracy 3m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4299','EPSG','4326','EPSG','1305',NULL,506.0,-122.0,611.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Ire',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1230','Tokyo to WGS 84 (1)','Derived at 31 stations.','For military purposes only. Accuracy 20m, 5m and 20m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4301','EPSG','4326','EPSG','2409',29.0,-148.0,507.0,685.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Jpn Kor',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1231','Tokyo to WGS 84 (2)','Derived at 16 stations.','For military purposes only. Accuracy 8m, 5m and 8m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4301','EPSG','4326','EPSG','3995',13.0,-148.0,507.0,685.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Jpn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1232','Tokyo to WGS 84 (3)','Derived at 29 stations. Replaced by Tokyo to WGS 84 (5) (code 1305).','For military purposes only. Accuracy 8m, 5m and 8m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4301','EPSG','4326','EPSG','3266',13.0,-146.0,507.0,687.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Kor',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1233','Tokyo to WGS 84 (4)','Derived at 3 stations.','For military purposes only. Accuracy 20m, 5m and 20m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4301','EPSG','4326','EPSG','2408',29.0,-158.0,507.0,676.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Jpn Ok',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1234','Yacare to WGS 84 (1)','Accuracy estimate not available.','For military purposes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4309','EPSG','4326','EPSG','3326',999.0,-155.0,171.0,37.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Ury',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1235','Zanderij to WGS 84 (1)','Derived at 5 stations.','For military purposes. Accuracy 5m, 5m and 8m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4311','EPSG','4326','EPSG','1222',11.0,-265.0,120.0,-358.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Sur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1236','AGD84 to WGS 84 (2)','"Higgins parameters". Replaced by AGD84 to GDA94 (2) (code 1280) and AGD84 to WGS 84 (7) (code 1669). Note: AGD84 officially adopted only in Queensland, South Australia and Western Australia.','Preliminary estimate.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4203','EPSG','4326','EPSG','2576',5.0,-116.0,-50.47,141.69,'EPSG','9001',-0.23,-0.39,-0.344,'EPSG','9104',0.0983,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Auslig-Aus old',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1237','WGS 72 to WGS 84 (1)','','For scientific purposes.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4322','EPSG','4326','EPSG','1262',2.0,0.0,0.0,4.5,'EPSG','9001',0.0,0.0,0.554,'EPSG','9104',0.2263,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA1',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1238','WGS 72 to WGS 84 (2)','','For scientific purposes.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4322','EPSG','4326','EPSG','1262',2.0,0.0,0.0,4.5,'EPSG','9001',0.0,0.0,0.554,'EPSG','9104',0.219,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA2',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1239','WGS 72BE to WGS 72 (1)','','Geodesy.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4324','EPSG','4322','EPSG','1262',2.0,0.0,0.0,-2.6,'EPSG','9001',0.0,0.0,0.26,'EPSG','9104',-0.6063,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1240','WGS 72BE to WGS 84 (1)','','Geodesy.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4324','EPSG','4326','EPSG','2346',2.0,0.0,0.0,1.9,'EPSG','9001',0.0,0.0,0.814,'EPSG','9104',-0.38,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1242','HD72 to WGS 84 (4)','Parameter value error in info source Hungarian text but correct in English summary. Replaces HD72 to WGS 84 (2) (code 1831).','Accuracy at metre level throughout Hungary.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4237','EPSG','4326','EPSG','1119',1.0,52.17,-71.82,-14.9,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELTE-Hun 2004',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1244','PZ-90 to WGS 84 (2)','Mandated for use in Russia by GosStandard of Russia Decree #327 of August 9, 2001. Republished but with one significant figure less precision to parameter values in GOST R 51794-2008 of December 18 2008.','Geodetic applications. Accuracy better than 0.5 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4740','EPSG','4326','EPSG','1198',0.5,-1.08,-0.27,-0.9,'EPSG','9001',0.0,0.0,-0.16,'EPSG','9104',-0.12,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GOST-Rus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1245','ED50 to WGS 84 (16)','Derived at 4 stations.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','1236',44.0,-112.0,-77.0,-145.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Tun',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1246','Herat North to WGS 84 (1)','Accuracy estimate not available.','For military purposes only.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4255','EPSG','4326','EPSG','1024',999.0,-333.0,-222.0,114.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Afg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1247','Kalianpur 1962 to WGS 84 (1)','Care! DMA ellipsoid is inconsistent with EPSG ellipsoid - transformation parameter values may not be appropriate. No accuracy estimate available.','For military purposes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4145','EPSG','4326','EPSG','3289',999.0,283.0,682.0,231.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Pak',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1248','ID74 to WGS 84 (1)','Derived at 1 station.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4238','EPSG','4326','EPSG','4020',44.0,-24.0,-15.0,5.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Idn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1249','NAD27 to WGS 84 (21)','Derived at 6 stations.','For military purposes only. Accuracy 6m, 8m and 10m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','2387',15.0,-2.0,152.0,149.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-AK AluE',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1250','NAD27 to WGS 84 (22)','Derived at 5 stations.','For military purposes. Accuracy 10m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','2388',18.0,2.0,204.0,105.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-AK AluW',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1251','NAD83 to WGS 84 (2)','Derived at 4 stations.','For military purposes only. Accuracy 5m, 2m and 5m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4269','EPSG','4326','EPSG','2157',8.0,-2.0,0.0,4.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-AK Alu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1252','NAD83 to WGS 84 (3)','Derived at 6 stations.','For military purposes only. Accuracy 2m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4269','EPSG','4326','EPSG','3883',4.0,1.0,1.0,-1.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-USA Hi',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1253','Nord Sahara 1959 to WGS 84 (1)','Derived at 3 stations.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4307','EPSG','4326','EPSG','3213',44.0,-186.0,-93.0,310.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Alg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1254','Pulkovo 1942 to WGS 84 (1)','Accuracy estimate not available.','For military purposes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4284','EPSG','4326','EPSG','3296',999.0,28.0,-130.0,-95.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Rus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1255','Nord Sahara 1959 to WGS 84 (2)','CAUTION: Source CRS described by DMA as from Voirol 1960. OGP believes that the data used in the derivation of these parameters contains a blunder. We recommend using transformation North Sahara 1959 to WGS84 (1) (code 1253). Derived at 2 stations.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4307','EPSG','4326','EPSG','1365',44.0,-123.0,-206.0,219.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Dza N',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1256','Fahud to WGS 84 (1)','Derived at 7 stations. Replaced by Fahud to WGS 84 (3) (code 6908).','For military purposes. Accuracy 3m, 3m and 9m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4232','EPSG','4326','EPSG','4009',10.0,-346.0,-1.0,224.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Omn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1257','Pulkovo 1995 to PZ-90 (1)','Mandated for use in Russia by GosStandard of Russia Decree #327 of August 9, 2001.','Accuracy better than 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4200','EPSG','4740','EPSG','1198',1.0,25.9,-130.94,-81.76,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GOST-Rus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1267','Pulkovo 1942 to WGS 84 (17)','Derived through concatenation of Pulkovo 1942 to PZ-90 (1) (tfm code 15844) and PZ-90 to WGS 84 (2) (tfm code 1244. Mandated for use in Russia by GOST R 51794-2001, but this has been superseded by GOST R 51794-2008. Replaced by tfm code 5044.','Accuracy 4 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4284','EPSG','4326','EPSG','3296',4.0,23.92,-141.27,-80.9,'EPSG','9001',0.0,-0.35,-0.82,'EPSG','9104',-0.12,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GOST-Rus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1271','Schwarzeck to WGS 84 (2)','Beware!  Source CRS uses GLM, tfm param in m. Example: Schwarzeck φ=19°35''46.952"S λ=20°41''50.649"E h=1185.99m; X=5623409.386 Y=2124618.003 Z=-2125847.632 GLM; X=5623485.84m Y=2124646.89m Z=-2125876.54m; WGS 84 X=5624101.48m Y=2124748.97m Z=-2126132.35m.','Not known.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4293','EPSG','4326','EPSG','1169',999.0,615.64,102.08,-255.81,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SLI-Nam',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1272','GGRS87 to WGS 84 (1)','','For applications requiring 1m or better accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4121','EPSG','4326','EPSG','3254',1.0,-199.87,74.79,246.62,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Hel-Grc',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1273','HD72 to ETRS89 (1)','May be taken as approximate transformation HD72 to WGS 84 - see code 1677.','?','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4237','EPSG','4258','EPSG','1119',NULL,-56.0,75.77,15.31,'EPSG','9001',-0.37,-0.2,-0.21,'EPSG','9104',-1.01,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELTE-Hun',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1274','Pulkovo 1942 to LKS94 (1)','May be taken as approximate transformation Pulkovo 1942 to WGS 84 - see code 1679.','For applications to an accuracy of 9 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4284','EPSG','4669','EPSG','3272',9.0,-40.595,-18.55,-69.339,'EPSG','9001',-2.508,-1.832,2.611,'EPSG','9104',-4.299,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'HNIT-Ltu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1275','ED50 to WGS 84 (17)','These same parameter values are used to transform to ETRS89. See ED50 to ETRS89 (10) (code 1650).','For applications to an accuracy of 2 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','1096',2.0,-84.0,-97.0,-117.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Fra',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1276','NTF to ED50 (1)','','For applications to an accuracy of 2 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4275','EPSG','4230','EPSG','3694',2.0,-84.0,37.0,437.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Fra',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1277','NTF to WGS 72 (1)','','For applications to an accuracy of 2 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4275','EPSG','4322','EPSG','3694',2.0,-168.0,-72.0,314.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Fra',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1278','AGD66 to GDA94 (1)','Given to greater precision but no better accuracy at http://www.dehaa.sa.gov.au For higher accuracy requirements see various regional transformations. May be taken as approximate transformation AGD66 to WGS 84 - see code 15788. Derived at 162 stations.','5m accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4202','EPSG','4283','EPSG','2575',5.0,-127.8,-52.3,152.9,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Auslig-Aus 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1279','AGD84 to GDA94 (1)','Derived at 327 stations. May be taken as approximate transformation AGD84 to WGS 84 - see code 15789. For higher accuracy use AGD84 to GDA94 (2) (code 1280). Note: AGD84 officially adopted only in Queensland, South Australia and Western Australia.','5m accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4203','EPSG','4283','EPSG','2576',5.0,-128.5,-53.0,153.4,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Auslig-Aus 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1280','AGD84 to GDA94 (2)','Replaces AGD84 to WGS 84 (2) (code 1236). May be taken as approximate transformation AGD84 to WGS 84 - see code 1669. Note: although applicable nationwide, AGD84 officially adopted only in Queensland, South Australia and Western Australia.','1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4203','EPSG','4283','EPSG','2576',1.0,-117.763,-51.51,139.061,'EPSG','9001',-0.292,-0.443,-0.277,'EPSG','9104',-0.191,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Auslig-Aus 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1281','Pulkovo 1995 to WGS 84 (1)','Derived through concatenation of Pulkovo 1995 to PZ-90 (1) (tfm code 1257) and PZ-90 to WGS 84 (2) (tfm code 1244). Mandated for use in Russia by GOST R 51794-2001, but this has been superseded by GOST R 51794-2008. Replaced by tfm code 5043.','Accuracy 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4200','EPSG','4326','EPSG','1198',1.0,24.82,-131.21,-82.66,'EPSG','9001',0.0,0.0,-0.16,'EPSG','9104',-0.12,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GOST-Rus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1282','Samboja to WGS 84 (1)','Datum shift derived through ITRF93.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4125','EPSG','4326','EPSG','1328',NULL,-404.78,685.68,45.47,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TOT-Idn Mah',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1283','LKS94 to WGS 84 (1)','','LKS94 is a realization of ETRS89 and coincident to WGS 84 within 1 metre. This transformation has an accuracy equal to the coincidence figure.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4669','EPSG','4326','EPSG','1145',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'HNIT-Ltu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1284','Arc 1960 to WGS 84 (2)','Derived at 24 stations.','For military purposes. Accuracy 4m, 3m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4210','EPSG','4326','EPSG','3264',6.0,-157.0,-2.0,-299.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Ken',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1285','Arc 1960 to WGS 84 (3)','Derived at 12 stations.','For military purposes. Accuracy 6m, 9m and 10m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4210','EPSG','4326','EPSG','3316',15.0,-175.0,-23.0,-303.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Tza',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1286','Segora to WGS 84 (1)','Accuracy estimate not available.','For military purposes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4294','EPSG','4326','EPSG','2354',NULL,-403.0,684.0,41.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Idn Kal',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1287','Pulkovo 1942 to WGS 84 (3)','Derived at 5 stations.','For military purposes. Accuracy 2m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4284','EPSG','4326','EPSG','1119',4.0,28.0,-121.0,-77.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Hun',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1288','Pulkovo 1942 to WGS 84 (4)','Derived at 11 stations.','For military purposes only. Accuracy 4m, 2m and 4m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4284','EPSG','4326','EPSG','1192',6.0,23.0,-124.0,-82.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Pol',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1289','Pulkovo 1942 to WGS 84 (5)','Derived at 6 stations.','For military purposes only. Accuracy 3m, 3m and 2m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4284','EPSG','4326','EPSG','1306',5.0,26.0,-121.0,-78.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Cze',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1290','Pulkovo 1942 to WGS 84 (6)','Derived at 5 stations.','For military purposes. Accuracy 2m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4284','EPSG','4326','EPSG','3268',4.0,24.0,-124.0,-82.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Lva',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1291','Pulkovo 1942 to WGS 84 (7)','Derived at 2 stations.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4284','EPSG','4326','EPSG','1131',44.0,15.0,-130.0,-84.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Kaz',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1292','Pulkovo 1942 to WGS 84 (8)','Derived at 7 stations.','For military purposes. Accuracy 3m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4284','EPSG','4326','EPSG','1025',6.0,24.0,-130.0,-92.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Alb',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1293','Pulkovo 1942 to WGS 84 (9)','Derived at 4 stations.','For military purposes. Accuracy 3m, 5m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4284','EPSG','4326','EPSG','1197',7.0,28.0,-121.0,-77.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Rom',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1294','Voirol 1875 to WGS 84 (1)','Accuracy estimate not available.','For military purposes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4304','EPSG','4326','EPSG','1365',999.0,-73.0,-247.0,227.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Dza N',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1296','Trinidad 1903 to WGS 84 (1)','Derived in 1989 by ONI for Amoco.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4302','EPSG','4326','EPSG','1339',2.0,-61.702,284.488,472.052,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Amoco-Tto Trin',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1297','Tete to Moznet (1)','Mean of 32 stations. To reduce the size of the residuals; four regional parameter sets (see codes 1298-1301) were developed. May be taken as approximate transformation Tete to WGS 84 - see code 1683.','Residuals as high as 30 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4127','EPSG','4130','EPSG','3281',30.0,-115.064,-87.39,-101.716,'EPSG','9001',0.058,-4.001,2.062,'EPSG','9104',9.366,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DNGC-Moz',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1298','Tete to Moznet (2)','Mean of 9 stations. May be taken as approximate transformation Tete to WGS 84 - see code 1684.','Residuals are generally under 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4127','EPSG','4130','EPSG','2350',1.0,-82.875,-57.097,-156.768,'EPSG','9001',2.158,-1.524,0.982,'EPSG','9104',-0.359,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DNGC-Moz A',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1299','Tete to Moznet (3)','Mean of 6 stations. May be taken as approximate transformation Tete to WGS 84 - see code 1685.','Residuals are generally under 4 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4127','EPSG','4130','EPSG','2351',4.0,-138.527,-91.999,-114.591,'EPSG','9001',0.14,-3.363,2.217,'EPSG','9104',11.748,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DNGC-Moz B',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1300','Tete to Moznet (4)','Mean of 11 stations. May be taken as approximate transformation Tete to WGS 84 - see code 1686.','Residuals are generally under 3 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4127','EPSG','4130','EPSG','2352',3.0,-73.472,-51.66,-112.482,'EPSG','9001',-0.953,-4.6,2.368,'EPSG','9104',0.586,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DNGC-Moz C',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1301','Tete to Moznet (5)','Mean of 7 stations. May be taken as approximate transformation Tete to WGS 84 - see code 1687.','Residuals are 5-10 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4127','EPSG','4130','EPSG','2353',10.0,219.315,168.975,-166.145,'EPSG','9001',-0.198,-5.926,2.356,'EPSG','9104',-57.104,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DNGC-Moz D',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1302','Moznet to WGS 84 (1)','','For many purposes Moznet can be considered to be coincident with WGS 84. Accuracy better than 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4130','EPSG','4326','EPSG','1167',1.0,0.0,0.0,0.0,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Moz',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1303','Pulkovo 1942 to WGS 84 (10)','Mean of 13 stations along entire Kazak coastline.','Residuals under 2 m.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4284','EPSG','4326','EPSG','2405',2.0,43.822,-108.842,-119.585,'EPSG','9001',1.455,-0.761,0.737,'EPSG','9104',0.549,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'KCS-Kaz Cas',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1304','Indian 1975 to WGS 84 (2)','Derived at 62 stations. Replaces Indian 1975 to WGS 84 (1) (code 1154).','For military purposes. Accuracy 3m, 2m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4240','EPSG','4326','EPSG','3741',5.0,210.0,814.0,289.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Tha',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1305','Tokyo to WGS 84 (5)','Derived at 29 stations. Replaces Tokyo to WGS 84 (3) (code 1232).','For military purposes. Accuracy 2m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4301','EPSG','4326','EPSG','3266',4.0,-147.0,506.0,687.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Kor',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1306','MGI to WGS 84 (1)','Accuracy estimate not available.','For military purposes only.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4312','EPSG','4326','EPSG','2370',999.0,682.0,-203.0,480.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-balk',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1307','Naparima 1972 to WGS 84 (3)','DMA does not differentiate between Naparima 1955 (Trinidad) and Naparima 1972 (Tobago). Consequently for Trinidad IOGP has duplicated this transformation as Naparima 1955 to WGS 84 (3) - see code 1556.','For military purposes only. Accuracy given by DMA is 15m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4271','EPSG','4326','EPSG','1322',26.0,-2.0,374.0,172.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Tto Tob',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1308','NAD83 to WGS 84 (4)','Strictly between NAD83 and ITRF94(1996.0). Superseded by NAD83 to WGS 84 (5) (code 1515).','Historical record only - superseded - see remarks.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4269','EPSG','4326','EPSG','1323',NULL,-0.9738,1.9453,0.5486,'EPSG','9001',-1.3357e-07,-4.872e-08,-5.507e-08,'EPSG','9101',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGS-Usa ITRF94',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1309','DHDN to ETRS89 (1)','Mean of 69 stations. May be taken as approximate tfm DHDN to WGS 84 (code 1673). Replaced by DHDN to ETRS89 (2) (tfm code 1776) and regional higher accuracy tfms. Note: these later tfms have been published using the Position Vector method.','For applications with an accuracy at 5 m level.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4314','EPSG','4258','EPSG','2326',5.0,582.0,105.0,414.0,'EPSG','9001',-1.04,-0.35,3.08,'EPSG','9104',8.3,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IfAG-Deu W',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1310','Pulkovo 1942 to ETRS89 (1)','Mean of 20 stations.','Residuals under 2 m.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4284','EPSG','4258','EPSG','1343',2.0,24.0,-123.0,-94.0,'EPSG','9001',-0.02,0.25,0.13,'EPSG','9104',1.1,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IfAG-Deu E',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1311','ED50 to WGS 84 (18)','Based on ED50 to WGS72 (precise ephemeris) 6-nations agreement of 1981 to which precise to broadcast and broadcast to WGS 84 transformations have been concatenated.','Recommended transformation for UKCS and IrishCS petroleum purposes.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2342',1.0,-89.5,-93.8,-123.1,'EPSG','9001',0.0,0.0,-0.156,'EPSG','9104',1.2,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UKOOA-CO',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1314','OSGB 1936 to WGS 84 (6)','For a more accurate transformation see OSGB 1936 / British National Grid to ETRS89 (2) (code 1039): contact the Ordnance Survey of Great Britain (http://www.gps.gov.uk/gpssurveying.asp) for details.','Oil exploration. Accuracy better than 4m and generally better than 2m.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4277','EPSG','4326','EPSG','1264',2.0,446.448,-125.157,542.06,'EPSG','9001',0.15,0.247,0.842,'EPSG','9104',-20.489,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UKOOA-Pet',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1315','OSGB 1936 to ED50 (UKOOA)','This transformation is concatenated from OSGB36 to WGS 84 (Petroleum) (code 1314) minus ED50 to WGS 84 (Common Offshore) (code 1311).','For oil exploration. Accuracy better than 4m and generally better than 2m.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4277','EPSG','4230','EPSG','1264',2.0,535.948,-31.357,665.16,'EPSG','9001',0.15,0.247,0.998,'EPSG','9104',-21.689,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UKOOA-UKCS',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1316','Manoca to WGS 84 (1)','','?','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4260','EPSG','4326','EPSG','1060',999.0,-70.9,-151.8,-41.4,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SCS-Cmr',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1317','Camacupa 1948 to WGS 72BE (1)','Derived by Geophysical Services Inc. in 1979 from mean of Transit results at 7 stations.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4220','EPSG','4324','EPSG','1604',10.0,-37.2,-370.6,-228.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GSI-Ago',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1318','Camacupa 1948 to WGS 84 (1)','','Used for oil exploration by Conoco.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4220','EPSG','4326','EPSG','2316',10.0,-42.01,-332.21,-229.75,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CON-Ago B5',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1319','Camacupa 1948 to WGS 84 (2)','','Used for oil exploration by Texaco.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4220','EPSG','4326','EPSG','2317',25.0,-40.0,-354.0,-224.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TEX-Ago B2',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1320','Camacupa 1948 to WGS 84 (3)','Replaced by Camacupa 1948 to WGS 84 (9). Used by Shell prior to 1994.','Oil exploration prior to 1994.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4220','EPSG','4326','EPSG','2321',10.0,-37.2,-370.6,-224.0,'EPSG','9001',0.0,0.0,0.554,'EPSG','9104',0.219,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SHL-Ago old',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1321','Camacupa 1948 to WGS 84 (4)','Mean of 123 Transit passes at station Cabo Ledo NE base in November 1990. Used by Elf for block 7 up to December 1992 then replaced by Camacupa 1948 to WGS 84 (7). Used by Total in block 8, ExxonMobil block 24, Western Geophysical for spec. data.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4220','EPSG','4326','EPSG','2320',10.0,-41.8,-342.2,-228.2,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GSI-Ago',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1322','Camacupa 1948 to WGS 84 (5)','Derived at station Djeno during coordination of platform PAL F2 in February 1992. Used by Elf for block 3 up to December 1992 then replaced by Camacupa 1948 to WGS 84 (7).','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4220','EPSG','4326','EPSG','2318',3.0,-55.5,-348.0,-229.2,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELF-Ago B3 old',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1323','Camacupa 1948 to WGS 84 (6)','Derived at Luanda observatory December 1992.','Used for oil exploration by Elf for 1993 block 7 shallow water survey.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4220','EPSG','4326','EPSG','2319',8.0,-43.0,-337.0,-233.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELF-Ago B7 old',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1324','Camacupa 1948 to WGS 84 (7)','Derived at platform PAL F2 in December 1992. For use in blocks 3, 7 and 17, replaced by Camacupa 1948 to WGS 84 (10) (code 1327).','Used for oil exploration by Elf for blocks 3, 7 and 17 between December 1992 and 1994 then superseded by Camacupa (offshore) to WGS 84 (10). Used by Exxon for block 15 since 1993.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4220','EPSG','4326','EPSG','2322',3.0,-48.0,-345.0,-231.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELF-Ago B15',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1325','Camacupa 1948 to WGS 84 (8)','Derived at platform PAL F2 in December 1992. Used by Total for block 2 between December 1992 and 1994 then replaced by Camacupa 1948 to WGS 84 (10).','Oil exploration between December 1992 and 1994.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4220','EPSG','4326','EPSG','2317',3.0,-48.6,-345.1,-230.8,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELF-Ago B2 old',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1326','Camacupa 1948 to WGS 84 (9)','Derived by GPS on two Topnav DGPS reference stations at Djeno and Luanda. Replaces Camacupa 1948 to WGS 84 (3). In block 18 replaced by BP from 1999 by Camacupa 1948 to WGS 84 (10).','Used by Shell since 1994.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4220','EPSG','4326','EPSG','2323',10.0,-41.057,-374.564,-226.287,'EPSG','9001',0.0,0.0,0.554,'EPSG','9104',0.219,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SHL-Ago B16',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1327','Camacupa 1948 to WGS 84 (10)','Derived at platform PAL F2 in 1994 by Topnav using Doris.','Used for oil exploration by Elf in blocks 3 and 17 since 1994. Used by Total in block 2 since 1994. Adopted by BP-Amoco Elf and Exxon for blocks 18 and 31-33 in 1999.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4220','EPSG','4326','EPSG','2324',5.0,-50.9,-347.6,-231.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELF-Ago N',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1328','Malongo 1987 to Mhast (1)','Malongo 1987 is an offshore extension of Mhast adopted by Chevron in 1987.','Used for oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4259','EPSG','4264','EPSG','1317',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CHV-Ago Cab',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1329','Mhast to WGS 84 (1)','Superseded in 1990 by trf Malongo 1987 to WGS 84 (2), code 1557. Malongo 1987 is an offshore extension of the Mhast cooordinate system.','Used for oil exploration by Chevron until superseded in 1990 by trf Malongo 1987 to WGS 84 (2), code 1557.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4264','EPSG','4326','EPSG','1317',10.0,-252.95,-4.11,-96.38,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CHV-Ago Cab',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1330','Malongo 1987 to WGS 84 (1)','Derived at Station Y in April 1989 using 572 transit satellite passes. Computed value for dZ was -96.42 but -96.38 has been utilised. Replaced Malongo 1987 to WGS 84 (3) (code 15791) in 1989. Replaced by Malongo 1987 to WGS 84 (2) (code 1557) in 1990.','Offshore oil exploration and production between April 1989 and June 1990.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4259','EPSG','4326','EPSG','3180',10.0,-252.95,-4.11,-96.38,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CHV-Ago Cab89',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1331','EST92 to ETRS89 (1)','','Not known.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4133','EPSG','4258','EPSG','3246',0.1,0.0,0.0,0.0,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UT-Est',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1332','Pulkovo 1942 to EST92 (1)','','Not known.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4284','EPSG','4133','EPSG','3246',9.0,21.53219,-97.00027,-60.74046,'EPSG','9001',-0.99548,-0.58147,-0.2418,'EPSG','9104',-4.5981,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UT-Est',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1333','EST92 to WGS 84 (1)','','Not known.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4133','EPSG','4326','EPSG','3246',0.5,0.055,-0.541,-0.185,'EPSG','9001',-0.0183,0.0003,0.007,'EPSG','9104',-0.014,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UT-Est',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1334','Pulkovo 1942 to WGS 84 (12)','','Not known.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4284','EPSG','4326','EPSG','3246',9.0,21.58719,-97.54127,-60.92546,'EPSG','9001',-1.01378,-0.58117,-0.2348,'EPSG','9104',-4.6121,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UT-Est',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1437','RT90 to ETRS89 (1)','Derived at 22 points in 1993. Replaced by RT90 to SWEREF99 (1) (code 1895) from 2001.¶This transformation is actually between ETRS89 and RR92. RR92 is a geographic 3D CRS where the horizontal component is RT90.','Accuracy 0.5m.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4124','EPSG','4258','EPSG','1225',0.5,419.3836,99.3335,591.3451,'EPSG','9001',-0.850389,-1.817277,7.862238,'EPSG','9104',-0.99496,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NLS-Swe',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1438','Fahud to WGS 84 (2)','','Oil exploration.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4232','EPSG','4326','EPSG','4009',25.0,-333.102,-11.02,230.69,'EPSG','9001',0.0,0.0,0.554,'EPSG','9104',0.219,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PDO-Omn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1439','PSD93 to WGS 84 (1)','Replaced PSD93 to WGS 84 (2) (code 8581) in 1997.','Oil exploration. Residuals 0.5m at 67% probability level.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4134','EPSG','4326','EPSG','3288',0.5,-180.624,-225.516,173.919,'EPSG','9001',-0.81,-1.898,8.336,'EPSG','9104',16.71006,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PDO-Omn 97',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1440','ED50 to WGS 84 (19)','','Used in oil industry.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','3254',999.0,-86.0,-92.2,-127.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'HEL-Grc',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1441','Antigua 1943 to WGS 84 (1)','','Not known.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4601','EPSG','4326','EPSG','1273',10.0,-255.0,-15.0,71.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DOS-Atg Ant',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1442','Dominica 1945 to WGS 84 (1)','','Not known.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4602','EPSG','4326','EPSG','3239',10.0,725.0,685.0,536.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DOS-Dma',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1443','Grenada 1953 to WGS 84 (1)','','Not known.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4603','EPSG','4326','EPSG','3118',10.0,72.0,213.7,93.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DOS-Grd',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1444','Montserrat 1958 to WGS 84 (1)','Derived at 1 satellite station.','Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4604','EPSG','4326','EPSG','3279',44.0,174.0,359.0,365.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DOS-Msr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1445','St. Kitts 1955 to WGS 84 (1)','','Not known.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4605','EPSG','4326','EPSG','3297',10.0,9.0,183.0,236.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DOS-Kna',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1446','St. Lucia 1955 to WGS 84 (1)','','Not known.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4606','EPSG','4326','EPSG','3298',10.0,-149.0,128.0,296.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DOS-Lca',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1448','HD72 to WGS 84 (3)','Parameter values taken from HD72 to ETRS89 (2) (code 1449) assuming that ETRS89 is equivalent to WGS 84 within the accuracy of the transformation. Replaces HD72 to WGS 84 (1) (code 1830).','Approximation at the +/- 1m level assuming that ETRS89 is equivalent to WGS 84.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4237','EPSG','4326','EPSG','1119',1.0,52.684,-71.194,-13.975,'EPSG','9001',0.312,0.1063,0.3729,'EPSG','9104',1.0191,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELTE-Hun 2003',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1449','HD72 to ETRS89 (2)','Derived at 1153 stations of the Hungarian National GPS Network. Values here correct parameter errors given in Hungarian standard MSZ 7222:2002. Replaces HD72 to ETRS89 (1), code 1829. May be taken as approximate tfm HD72 to WGS 84 - see tfm code 1448.','Throughout Hungary the average horizontal error of the transformation is 0.19 m, the maximum is 0.41 m.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4237','EPSG','4258','EPSG','1119',0.4,52.684,-71.194,-13.975,'EPSG','9001',0.312,0.1063,0.3729,'EPSG','9104',1.0191,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'MSZ-Hun',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1458','AGD66 to GDA94 (2)','For higher accuracy requirements see AGD66 to GDA94 (11) (code 1803). May be taken as approximate transformation AGD66 to WGS 84 - see code 1665. See code 5827 for a marginally better accuracy transformation derived locally.','Recommended for mid-accuracy use in A.C.T. 1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4202','EPSG','4283','EPSG','2283',1.0,-129.193,-41.212,130.73,'EPSG','9001',-0.246,-0.374,-0.329,'EPSG','9104',-2.955,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Auslig-ACT 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1459','AGD66 to GDA94 (3)','Replaced in 2000 by AGD66 to GDA94 (8) (code 1594). Application gives result differences which are sub-metre.','1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4202','EPSG','4283','EPSG','1282',1.0,-120.695,-62.73,165.46,'EPSG','9001',-0.109,0.141,0.116,'EPSG','9104',2.733,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Auslig-Tas 1m old',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1460','AGD66 to GDA94 (4)','For higher accuracy requirements see AGD66 to GDA94 (11) (code 1803). May be taken as approximate transformation AGD66 to WGS 84 - see code 1666.','Recommended for mid-accuracy use in NSW and Victoria. 1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4202','EPSG','4283','EPSG','2286',1.0,-119.353,-48.301,139.484,'EPSG','9001',-0.415,-0.26,-0.437,'EPSG','9104',-0.613,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Auslig-NSW Vic 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1469','Locodjo 1965 to WGS 84 (1)','','Not known.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4142','EPSG','4326','EPSG','2282',15.0,-125.0,53.0,467.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Civ',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1470','Abidjan 1987 to WGS 84 (1)','Derived in Abidjan for use in the immediate area, but used by E&P industry more widely onshore and offshore. A similar transformation (tfm code 6872) was used by Western Geophysical for offshore surveys in the 1990s.','Accuracy is submetre in the area around Abidjan but unknown farther afield. There is some evidence of unknown reliability that suggests accuracy of better than 2m throughout offshore.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4143','EPSG','4326','EPSG','1075',2.0,-124.76,53.0,466.79,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Civ',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1471','MGI to WGS 84 (2)','','For applications to an accuracy of 1.5 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4312','EPSG','4326','EPSG','1037',NULL,-577.326,-90.129,-463.919,'EPSG','9001',-15.8537,-4.55,-16.3489,'EPSG','9113',-2.4232,'EPSG','9201',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BEV-Aut',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1473','NAD83(CSRS98) to WGS 84 (1)','For many purposes NAD83(CSRS98) can be considered to be coincident with WGS 84.','Approximation at the +/- 1m level assuming that NAD83(CSRS98) is equivalent to WGS 84.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4140','EPSG','4326','EPSG','1336',NULL,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Can',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1504','Cape to Hartebeesthoek94 (1)','Residuals should not exceed 15 metres. Also used to transform Cape to WGS 84 - see code 1129.','Accuracy 15m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4222','EPSG','4148','EPSG','3309',15.0,-134.73,-110.92,-292.66,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DSM-Zaf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1505','Hartebeesthoek94 to WGS 84 (1)','','For many purposes Hartebeesthoek94 datum can be considered to be coincident with WGS 84.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4148','EPSG','4326','EPSG','4540',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Zaf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1508','CH1903 to WGS 84 (1)','Implemented in Bundesamt für Landestopographie programme GRANIT.','?','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4149','EPSG','4326','EPSG','1286',NULL,660.077,13.551,369.344,'EPSG','9001',2.484,1.783,2.939,'EPSG','9113',5.66,'EPSG','9201',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BfL-CH 1',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1509','CH1903+ to CHTRF95 (1)','This transformation is also given as CH1903+ to ETRS89 (1) (code 1647). CHTRF95 is a realisation of ETRS89. May be taken as approximate transformation CH1903+ to WGS 84 - see code 1676.','For applications to an accuracy of 0.1 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4150','EPSG','4151','EPSG','1286',0.1,674.374,15.056,405.346,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BfL-CH',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1510','CH1903 to WGS 84 (2)','These parameters are strictly between CH1903+ and CHTRF95 but are used from CH1903 as an approximation which is within the accuracy of the distortions in the CH1903 network.','Accuracy 1.5 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4149','EPSG','4326','EPSG','1286',NULL,674.374,15.056,405.346,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BfL-CH 2',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1511','CHTRF95 to WGS 84 (1)','','For many purposes CHTRF95 can be considered to be coincident with WGS 84.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4151','EPSG','4326','EPSG','1286',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-CH',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1512','Rassadiran to WGS 84 (1)','Derived in 1998 at Assaluyeh (Taheri refinery) by Geoid for Total. Used for South Pars phases 2 and 3.','Oil industry engineering survey. Used only for terminal site.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4153','EPSG','4326','EPSG','1338',0.5,-133.63,-157.5,-158.62,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TOT-Irn Taheri',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1513','FD58 to WGS 84 (1)','Derived in 1998 in Kangan district by Geoid for Total. Used for South Pars phases 2 and 3.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4132','EPSG','4326','EPSG','2362',0.5,-241.54,-163.64,396.06,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TOT-Irn Kangan',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1514','ED50(ED77) to WGS 84 (1)','Used for South Pars phases 6, 7 and 8.','Transformation for whole country: accuracy about 1m.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4154','EPSG','4326','EPSG','1123',1.0,-110.33,-97.73,-119.85,'EPSG','9001',0.3423,1.1634,0.2715,'EPSG','9104',0.063,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NCCI-Irn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1515','NAD83 to WGS 84 (5)','Strictly between NAD83 and ITRF96(1997.0). Supersedes NAD83 to WGS 84 (4) (code 1308).','Geodesy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4269','EPSG','4326','EPSG','1323',NULL,-0.991,1.9072,0.5129,'EPSG','9001',-1.25033e-07,-4.6785e-08,-5.6529e-08,'EPSG','9101',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGS-Usa ITRF96',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1516','La Canoa to WGS 84 (18)','Also used for PSAD56 to WGS 84 transformations.','Parameter values estimated accuracy: ± 2.0m; ± 2.7m; ± 1.3m respectively.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4247','EPSG','4326','EPSG','2363',2.5,-273.5,110.6,-357.9,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'LAG-Ven E',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1517','Conakry 1905 to WGS 84 (1)','','Not known.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4315','EPSG','4326','EPSG','3257',30.0,-23.0,259.0,-9.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Gin',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1518','Dabola 1981 to WGS 84 (1)','','Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4155','EPSG','4326','EPSG','3257',25.0,-83.0,37.0,124.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Gin',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1527','Campo Inchauspe to WGS 84 (2)','Derived through ties at 2 stations (Cerro Colorado and Chihuido Sur) to 4 IGS stations in February 1995','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4221','EPSG','4326','EPSG','2325',0.5,-154.5,150.7,100.4,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TOT-Arg Neu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1528','Chos Malal 1914 to Campo Inchauspe (1)','Derived through common coordinates at 5 stations.','Oil exploration. Accuracy 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4160','EPSG','4221','EPSG','2325',10.0,160.0,26.0,41.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TOT-Arg Neu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1529','Hito XVIII to WGS 84 (1)','Derived through ties at 3 stations (RC03, TOTAL11 and MP12) to 3 IGS stations in November 1995','Oil exploration.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4254','EPSG','4326','EPSG','2357',0.5,18.38,192.45,96.82,'EPSG','9001',0.056,-0.142,-0.2,'EPSG','9104',-0.0013,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TOT-Arg TdF',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1530','NAD27 to WGS 84 (30)','','Accuracy 3m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','1077',3.0,-4.2,135.4,181.9,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ICH-Cub',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1531','Nahrwan 1967 to WGS 84 (4)','Parameter values adopted by Total are mean of those derived by Oceonics and Geoid through ties at platform AK1 to 4 IGS stations in March 1995.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4270','EPSG','4326','EPSG','2392',0.5,-245.0,-153.9,382.8,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TOT-UAE Abk',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1532','M''poraloko to WGS 84 (2)','Derived as mean of Doris determinations at 3 stations in Port Gentil area in 1994.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4266','EPSG','4326','EPSG','1100',0.5,-80.7,-132.5,41.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Elf-Gab94',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1533','Kalianpur 1937 to WGS 84 (2)','','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4144','EPSG','4326','EPSG','2361',5.0,214.0,804.0,268.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TOT-Mmr Moat',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1534','Minna to WGS 84 (3)','','Oil exploration.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4263','EPSG','4326','EPSG','2371',NULL,-111.92,-87.85,114.5,'EPSG','9001',1.875,0.202,0.219,'EPSG','9104',0.032,'EPSG','9201',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SHL-Nig S',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1536','Nahrwan 1967 to WGS 84 (5)','Derived by Brown & Root in 1992 for Qatar General Petroleum Corporation North Field development. Adopted by QGPC for all offshore Qatar.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4270','EPSG','4326','EPSG','2406',1.0,-250.2,-153.09,391.7,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'B&R-Qat off',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1537','Indian 1975 to WGS 84 (3)','Derived in 1995 at point RTSD181.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4240','EPSG','4326','EPSG','2358',1.0,204.64,834.74,293.8,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Fug-Tha',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1538','Carthage to WGS 84 (2)','Derived at station Chaffar January 1995.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4223','EPSG','4326','EPSG','1489',1.0,-260.1,5.5,432.2,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Elf-Tun',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1539','South Yemen to Yemen NGN96 (1)','May be used as an approximate transformation to WGS 84 - see South Yemen to WGS 84 (1) (code 1682).','For applications to an accuracy of 5 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4164','EPSG','4163','EPSG','1340',5.0,-76.0,-138.0,67.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Yem South',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1540','Yemen NGN96 to WGS 84 (1)','','Accuracy better than 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4163','EPSG','4326','EPSG','1257',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Yem',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1541','Indian 1960 to WGS 72BE (1)','Derived in Vung Tau area by Technical Navigation for Deminex in 1978.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4131','EPSG','4324','EPSG','1495',25.0,199.0,931.0,317.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PV-Vnm',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1542','Indian 1960 to WGS 84 (2)','Derived at 2 stations.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4131','EPSG','4326','EPSG','2359',44.0,198.0,881.0,317.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Vnm 16N',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1543','Indian 1960 to WGS 84 (3)','Derived at 1 station.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4131','EPSG','4326','EPSG','2360',44.0,182.0,915.0,344.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Vnm ConSon',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1544','Hanoi 1972 to WGS 84 (1)','Derived in Vung Tau area.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4147','EPSG','4326','EPSG','1494',5.0,-17.51,-108.32,-62.39,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BP-Vnm',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1545','Egypt 1907 to WGS 72 (1)','','Not known.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4229','EPSG','4322','EPSG','1086',5.0,-121.8,98.1,-15.2,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'MCE-Egy',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1546','Egypt 1907 to WGS 84 (3)','','Used for oil exploration by GUPCO.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4229','EPSG','4326','EPSG','2341',30.0,-146.21,112.63,4.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Racal-Egy GoS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1547','Bissau to WGS 84 (1)','Derived at 2 stations.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4165','EPSG','4326','EPSG','3258',25.0,-173.0,253.0,27.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Gnb',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1548','SAD69 to WGS 84 (14)','Derived by Brazilean Institute of Geography and Statistics (IGBE) in 1989. Used by ANP.','Medium and small scale mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4291','EPSG','4326','EPSG','1053',NULL,-66.87,4.37,-38.52,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGBE-Bra',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1549','Aratu to WGS 84 (1)','','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','2307',999.0,-158.0,315.0,-148.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra Camp',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1550','Aratu to WGS 84 (2)','Replaced by Aratu to WGS 84 (18) (tfm code 5061) which Petrobras now recommends for the area.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','2308',5.0,-139.62,290.53,-150.29,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra TucN',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1551','Aratu to WGS 84 (3)','Replaced by Aratu to WGS 84 (18) (tfm code 5061) which Petrobras now recommends for the area.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','2309',5.0,-141.15,293.44,-150.56,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra TucC',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1552','Aratu to WGS 84 (4)','Replaced by Aratu to WGS 84 (18) (tfm code 5061) which Petrobras now recommends for the area.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','2310',5.0,-142.48,296.03,-149.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra TucS',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1555','Naparima 1955 to WGS 84 (2)','Derived in 1989 by ONI for Amoco.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4158','EPSG','4326','EPSG','3143',1.0,-0.465,372.095,171.736,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Amoco-Tto Trin',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1556','Naparima 1955 to WGS 84 (3)','DMA does not differentiate between Naparima 1955 (Trinidad) and Naparima 1972 (Tobago). Consequently for Trinidad IOGP has duplicated this transformation as Naparima 1972 to WGS 84 (3) - see code 1307.','For military purposes only. Accuracy given by DMA is 15m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4158','EPSG','4326','EPSG','3143',26.0,-2.0,374.0,172.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Tto Trin',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1557','Malongo 1987 to WGS 84 (2)','Derived at station Y in July 1990 through Transit single point positioning using 187 passes by Geodetic Survey Ltd. Replaces Malongo 1987 to WGS 84 (1) (trf code 1330).','Offshore oil exploration and production from June 1990.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4259','EPSG','4326','EPSG','3180',5.0,-254.1,-5.36,-100.29,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CHV-Ago Cab90',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1558','Korean 1995 to WGS 84 (1)','Derived at 5 stations.','For military purposes. Accuracy 1m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4166','EPSG','4326','EPSG','3266',2.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Kor',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1560','Nord Sahara 1959 to WGS 72BE (1)','Derived at IGN monument CFP19 using Transit.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4307','EPSG','4324','EPSG','2393',8.0,-156.5,-87.2,285.9,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGG-Alg HM',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1561','Qatar 1974 to WGS 84 (1)','Derived at 3 stations.','For military purposes only. Accuracy 20m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4285','EPSG','4326','EPSG','1346',35.0,-128.0,-283.0,22.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Qat',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1562','Qatar 1974 to WGS 84 (2)','Derived by Brown & Root in 1992 for Qatar General Petroleum Corporation.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4285','EPSG','4326','EPSG','2406',1.0,-128.16,-282.42,21.93,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'B&R-Qat off',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1563','Qatar 1974 to WGS 84 (3)','Derived by Qatar Centre for GIS. See Qatar 1974 to WGS 84 (2) (code 1562) for transformation used by QGPC for offshore petroleum industry.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4285','EPSG','4326','EPSG','1346',1.0,-128.033,-283.697,21.052,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGIS-Qat',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1564','NZGD49 to WGS 84 (2)','These parameter values are taken from NZGD49 to NZGD2000 (2) (code 1701) and assume that NZGD2000 and WGS 84 are coincident to within the accuracy of the transformation. For improved accuracy use NZGD49 to WGS 84 (4) (code 1670).','Transformation accuracy about 4 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4272','EPSG','4326','EPSG','3285',4.0,59.47,-5.04,187.44,'EPSG','9001',-0.47,0.1,-1.024,'EPSG','9104',-4.5993,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OSG-Nzl 4m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1565','NZGD2000 to WGS 84 (1)','','Assumes NZGD2000 is coincident to WGS 84 to the 1m accuracy level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4167','EPSG','4326','EPSG','1175',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OSG-Nzl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1566','NZGD49 to NZGD2000 (1)','For better accuracy use NZGD49 to NZGD2000 (2) (code 1701) or NZGD49 to NZGD2000 (3) (code 1568).','5m accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4272','EPSG','4167','EPSG','3285',5.0,54.4,-20.1,183.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OSG-Nzl 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1567','NZGD49 to NZGD2000 (2)','4m accuracy. For better accuracy use NZGD49 to NZGD2000 (3) (code 1568)','4m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4272','EPSG','4167','EPSG','1175',NULL,59.47,-5.04,187.44,'EPSG','9001',-0.47,0.1,1.024,'EPSG','9104',-4.5993,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OSG-Nzl 4m',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1569','Accra to WGS 84 (1)','Derived at 3 common points.','Military survey','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4168','EPSG','4326','EPSG','1104',25.0,-199.0,32.0,322.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'MCE-Gha',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1570','Accra to WGS 72BE (1)','Derived be single point Transit observation at several locations.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4168','EPSG','4324','EPSG','1505',25.0,-171.16,17.29,323.31,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GSI-Gha',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1571','Amersfoort to ETRS89 (1)','Dutch sources also quote an equivalent transformation with parameter values dX=+593.032 dY=+26.000 dZ=+478.741m, rX rY rZ and dS as this tfm. These values belong to a different transformation method and cannot be used with the Coordinate Frame method.','Accuracy 0.5m','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4258','EPSG','4326','EPSG','1172',NULL,565.04,49.91,465.84,'EPSG','9001',1.9848,-1.7439,9.0587,'EPSG','9109',4.0772,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NCG-Nld 2000',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1577','American Samoa 1962 to WGS 84 (1)','Transformation based on observations at 2 stations in 1993.','For military purposes. One sigma uncertainty is 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4169','EPSG','4326','EPSG','3109',44.0,-115.0,118.0,426.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Asm',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1580','NAD83(HARN) to WGS 84 (1)','For many purposes NAD83(HARN) can be considered to be coincident with WGS 84.','Approximation at the +/- 1m level assuming that NAD83(HARN) is equivalent to WGS 84.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4152','EPSG','4326','EPSG','1337',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Usa',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1581','SIRGAS to WGS 84 (1)','','For military purposes. Accuracy 1m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4170','EPSG','4326','EPSG','3448',2.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-S America',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1582','PSAD56 to WGS 84 (10)','Derived May 1995 by Geoid for Total. OSU91A geoid model used.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4248','EPSG','4326','EPSG','2400',3.0,-259.73,173.12,-398.27,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TOT-Bol  Mad',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1583','PSAD56 to WGS 84 (11)','Derived July 1997 by Geoid from data recorded by UGA for Total. OSU91A geoid model used.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4248','EPSG','4326','EPSG','2401',0.5,-307.7,265.3,-363.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TOT-Bol  B20',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1584','Deir ez Zor to WGS 72BE (1)','Recomputed in 1991 by Elf from data derived in 1983 at station 254 Deir by Geco using Transit. Derivation of 1983 parameter values of dX=-163.2 dY=-12.7 dZ=+232.7 contained errors in geodetic parameters for Syria.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4227','EPSG','4324','EPSG','2329',5.0,-174.6,-3.1,236.2,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GECO-Syr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1585','Deir ez Zor to WGS 84 (2)','','?','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4227','EPSG','4326','EPSG','1227',999.0,-177.5,14.1,237.6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Syr',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1586','Deir ez Zor to WGS 84 (3)','Derived in 1995 by CGG for Al Furat Petroleum Company. Can be approximated using geocentric translations of dX=-174.3m, dY=+14.1m, dZ=+237.6m.','Oil exploration.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4227','EPSG','4326','EPSG','2327',999.0,-175.09,1.218,238.831,'EPSG','9001',-0.047,0.019,0.808,'EPSG','9104',0.1698,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SHL-Syr Whal',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1587','Deir ez Zor to WGS 84 (4)','Derived at four stations by Topnav in 1997.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4227','EPSG','4326','EPSG','2328',1.0,-191.77,15.01,235.07,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELF-Syr Shad',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1588','ED50 to ETRS89 (1)','Included in Statens Kartverk programme wsktrans from 1997. The same parameter values were adopted for ED50 to WGS84 (variant 23) transformation offshore Norway north of 62N from April 2001 - see code 1612.','Accuracy 1m.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4258','EPSG','2332',1.0,-116.641,-56.931,-110.559,'EPSG','9001',4.327,4.464,-4.444,'EPSG','9109',-3.52,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NMA-Nor N65 1997',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1591','RGF93 to ETRS89 (1)','May be taken as approximate transformation RGF93 to WGS 84 - see code 1671.','RGF93 is a national realization of ETRS89.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4171','EPSG','4258','EPSG','1096',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Fra',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1592','Timbalai 1948 to WGS 84 (2)','Originally used by BSP offshore only, use extended to onshore in 2010.','Oil exploration and production.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4298','EPSG','4326','EPSG','1055',5.0,-678.0,670.0,-48.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BSP-Brn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1594','AGD66 to GDA94 (8)','Replaces AGD66 to GDA94 (3) (code 1459) from August 2000. For higher accuracy requirements see AGD66 to GDA94 (11) (code 1803). May be taken as approximate transformation AGD66 to WGS 84 - see code 1667.','Recommended for mid-accuracy use in Tasmania. 1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4202','EPSG','4283','EPSG','1282',1.0,-120.271,-64.543,161.632,'EPSG','9001',-0.217,0.067,0.129,'EPSG','9104',2.499,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OSG-Tas 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1595','AGD66 to GDA94 (9)','For higher accuracy requirements see AGD66 to GDA94 (11) (code 1803). May be taken as approximate transformation AGD66 to WGS 84 - see code 1668.','Recommended for mid-accuracy use in Northern Territory. 1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4202','EPSG','4283','EPSG','2284',1.0,-124.133,-42.003,137.4,'EPSG','9001',0.008,-0.557,-0.178,'EPSG','9104',-1.854,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Auslig-NT 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1597','Bogota 1975 to WGS 84 (2)','Derived in 1995 by WGC at first order stations Recreo and Mena via multi-day ties to 4 IGS stations. Residuals under 20cm.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4218','EPSG','4326','EPSG','2315',0.2,304.5,306.5,-318.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BP-Col CusCup',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1598','POSGAR to WGS 84 (1)','','?','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4172','EPSG','4326','EPSG','1033',NULL,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Arg',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1609','BD72 to WGS 84 (1)','Scale difference is given by information source as 0.999999. Given in this record in ppm to assist application usage. Very similar parameter values (to slightly less precision) used for BD72 to ETRS89: see code 1652.','For applications to an accuracy of 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4313','EPSG','4326','EPSG','1347',1.0,-99.059,53.322,-112.486,'EPSG','9001',-0.419,0.83,-1.885,'EPSG','9104',-1.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Bel 7',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1610','BD72 to WGS 84 (2)','','For applications to an accuracy of 5 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4313','EPSG','4326','EPSG','1347',5.0,-125.8,79.9,-100.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Bel 3',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1611','IRENET95 to ETRS89 (1)','May be taken as approximate transformation IRENET95 to WGS 84 - see code 1678.','IRENET95 is a regional realization of ETRS89.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4173','EPSG','4258','EPSG','1305',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OSI-Ire',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1612','ED50 to WGS 84 (23)','Parameter values are taken from ED50 to ETRS89 (1), code 1588. Adopted for ED50 to WGS84 transformations offshore Norway north of 62N from April 2001 when it replaced code 1590. Included in Statens Kartverk programme wsktrans from v4.0.','Oil industry offshore.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2601',1.0,-116.641,-56.931,-110.559,'EPSG','9001',0.893,0.921,-0.917,'EPSG','9104',-3.52,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Nor N62 2001',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1613','ED50 to WGS 84 (24)','Approximation to 1 metre of concatenated transformation ED50 to WGS 84 (14), code 8653. 8653 remains the transformation promulgated by Statens Kartverk but 1613 recommended by EPSG for practical oil industry usage.','Approximation to 1 metre for oil industry use.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2334',1.0,-90.365,-101.13,-123.384,'EPSG','9001',0.333,0.077,0.894,'EPSG','9104',1.994,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Nor S62 2001',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1614','Sierra Leone 1968 to WGS 84 (1)','Determined at 8 stations. Info. source has the source CRS as Sierra Leone 1960. Sierra Leone 1968 is a readjustment of the 1960 network: coordinates changed by less than 3 metres.','Accuracy +/- 15m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4175','EPSG','4326','EPSG','3306',26.0,-88.0,4.0,101.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Sle',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1615','Timbalai 1948 to WGS 84 (3)','CARE! Erroneous GPS data was used in the derivation of these parameters. They produce a coordinate difference of 10m horizontally and 50m vertically compared to Timbalai 1948 to WGS 84 (2) (code 1592).','Topographic and engineering survey onshore.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4298','EPSG','4326','EPSG','2349',100.0,-726.282,703.611,-48.999,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SD-Brn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1616','PSD93 to WGS 72 (1)','','Oil exploration. Residuals 1.2m at 67% probability level.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4134','EPSG','4322','EPSG','3288',1.2,-182.046,-225.604,168.884,'EPSG','9001',-0.616,-1.655,7.824,'EPSG','9104',16.641,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PDO-Omn 93',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1617','PSD93 to WGS 84 (3)','Accuracy better than 0.5m in block 4.','Oil exploration.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4134','EPSG','4326','EPSG','2404',0.5,-191.808,-250.512,167.861,'EPSG','9001',-0.792,-1.653,8.558,'EPSG','9104',20.703,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Tot-Omn 95',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1618','MGI to WGS 84 (3)','Same transformation parameters used for MGI to ETRS89 (1) (code 1619).','For applications to an accuracy of 1.5 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4312','EPSG','4326','EPSG','1037',1.5,577.326,90.129,463.919,'EPSG','9001',5.137,1.474,5.297,'EPSG','9104',2.4232,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BEV-Aut',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1619','MGI to ETRS89 (1)','Same transformation parameters used for MGI to WGS 84 (3) (code 1618). Precision of parameter values in this record were increased effective 16-Dec-2006 (db v6.12): see change record 2006.971.','For applications to an accuracy of 1.5 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4312','EPSG','4258','EPSG','1037',1.5,577.326,90.129,463.919,'EPSG','9001',5.137,1.474,5.297,'EPSG','9104',2.4232,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BEV-Aut',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1620','MGI to ETRS89 (2)','May be taken as approximate transformation MGI to WGS 84 - see code 1621.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4312','EPSG','4258','EPSG','1076',1.0,551.7,162.9,467.9,'EPSG','9001',6.04,1.96,-11.38,'EPSG','9104',-4.82,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DGU-Hrv',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1621','MGI to WGS 84 (4)','Parameter values from MGI to ETRS89 (2) (code 1620). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4312','EPSG','4326','EPSG','1076',1.0,551.7,162.9,467.9,'EPSG','9001',6.04,1.96,-11.38,'EPSG','9104',-4.82,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Hrv',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1622','S-JTSK to ETRS89 (1)','May be taken as approximate transformation S-JTSK to WGS 84 - see code 1623. Replaced by S-JTSK/05 to ETRS89 (1) (code 5226) in 2009.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4156','EPSG','4258','EPSG','1079',1.0,570.8,85.7,462.8,'EPSG','9001',4.998,1.587,5.261,'EPSG','9104',3.56,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CUZK-Cze',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1623','S-JTSK to WGS 84 (1)','Parameter values from S-JTSK to ETRS89 (1) (code 1622). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation. Replaced by S-JTSK to WGS 84 (5) (code 5239).','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4156','EPSG','4326','EPSG','1079',1.0,570.8,85.7,462.8,'EPSG','9001',4.998,1.587,5.261,'EPSG','9104',3.56,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Cze',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1624','S-JTSK to ETRS89 (2)','May be taken as approximate transformation S-JTSK to WGS 84 - see code 1625.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4156','EPSG','4258','EPSG','1211',1.0,559.0,68.7,451.5,'EPSG','9001',7.92,4.073,4.251,'EPSG','9104',5.71,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UGKK-Svk',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1625','S-JTSK to WGS 84 (2)','Parameter values from S-JTSK to ETRS89 (2) (code 1624). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4156','EPSG','4326','EPSG','1211',1.0,559.0,68.7,451.5,'EPSG','9001',7.92,4.073,4.251,'EPSG','9104',5.71,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Svk',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1626','ED50 to ETRS89 (4)','May be taken as approximate transformation ED50 to WGS 84 - see code 1627.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4258','EPSG','3237',1.0,-81.1,-89.4,-115.8,'EPSG','9001',0.485,0.024,0.413,'EPSG','9104',-0.54,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'KMS-Dnk',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1627','ED50 to WGS 84 (25)','Parameter values from ED50 to ETRS89 (4) (code 1626). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','3237',1.0,-81.1,-89.4,-115.8,'EPSG','9001',0.485,0.024,0.413,'EPSG','9104',-0.54,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Dnk',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1628','ED50 to ETRS89 (5)','May be taken as approximate transformation ED50 to WGS 84 - see code 1629.','For applications to an accuracy of 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4258','EPSG','1105',1.0,-116.8,-106.4,-154.4,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DGC-Gib',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1629','ED50 to WGS 84 (26)','Parameter values from ED50 to ETRS89 (5) (code 1628). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','1105',1.0,-116.8,-106.4,-154.4,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Gib',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1630','ED50 to ETRS89 (6)','May be taken as approximate transformation ED50 to WGS 84 - see code 1631.','For applications to an accuracy of 1.5 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4258','EPSG','2335',1.5,-181.5,-90.3,-187.2,'EPSG','9001',0.144,0.492,-0.394,'EPSG','9104',17.57,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CNIG-Esp Bal',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1631','ED50 to WGS 84 (27)','Parameter values from ED50 to ETRS89 (6) (code 1630). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1.5 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2335',1.5,-181.5,-90.3,-187.2,'EPSG','9001',0.144,0.492,-0.394,'EPSG','9104',17.57,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Esp Bal',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1632','ED50 to ETRS89 (7)','May be taken as approximate transformation ED50 to WGS 84 - see code 1633.','For applications to an accuracy of 1.5 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4258','EPSG','2336',1.5,-131.0,-100.3,-163.4,'EPSG','9001',-1.244,-0.02,-1.144,'EPSG','9104',9.39,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CNIG-Esp',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1633','ED50 to WGS 84 (28)','Parameter values from ED50 to ETRS89 (7) (code 1632). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1.5 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2336',1.5,-131.0,-100.3,-163.4,'EPSG','9001',-1.244,-0.02,-1.144,'EPSG','9104',9.39,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Esp',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1634','ED50 to ETRS89 (8)','May be taken as approximate transformation ED50 to WGS 84 - see code 1635.','For applications to an accuracy of 1.5 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4258','EPSG','2337',1.5,-178.4,-83.2,-221.3,'EPSG','9001',0.54,-0.532,-0.126,'EPSG','9104',21.2,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CNIG-Esp NW',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1635','ED50 to WGS 84 (29)','Parameter values from ED50 to ETRS89 (8) (code 1634). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1.5 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2337',1.5,-178.4,-83.2,-221.3,'EPSG','9001',0.54,-0.532,-0.126,'EPSG','9104',21.2,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Esp NW',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1638','KKJ to ETRS89 (1)','May be taken as approximate transformation KKJ to WGS 84 - see code 1639. Replaced by KKJ to ETRS89 (2) (code 10098).','For applications to an accuracy of 1 to 2 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4123','EPSG','4258','EPSG','3333',1.5,-90.7,-106.1,-119.2,'EPSG','9001',4.09,0.218,-1.05,'EPSG','9104',1.37,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NLS-Fin',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1639','KKJ to WGS 84 (1)','Parameter values from KKJ to ETRS89 (1) (code 1638). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation. Replaced by KKJ to WGS 84 (2) (code 10099).','For applications to an accuracy of 1 to 2 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4123','EPSG','4326','EPSG','3333',1.5,-90.7,-106.1,-119.2,'EPSG','9001',4.09,0.218,-1.05,'EPSG','9104',1.37,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Fin',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1640','TM65 to ETRS89 (1)','May be taken as approximate transformation TM65 to WGS 84 - see code 1641.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4299','EPSG','4258','EPSG','1305',NULL,482.5,-130.6,564.6,'EPSG','9001',-1.042,-0.214,-0.631,'EPSG','9104',8.15,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OSI-Ire',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1641','TM65 to WGS 84 (2)','Parameter values from TM75 to ETRS89 (2) (code 1953). Assumes each pair of (i) TM65 and TM75, and (ii) ETRS89 and WGS 84, can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4299','EPSG','4326','EPSG','1305',1.0,482.5,-130.6,564.6,'EPSG','9001',-1.042,-0.214,-0.631,'EPSG','9104',8.15,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Ire',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1642','Luxembourg 1930 to ETRS89 (1)','May be taken as approximate transformation Luxembourg 1930 to WGS 84 - see code 1643. Replaced by Luxembourg 1930 to ETRS89 (3) (code 5485).','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4181','EPSG','4258','EPSG','1146',1.0,-193.0,13.7,-39.3,'EPSG','9001',-0.41,-2.933,2.688,'EPSG','9104',0.43,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ACT-Lux',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1643','Luxembourg 1930 to WGS 84 (1)','Parameter values from Luxembourg 1930 to ETRS89 (1) (code 1642). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4181','EPSG','4326','EPSG','1146',1.0,-193.0,13.7,-39.3,'EPSG','9001',-0.41,-2.933,2.688,'EPSG','9104',0.43,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Lux',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1644','Pulkovo 1942(58) to ETRS89 (1)','May be taken as approximate transformation Pulkovo 1942(58) to WGS 84 - see code 1645. Parameter values given to greater precision but to no better accuracy in GUGiK Technical Instruction G-2, Warsaw 2001.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4179','EPSG','4258','EPSG','3293',1.0,33.4,-146.6,-76.3,'EPSG','9001',-0.359,-0.053,0.844,'EPSG','9104',-0.84,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GUGK-Pol',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1645','Pulkovo 1942(58) to WGS 84 (1)','Parameter values from Pulkovo 1942(58) to ETRS89 (1) (code 1644). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4179','EPSG','4326','EPSG','3293',1.0,33.4,-146.6,-76.3,'EPSG','9001',-0.359,-0.053,0.844,'EPSG','9104',-0.84,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Pol',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1646','CH1903 to ETRS89 (1)','In EPSG db v5.2 to v8.9 given to 1dm to accord with Eurogeographics precision ; the difference in output coordinates of cms is considered by swisstopo to be insignificant given the tfm accuracy. Superseded by CH1903 to ETRS89 (2) (tfm code 7674).','Parameter values from CH1903+ to ETRS89 (tfm code 1647) and are used as an approximation from CH1903 with a lesser accuracy of 1.5m which equates to the magnitude of distortions in the CH1903 network.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4149','EPSG','4258','EPSG','1286',1.5,674.374,15.056,405.346,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BfL-Che',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1647','CH1903+ to ETRS89 (1)','This transformation is also given as CH1903+ to CHTRF95 (1) (code 1509). CHTRF95 is a local realisation of ETRS89.','For applications to an accuracy of 0.1 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4150','EPSG','4258','EPSG','1286',0.1,674.374,15.056,405.346,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BfL-Che',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1648','EST97 to ETRS89 (1)','May be taken as approximate transformation EST97 to WGS 84 - see code 1649.','EST97 is a national realization of ETRS89.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4180','EPSG','4258','EPSG','1090',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NLB-Est',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1649','EST97 to WGS 84 (1)','Parameter values taken from EST97 to ETRS89 (1) (code 1648). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4180','EPSG','4326','EPSG','1090',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Est',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1650','ED50 to ETRS89 (10)','These same parameter values are used to transform to WGS 84. See ED50 to WGS 84 (17) (code 1275).','For applications to an accuracy of 2 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4258','EPSG','1096',2.0,-84.0,-97.0,-117.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Fra',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1651','NTF to ETRS89 (1)','These same parameter values are used to transform to WGS 84. See NTF to WGS 84 (1) (code 1193).','For applications to an accuracy of 2 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4275','EPSG','4258','EPSG','3694',2.0,-168.0,-60.0,320.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Fra',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1652','BD72 to ETRS89 (1)','May be taken as approximate transformation BD72 to WGS 84 - see code 1609.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4313','EPSG','4258','EPSG','1347',1.0,-99.1,53.3,-112.5,'EPSG','9001',0.419,-0.83,1.885,'EPSG','9104',-1.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Bel',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1653','NGO 1948 to ETRS89 (1)','May be taken as approximate transformation NGO 1948 to WGS 84 - see code 1654.','For applications to an accuracy of 3 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4273','EPSG','4258','EPSG','1352',3.0,278.3,93.0,474.5,'EPSG','9001',7.889,0.05,-6.61,'EPSG','9104',6.21,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SKV-Nor',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1654','NGO 1948 to WGS 84 (1)','Parameter values from NGO 1948 to ETRS89 (1) (code 1653). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 3 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4273','EPSG','4326','EPSG','1352',3.0,278.3,93.0,474.5,'EPSG','9001',7.889,0.05,-6.61,'EPSG','9104',6.21,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Nor',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1655','Lisbon to ETRS89 (1)','Derived in 2000 at 8 stations. Replaced by 2001 derivation (tfm code 1997). May be taken as approximate transformation to WGS 84 - see tfm code 1656,','For applications to an accuracy of 3 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4207','EPSG','4258','EPSG','1294',3.0,-280.9,-89.8,130.2,'EPSG','9001',-1.721,0.355,-0.371,'EPSG','9104',-5.92,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ICC-Prt 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1656','Lisbon to WGS 84 (1)','Parameter values from Lisbon to ETRS89 (1) (code 1655). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation. Replaced by Lisbon to WGS 84 (4) (code 1988).','For applications to an accuracy of 3 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4207','EPSG','4326','EPSG','1294',3.0,-280.9,-89.8,130.2,'EPSG','9001',-1.721,0.355,-0.371,'EPSG','9104',-5.92,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Prt 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1657','Datum 73 to ETRS89 (1)','Derived in 2000 at 8 stations. Replaced by 2001 derivation (tfm code 1992). May be taken as approximate tfm to WGS 84 - see tfm 1658.','For applications to an accuracy of 2 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4274','EPSG','4258','EPSG','1294',2.0,-238.2,85.2,29.9,'EPSG','9001',0.166,0.046,1.248,'EPSG','9104',2.03,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ICC-Prt 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1658','Datum 73 to WGS 84 (1)','Parameter values from Datum 73 to ETRS89 (1) (code 1657). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation. Replaced by Datum 73 to WGS 84 (4) (tfm code 1987).','For applications to an accuracy of 2 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4274','EPSG','4326','EPSG','1294',2.0,-238.2,85.2,29.9,'EPSG','9001',0.166,0.046,1.248,'EPSG','9104',2.03,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Prt 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1659','Monte Mario to ETRS89 (1)','May be taken as approximate transformation Monte Mario to WGS 84 - see code 1660.','Accuracy: 4 metres','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4265','EPSG','4258','EPSG','2372',4.0,-104.1,-49.1,-9.9,'EPSG','9001',0.971,-2.917,0.714,'EPSG','9104',-11.68,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Ita main',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1660','Monte Mario to WGS 84 (4)','Parameter values from Monte Mario to ETRS89 (1) (code 1659). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','Accuracy: 4 metres','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4265','EPSG','4326','EPSG','2372',4.0,-104.1,-49.1,-9.9,'EPSG','9001',0.971,-2.917,0.714,'EPSG','9104',-11.68,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Ita main',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1661','Monte Mario to ETRS89 (2)','May be taken as approximate transformation Monte Mario to WGS 84 - see code 1662.','Accuracy: 4 metres','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4265','EPSG','4258','EPSG','2339',4.0,-168.6,-34.0,38.6,'EPSG','9001',-0.374,-0.679,-1.379,'EPSG','9104',-9.48,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Ita Sar',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1662','Monte Mario to WGS 84 (2)','Parameter values from Monte Mario to ETRS89 (2) (code 1661). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','Accuracy: 4 metres','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4265','EPSG','4326','EPSG','2339',4.0,-168.6,-34.0,38.6,'EPSG','9001',-0.374,-0.679,-1.379,'EPSG','9104',-9.48,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Ita Sar',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1663','Monte Mario to ETRS89 (3)','May be taken as approximate transformation Monte Mario to WGS 84 - see code 1664.','Accuracy: 4 metres','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4265','EPSG','4258','EPSG','2340',4.0,-50.2,-50.4,84.8,'EPSG','9001',-0.69,-2.012,0.459,'EPSG','9104',-28.08,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Ita Sic',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1664','Monte Mario to WGS 84 (3)','Parameter values from Monte Mario to ETRS89 (3) (code 1663). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','Accuracy: 4 metres','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4265','EPSG','4326','EPSG','2340',4.0,-50.2,-50.4,84.8,'EPSG','9001',-0.69,-2.012,0.459,'EPSG','9104',-28.08,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Ita Sic',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1665','AGD66 to WGS 84 (12)','Parameter values from AGD66 to GDA94 (2) (code 1458). Assumes GDA94 and WGS 84 can be considered the same to within the accuracy of the transformation.','Recommended for mid-accuracy use in A.C.T. 1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4202','EPSG','4326','EPSG','2283',1.0,-129.193,-41.212,130.73,'EPSG','9001',-0.246,-0.374,-0.329,'EPSG','9104',-2.955,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-ACT 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1666','AGD66 to WGS 84 (13)','Parameter values from AGD66 to GDA94 (4) (code 1460). Assumes GDA94 and WGS 84 can be considered the same to within the accuracy of the transformation.','Recommended for mid-accuracy use in NSW and Victoria. 1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4202','EPSG','4326','EPSG','2286',1.0,-119.353,-48.301,139.484,'EPSG','9001',-0.415,-0.26,-0.437,'EPSG','9104',-0.613,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-NSW Vic 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1667','AGD66 to WGS 84 (14)','Parameter values from AGD66 to GDA94 (8) (code 1594). Assumes GDA94 and WGS 84 can be considered the same to within the accuracy of the transformation.','Recommended for mid-accuracy use in Tasmania. 1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4202','EPSG','4326','EPSG','1282',1.0,-120.271,-64.543,161.632,'EPSG','9001',-0.217,0.067,0.129,'EPSG','9104',2.499,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Tas 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1668','AGD66 to WGS 84 (15)','Parameter values from AGD66 to GDA94 (9) (code 1595). Assumes GDA94 and WGS 84 can be considered the same to within the accuracy of the transformation.','Recommended for mid-accuracy use in Northern Territory. 1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4202','EPSG','4326','EPSG','2284',1.0,-124.133,-42.003,137.4,'EPSG','9001',0.008,-0.557,-0.178,'EPSG','9104',-1.854,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-NT 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1669','AGD84 to WGS 84 (7)','Parameter values from AGD84 to GDA94 (2) (code 1280). Assumes GDA94 and WGS 84 can be considered the same to within the accuracy of the transformation. Replaces AGD84 to WGS 84 (2) (code 1236). Note: AGD84 officially adopted only in Qld, SA and WA.','1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4203','EPSG','4326','EPSG','2576',1.0,-117.763,-51.51,139.061,'EPSG','9001',-0.292,-0.443,-0.277,'EPSG','9104',-0.191,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Aus 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1671','RGF93 to WGS 84 (1)','Parameter values from RGF93 to ETRS89 (1) (code 1591) assuming that ETRS89 is equivalent to WGS 84 within the accuracy of the transformation.','Approximation at the +/- 1m level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4171','EPSG','4326','EPSG','1096',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Fra',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1672','Amersfoort to WGS 84 (2)','Parameter values from Amersfoort to ETRS89 (1) (code 1751) assuming that ETRS89 is equivalent to WGS 84 within the accuracy of the transformation. Replaces Amersfoort to WGS 84 (1) (code 1112). Replaced by Amersfoort to WGS 84 (3) (code 15934).','Approximation at the +/- 1m level.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4289','EPSG','4326','EPSG','1275',1.0,565.04,49.91,465.84,'EPSG','9001',1.9848,-1.7439,9.0587,'EPSG','9109',4.0772,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Nld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1673','DHDN to WGS 84 (1)','Parameter values from DHDN to ETRS89 (1) (code 1309) assuming that ETRS89 is equivalent to WGS 84 within the accuracy of the transformation. Replaced by DHDN to WGS 84 (2) (tfm code 1777).','For applications with an accuracy at 5 m level.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4314','EPSG','4326','EPSG','2326',5.0,582.0,105.0,414.0,'EPSG','9001',-1.04,-0.35,3.08,'EPSG','9104',8.3,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Deu W',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1674','Pulkovo 1942(83) to ETRS89 (1)','Mean of 20 stations. May be taken as approximate transformation to WGS 84 - see code 1675. Also given by EuroGeographics at http://crs.ifag.de/ as a Position Vector transformation with changed values for rotations. In 2001 partially replaced by tfm 1775.','Residuals under 2 m.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4178','EPSG','4258','EPSG','1343',2.0,24.0,-123.0,-94.0,'EPSG','9001',-0.02,0.25,0.13,'EPSG','9104',1.1,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IfAG-Deu E',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1675','Pulkovo 1942(83) to WGS 84 (1)','Parameter values from Pulkovo 1942(83) to ETRS89 (1) (code 1674) assuming that ETRS89 is equivalent to WGS 84 within the accuracy of the transformation.','Residuals under 2 m.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4178','EPSG','4326','EPSG','1343',2.0,24.0,-123.0,-94.0,'EPSG','9001',-0.02,0.25,0.13,'EPSG','9104',1.1,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Deu E',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1676','CH1903+ to WGS 84 (1)','Parameter values are from CH1903+ to CHTRF95 (1) (code 1509) assuming that CHTRF95 is equivalent to WGS 84. That transformation is also given as CH1903+ to ETRS89 (1) (code 1647). CHTRF95 is a realisation of ETRS89.','Approximation at the +/- 1m level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4150','EPSG','4326','EPSG','1286',1.0,674.374,15.056,405.346,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BfL-CH',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1677','HD72 to WGS 84 (1)','Parameter values taken from HD72 to ETRS89 (1) (code 1273) assuming that ETRS89 is equivalent to WGS 84 within the accuracy of the transformation.','Approximation at the +/- 1m level.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4237','EPSG','4326','EPSG','1119',NULL,56.0,75.77,15.31,'EPSG','9001',-0.37,-0.2,-0.21,'EPSG','9104',-1.01,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Hun',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1678','IRENET95 to WGS 84 (1)','Assumes that ETRS89 is equivalent to WGS 84 within the accuracy of the transformation. IRENET95 is a regional realisation of ETRS89.','Approximation at the +/- 1m level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4173','EPSG','4326','EPSG','1305',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Ire',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1679','Pulkovo 1942 to WGS 84 (2)','Parameter values taken from Pulkovo 1942 to LKS94(ETRS89) (1) (code 1274) assuming that LKS94(ETRS89) is equivalent to WGS 84 within the accuracy of the transformation.','Approximation at the +/- 9m level.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4284','EPSG','4326','EPSG','3272',9.0,-40.595,-18.55,-69.339,'EPSG','9001',-2.508,-1.832,2.611,'EPSG','9104',-4.299,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Ltu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1680','RT90 to WGS 84 (1)','Parameter values from RT90 to ETRS89 (1) (code 1437) assuming that ETRS89 is equivalent to WGS 84 within the accuracy of the transformation. Replaced by RT90 to WGS 84 (2) (code 1896) from 2001.','Approximation at the +/- 1m level.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4124','EPSG','4326','EPSG','1225',1.0,419.3836,99.3335,591.3451,'EPSG','9001',-0.850389,-1.817277,7.862238,'EPSG','9104',-0.99496,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Swe',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1682','South Yemen to WGS 84 (1)','Parameter values taken from South Yemen to Yemen NGN96 (1) (code 1539) assuming that NGN96 is equivalent to WGS 84 within the accuracy of the transformation.','Approximation at the +/- 5m level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4164','EPSG','4326','EPSG','1340',5.0,-76.0,-138.0,67.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Yem South',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1683','Tete to WGS 84 (1)','Parameter values taken from Tete to Moznet (1) (code 1297) assuming that Moznet is equivalent to WGS 84 within the accuracy of the transformation.','Residuals as high as 30 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4127','EPSG','4326','EPSG','3281',30.0,-115.064,-87.39,-101.716,'EPSG','9001',0.058,-4.001,2.062,'EPSG','9104',9.366,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Moz',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1684','Tete to WGS 84 (2)','Parameter values taken from Tete to Moznet (2) (code 1298) assuming that Moznet is equivalent to WGS 84 within the accuracy of the transformation.','Residuals are generally under 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4127','EPSG','4326','EPSG','2350',1.0,-82.875,-57.097,-156.768,'EPSG','9001',2.158,-1.524,0.982,'EPSG','9104',-0.359,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Moz A',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1685','Tete to WGS 84 (3)','Parameter values taken from Tete to Moznet (3) (code 1299) assuming that Moznet is equivalent to WGS 84 within the accuracy of the transformation.','Residuals are generally under 4 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4127','EPSG','4326','EPSG','2351',4.0,-138.527,-91.999,-114.591,'EPSG','9001',0.14,-3.363,2.217,'EPSG','9104',11.748,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Moz B',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1686','Tete to WGS 84 (4)','Parameter values taken from Tete to Moznet (4) (code 1300) assuming that Moznet is equivalent to WGS 84 within the accuracy of the transformation.','Residuals are generally under 3 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4127','EPSG','4326','EPSG','2352',3.0,-73.472,-51.66,-112.482,'EPSG','9001',-0.953,-4.6,2.368,'EPSG','9104',0.586,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Moz C',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1687','Tete to WGS 84 (5)','Parameter values taken from Tete to Moznet (5) (code 1301) assuming that Moznet is equivalent to WGS 84 within the accuracy of the transformation.','Residuals are 5-10 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4127','EPSG','4326','EPSG','2353',10.0,219.315,168.975,-166.145,'EPSG','9001',-0.198,-5.926,2.356,'EPSG','9104',-57.104,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Moz D',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1701','NZGD49 to NZGD2000 (2)','For better accuracy use NZGD49 to NZGD2000 (3) (code 1568).','4m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4272','EPSG','4167','EPSG','3285',4.0,59.47,-5.04,187.44,'EPSG','9001',-0.47,0.1,-1.024,'EPSG','9104',-4.5993,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OSG-Nzl 4m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1751','Amersfoort to ETRS89 (1)','Replaced by Amersfoort to ETRS89 (3) (tfm code 15739). Dutch sources also quote an equivalent transformation using the Molodenski-Badekas 10-parameter method (M-B) - see tfm code 1066.','Accuracy 0.5m','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4289','EPSG','4258','EPSG','1275',0.5,565.04,49.91,465.84,'EPSG','9001',1.9848,-1.7439,9.0587,'EPSG','9109',4.0772,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NCG-Nld 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1753','CH1903 to WGS 84 (1)','Implemented in Bundesamt für Landestopografie programme GRANIT. Used from 1987 to 1997. Not recommended for current usage - replaced by CH1903 to WGS 84 (2) (code 1766).','Used in programme GRANIT between 1987 and 1997.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4149','EPSG','4326','EPSG','1286',1.0,660.077,13.551,369.344,'EPSG','9001',2.484,1.783,2.939,'EPSG','9113',5.66,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BfL-CH 1',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1754','Minna to WGS 84 (3)','Derived at 8 stations across the Niger delta. Used by Shell SPDC throughout southern Nigeria onshore, delta and shallow offshore from 1994 and by Total in OPL246. Sometimes given with parameter values to greater resolution; values here are adequate.','Oil exploration.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4263','EPSG','4326','EPSG','2371',5.0,-111.92,-87.85,114.5,'EPSG','9001',1.875,0.202,0.219,'EPSG','9104',0.032,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SHL-Nga S',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1766','CH1903 to WGS 84 (2)','Parameters values from CH1903 to ETRS89 (1) (tfm code 1646) assuming ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation. Replaces CH1903 to WGS 84 (1) (code 1753). Replaced by CH1903 to WGS 84 (3) (code 7788).','Parameter values originally from CH1903+ to ETRS89 (tfm code 1647) and are used in tfm code 1646 as an approximation from CH1903 to ETRS89 with a lesser accuracy of 1.5m which equates to the magnitude of distortions in the CH1903 network.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4149','EPSG','4326','EPSG','1286',1.5,674.374,15.056,405.346,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BfL-CH 2',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1767','REGVEN to SIRGAS 1995 (1)','','Accuracy 2 centimetres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4189','EPSG','4170','EPSG','1251',0.02,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CN-Ven',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1768','REGVEN to WGS 84 (1)','','Approximation at the +/- 1m level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4189','EPSG','4326','EPSG','1251',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Ven',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1769','PSAD56 to REGVEN (1)','May be taken as transformation to WGS 84 - see PSAD56 to WGS 84 (13) (code 1095).','Spatial referencing.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4248','EPSG','4189','EPSG','3327',15.0,-270.933,115.599,-360.226,'EPSG','9001',-5.266,-1.238,2.381,'EPSG','9104',-5.109,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2464351.59,-5783466.61,974809.81,'EPSG','9001','IGSB-Ven',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1770','PSAD56 to WGS84 (1)','Parameter vales are from PSAD56 to REGVEN (1) (code 1769) assuming that REGVEN is equivalent to WGS 84 within the accuracy of the transformation.','Approximation at the +/- 1m level.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4248','EPSG','4326','EPSG','1251',NULL,-270.933,115.599,-360.226,'EPSG','9001',-5.266,-1.238,2.381,'EPSG','9104',-5.109,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2464351.59,-5783466.61,974809.81,'EPSG','9001','EPSG-Ven',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1771','La Canoa to REGVEN (1)','May be used as transformation to WGS 84 - see La Canoa to WGS 84 (13) (code 1096)','Spatial referencing.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4247','EPSG','4189','EPSG','3327',15.0,-270.933,115.599,-360.226,'EPSG','9001',-5.266,-1.238,2.381,'EPSG','9104',-5.109,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2464351.59,-5783466.61,974809.81,'EPSG','9001','IGSB-Ven',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1772','La Canoa to WGS84 (1)','Parameter values are from La Canoa to REGVEN (1) (code 1771) assuming that REGVEN is equivalent to WGS 84 within the accuracy of the transformation.','Approximation at the +/- 1m level.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4247','EPSG','4326','EPSG','1251',NULL,-270.933,115.599,-360.226,'EPSG','9001',-5.266,-1.238,2.381,'EPSG','9104',-5.109,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2464351.59,-5783466.61,974809.81,'EPSG','9001','EPSG-Ven',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1773','POSGAR 98 to WGS 84 (1)','','Approximation at the +/- 1m level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4190','EPSG','4326','EPSG','1033',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Arg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1774','POSGAR 98 to SIRGAS 1995 (1)','','POSGAR 98 is a densification of SIRGAS 1995.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4190','EPSG','4170','EPSG','1033',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Arg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1775','Pulkovo 1942(83) to ETRS89 (2)','Derived at 35 points of the German GPS Network DREF. From 2001 replaces Pulkovo 1942(83) to ETRS89 (1) (code 1674) within Mecklenburg-Vorpommern and Sachsen-Anhalt. From 2009 replaces tfm 1674 in all other states of former East Germany.','For applications with an accuracy at 0.1m level','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4178','EPSG','4258','EPSG','1343',0.1,24.9,-126.4,-93.2,'EPSG','9001',-0.063,-0.247,-0.041,'EPSG','9104',1.01,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IfAG-Deu E 0.1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1776','DHDN to ETRS89 (2)','Mean of 109 stations. Replaces DHDN to ETRS89 (1) (tfm code 1309). May be taken as approximate transformation DHDN to WGS 84 - see code 1777.','For applications with an accuracy at 3 m level','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4314','EPSG','4258','EPSG','2326',3.0,598.1,73.7,418.2,'EPSG','9001',0.202,0.045,-2.455,'EPSG','9104',6.7,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IfAG-Deu W 3m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1777','DHDN to WGS 84 (2)','Parameter values from DHDN to ETRS89 (2) (code 1776) assuming that ETRS89 is equivalent to WGS 84 within the accuracy of the transformation. Replaces DHDN to WGS 84 (1) (tfm code 1673).','For applications with an accuracy at 3 m level','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4314','EPSG','4326','EPSG','2326',3.0,598.1,73.7,418.2,'EPSG','9001',0.202,0.045,-2.455,'EPSG','9104',6.7,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Deu W 3m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1778','DHDN to ETRS89 (3)','Derived in 2001 at 41 points of the German GPS Network DREF.','For applications with an accuracy at sub-metre level.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4314','EPSG','4258','EPSG','2543',1.0,597.1,71.4,412.1,'EPSG','9001',0.894,0.068,-1.563,'EPSG','9104',7.58,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IfAG-Deu W-S',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1779','DHDN to ETRS89 (4)','Derived at 27 points of the German GPS Network DREF.','For applications with an accuracy at sub-metre level.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4314','EPSG','4258','EPSG','2542',1.0,584.8,67.0,400.3,'EPSG','9001',0.105,0.013,-2.378,'EPSG','9104',10.29,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IfAG-Deu W-cen',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1780','DHDN to ETRS89 (5)','Derived at 21 points of the German GPS Network DREF.','For applications with an accuracy at sub-metre level','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4314','EPSG','4258','EPSG','2541',1.0,590.5,69.5,411.6,'EPSG','9001',-0.796,-0.052,-3.601,'EPSG','9104',8.3,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IfAG-Deu W-N',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1781','DHDN to ETRS89 (6)','Derived at 10 points of the German GPS Network DREF.','For applications with an accuracy at 0.1m level','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4314','EPSG','4258','EPSG','2544',0.1,599.4,72.4,419.2,'EPSG','9001',-0.062,-0.022,-2.723,'EPSG','9104',6.46,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IfAG-Deu Thur',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1782','DHDN to ETRS89 (7)','Derived at 35 points of the German GPS Network DREF.','For applications with an accuracy at 0.1m level','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4314','EPSG','4258','EPSG','2545',0.1,612.4,77.0,440.2,'EPSG','9001',-0.054,0.057,-2.797,'EPSG','9104',2.55,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IfAG-Deu Sach',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1783','ED50 to ETRS89 (9)','May be taken as approximate transformation ED50 to WGS 84 - see code 1784. Note: the ETRS89 CRS is not used in Turkey.','For applications to an accuracy of 2 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4258','EPSG','1237',2.0,-84.1,-101.8,-129.7,'EPSG','9001',0.0,0.0,0.468,'EPSG','9104',1.05,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'HGK-Tur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1784','ED50 to WGS 84 (30)','Parameter values from ED50 to ETRS89 (9) (code 1783). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 2 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','1237',2.0,-84.1,-101.8,-129.7,'EPSG','9001',0.0,0.0,0.468,'EPSG','9104',1.05,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Tur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1785','MGI to ETRS89 (3)','May be taken as approximate transformation MGI to WGS 84 - see code 1786.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4312','EPSG','4258','EPSG','1212',1.0,426.9,142.6,460.1,'EPSG','9001',4.91,4.49,-12.42,'EPSG','9104',17.1,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GURS-Svn',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1786','MGI to WGS 84 (5)','Parameter values from MGI to ETRS89 (3) (code 1785). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4312','EPSG','4326','EPSG','1212',1.0,426.9,142.6,460.1,'EPSG','9001',4.91,4.49,-12.42,'EPSG','9104',17.1,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Svn',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1787','RT90 to ETRS89 (2)','Derived at 165 points. Supersedes RT90 to ETRS89 (1) (code 1437). May be taken as approximate transformation RT90 to WGS 84 - see code 1787.','Accuracy 0.1m.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4124','EPSG','4258','EPSG','1225',NULL,414.1,41.3,603.1,'EPSG','9001',-0.855,2.141,-7.023,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NLS-Swe 2001',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1788','RT90 to WGS 84 (2)','Parameter values from RT90 to ETRS89 (1) (code 1787) assuming that ETRS89 is equivalent to WGS 84 within the accuracy of the transformation. Supersedes RT90 to WGS 84 (1) (code 1680).','Approximation at the +/- 1m level.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4124','EPSG','4326','EPSG','1225',NULL,414.1,41.3,603.1,'EPSG','9001',-0.855,2.141,-7.023,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Swe 2001',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1789','Dealui Piscului 1933 to WGS 84 (1)','Parameter values taken from Pulkovo 1942 to WGS 84 (9) (code 1293) assuming that','?','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4316','EPSG','4326','EPSG','1197',NULL,103.25,-100.4,-307.19,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NAMR-Rom',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1790','Lisbon to ETRS89 (2)','Derived in 2001. Supersedes Lisbon to ETRS89 (1) (code 1655).','For applications to an accuracy of 2 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4207','EPSG','4258','EPSG','1294',NULL,-282.1,-72.2,120.0,'EPSG','9001',-1.592,0.145,-0.89,'EPSG','9104',-4.46,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ICC-Prt 2001',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1791','Lisbon to WGS 84 (2)','Parameter values from Lisbon to ETRS89 (2) (code 1790). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 2 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4207','EPSG','4258','EPSG','1294',NULL,-282.1,-72.2,120.0,'EPSG','9001',-1.592,0.145,-0.89,'EPSG','9104',-4.46,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Prt 2001',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1792','Datum 73 to ETRS89 (2)','Derived in 2001. Supersedes Datum 73 to ETRS89 (1) (code 1657).','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4274','EPSG','4258','EPSG','1294',NULL,-231.0,102.6,29.8,'EPSG','9001',0.615,-0.198,0.881,'EPSG','9104',1.79,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ICC-Prt 2001',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1793','Datum 73 to WGS 84 (2)','Parameter values from Datum 73 to ETRS89 (2) (code 1792). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4274','EPSG','4258','EPSG','1294',NULL,-231.0,102.6,29.8,'EPSG','9001',0.615,-0.198,0.881,'EPSG','9104',1.79,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Prt 2001',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1794','MGI to WGS 84 (6)','For more accurate transformation see MGI to WGS 84 (7) (code 1795).','Oil industry','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4312','EPSG','4326','EPSG','3536',999.0,695.5,-216.6,491.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'JPet-Yug',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1795','MGI to WGS 84 (7)','','Oil industry','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4312','EPSG','4326','EPSG','3536',999.0,408.0895,-288.9616,791.5498,'EPSG','9001',-4.078662,0.022669,9.825424,'EPSG','9104',94.060626,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,4444943.0248,1518098.4827,4302370.0765,'EPSG','9001','JPET-Yug MB',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1796','Manoca 1962 to WGS 84 (1)','Derived at two points, checked at a third by Stolt Comex Seaway and Geoid for Elf.','Oil industry','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4193','EPSG','4326','EPSG','2555',0.5,-70.9,-151.8,-41.4,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELF94-Cmr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1797','Qornoq 1927 to WGS 84 (1)','Derived at 2 stations.','For military purposes. Accuracy 25m, 25m and 32m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4194','EPSG','4326','EPSG','3362',48.0,164.0,138.0,-189.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Grl S',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1798','Qornoq 1927 to WGS 84 (2)','','Topographic mapping.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4194','EPSG','4326','EPSG','3362',1.0,163.511,127.533,-159.789,'EPSG','9001',0.0,0.0,0.814,'EPSG','9104',-0.6,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'KMS-Grl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1799','Scoresbysund 1952 to WGS 84 (1)','','Topographic mapping.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4195','EPSG','4326','EPSG','2570',1.0,105.0,326.0,-102.5,'EPSG','9001',0.0,0.0,0.814,'EPSG','9104',-0.6,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'KMS-Grl Scosd',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1800','Ammassalik 1958 to WGS 84 (1)','','Topographic mapping.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4196','EPSG','4326','EPSG','2571',1.0,-45.0,417.0,-3.5,'EPSG','9001',0.0,0.0,0.814,'EPSG','9104',-0.6,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'KMS-Grl Ammlk',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1801','Pointe Noire to WGS 84 (2)','Derived in 1994 by CGG/Topnav using DORIS system on various stations along the coastline.','Not known.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4282','EPSG','4326','EPSG','2574',4.0,-145.0,52.7,-291.6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGG94-Cog',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1802','Pointe Noire to WGS 84 (3)','Derived by Geoid for Elf in May 1995 using GPS and IGS data by tying 4 geodetic points to ITRF93 epoch 1995.4.','Used by Elf since May 1995 for all offshore Congo operations.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4282','EPSG','4326','EPSG','2574',0.15,-178.3,-316.7,-131.5,'EPSG','9001',5.278,6.077,10.979,'EPSG','9104',19.166,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELF95-Cog',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1805','Garoua to WGS 72BE (1)','Derived in 1981 by Decca Survey France for Elf Serepca.','Oil industry exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4197','EPSG','4324','EPSG','2590',5.0,-56.1,-167.8,13.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELF-Cmr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1806','Kousseri to WGS 72BE (1)','Derived in 1981 by Decca Survey France for Elf Serepca.','Oil industry exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4198','EPSG','4324','EPSG','2591',5.0,-104.4,-136.6,201.2,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELF-Cmr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1807','Pulkovo 1942 to WGS 84 (13)','Derived via WGS72 values taken from SOCAR Magnavox 1502 manual. Used by AIOC 1995-1997 then replaced by the AIOC97 values (tfm code 1808).¶Do not confuse with AIOC95 vertical datum as used in southern Caspian Sea and at Sangachal terminal by AIOC.','Oil industry operations by AIOC prior to 1997.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4284','EPSG','4326','EPSG','1038',10.0,27.0,-135.0,-84.5,'EPSG','9001',0.0,0.0,0.554,'EPSG','9104',0.2263,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BP-Aze Aioc95',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1808','Pulkovo 1942 to WGS 84 (14)','Mean of 3 stations in western Georgia, 4 stations in eastern Georgia and 4 stations in eastern Azerbaijan. Derived for use on AIOC early oil western export pipeline, but adopted for all AIOC work replacing the 1995 AIOC transformation (code 1807).','Oil industry operations.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4284','EPSG','4326','EPSG','2593',5.0,686.1,-123.5,-574.4,'EPSG','9001',8.045,-23.366,10.791,'EPSG','9104',-2.926,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BP-Aze Aioc97',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1809','Pulkovo 1942 to WGS 84 (15)','Parameter values calculated by Elf Exploration and Production based on geodetic survey carried out by Azerbaijan State Committee for Geodesy and Cartography.','Oil industry operations.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4284','EPSG','4326','EPSG','2594',2.0,926.4,-715.9,-186.4,'EPSG','9001',-10.364,-20.78,26.452,'EPSG','9104',-7.224,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TFE-Aze97',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1810','ED50 to WGS 84 (31)','Derived via concatenation through WGS72. The ED50 to WGS72 step is the Sepplin 1974 value for all Europe.','Oil industry exploration and production operations.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2595',15.0,-84.0,-103.0,-122.5,'EPSG','9001',0.0,0.0,0.554,'EPSG','9104',0.2263,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'wgc72-Egy',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1811','PSAD56 to WGS 84 (12)','Used by Petrobras for shelf operations.','Oil industry exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4248','EPSG','4326','EPSG','1754',10.0,-291.87,106.37,-364.52,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Braz N',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1812','Indian 1975 to WGS 84 (4)','','Cadastral survey.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4240','EPSG','4326','EPSG','3317',3.0,293.0,836.0,318.0,'EPSG','9001',0.5,1.6,-2.8,'EPSG','9104',2.1,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Auslig-Tha',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1813','Batavia to WGS 84 (2)','Used by ARCO offshore NW Java area.','Oil industry operations.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4211','EPSG','4326','EPSG','2577',5.0,-378.873,676.002,-46.255,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ARCO-Idn ONWJ',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1814','Batavia to WGS 84 (3)','Used by PT Komaritim for Nippon Steel during East Java Gas Pipeline construction.','Oil industry operations.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4211','EPSG','4326','EPSG','2588',5.0,-377.7,675.1,-52.2,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'KOM-Idn EJGP',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1815','Nord Sahara 1959 to WGS 84 (4)','Used by BP in District 3 and In Salah Gas.','Oil industry operations.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4307','EPSG','4326','EPSG','2598',5.0,-152.9,43.8,358.3,'EPSG','9001',2.714,1.386,-2.788,'EPSG','9104',-6.743,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BP-Alg D3',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1816','Nord Sahara 1959 to WGS 84 (5)','Derived at astro station central to concession. Significant and varying differences (>100m) at 4 neighbouring astro stations.','Oil industry operations.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4307','EPSG','4326','EPSG','2599',100.0,-95.7,10.2,158.9,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BPA-Alg InAm',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1817','Nord Sahara 1959 to WGS 84 (6)','Derived at astro station Guerrara.','Oil industry operations.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4307','EPSG','4326','EPSG','2600',100.0,-165.914,-70.607,305.009,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ARCO-Alg HBR',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1818','Minna to WGS 84 (4)','Concatenated via WGS 72BE.','Oil industry operations.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4263','EPSG','4326','EPSG','1717',12.0,-89.0,-112.0,125.9,'EPSG','9001',0.0,0.0,0.814,'EPSG','9104',-0.38,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'RSL-Nga',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1819','Minna to WGS 84 (5)','Used by Shell in southern Nigeria and Total in OPL246.','Oil industry operations.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4263','EPSG','4326','EPSG','2371',NULL,-111.92,-87.85,114.5,'EPSG','9001',1.875,0.202,0.219,'EPSG','9104',0.032,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SPD-Nga S',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1820','Minna to WGS 84 (6)','Derived by Nortech at station L40 Minna using NNPC 1989 GPS network tied to 4 ADOS stations. Used by Conoco in OPLs 219-220 to cm precision and ExxonMobil in OPL 209 to dm precision..','Oil industry operations.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4263','EPSG','4326','EPSG','3813',12.0,-93.2,-93.31,121.156,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CON89-Nga',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1821','Minna to WGS 84 (7)','Derived by Elf Petroleum Nigeria in 1994 at 3 stations (M101 onshore, offshore platforms XSW06 and XSV39) and used in OMLs 99-102 and OPLs 222-223.','Oil industry operations.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4263','EPSG','4326','EPSG','3814',6.0,-88.98,-83.23,113.55,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELF94-Nga',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1822','Minna to WGS 84 (8)','Used by Shell SNEPCO for OPLs 209-213 and 316. Derived during 1990 Niger Delta control survey at 4 stations (XSU27, 30 31 and 35).','Oil industry exploration and production.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4263','EPSG','4326','EPSG','3815',10.0,-92.726,-90.304,115.735,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SHL-Nga OPL W',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1823','Minna to WGS 84 (9)','Used by Shell SNEPCO for OPLs 217-223. Derived during 1990 Niger Delta control survey at 4 stations (XSU38, 41, 44 and 45).','Oil industry exploration and production.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4263','EPSG','4326','EPSG','3816',8.0,-93.134,-86.647,114.196,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SHL-Nga OPL S',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1824','Minna to WGS 84 (10)','Used by Shell SNEPCO for Gongola basin.','Oil industry exploration and production.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4263','EPSG','4326','EPSG','3824',25.0,-93.0,-94.0,124.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SHL-Nga Gongola',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1825','Hong Kong 1980 to WGS 84 (1)','Published 1st March 2002. Parameter values from Hong Kong 1980 to Hong Kong Geodetic CS (1) (code 8437) with change of rotation convention. Assumes Hong Kong Geodetic CS and WGS 84 are equivalent within the accuracy of the transformation.','Accuracy to 1m level.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4611','EPSG','4326','EPSG','1118',1.0,-162.619,-276.959,-161.764,'EPSG','9001',0.067753,-2.243649,-1.158827,'EPSG','9104',-1.094246,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'LSD-HKG 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1826','JGD2000 to WGS 84 (1)','','Approximation at the +/- 1m level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4612','EPSG','4326','EPSG','1129',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Jpn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1828','Yoff to WGS 72 (1)','','Military survey.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4310','EPSG','4322','EPSG','1207',25.0,-37.0,157.0,85.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-SEN',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1829','HD72 to ETRS89 (1)','Derived at 5 stations. OGP recommends corrected Hungarian standard MSZ 7222 (tfm code 1449) be used in preference to this transformation. May be taken as approximate transformation HD72 to WGS 84 - see code 1830.','Accuracy at decimetre level throughout Hungary.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4237','EPSG','4258','EPSG','1119',0.5,56.0,-75.77,-15.31,'EPSG','9001',0.37,0.2,0.21,'EPSG','9104',1.01,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'FOMI-Hun',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1830','HD72 to WGS 84 (1)','Parameter values taken from HD72 to ETRS89 (1) (code 1829) assuming that ETRS89 is equivalent to WGS 84 within the accuracy of the transformation. OGP recommends use of newer MSZ 7222 equivalent (tfm code 1448) in preference to this transformation.','Approximation at the +/- 1m level assuming that ETRS89 is equivalent to WGS 84.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4237','EPSG','4326','EPSG','1119',1.0,56.0,-75.77,-15.31,'EPSG','9001',0.37,0.2,0.21,'EPSG','9104',1.01,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Hun',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1831','HD72 to WGS 84 (2)','Derived at fundamental point Szolohegy and tested at 99 stations throughout Hungary. OGP recommends use of newer transformation (tfm code 1242) in preference to this transformation.','Accuracy better than 1m in all three dimensions throughout Hungary.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4237','EPSG','4326','EPSG','1119',1.0,57.01,-69.97,-9.29,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELTE-Hun',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1832','ID74 to WGS 84 (2)','Derived via coordinates of 2 Pulse8 stations. Use of ID74 to WGS 84 (3) (code 1833) is recommended.','For oil industry purposes.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4238','EPSG','4326','EPSG','4020',25.0,2.691,-14.757,4.724,'EPSG','9001',0.0,0.0,0.774,'EPSG','9104',-0.6,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Rac91-Idn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1833','ID74 to WGS 84 (3)','Parameter values from ID74 to DGN95 (1) (code 15911) assuming that DGN95 is equivalent to WGS 84 within the accuracy of the transformation.','Standard deviations of translations are 1.3, 1.1 and 3.6m, of rotations 0.11, 0.06 and 0.04 sec and ppm 0.18.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4238','EPSG','4326','EPSG','4020',3.0,-1.977,-13.06,-9.993,'EPSG','9001',-0.364,-0.254,-0.689,'EPSG','9104',-1.037,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Bak-Idn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1834','Segara to WGS 84 (1)','Accuracy estimate not available.','For military purposes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4294','EPSG','4326','EPSG','2354',NULL,-403.0,684.0,41.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Idn Kal',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1835','Segara to WGS 84 (2)','','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4294','EPSG','4326','EPSG','1360',NULL,-387.06,636.53,46.29,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Shl-Idn Kal E',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1836','Segara to WGS 84 (3)','','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4294','EPSG','4326','EPSG','2770',NULL,-403.4,681.12,46.56,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Shl-Idn Kal NE',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1837','Makassar to WGS 84 (1)','','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4257','EPSG','4326','EPSG','1316',999.0,-587.8,519.75,145.76,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Shl-Idn Sul SW',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1838','Segara to WGS 84 (4)','Datum shift derived through ITRF93.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4613','EPSG','4326','EPSG','1328',1.0,-404.78,685.68,45.47,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TOT-Idn Mah',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1839','Beduaram to WGS 72BE (1)','Derived by Elf in 1986.','Oil exploration. Accuracy estimated at 15m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4213','EPSG','4324','EPSG','2771',15.0,-101.0,-111.0,187.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELF-Ner SE',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1840','QND95 to WGS 84 (1)','Transformation defines QND95. May be approximated to 1m throughout Qatar by geocentric translation transformation with dX=-127.78098m, dY=-283.37477m, dZ=+21.24081m.','Parameter values are defined and therefore exact.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4614','EPSG','4326','EPSG','1346',0.0,-119.4248,-303.65872,-11.00061,'EPSG','9001',1.164298,0.174458,1.096259,'EPSG','9104',3.657065,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGIS-Qat',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1842','NAD83(CSRS) to WGS 84 (1)','For many purposes NAD83(CSRS) can be considered to be coincident with WGS 84.','Approximation at the +/- 1m level assuming that NAD83(CSRS) is equivalent to WGS 84.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4617','EPSG','4326','EPSG','1061',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Can',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1852','Timbalai 1948 to WGS 84 (4)','Derived by Racal Survey for SSB at 24 coastal stations (including Timbalai fundamental point and 6 other primary triangulation stations) between in Sabah (Kudat southwards) and Sarawak (Sibu northwards).','Oil exploration.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4298','EPSG','4326','EPSG','2780',5.0,-533.4,669.2,-52.5,'EPSG','9001',0.0,0.0,4.28,'EPSG','9104',9.4,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SSB-Mys E',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1853','ED50 to WGS 84 (39)','Derived at a single point in Galway docks.','Used by Enterprise for Corrib.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2961',5.0,-82.31,-95.23,-114.96,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Ent-Ire Corrib',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1854','FD58 to WGS 84 (2)','Derived by Geoid for Elf in 1999. EGM96 geoid used.','Oil Exploration','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4132','EPSG','4326','EPSG','2782',0.5,-239.1,-170.02,397.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TFE-Irn Lavan',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1855','FD58 to WGS 84 (3)','Derived by Geoid for Elf in 1999. EGM96 geoid used.','Oil Exploration','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4132','EPSG','4326','EPSG','2781',0.5,-244.72,-162.773,400.75,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TFE-Irn Kharg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1856','ED50(ED77) to WGS 84 (3)','Derived in Kangan district by Geoid for Total in 1998. Used for South Pars phases 2 and 3.','Petroleum Exploration and Production.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4154','EPSG','4326','EPSG','2783',0.5,-122.89,-159.08,-168.74,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TFE-Irn SPars',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1857','ED50(ED77) to WGS 84 (4)','Derived in 1999 on Lavan island by Geoid for Elf.','Petroleum Exploration and Production.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4154','EPSG','4326','EPSG','2782',0.5,-84.78,-107.55,-137.25,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TFE-Irn Lavan',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1858','ED50(ED77) to WGS 84 (5)','Derived by Geoid for Elf in 1999. EGM96 geoid used.','Petroleum Exploration and Production.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4154','EPSG','4326','EPSG','2781',0.5,-123.92,-155.515,-157.721,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TFE-Irn Kharg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1859','ELD79 to WGS 84 (1)','Used by Repsol in Murzuq field, and PetroCanada and previous licence holders in NC177 and 72 (En Naga field). Reliability of connection to ELD79 questionned.','Oil Exploration','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4159','EPSG','4326','EPSG','2785',20.0,-69.06,-90.71,-142.56,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'REP-Lby MZQ',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1860','ELD79 to WGS 84 (2)','Derived December 2001 by NAGECO. Connected to ITRF via Remsa 2000 data. Used by TotalFinaElf.','Oil Exploration. 3-dimensional SD at 11 points is 0.5m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4159','EPSG','4326','EPSG','2785',0.5,-113.997,-97.076,-152.312,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TFE-Lby MZQ',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1861','ELD79 to WGS 84 (3)','Derived by GEOID in 1994 from Transit satellite data. Used by TotalFinaElf.','Oil Exploration','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4159','EPSG','4326','EPSG','2786',2.0,-114.5,-96.1,-151.9,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TFE-Lby MBK94',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1862','ELD79 to WGS 84 (4)','Derived by Geoid in 2000 from ITRF connection by NAGECO for TotalFinaElf. For historic compatibility TFE use the 1994 tfm ELD79 to WGS 84 (3) (code 1861) rather than this transformation.','Oil Exploration','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4159','EPSG','4326','EPSG','2786',0.5,-194.513,-63.978,-25.759,'EPSG','9001',-3.4027,3.756,-3.352,'EPSG','9104',-0.9175,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TFE-Lby MBK00',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1863','ELD79 to WGS 84 (5)','Derived for the Great Man-made River Authority (GMRA).','Engineering survey and oil exploration','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4159','EPSG','4326','EPSG','2786',6.0,-389.691,64.502,210.209,'EPSG','9001',-0.086,-14.314,6.39,'EPSG','9104',0.9264,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GMRA-Lby',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1864','SAD69 to WGS 84 (1)','Derived at 84 stations.','For military purposes only. Accuracy 15m, 6m and 9m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','4016',19.0,-57.0,1.0,-41.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-mean',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1865','SAD69 to WGS 84 (2)','Derived at 10 stations. Note: SAD69 not adopted in Argentina: see Campo Inchauspe (CRS code 4221).','For military purposes only. Accuracy 5m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','3215',9.0,-62.0,-1.0,-37.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Arg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1866','SAD69 to WGS 84 (3)','Derived at 4 stations. Note: SAD69 not adopted in Bolivia: see PSAD56 (CRS code 4248).','For military purposes. Accuracy 15m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','1049',26.0,-61.0,2.0,-48.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Bol',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1867','SAD69 to WGS 84 (4)','Derived at 22 stations.','For military purposes only. Accuracy 3m, 5m and 5m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','3887',8.0,-60.0,-2.0,-41.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Bra',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1868','SAD69 to WGS 84 (5)','Derived at 9 stations. Note: SAD69 not adopted in Chile north of 43°30''S. Replaced by SAD69 to WGS 84 (17) to (19) (codes 6974, 6975 and 6976).','For military purposes only. Accuracy 15m, 8m and 11m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','3227',21.0,-75.0,-1.0,-44.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Chile',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1869','SAD69 to WGS 84 (6)','Derived at 7 stations. Note: SAD69 not adopted in Colombia: see Bogota 1975 (CRS code 4218).','For military purposes only. Accuracy 6m, 6m and 5m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','3229',10.0,-44.0,6.0,-36.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Col',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1870','SAD69 to WGS 84 (7)','Derived at 11 stations. Note: SAD69 not adopted in Ecuador: see PSAD56 (CRS code 4248).','For military purposes. Accuracy 3m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','3241',6.0,-48.0,3.0,-44.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Ecu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1871','SAD69 to WGS 84 (8)','Derived at 1 station. Note: SAD69 not adopted in Ecuador.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','2356',44.0,-47.0,26.0,-42.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Ecu Gal',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1872','SAD69 to WGS 84 (9)','Derived at 5 stations. Note: SAD69 not adopted in Guyana.','For military purposes only. Accuracy 9m, 5m and 5m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','3259',12.0,-53.0,3.0,-47.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Guy',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1873','SAD69 to WGS 84 (10)','Derived at 4 stations. Note: SAD69 not adopted in Paraguay.','For military purposes. Accuracy 15m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','1188',26.0,-61.0,2.0,-33.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Pgy',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1874','SAD69 to WGS 84 (11)','Derived at 6 stations. Note: SAD69 not adopted in Peru: see PSAD56 (CRS code 4248).','For military purposes. Accuracy 5m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','3292',9.0,-58.0,0.0,-44.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Peru',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1875','SAD69 to WGS 84 (12)','Derived at 1 station. Note: SAD69 not adopted in Trinidad and Tobago.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','3143',44.0,-45.0,12.0,-33.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Tto',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1876','SAD69 to WGS 84 (13)','Derived at 5 stations. Note: SAD69 not adopted in Venezuela: see PSAD56 (CRS code 4248).','For military purposes only. Accuracy 3m, 6m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','3327',8.0,-45.0,8.0,-33.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Ven',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1877','SAD69 to WGS 84 (14)','Derived by Brazilian Institute of Geography and Statistics (IBGE) in 1989 at Chua origin point. In use by Shell throughout Brazil. For use by Petrobras and ANP, replaced by tfm code 5882 from 1994.','Medium and small scale mapping. Valid for transforming GPS observations conducted in the period 1987 to 1993 inclusive.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','1053',5.0,-66.87,4.37,-38.52,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGBE-Bra',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1878','SWEREF99 to ETRS89 (1)','Can be taken as an approximate transformation SWEREF99 to WGS 84 - see code 1879.','Geodetic survey.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4619','EPSG','4258','EPSG','1225',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NLS-Swe',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1879','SWEREF99 to WGS 84 (1)','Parameter values taken from SWEREF to ETRS89 (1) (code 1878) assuming that ETRS89 is equivalent to WGS 84 within the accuracy of the transformation.','Geographic Information Systems.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4619','EPSG','4326','EPSG','1225',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Swe',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1880','Point 58 to WGS 84 (1)','Derived at one point in each of Burkina Faso and Niger.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4620','EPSG','4326','EPSG','2791',44.0,-106.0,-129.0,165.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Bfa Ner',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1885','Azores Oriental 1940 to WGS 84 (1)','Derived at 2 stations.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4184','EPSG','4326','EPSG','1345',44.0,-203.0,141.0,53.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Prt Az E',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1886','Azores Central 1948 to WGS 84 (1)','Derived at 5 stations.','For military purposes only. Accuracy 3m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4183','EPSG','4326','EPSG','1301',6.0,-104.0,167.0,-38.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Prt Az C',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1887','Azores Occidental 1939 to WGS 84 (1)','Derived at 3 stations.','For military purposes only. Accuracy 20m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4182','EPSG','4326','EPSG','1344',35.0,-425.0,-169.0,81.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Prt Az W',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1888','Porto Santo to WGS 84 (1)','Derived at 2 stations.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4615','EPSG','4326','EPSG','1314',44.0,-499.0,-249.0,314.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Prt Mad',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1889','Selvagen Grande to WGS 84 (1)','Derived at 1 station.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4616','EPSG','4326','EPSG','2779',NULL,-289.0,-124.0,60.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Prt Sel',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1890','Australian Antarctic to WGS 84 (1)','For many purposes Australian Antarctic can be considered to be coincident with WGS 84.','Approximation at the +/- 1m level assuming that Australian Antarctic is equivalent to WGS 84.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4176','EPSG','4326','EPSG','1278',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Ata Aus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1892','Hito XVIII 1963 to WGS 84 (2)','Derived at 2 stations. As the source CRS was used for the border survey this transformation is probably also applicable to adjacent areas of Argentina.','Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4254','EPSG','4326','EPSG','2805',44.0,16.0,196.0,93.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Chl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1893','Puerto Rico to WGS 84 (3)','Derived at 11 stations.','For military purposes only. Accuracy 3m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4139','EPSG','4326','EPSG','1335',6.0,11.0,72.0,-101.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Pri',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1894','Gandajika 1970 to WGS 84 (1)','Derived at 1 station.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4233','EPSG','4326','EPSG','1152',25.0,-133.0,-321.0,50.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Mdv',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1895','RT90 to SWEREF99 (1)','Derived at 165 points in 2001. Also given by EuroGeographics as RT90 to ETRS89 using the Position Vector transformation method. Replaces RT90 to ETRS89 (1) (code 1437). May be taken as approximate transformation RT90 to WGS 84 - see code 1896.','Accuracy 0.1m.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4124','EPSG','4619','EPSG','1225',0.1,414.1,41.3,603.1,'EPSG','9001',0.855,-2.141,7.023,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NLS-Swe 2001',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1896','RT90 to WGS 84 (2)','Parameter values from RT90 to SWEREF99 (1) (code 1895) assuming that SWEREF99 is equivalent to WGS 84 within the accuracy of the transformation. Replaces RT90 to WGS 84 (1) (code 1680).','Approximation at the +/- 1m level.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4124','EPSG','4326','EPSG','1225',1.0,414.1,41.3,603.1,'EPSG','9001',0.855,-2.141,7.023,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Swe 2001',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1897','Segara to WGS 84 (1)','Accuracy estimate not available.','For military purposes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4613','EPSG','4326','EPSG','1360',999.0,-403.0,684.0,41.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Idn Kal',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1898','Segara to WGS 84 (2)','','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4613','EPSG','4326','EPSG','1359',5.0,-387.06,636.53,46.29,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Shl-Idn Kal E',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1899','Segara to WGS 84 (3)','','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4613','EPSG','4326','EPSG','2770',10.0,-403.4,681.12,46.56,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Shl-Idn Kal NE',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1900','NAD83(HARN) to WGS 84 (2)','Approximation derived ignoring time-dependent parameters and assuming ITRF94(1996.0) and WGS 84, plus NAD83(CORS94) and NAD83(HARN), can be considered the same within the accuracy of the transformation. Replaced by NAD83(HARN) to WGS 84 (3) (code 1901).','Historical record only - superseded - see remarks.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4152','EPSG','4326','EPSG','1323',1.0,-0.9738,1.9453,0.5486,'EPSG','9001',-1.3357e-07,-4.872e-08,-5.507e-08,'EPSG','9101',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGS-Usa ITRF94',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1901','NAD83(HARN) to WGS 84 (3)','Approximation derived from tfm code 6864 ignoring time-dependent parameters and assuming ITRF96(1997.0) and WGS 84, plus NAD83(CORS96) and NAD83(HARN), can be considered the same within the accuracy of the tfm. In USA only replaces tfm code 1900.','Geodesy. Accuracy with respect to CORS at stations adjusted to HARN network is better than 0.05-0.07m. For locations outside a HARN network (i.e. NAD83), accuracy may be only 1m but will usually be better than 0.5m.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4152','EPSG','4326','EPSG','1323',1.0,-0.991,1.9072,0.5129,'EPSG','9001',-1.25033e-07,-4.6785e-08,-5.6529e-08,'EPSG','9101',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGS-Usa ITRF96',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1902','Manoca 1962 to WGS 72BE (1)','Derived at 6 stations using Transit in 1977.','Oil exploration','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4193','EPSG','4324','EPSG','2555',5.0,-56.7,-171.8,-40.6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GOC-Cmr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1903','Fort Marigot to WGS 84 (1)','','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4621','EPSG','4326','EPSG','2828',10.0,137.0,248.0,-430.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Glp',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1904','Guadeloupe 1948 to WGS 84 (1)','','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4622','EPSG','4326','EPSG','2829',10.0,-467.0,-16.0,-300.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Glp 10m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1905','Guadeloupe 1948 to WGS 84 (2)','','Accuracy +/- 0.1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4622','EPSG','4326','EPSG','2829',0.1,-472.29,-5.63,-304.12,'EPSG','9001',0.4362,-0.8374,0.2563,'EPSG','9104',1.8984,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Glp 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1906','CSG67 to WGS 84 (1)','','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4623','EPSG','4326','EPSG','3105',10.0,-186.0,230.0,110.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Guf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1907','RGFG95 to WGS 84 (1)','','Accuracy +/- 2 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4624','EPSG','4326','EPSG','1097',2.0,2.0,2.0,-2.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Guf',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1908','CSG67 to RGFG95 (1)','','Accuracy better than +/- 0.1 metre in the coastal area, better than +/- 1 metre in the interior.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4623','EPSG','4624','EPSG','3105',1.0,-193.066,236.993,105.447,'EPSG','9001',0.4814,-0.8074,0.1276,'EPSG','9104',1.5649,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Guf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1909','Martinique 1938 to WGS 84 (1)','','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4625','EPSG','4326','EPSG','3276',10.0,186.0,482.0,151.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Mtq 10m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1910','Martinique 1938 to WGS 84 (2)','','Accuracy +/- 0.1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4625','EPSG','4326','EPSG','3276',0.1,126.93,547.94,130.41,'EPSG','9001',-2.7867,5.1612,-0.8584,'EPSG','9104',13.8227,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Mtq 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1911','Reunion 1947 to WGS 84 (1)','Derived at 1 station.','Accuracy +/- 30 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4626','EPSG','4326','EPSG','1196',30.0,94.0,-948.0,-1292.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Reu 30m',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1912','RGR92 to WGS 84 (1)','','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4627','EPSG','4326','EPSG','3902',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Reu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1913','Tahaa 54 to WGS 84 (1)','','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4629','EPSG','4326','EPSG','2812',10.0,65.0,342.0,77.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Pyf Tahaa',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1914','IGN72 Nuku Hiva to WGS 84 (1)','','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4630','EPSG','4326','EPSG','3129',10.0,84.0,274.0,65.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Pyf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1915','K0 1949 to WGS 84 (1)','Also published in US NIMA/NGA TR8350.2 which gives accuracy of +/-25m in each axis and states that derived at one station.','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4631','EPSG','4326','EPSG','2816',10.0,145.0,-187.0,103.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Atf Kerg',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1916','Combani 1950 to WGS 84 (1)','','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4632','EPSG','4326','EPSG','3340',10.0,-382.0,-59.0,-262.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Myt',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1917','IGN56 Lifou to WGS 84 (1)','Withdrawn by information source and replaced by improved information from local authority - see tfm code 15902.','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4633','EPSG','4326','EPSG','2814',10.0,336.0,223.0,-231.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Ncl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1918','IGN72 Grand Terre to WGS 84 (1)','','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4634','EPSG','4326','EPSG','1174',NULL,-13.0,-348.0,292.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Ncl',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1919','ST87 Ouvea to WGS 84 (1)','','Accuracy better than +/- 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4635','EPSG','4326','EPSG','2813',1.0,-122.383,-188.696,103.344,'EPSG','9001',3.5107,-4.9668,-5.7047,'EPSG','9104',4.4798,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1920','RGNC 1991 to WGS 84 (1)','','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4645','EPSG','4326','EPSG','1174',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Ncl',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1921','Petrels 1972 to WGS 84 (1)','','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4636','EPSG','4326','EPSG','2817',10.0,365.0,194.0,166.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Ata Adel',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1922','Perroud 1950 to WGS 84 (1)','','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4637','EPSG','4326','EPSG','2818',10.0,325.0,154.0,172.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Ata Adel',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1923','Saint Pierre et Miquelon 1950 to WGS 84 (1)','','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4638','EPSG','4326','EPSG','3299',10.0,30.0,430.0,368.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Spm',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1924','Tahiti 52 to WGS 84 (1)','','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4628','EPSG','4326','EPSG','2811',10.0,162.0,117.0,154.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Pyf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1925','MOP78 to WGS 84 (1)','','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4639','EPSG','4326','EPSG','2815',10.0,252.0,-132.0,-125.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Wlf Wallis',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1926','Reunion 1947 to RGR92 (1)','Note: Because of the large rotation about the Y-axis this transformation is not reversible. Errors of up to 0.5m may occur. For the reverse transformation use RGR92 to Reunion 1947 [alias Piton des Neiges] (1) (code 1964).','Accuracy better than +/- 0.1 metre. Not reversible - see remarks.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4626','EPSG','4627','EPSG','3337',0.1,789.524,-626.486,-89.904,'EPSG','9001',0.6006,76.7946,-10.5788,'EPSG','9104',-32.3241,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Reu 0.1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1927','IGN56 Lifou to WGS 84 (2)','Withdrawn by information source and replaced by improved information - see tfm code 15902.','Accuracy better than +/- 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4633','EPSG','4326','EPSG','2814',1.0,137.092,131.66,91.475,'EPSG','9001',-1.9436,-11.5993,-4.3321,'EPSG','9104',-7.4824,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1928','IGN53 Mare to WGS 84 (1)','Withdrawn by information source and replaced by improved information - see tfm code 15901.','Accuracy better than +/- 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4641','EPSG','4326','EPSG','2819',1.0,-408.809,366.856,-412.987,'EPSG','9001',1.8842,-0.5308,2.1655,'EPSG','9104',-121.0993,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1929','IGN72 Grand Terre to WGS 84 (2)','','Accuracy better than +/- 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4634','EPSG','4326','EPSG','2822',NULL,97.295,-263.247,310.882,'EPSG','9001',-1.5999,0.8386,3.1409,'EPSG','9104',13.3259,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1930','ST84 Ile des Pins to WGS 84 (1)','','Accuracy better than +/- 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4642','EPSG','4326','EPSG','2820',1.0,244.416,85.339,168.114,'EPSG','9001',-8.9353,7.7523,12.5953,'EPSG','9104',14.268,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1931','ST71 Belep to WGS 84 (1)','','Accuracy better than +/- 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4643','EPSG','4326','EPSG','2821',1.0,-480.26,-438.32,-643.429,'EPSG','9001',16.3119,20.1721,-4.0349,'EPSG','9104',-111.7002,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1932','NEA74 Noumea to WGS 84 (1)','','Accuracy better than +/- 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4644','EPSG','4326','EPSG','2823',1.0,-166.207,-154.777,254.831,'EPSG','9001',-37.5444,7.7011,-10.2025,'EPSG','9104',-30.8598,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1933','RGR92 to Piton des Nieges (1)','Note: Because of the large rotation about the Y-axis this transformation is not reversible. For the reverse transformation see Piton des Nieges to RGR92 (1) (code 1926).','Accuracy better than +/- 0.1 metre. Not reversible - see remarks.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4627','EPSG','4626','EPSG','1196',NULL,-789.99,627.333,89.685,'EPSG','9001',-0.6072,-76.8019,10.568,'EPSG','9104',32.2083,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Reu 0.1m',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1934','RRAF 1991 to WGS 84 (1)','RRAF 1991 was defined to be WGS84 at a single point in Martinique during the 1988 Tango mission.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4640','EPSG','4326','EPSG','2824',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-FrAnt',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1935','ITRF97 to ITRF2000 (1)','At epoch 1997.0. Rates dX=0.0000 m/yr, dy=0.0006 m/yr, dZ=0.0014 m/yr, rX=rY=0.0"/yr, rZ=-0.00002"/yr, dS=-0.00001 ppm/yr.','Geodesy.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4918','EPSG','4919','EPSG','1262',0.0,-0.0067,-0.0061,0.0185,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',-0.00155,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1936','ITRF96 to ITRF2000 (1)','At epoch 1997.0. Rates dX=0.0000 m/yr, dy=0.0006 m/yr, dZ=0.0014 m/yr, rX=rY=0.0"/yr, rZ=-0.00002"/yr, dS=-0.00001 ppm/yr.','Geodesy.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4917','EPSG','4919','EPSG','1262',0.0,-0.0067,-0.0061,0.0185,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',-0.00155,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1937','ITRF94 to ITRF2000 (1)','At epoch 1997.0. Rates dX=0.0000 m/yr, dy=0.0006 m/yr, dZ=0.0014 m/yr, rX=rY=0.0"/yr, rZ=-0.00002"/yr, dS=-0.00001 ppm/yr.','Geodesy.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4916','EPSG','4919','EPSG','1262',0.0,-0.0067,-0.0061,0.0185,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',-0.00155,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1938','ITRF93 to ITRF2000 (1)','At epoch 1988.0. Rates dX=0.0029 m/yr, dy=0.0002 m/yr, dZ=0.0006 m/yr, rX=0.00011"/yr, rY=0.00019"/yr, rZ=-0.00007"/yr, dS=-0.00001 ppm/yr.','Geodesy.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4915','EPSG','4919','EPSG','1262',0.0,-0.0127,-0.0065,0.0209,'EPSG','9001',0.00039,-0.0008,0.00114,'EPSG','9104',-0.00195,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1939','ITRF92 to ITRF2000 (1)','At epoch 1988.0. Rates dX=0.0000 m/yr, dy=0.0006 m/yr, dZ=0.0014 m/yr, rX=rY=0.0"/yr, rZ=-0.00002"/yr, dS=-0.00001 ppm/yr.','Geodesy.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4914','EPSG','4919','EPSG','1262',0.0,-0.0147,-0.0135,0.0139,'EPSG','9001',0.0,0.0,0.00018,'EPSG','9104',-0.00075,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1940','ITRF91 to ITRF2000 (1)','At epoch 1988.0. Rates dX=0.0000 m/yr, dy=0.0006 m/yr, dZ=0.0014 m/yr, rX=rY=0.0"/yr, rZ=-0.00002"/yr, dS=-0.00001 ppm/yr.','Geodesy.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4913','EPSG','4919','EPSG','1262',0.0,-0.0267,-0.0275,0.0199,'EPSG','9001',0.0,0.0,0.00018,'EPSG','9104',-0.00215,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1941','ITRF90 to ITRF2000 (1)','At epoch 1988.0. Rates dX=0.0000 m/yr, dy=0.0006 m/yr, dZ=0.0014 m/yr, rX=rY=0.0"/yr, rZ=-0.00002"/yr, dS=-0.00001 ppm/yr.','Geodesy.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4912','EPSG','4919','EPSG','1262',0.0,-0.0247,-0.0235,0.0359,'EPSG','9001',0.0,0.0,0.00018,'EPSG','9104',-0.00245,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1942','ITRF89 to ITRF2000 (1)','At epoch 1988.0. Rates dX=0.0000 m/yr, dy=0.0006 m/yr, dZ=0.0014 m/yr, rX=rY=0.0"/yr, rZ=-0.00002"/yr, dS=-0.00001 ppm/yr.','Geodesy.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4911','EPSG','4919','EPSG','1262',0.0,-0.0297,-0.0475,0.0739,'EPSG','9001',0.0,0.0,0.00018,'EPSG','9104',0.00585,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1943','ITRF88 to ITRF2000 (1)','At epoch 1988.0. Rates dX=0.0000 m/yr, dy=0.0006 m/yr, dZ=0.0014 m/yr, rX=rY=0.0"/yr, rZ=-0.00002"/yr, dS=-0.00001 ppm/yr.','Geodesy.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4910','EPSG','4919','EPSG','1262',0.0,-0.0247,-0.0115,0.0979,'EPSG','9001',-0.0001,0.0,0.00018,'EPSG','9104',-0.00895,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1944','Lisbon to WGS 84 (2)','Parameter values from Lisbon to ETRS89 (2) (code 1790). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 2 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4207','EPSG','4326','EPSG','1294',NULL,-282.1,-72.2,120.0,'EPSG','9001',-1.592,0.145,-0.89,'EPSG','9104',-4.46,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Prt 2001',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1945','Datum 73 to WGS 84 (2)','Parameter values from Datum 73 to ETRS89 (2) (code 1792). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4274','EPSG','4326','EPSG','1294',NULL,-231.0,102.6,29.8,'EPSG','9001',0.615,-0.198,0.881,'EPSG','9104',1.79,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Prt 2001',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1946','NAD83(CSRS) to WGS 84 (2)','Approximation derived from tfm code 6864 ignoring time-dependent parameters and assuming ITRF96(1997.0) and WGS 84 can be considered the same within the accuracy of the transformation.','Geodesy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4617','EPSG','4326','EPSG','1061',1.0,-0.991,1.9072,0.5129,'EPSG','9001',-1.25033e-07,-4.6785e-08,-5.6529e-08,'EPSG','9101',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGS-Usa ITRF96',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1950','NAD83 to NAD83(CSRS) (4)','Used as part of NAD27 to/from WGS 84 transformation for offshore oil operations - see code 8647.','Accuracy 1 to 2 metres. Used for oil industry operations only.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4269','EPSG','4617','EPSG','2831',2.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Can E Off',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1951','Hjorsey 1955 to WGS 84 (1)','Derived at 6 stations. Replaced by Hjorsey 1955 to WGS 84 (2) (code 6909).','Accuracy 3m, 3m and 5m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4658','EPSG','4326','EPSG','3262',7.0,-73.0,46.0,-86.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Isl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1952','ISN93 to WGS 84 (1)','For many purposes ISN93 can be considered to be coincident with WGS 84.','Approximation at the +/- 1m level assuming that ISN93 is equivalent to WGS 84.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4659','EPSG','4326','EPSG','1120',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Isl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1953','TM75 to ETRS89 (2)','TM75 is based on the geodetic datum of 1965 which should not be confused with the mapping adjustment of 1965 (TM65). May be taken as approximate transformations TM75 to WGS 84, TM65 to WGS 84 and OSNI 1952 to WGS 84 - see codes 1954, 1641 and 1955.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4300','EPSG','4258','EPSG','1305',1.0,482.5,-130.6,564.6,'EPSG','9001',-1.042,-0.214,-0.631,'EPSG','9104',8.15,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OSI-Ire',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1954','TM75 to WGS 84 (2)','Parameter values taken from TM65 to ETRS89 (2) (code 1953). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4300','EPSG','4326','EPSG','1305',1.0,482.5,-130.6,564.6,'EPSG','9001',-1.042,-0.214,-0.631,'EPSG','9104',8.15,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Ire',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1955','OSNI 1952 to WGS 84 (1)','Parameter values from TM75 to ETRS89 (2) (code 1953). Assumes each pair of (i) OSNI 1952 and TM75, and (ii) ETRS89 and WGS 84, can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4188','EPSG','4326','EPSG','2530',1.0,482.5,-130.6,564.6,'EPSG','9001',-1.042,-0.214,-0.631,'EPSG','9104',8.15,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Ire',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1956','TM75 to WGS 84 (3)','Derived at 7 stations. TM75 is based on the geodetic datum of 1965 which should not be confused with the mapping adjustment of 1965 (TM65).','For military purposes only. Accuracy 3m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4300','EPSG','4326','EPSG','1305',6.0,506.0,-122.0,611.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Ire',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1957','Helle 1954 to WGS 84 (1)','Derived at 3 stations. Residuals under 1m.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4660','EPSG','4326','EPSG','2869',1.0,982.6087,552.753,-540.873,'EPSG','9001',32.39344,-153.25684,-96.2266,'EPSG','9109',16.805,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SKV-SJM Jan Mayen',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1958','LKS92 to WGS 84 (1)','','LKS92 is a national realization of ETRS89 and coincident to WGS84 within 1 metre. This transformation has an accuracy equal to the coincidence figure.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4661','EPSG','4326','EPSG','1139',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Vzd-Lva',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1959','St. Vincent 1945 to WGS 84 (1)','Derived at 4 points.','1m accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4607','EPSG','4326','EPSG','3300',1.0,195.671,332.517,274.607,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'LSU-Vct',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1960','ED87 to WGS 84 (2)','','Scientific research.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4231','EPSG','4326','EPSG','1297',1.0,-83.11,-97.38,-117.22,'EPSG','9001',0.005693,-0.04469,0.04428,'EPSG','9104',1.218,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS-Eur',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1961','ED50 to WGS 84 (32)','Parameter values taken from ED87 to WGS 84 (2) (tfm code 1960) assuming that ED87 is identical to ED50. Errors caused by this assumption can reach 3m.','Used by NAM for offshore operations.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','1630',NULL,-83.11,-97.38,-117.22,'EPSG','9001',0.005693,-0.04469,0.4428,'EPSG','9104',1.218,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NAM-Nld-Nsea',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1962','IGN72 Grande Terre to WGS 84 (1)','Withdrawn by information source and replaced by improved information from local authority - see tfm code 15903.','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4662','EPSG','4326','EPSG','2822',10.0,-13.0,-348.0,292.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Ncl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1963','IGN72 Grande Terre to WGS 84 (2)','Withdrawn by information source and replaced by improved information - see tfm code 15903.','Accuracy better than +/- 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4662','EPSG','4326','EPSG','2822',1.0,97.295,-263.247,310.882,'EPSG','9001',-1.5999,0.8386,3.1409,'EPSG','9104',13.3259,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1964','RGR92 to Reunion 1947 (1)','Note: Because of the large rotation about the Y-axis this transformation is not reversible. Errors of up to 0.5m may occur. For the reverse transformation use Piton des Neiges to RGR92 (1) (code 1926).','Accuracy better than +/- 0.1 metre. Not reversible - see remarks.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4627','EPSG','4626','EPSG','3337',0.1,-789.99,627.333,89.685,'EPSG','9001',-0.6072,-76.8019,10.568,'EPSG','9104',32.2083,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Reu 0.1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1965','Selvagem Grande to WGS 84 (1)','Derived at 1 station.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4616','EPSG','4326','EPSG','2779',44.0,-289.0,-124.0,60.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Prt Sel',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1966','Porto Santo 1995 to WGS 84 (2)','Derived at Forte de Sao Tiago.','For low resolution applications.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4663','EPSG','4326','EPSG','2870',5.0,-502.862,-247.438,312.724,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt Mad 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1967','Porto Santo 1995 to WGS 84 (3)','','For medium resolution applications.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4663','EPSG','4326','EPSG','2870',1.0,-210.502,-66.902,-48.476,'EPSG','9001',-2.094,15.067,5.817,'EPSG','9104',0.485,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt Mad 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1968','Azores Oriental 1995 to WGS 84 (2)','Calculated in 2001.','For low resolution applications.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4664','EPSG','4326','EPSG','2871',5.0,-204.633,140.216,55.199,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt Az Mig 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1969','Azores Oriental 1995 to WGS 84 (3)','Calculated in 2001.','For medium resolution applications.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4664','EPSG','4326','EPSG','2871',1.0,-211.939,137.626,58.3,'EPSG','9001',0.089,-0.251,-0.079,'EPSG','9104',0.384,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt Az Mig 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1970','Azores Oriental 1995 to WGS 84 (4)','Mean for all islands in group.','For low resolution applications.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4664','EPSG','4326','EPSG','1345',5.0,-204.619,140.176,55.226,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt Az E 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1971','Azores Oriental 1995 to WGS 84 (5)','Mean for all islands in group.','For medium resolution applications.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4664','EPSG','4326','EPSG','1345',1.0,-208.719,129.685,52.092,'EPSG','9001',0.195,0.014,-0.327,'EPSG','9104',0.198,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt Az E 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1972','Azores Central 1995 to WGS 84 (2)','','For low resolution applications.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4665','EPSG','4326','EPSG','2872',5.0,-106.301,166.27,-37.916,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt Az Ter 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1973','Azores Central 1995 to WGS 84 (3)','','For medium resolution applications.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4665','EPSG','4326','EPSG','2872',1.0,-105.854,165.589,-38.312,'EPSG','9001',0.003,0.026,-0.024,'EPSG','9104',-0.048,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt Az Ter 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1974','Azores Central 1995 to WGS 84 (4)','','For low resolution applications.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4665','EPSG','4326','EPSG','2873',5.0,-106.248,166.244,-37.845,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt Az Fai 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1975','Azores Central 1995 to WGS 84 (5)','','For medium resolution applications.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4665','EPSG','4326','EPSG','2873',1.0,-104.0,162.924,-38.882,'EPSG','9001',0.075,0.071,-0.051,'EPSG','9104',-0.338,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt Az Fai 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1976','Azores Central 1995 to WGS 84 (6)','','For low resolution applications.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4665','EPSG','4326','EPSG','2874',5.0,-106.044,166.655,-37.876,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt Az Pic 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1977','Azores Central 1995 to WGS 84 (7)','','For medium resolution applications.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4665','EPSG','4326','EPSG','2874',1.0,-95.323,166.098,-69.942,'EPSG','9001',0.215,1.031,-0.047,'EPSG','9104',1.922,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt Az Pic 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1978','Azores Central 1995 to WGS 84 (8)','','For low resolution applications.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4665','EPSG','4326','EPSG','2875',5.0,-106.253,166.239,-37.854,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt Az SJ 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1979','Azores Central 1995 to WGS 84 (9)','','For medium resolution applications.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4665','EPSG','4326','EPSG','2875',1.0,-100.306,161.246,-48.761,'EPSG','9001',0.192,0.385,-0.076,'EPSG','9104',0.131,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt Az SJ 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1980','Azores Central 1995 to WGS 84 (10)','Mean for all islands in group.','For low resolution applications.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4665','EPSG','4326','EPSG','1301',5.0,-106.226,166.366,-37.893,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt Az C 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1981','Azores Central 1995 to WGS 84 (11)','Mean for all islands in group.','For medium resolution applications.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4665','EPSG','4326','EPSG','1301',1.0,-103.088,162.481,-28.276,'EPSG','9001',-0.167,-0.082,-0.168,'EPSG','9104',-1.504,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt Az C 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1982','Azores Occidental 1939 to WGS 84 (2)','Derived at 2 stations in 1999.','For low resolution applications.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4182','EPSG','4326','EPSG','1344',5.0,-422.651,-172.995,84.02,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt Az W',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1983','Datum 73 to WGS 84 (3)','','For low resolution applications.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4274','EPSG','4326','EPSG','1294',5.0,-223.237,110.193,36.649,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1984','Lisbon to WGS 84 (3)','','For low resolution applications.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4207','EPSG','4326','EPSG','1294',5.0,-304.046,-60.576,103.64,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1985','ED50 to WGS 84 (33)','May be taken as a transformation from ED50 to ETRS89 - see tfm code 5040.','For low resolution applications.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','1294',5.0,-87.987,-108.639,-121.593,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1986','Lisbon 1890 to WGS 84 (1)','May be taken as a transformation from Lisbon 1890 to ETRS89 - see tfm code 5039.','For low resolution applications.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4666','EPSG','4326','EPSG','1294',5.0,508.088,-191.042,565.223,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1987','Datum 73 to WGS 84 (4)','','For medium resolution applications.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4274','EPSG','4326','EPSG','1294',1.0,-239.749,88.181,30.488,'EPSG','9001',-0.263,-0.082,-1.211,'EPSG','9104',2.229,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1988','Lisbon to WGS 84 (4)','','For medium resolution applications.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4207','EPSG','4326','EPSG','1294',2.0,-288.885,-91.744,126.244,'EPSG','9001',1.691,-0.41,0.211,'EPSG','9104',-4.598,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1989','ED50 to WGS 84 (34)','','For medium resolution applications.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','1294',1.0,-74.292,-135.889,-104.967,'EPSG','9001',0.524,0.136,-0.61,'EPSG','9104',-3.761,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1990','Lisbon 1890 to WGS 84 (2)','','For medium resolution applications.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4666','EPSG','4326','EPSG','1294',1.0,631.392,-66.551,481.442,'EPSG','9001',-1.09,4.445,4.487,'EPSG','9104',-4.43,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1992','Datum 73 to ETRS89 (3)','Parameters calculated in 1998 using 9 common stations. Published in 2001. Replaces Datum 73 to ETRS89 (1) (code 1657). Replaced by Datum 73 to ETRS89 (5) (code 5037).','For medium resolution applications.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4274','EPSG','4258','EPSG','1294',1.0,-231.034,102.615,26.836,'EPSG','9001',-0.615,0.198,-0.881,'EPSG','9104',1.786,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1993','IKBD-92 to WGS 84 (4)','For all practical purposes this transformation is exact.','Boundary demarcation.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4667','EPSG','4326','EPSG','2876',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UN-Irq Kwt',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1994','Reykjavik 1900 to WGS 84 (1)','','Low accuracy applications.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4657','EPSG','4326','EPSG','3262',10.0,-28.0,199.0,5.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'LMI-Isl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1995','Dealul Piscului 1930 to WGS 84 (1)','','Oil exploration','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4316','EPSG','4326','EPSG','3295',10.0,103.25,-100.4,-307.19,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NAMR-Rom',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1996','Dealul Piscului 1970 to WGS 84 (1)','','Oil exploration','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4317','EPSG','4326','EPSG','1197',10.0,44.107,-116.147,-54.648,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Shell-Rom',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','1997','Lisbon to ETRS89 (2)','Derived in 2001. Replaces Lisbon to ETRS89 (1) (code 1655). Also given to greater precision but no more accuracy on ICC web site using Coordinate Frame method. Replaced by Lisbon to ETRS89 (3) (code 5038).','For applications to an accuracy of 2 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4207','EPSG','4258','EPSG','1294',2.0,-282.1,-72.2,120.0,'EPSG','9001',-1.529,0.145,-0.89,'EPSG','9104',-4.46,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ICC-Prt 2001',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1998','ED50 to WGS 84 (36)','Approximation to better than 0.5m of transformation adopted in June 2003 (see ED50 to WGS 84 (35), code 1052). Acceptable to Landesbergamt for Lower Saxony and Bundesanstalt für Seeschifffahrt und Hydrographie.','Recommended transformation for Germany North Sea petroleum purposes.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2879',1.0,-157.89,-17.16,-78.41,'EPSG','9001',2.118,2.697,-1.434,'EPSG','9104',-5.38,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Ger Nsea',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','1999','ED50 to WGS 84 (32)','Parameter values taken from ED87 to WGS 84 (2) (tfm code 1960) assuming that ED87 is identical to ED50. Errors caused by this assumption can reach 3m.','Used by NAM for offshore operations.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','1630',3.0,-83.11,-97.38,-117.22,'EPSG','9001',0.005693,-0.04469,0.04428,'EPSG','9104',1.218,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NAM-Nld-Nsea',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','3817','HD1909 to WGS 84 (1)','Horizontal coordinates of 66 points of the National Geodetic Network were used to compute this transformation.','GIS and topographic survey.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3819','EPSG','4326','EPSG','1119',3.0,595.48,121.69,515.35,'EPSG','9001',-4.115,2.9383,-0.853,'EPSG','9104',-3.408,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELTE-Hun',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3830','TWD97 to WGS 84 (1)','Approximation at the +/- 1m level assuming that TWD97 is equivalent to WGS 84.','Accuracy +/- 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','3824','EPSG','4326','EPSG','1228',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Twn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3894','IGRS to WGS 84 (1)','Approximation at the +/- 1m level assuming that IGRS is equivalent to WGS 84 within the accuracy of the transformation.','Accuracy 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','3889','EPSG','4326','EPSG','1124',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Irq',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3904','ED50 to WGS 84 (32)','Parameter values from ED87 to WGS 84 (32) (tfm code 3905), assuming that ED87 is identical to ED50. Errors caused by this assumption can reach 3-5m. Used by NAM for offshore operations until mid 2004, then replaced by tfm code 1311.','E&P operations in the Dutch sector of the North Sea.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','1630',5.0,-83.11,-97.38,-117.22,'EPSG','9001',0.0276,-0.2167,0.2147,'EPSG','9109',0.1218,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Rws-Nld-Nsea',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3905','ED87 to WGS 84 (2)','Parameter values taken from ED87 to ETRS89 (1) (tfm code 4078) assuming that ETRS89 is coincident with WGS 84 within the accuracy of the transformation. Used as a tfm between ED50 and WGS 84 - see code 3904.','Scientific research.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4231','EPSG','4326','EPSG','1297',1.0,-83.11,-97.38,-117.22,'EPSG','9001',0.0276,-0.2167,0.2147,'EPSG','9109',0.1218,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Eur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3914','MGI 1901 to ETRS89 (3)','Derived at 11 points. May be taken as approximate transformation MGI 1901 to WGS 84 - see code 3915. Superseded by MGI 1901 to Slovenia 1996 (12) (code 8689).','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','3906','EPSG','4258','EPSG','3307',1.0,426.9,142.6,460.1,'EPSG','9001',4.91,4.49,-12.42,'EPSG','9104',17.1,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GURS-Svn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3915','MGI 1901 to WGS 84 (5)','Parameter values from MGI 1901 to ETRS89 (3) (code 3914). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','3906','EPSG','4326','EPSG','3307',1.0,426.9,142.6,460.1,'EPSG','9001',4.91,4.49,-12.42,'EPSG','9104',17.1,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Svn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3916','MGI 1901 to Slovenia 1996 (1)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible. May be taken as approx tfm MGI 1901 to WGS 84 (see code 3917).','1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4765','EPSG','3307',1.0,409.545,72.164,486.872,'EPSG','9001',-3.085957,-5.46911,11.020289,'EPSG','9104',17.919665,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3917','MGI 1901 to WGS 84 (9)','Parameter values from MGI 1901 to Slovenia 1996 (1) (code 3916). Assumes Slovenia 1996 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4326','EPSG','3307',1.0,409.545,72.164,486.872,'EPSG','9001',-3.085957,-5.46911,11.020289,'EPSG','9104',17.919665,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Svn 96',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3918','MGI 1901 to Slovenia 1996 (2)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.5m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4765','EPSG','3564',0.5,315.393,186.223,499.609,'EPSG','9001',-6.445954,-8.131631,13.208641,'EPSG','9104',23.449046,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn W',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3919','MGI 1901 to Slovenia 1996 (3)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.5m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4765','EPSG','3565',0.5,464.939,-21.478,504.497,'EPSG','9001',0.403,-4.228747,9.954942,'EPSG','9104',12.795378,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn NE',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3921','MGI 1901 to Slovenia 1996 (4)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.5m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4765','EPSG','3566',0.5,459.968,82.193,458.756,'EPSG','9001',-3.565234,-3.700593,10.860523,'EPSG','9104',15.507563,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn SE 0.5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3922','MGI 1901 to Slovenia 1996 (5)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.3m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4765','EPSG','3567',0.3,427.914,105.528,510.908,'EPSG','9001',-4.992523,-5.898813,10.306673,'EPSG','9104',12.431493,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn SE 0.3m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3923','MGI 1901 to Slovenia 1996 (6)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.3m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4765','EPSG','3568',0.3,468.63,81.389,445.221,'EPSG','9001',-3.839242,-3.262525,10.566866,'EPSG','9104',16.132726,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn Dol',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3924','MGI 1901 to Slovenia 1996 (7)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.3m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4765','EPSG','3569',0.3,439.5,-11.77,494.976,'EPSG','9001',-0.026585,-4.65641,10.155824,'EPSG','9104',16.270002,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn Staj',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3925','MGI 1901 to Slovenia 1996 (8)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.3m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4765','EPSG','3570',0.3,524.442,3.275,519.002,'EPSG','9001',0.013287,-3.119714,10.232693,'EPSG','9104',4.184981,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn Pom',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3926','MGI 1901 to Slovenia 1996 (9)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.3m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4765','EPSG','3571',0.3,281.529,45.963,537.515,'EPSG','9001',-2.570437,-9.648271,10.759507,'EPSG','9104',26.465548,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn Gor',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3927','MGI 1901 to Slovenia 1996 (10)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.3m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4765','EPSG','3572',0.3,355.845,274.282,462.979,'EPSG','9001',-9.086933,-6.491055,14.502181,'EPSG','9104',20.888647,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn Prim',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3928','MGI 1901 to Slovenia 1996 (11)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.3m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4765','EPSG','3573',0.3,400.629,90.651,472.249,'EPSG','9001',-3.261138,-5.263404,11.83739,'EPSG','9104',20.022676,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn cen',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3962','MGI 1901 to WGS 84 (1)','Accuracy estimate not available from information source but established empirically by OGP.','For military purposes only.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','3906','EPSG','4326','EPSG','2370',5.0,682.0,-203.0,480.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-balk',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3963','MGI 1901 to ETRS89 (2)','May be taken as approximate transformation MGI 1901 to WGS 84 - see code 3964.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','3906','EPSG','4258','EPSG','3234',1.0,551.7,162.9,467.9,'EPSG','9001',6.04,1.96,-11.38,'EPSG','9104',-4.82,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DGU-Hrv',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3964','MGI 1901 to WGS 84 (4)','Parameter values from MGI 1901 to ETRS89 (2) (code 3963). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','3906','EPSG','4326','EPSG','3234',1.0,551.7,162.9,467.9,'EPSG','9001',6.04,1.96,-11.38,'EPSG','9104',-4.82,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Hrv',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3965','MGI 1901 to WGS 84 (6)','','Oil industry','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','3906','EPSG','4326','EPSG','3536',10.0,695.5,-216.6,491.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'JPet-Yug',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3971','PSAD56 to SIRGAS 1995 (1)','Derived at 42 points. May be taken as transformation PSAD56 to WGS 84 - see code 3990.','Suitable for mapping at 1:25,000 scale and smaller.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4248','EPSG','4170','EPSG','3241',5.0,-60.31,245.935,31.008,'EPSG','9001',-12.324,-3.755,7.37,'EPSG','9104',0.447,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Ecu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3972','Chua to WGS 84 (2)','Mandatory for SICAD use until 2005. Replaced by Chua to SIRGAS 2000 (tfm code 4069).','Used by governmental agencies in Distrito Federal until adoption of SIRGAS 2000 by Brazil in 2005. Legally mandated for Cartography System of Distrito Federal (SICAD) until 2005.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4224','EPSG','4326','EPSG','3619',5.0,-143.87,243.37,-33.52,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SICAD-Bra DF pre 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3990','PSAD56 to WGS 84 (14)','Parameter values from PSAD56 to SIRGAS 1995 (1) (code 3971). Assumes SIRGAS 1995 and WGS 84 can be considered the same to within the accuracy of the transformation.','Suitable for mapping at 1:25,000 scale and smaller.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4248','EPSG','4326','EPSG','3241',5.0,-60.31,245.935,31.008,'EPSG','9001',-12.324,-3.755,7.37,'EPSG','9104',0.447,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Ecu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','3998','Arc 1960 to WGS 84 (4)','Derived at 3 stations. From inspection of parameter values and geographic applicability of CRS, OGP believes that the published source CRS (Arc 1950) has been misidentified by information source. Analysis of TR8350.2 contour charts suggest Arc 1960.','For military purposes. Accuracy 20m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4210','EPSG','4326','EPSG','1058',35.0,-153.0,-5.0,-292.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Bdi',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4064','RGRDC 2005 to WGS 84 (1)','Approximation at the +/- 1m level assuming that RGRDC 2005 is equivalent to WGS 84 within the accuracy of the transformation.','Accuracy 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4046','EPSG','4326','EPSG','3613',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-DUC',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4065','Katanga 1955 to RGRDC 2005 (1)','Derived at 4 stations in Lubumbashi area. May be taken as approximate transformation Katanga 1955 to WGS 84 - see code 4066.','Accuracy 1.5m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4695','EPSG','4046','EPSG','3614',1.5,-103.746,-9.614,-255.95,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Rec-DUC',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4066','Katanga 1955 to WGS 84 (1)','Parameter values taken from Katanga 1955 to RGRDC 2005 (1) (code 4065) assuming that RGRDC 2005 is equivalent to WGS 84 within the accuracy of the transformation.','Accuracy 1.5m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4695','EPSG','4326','EPSG','3614',1.5,-103.746,-9.614,-255.95,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Rec-DUC',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4067','Katanga 1955 to RGRDC 2005 (2)','Derived at 5 stations across Lubumbashi-Likasi region. Used as transformation Katanga 1955 to WGS 84 - see code 4068.','Accuracy 0.5m.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4695','EPSG','4046','EPSG','3614',0.5,-102.283,-10.277,-257.396,'EPSG','9001',-3.976,-0.002,-6.203,'EPSG','9104',12.315,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,5580868.818,2826402.46,-1243557.996,'EPSG','9001','SDG-DUC',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4068','Katanga 1955 to WGS 84 (2)','Parameter values taken from Katanga 1955 to RGRDC 2005 (2) (code 4067) assuming that RGRDC 2005 is equivalent to WGS 84 within the accuracy of the transformation.','Accuracy 1m.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4695','EPSG','4326','EPSG','3614',1.0,-102.283,-10.277,-257.396,'EPSG','9001',-3.976,-0.002,-6.203,'EPSG','9104',12.315,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,5580868.818,2826402.46,-1243557.996,'EPSG','9001','SDG-DUC',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4069','Chua to SIRGAS 2000 (1)','Mandatory for SICAD use. Replaces Chua to WGS 84 (2) (code 3972). May be used as a tfm to WGS 84 - see tfm code 4834.','Used by governmental agencies in Distrito Federal after adoption of SIRGAS 2000 by Brazil in 2005. Legally mandated for Cartography System of Distrito Federal (SICAD).','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4224','EPSG','4674','EPSG','3619',5.0,-144.35,242.88,-33.2,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SICAD-Bra DF',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4070','Chua to WGS 84 (3)','Parameter values from Chua to SIRGAS 2000 (1) (tfm code 4069) assuming that within the tfm accuracy SIRGAS 2000 is equivalent to WGS 84.','Cartography System of Distrito Federal (SICAD)','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4224','EPSG','4674','EPSG','1053',5.0,-144.35,242.88,-33.2,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Bra DF post 2000',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','4076','SREF98 to ETRS89 (1)','May be taken as approximate transformation SREF98 to WGS 84 - see code 4077.','SREF98 is a natiional realization of ETRS89.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4075','EPSG','4258','EPSG','4543',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Srb',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4077','SREF98 to WGS 84 (1)','Approximation at the +/- 1m level assuming that ETRS89 is equivalent to WGS 84. SREF98 is a regional realisation of ETRS89.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4075','EPSG','4326','EPSG','4543',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Srb',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4078','ED87 to ETRS89 (1)','May be used as a transformation between ED87 and WGS 84 - see tfm code 3905.','Scientific research.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4231','EPSG','4258','EPSG','1297',0.3,-83.11,-97.38,-117.22,'EPSG','9001',0.0276,-0.2167,0.2147,'EPSG','9109',0.1218,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS-Eur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4084','REGCAN95 to WGS 84 (1)','Approximation at the +/- 1m level assuming that REGCAN95 is equivalent to WGS 84.','Accuracy +/- 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4081','EPSG','4326','EPSG','3199',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-esp',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4290','Cadastre 1997 to WGS 84 (1)','Parameter values taken from Cadastre 1997 to RGM04 (1) (transformation code 4478) assuming that RGM04 is coincident with WGS 84 within the accuracy of the transformation.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4475','EPSG','4326','EPSG','3340',1.0,-381.788,-57.501,-256.673,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Myt',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4461','NAD83(HARN) to NAD83(NSRS2007) (1)','Accuracy 0.1 to 0.2m in California, 0.05-0.11 in Oregon, elsewhere better than 0.05m.','For applications to an accuracy of 0.2 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4152','EPSG','4759','EPSG','1323',0.1,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-USA conus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4476','RGM04 to WGS 84 (1)','Approximation at the +/- 1m level assuming that RGM04 is equivalent to WGS 84.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4470','EPSG','4326','EPSG','1159',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Myt',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4477','RGSPM06 to WGS 84 (1)','Approximation at the +/- 1m level assuming that RGSPM06 is equivalent to WGS 84.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4463','EPSG','4326','EPSG','1220',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-SPM',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4478','Cadastre 1997 to RGM04 (1)','May be taken as approximate transformation Cadastre 1997 to WGS 84 - see transformation code 4290.','Accuracy +/- 0.1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4475','EPSG','4470','EPSG','3340',0.1,-381.788,-57.501,-256.673,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Certu-Myt',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4560','RRAF 1991 to WGS 84 (1)','Approximation at the +/- 1m level assuming that RRAF91 is equivalent to WGS 84 within the accuracy of the transformation.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4558','EPSG','4326','EPSG','2824',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-FrAnt',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4590','ITRF88 to ITRF2000 (1)','At epoch 1988.0. Rates dX=0.0000 m/yr, dy=0.0006 m/yr, dZ=0.0014 m/yr, rX=rY=0.0"/yr, rZ=-0.00002"/yr, dS=-0.00001 ppm/yr.','Geodesy.','EPSG','1033','Position Vector transformation (geocentric domain)','EPSG','4910','EPSG','4919','EPSG','1262',0.0,-0.0247,-0.0115,0.0979,'EPSG','9001',-0.0001,0.0,0.00018,'EPSG','9104',-0.00895,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','4591','ITRF89 to ITRF2000 (1)','At epoch 1988.0. Rates dX=0.0000 m/yr, dy=0.0006 m/yr, dZ=0.0014 m/yr, rX=rY=0.0"/yr, rZ=-0.00002"/yr, dS=-0.00001 ppm/yr.','Geodesy.','EPSG','1033','Position Vector transformation (geocentric domain)','EPSG','4911','EPSG','4919','EPSG','1262',0.0,-0.0297,-0.0475,0.0739,'EPSG','9001',0.0,0.0,0.00018,'EPSG','9104',-0.00585,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','4592','ITRF90 to ITRF2000 (1)','At epoch 1988.0. Rates dX=0.0000 m/yr, dy=0.0006 m/yr, dZ=0.0014 m/yr, rX=rY=0.0"/yr, rZ=-0.00002"/yr, dS=-0.00001 ppm/yr.','Geodesy.','EPSG','1033','Position Vector transformation (geocentric domain)','EPSG','4912','EPSG','4919','EPSG','1262',0.0,-0.0247,-0.0235,0.0359,'EPSG','9001',0.0,0.0,0.00018,'EPSG','9104',-0.00245,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','4593','ITRF91 to ITRF2000 (1)','At epoch 1988.0. Rates dX=0.0000 m/yr, dy=0.0006 m/yr, dZ=0.0014 m/yr, rX=rY=0.0"/yr, rZ=-0.00002"/yr, dS=-0.00001 ppm/yr.','Geodesy.','EPSG','1033','Position Vector transformation (geocentric domain)','EPSG','4913','EPSG','4919','EPSG','1262',0.0,-0.0267,-0.0275,0.0199,'EPSG','9001',0.0,0.0,0.00018,'EPSG','9104',-0.00215,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','4594','ITRF92 to ITRF2000 (1)','At epoch 1988.0. Rates dX=0.0000 m/yr, dy=0.0006 m/yr, dZ=0.0014 m/yr, rX=rY=0.0"/yr, rZ=-0.00002"/yr, dS=-0.00001 ppm/yr.','Geodesy.','EPSG','1033','Position Vector transformation (geocentric domain)','EPSG','4914','EPSG','4919','EPSG','1262',0.0,-0.0147,-0.0135,0.0139,'EPSG','9001',0.0,0.0,0.00018,'EPSG','9104',-0.00075,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','4595','ITRF93 to ITRF2000 (1)','At epoch 1988.0. Rates dX=0.0029 m/yr, dy=0.0002 m/yr, dZ=0.0006 m/yr, rX=0.00011"/yr, rY=0.00019"/yr, rZ=-0.00007"/yr, dS=-0.00001 ppm/yr.','Geodesy.','EPSG','1033','Position Vector transformation (geocentric domain)','EPSG','4915','EPSG','4919','EPSG','1262',0.0,-0.0127,-0.0065,0.0209,'EPSG','9001',0.00039,-0.0008,0.00114,'EPSG','9104',-0.00195,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','4596','ITRF94 to ITRF2000 (1)','At epoch 1997.0. Rates dX=0.0000 m/yr, dy=0.0006 m/yr, dZ=0.0014 m/yr, rX=rY=0.0"/yr, rZ=-0.00002"/yr, dS=-0.00001 ppm/yr.','Geodesy.','EPSG','1033','Position Vector transformation (geocentric domain)','EPSG','4916','EPSG','4919','EPSG','1262',0.0,-0.0067,-0.0061,0.0185,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',-0.00155,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','4597','ITRF96 to ITRF2000 (1)','At epoch 1997.0. Rates dX=0.0000 m/yr, dy=0.0006 m/yr, dZ=0.0014 m/yr, rX=rY=0.0"/yr, rZ=-0.00002"/yr, dS=-0.00001 ppm/yr.','Geodesy.','EPSG','1033','Position Vector transformation (geocentric domain)','EPSG','4917','EPSG','4919','EPSG','1262',0.0,-0.0067,-0.0061,0.0185,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',-0.00155,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','4598','ITRF97 to ITRF2000 (1)','At epoch 1997.0. Rates dX=0.0000 m/yr, dy=0.0006 m/yr, dZ=0.0014 m/yr, rX=rY=0.0"/yr, rZ=-0.00002"/yr, dS=-0.00001 ppm/yr.','Geodesy.','EPSG','1033','Position Vector transformation (geocentric domain)','EPSG','4918','EPSG','4919','EPSG','1262',0.0,-0.0067,-0.0061,0.0185,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',-0.00155,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','4599','ITRF2000 to ITRF2005 (1)','At epoch 2000.0. Rates dX=0.0002 m/yr, dy=-0.0001 m/yr, dZ=0.0018 m/yr, rX=rY=rZ=0.0"/yr, dS=-0.00008 ppm/yr.','Geodesy.','EPSG','1033','Position Vector transformation (geocentric domain)','EPSG','4919','EPSG','4896','EPSG','1262',0.0,-0.0001,0.0008,0.0058,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',-0.0004,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','4827','S-JTSK to ETRS89 (4)','Derived at approximately 700 points. Scale difference incorporated into rotation matrix. Replaces S-JTSK to ETRS89 (3) (code 4829) to use more common method. May be taken as approximate transformation S-JTSK to WGS 84 - see code 4836.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4156','EPSG','4258','EPSG','1211',1.0,485.0,169.5,483.8,'EPSG','9001',7.786,4.398,4.103,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UGKK-Svk',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4828','S-JTSK to WGS 84 (4)','Parameter values from S-JTSK to ETRS89 (4) (code 4827). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4156','EPSG','4326','EPSG','1211',1.0,485.0,169.5,483.5,'EPSG','9001',7.786,4.398,4.103,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Svk',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','4829','S-JTSK to ETRS89 (3)','Replaced by S-JTSK to ETRS89 (4) (code 4827) to use more commonly encountered  transformation method.','For applications to an accuracy of 0.5 metre.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4156','EPSG','4258','EPSG','1211',0.5,558.7,68.8,452.2,'EPSG','9001',-8.025,-4.105,-4.295,'EPSG','9104',5.74,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,3977358.114,1407223.203,4765441.589,'EPSG','9001','UGKK-Svk',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4830','Amersfoort to ETRS89 (5)','Replaces Amersfoort to ETRS89 (3) (tfm code 15739). Dutch sources also quote an equivalent transformation using the Molodenski-Badekas method - see tfm code 4831.','Accuracy 0.5m','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4289','EPSG','4258','EPSG','1275',0.5,565.4171,50.3319,465.5524,'EPSG','9001',1.9342,-1.6677,9.1019,'EPSG','9109',4.0725,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NCG-Nld 2008',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4831','Amersfoort to ETRS89 (6)','Replaces Amersfoort to ETRS89 (4) (tfm code 15740). Dutch sources also quote an equivalent transformation using the Coordinate Frame 7-parameter method - see tfm code 4830.','Accuracy 0.5m','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4289','EPSG','4258','EPSG','1275',0.5,593.0248,25.9984,478.7459,'EPSG','9001',1.9342,-1.6677,9.1019,'EPSG','9109',4.0725,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,3903453.1482,368135.3134,5012970.3051,'EPSG','9001','NCG-Nld 2008',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4832','Mexico ITRF92 to WGS 84 (1)','','Accuracy 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4483','EPSG','4326','EPSG','1160',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Mex',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4833','Amersfoort to WGS 84 (4)','Parameter values from Amersfoort to ETRS89 (5) (tfm code 4830) assuming that ETRS89 is equivalent to WGS 84 within the accuracy of the transformation. Replaces Amersfoort to WGS 84 (3) (code 15934).','Approximation at the +/- 1m level.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4289','EPSG','4326','EPSG','1275',1.0,565.4171,50.3319,465.5524,'EPSG','9001',1.9342,-1.6677,9.1019,'EPSG','9109',4.0725,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Nld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4834','Chua to WGS 84 (3)','Parameter values from Chua to SIRGAS 2000 (1) (tfm code 4069) assuming that within the tfm accuracy SIRGAS 2000 is equivalent to WGS 84.','Cartography System of Distrito Federal (SICAD)','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4224','EPSG','4326','EPSG','3619',5.0,-144.35,242.88,-33.2,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Bra DF post 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4835','Tahiti 79 to WGS 84 (1)','Approximation at the +/- 1m level assuming that RGPF is equivalent to WGS 84. Parameter values taken from Tahiti 79 to RGPF (1) (tfm code 15756).','Accuracy +/- 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4690','EPSG','4326','EPSG','3124',1.0,221.525,152.948,176.768,'EPSG','9001',2.3847,1.3896,0.877,'EPSG','9104',11.4741,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Pyf',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','4836','S-JTSK to WGS 84 (4)','Parameter values from S-JTSK to ETRS89 (4) (code 4827). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4156','EPSG','4326','EPSG','1211',1.0,485.0,169.5,483.8,'EPSG','9001',7.786,4.398,4.103,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Svk',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4840','RGFG95 to WGS 84 (2)','Replaces RGFG95 to WGS 84 (1) (code 1907) which was not put into official use but issued in error.','Accuracy +/- 2 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4624','EPSG','4326','EPSG','1097',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Guf 2',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','4905','PTRA08 to WGS 84 (1)','','PTRA08 and WGS 84 are realizations of ITRS coincident to within 1 metre. This transformation has an accuracy equal to the coincidence figure.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5013','EPSG','4326','EPSG','3670',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-pt RA',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5021','Porto Santo 1995 to PTRA08 (1)','Derived at 34 points in May 2009. Residuals at 25 test points within 0.5m horizontal and 2m vertical. Info source also provides a Position Vector tfm of similar accuracy. See codes 5022 and 5023 for preferred tfms for islands of Porto Santo and Maderia.','2-metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4663','EPSG','5013','EPSG','1314',2.0,-503.229,-247.375,312.582,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGP-Prt MadArch',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5022','Porto Santo 1995 to PTRA08 (2)','Derived at 22 points in May 2009. Residuals at 17 test points within 0.1m horizontal and 1m vertical. Info source also provides a less accurate 3-parameter transformation (dX=-503.174m, dY=-247.255m, dZ=312.316m).','1 metre accuracy.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4663','EPSG','5013','EPSG','3679',1.0,-303.956,224.556,214.306,'EPSG','9001',9.405,-6.626,-12.583,'EPSG','9104',1.327,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGP-Prt Mad',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5023','Porto Santo 1995 to PTRA08 (3)','Derived at 14 points in May 2009. Residuals at 6 test points within 0.1m horizontal and 0.2m vertical. Info source also provides a 7-parameter Position Vector transformation of similar accuracy.','For applications requiring sub-metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4663','EPSG','5013','EPSG','3680',0.2,-503.3,-247.574,313.025,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGP-Prt Porto Santo',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5024','Azores Oriental 1995 to PTRA08 (1)','Derived at 53 points in May 2009. Residuals at 58 test points within 0.2m horizontal and 2m vertical. Info source also provides a Position Vector tfm of similar accuracy. See codes 5025-26 for preferred tfms for islands of Sao Miguel and Santa Maria.','2-metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4664','EPSG','5013','EPSG','1345',2.0,-204.926,140.353,55.063,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGP-Prt Az E',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5025','Azores Oriental 1995 to PTRA08 (2)','Derived at 36 points in May 2009. Residuals at 43 test points within 0.2m horizontal and 0.3m vertical. Info source also provides a 7-parameter Position Vector transformation of similar accuracy.','0.3-metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4664','EPSG','5013','EPSG','2871',0.3,-204.519,140.159,55.404,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGP-Prt Az Mig',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5026','Azores Oriental 1995 to PTRA08 (3)','Derived at 18 points in May 2009. Residuals at 14 test points within 0.1m. Info source also provides a 7-parameter Position Vector transformation of similar accuracy.','0.1-metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4664','EPSG','5013','EPSG','3683',0.1,-205.808,140.771,54.326,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGP-Prt Az S.Maria',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5027','Azores Central 1995 to PTRA08 (1)','Derived at 112 points in May 2009. Residuals at 184 test points within 0.5m horizontal and 1m vertical. Info source also provides a Position Vector tfm of similar accuracy. See codes 5028-32 for preferred tfms for individual islands.','2-metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4665','EPSG','5013','EPSG','1301',2.0,-105.679,166.1,-37.322,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGP-Prt Az C',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5028','Azores Central 1995 to PTRA08 (2)','Derived at 24 points in May 2009. Residuals at 37 test points within 0.1m horizontal and 0.3m vertical. Info source also provides a Position Vector tfm of similar accuracy.','0.5-metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4665','EPSG','5013','EPSG','2873',0.5,-105.377,165.769,-36.965,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGP-Prt Az Faial',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5029','Azores Central 1995 to PTRA08 (3)','Derived at 11 points in May 2009. Residuals at 15 test points within 0.1m horizontal and 0.2m vertical. Info source also provides a Position Vector tfm of similar accuracy.','0.2-metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4665','EPSG','5013','EPSG','3681',0.2,-105.359,165.804,-37.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGP-Prt Az Graciosa',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5030','Azores Central 1995 to PTRA08 (4)','Derived at 34 points in May 2009. Residuals at 38 test points within 0.2m horizontal and 1m vertical. Info source also provides a Position Vector tfm of similar accuracy.','1-metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4665','EPSG','5013','EPSG','2874',1.0,-105.531,166.39,-37.326,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGP-Prt Az Pico',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5031','Azores Central 1995 to PTRA08 (5)','Derived at 17 points in May 2009. Residuals at 60 test points within 0.1m horizontal and 0.8m vertical. Info source also provides a Position Vector tfm of similar accuracy.','0.8-metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4665','EPSG','5013','EPSG','2875',0.8,-105.756,165.972,-37.313,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGP-Prt Az S.Jorge',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5032','Azores Central 1995 to PTRA08 (6)','Derived at 26 points in May 2009. Residuals at 34 test points within 0.1m horizontal and 0.6m vertical. Info source also provides a Position Vector tfm of similar accuracy.','0.6-metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4665','EPSG','5013','EPSG','2872',0.6,-106.235,166.236,-37.768,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGP-Prt Az Terceira',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5033','Azores Occidental 1939 to PTRA08 (1)','Derived at 21 points in May 2009. Residuals at 18 test points within 0.1m horizontal and 0.2m vertical. Info source also provides a Position Vector tfm of similar accuracy. See codes 5034-35 for preferred tfms for islands of Flores and Corvo.','0.5-metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4182','EPSG','5013','EPSG','1344',0.5,-423.058,-172.868,83.772,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGP-Prt Az W',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5034','Azores Occidental 1939 to PTRA08 (2)','Derived at 18 points in May 2009. Residuals at 15 test points within 0.1m horizontal and 0.2m vertical. Info source also provides a Position Vector tfm of similar accuracy.','0.2-metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4182','EPSG','5013','EPSG','3684',0.2,-423.053,-172.871,83.771,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGP-Prt Az Flores',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5035','Azores Occidental 1939 to PTRA08 (3)','Derived at 3 points in May 2009. Residuals at these points within 0.1m horizontal and 0.3m vertical. Info source also provides a Position Vector tfm of similar accuracy.','0.3-metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4182','EPSG','5013','EPSG','3685',0.3,-423.024,-172.923,83.83,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGP-Prt Az Corvo',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5036','Datum 73 to ETRS89 (4)','Derived in July 2009 from 119 common stations. Residuals at 833 test points under 3m.','3-metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4274','EPSG','4258','EPSG','1294',3.0,-223.15,110.132,36.711,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt 2009 3m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5037','Datum 73 to ETRS89 (5)','Derived in July 2009 from 119 common stations. Residuals at 833 test points under 2m. Replaces Datum 73 to ETRS89 (3) (tfm code 1992).','2-metre accuracy.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4274','EPSG','4258','EPSG','1294',2.0,-230.994,102.591,25.199,'EPSG','9001',0.633,-0.239,0.9,'EPSG','9104',1.95,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt 2009 2m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5038','Lisbon to ETRS89 (3)','Derived in July 2009 from 119 common stations. Info source also gives a Position Vector tfm which is of similar accuracy. Replaces Lisbon to ETRS89 (2) (tfm code 1997).','Average residual at 833 test points 2.5m, maximum 7m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4207','EPSG','4258','EPSG','1294',2.5,-303.861,-60.693,103.607,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt 2009 7m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5039','Lisbon 1890 to ETRS89 (1)','Parameter values taken from Lisbon 1890 to WGS 84 (1) (tfm code 1986) assuming that ETRS89 is equivalent to WGS 84 within the accuracy of the transformation.','For low resolution applications.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4666','EPSG','4258','EPSG','1294',5.0,508.088,-191.042,565.223,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5040','ED50 to ETRS89 (13)','Parameter values taken from ED50 to WGS 84 (33) (tfm code 1985) assuming that ETRS89 and WGS 84 are the same within the accuracy of the transformation.','For low resolution applications.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4258','EPSG','1294',5.0,-87.987,-108.639,-121.593,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGC-Prt 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5043','Pulkovo 1995 to WGS 84 (2)','Derived through concatenation of Pulkovo 1995 to PZ-90.02 to WGS 84. Replaces Pulkovo 1995 to WGS 84 (1), tfm code 1281.','Accuracy 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4200','EPSG','4326','EPSG','1198',1.0,24.47,-130.89,-81.56,'EPSG','9001',0.0,0.0,-0.13,'EPSG','9104',-0.22,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GOST-Rus 2008',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5044','Pulkovo 1942 to WGS 84 (20)','Derived through concatenation of Pulkovo 1942 to PZ-90.02 to WGS 84. Replaces Pulkovo 1942 to WGS 84 (17) (code 1267).','Accuracy 3 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4284','EPSG','4326','EPSG','3296',3.0,23.57,-140.95,-79.8,'EPSG','9001',0.0,-0.35,-0.79,'EPSG','9104',-0.22,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GOST-Rus 2008',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5050','Aratu to SIRGAS 2000 (1)','Derived in 2002. Petrobras preferred transformation for all purposes in the area. May be used as transformation between Aratu and WGS 84 - see tfm code 5051.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4674','EPSG','3700',0.5,-157.84,308.54,-146.6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra BS 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5051','Aratu to WGS 84 (13)','Parameters from Aratu to SIRGAS 2000 (1) (tfm code 5050) assuming that SIRGAS 2000 and WGS 84 are equal within the accuracy of the transformation. Petrobras preferred parameters for all purposes in the area. Replaces tfm codes 15711 and 15734.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','3700',1.0,-157.84,308.54,-146.6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra BS 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5052','Aratu to SIRGAS 2000 (2)','Derived in 2002. Petrobras preferred transformation for all purposes in the area. May be used as transformation between Aratu and WGS 84 - see tfm code 5053.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4674','EPSG','2963',0.5,-160.31,314.82,-142.25,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra BC 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5053','Aratu to WGS 84 (14)','Parameters from Aratu to SIRGAS 2000 (2) (tfm code 5052) assuming that SIRGAS 2000 and WGS 84 are equal within the accuracy of the transformation. Petrobras preferred parameters for all purposes in the area. Replaces tfm codes 15710 and 15754.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','2963',1.0,-160.31,314.82,-142.25,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra BC 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5054','Aratu to SIRGAS 2000 (3)','Derived in 2002. Petrobras preferred transformation for all purposes in the area. May be used as transformation between Aratu and WGS 84 - see tfm code 5055.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4674','EPSG','2964',0.5,-161.11,310.25,-144.64,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra ES 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5055','Aratu to WGS 84 (15)','Parameters from Aratu to SIRGAS 2000 (3) (tfm code 5054) assuming that SIRGAS 2000 and WGS 84 are equal within the accuracy of the transformation. Petrobras preferred parameters for all purposes in the area. Replaces tfms 15712 and 15754.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','2964',1.0,-161.11,310.25,-144.64,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra ES 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5056','Aratu to SIRGAS 2000 (4)','Derived in 2002. Petrobras preferred transformation for all purposes in the area. May be used as transformation between Aratu and WGS 84 - see tfm code 5057.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4674','EPSG','3699',0.5,-160.4,302.29,-144.19,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra BSUL 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5057','Aratu to WGS 84 (16)','Parameters from Aratu to SIRGAS 2000 (4) (tfm code 5056) assuming that SIRGAS 2000 and WGS 84 are equal within the accuracy of the transformation. Petrobras preferred parameters for all purposes in the area.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','3699',1.0,-160.4,302.29,-144.19,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra BSUL 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5058','Aratu to SIRGAS 2000 (5)','Derived in 2002. Petrobras preferred transformation for all purposes in the area. May be used as transformation between Aratu and WGS 84 - see tfm code 5059.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4674','EPSG','3692',0.5,-153.54,302.33,-152.37,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra BREC 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5059','Aratu to WGS 84 (17)','Parameters from Aratu to SIRGAS 2000 (5) (tfm code 5058) assuming that SIRGAS 2000 and WGS 84 are equal within the accuracy of the transformation. Petrobras preferred parameters for all purposes in the area.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','3692',1.0,-153.54,302.33,-152.37,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra BREC 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5060','Aratu to SIRGAS 2000 (6)','Derived in 2002. Petrobras preferred transformation for all purposes in the area. May be used as transformation between Aratu and WGS 84 - see tfm code 5061.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4674','EPSG','3693',0.5,-151.5,300.09,-151.15,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra BTUC 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5061','Aratu to WGS 84 (18)','Parameters from Aratu to SIRGAS 2000 (6) (tfm code 5060) assuming that SIRGAS 2000 and WGS 84 are equal within the accuracy of the transformation. Petrobras preferred parameters for all purposes in the area. Replaces tfms 1550-1552.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','3693',1.0,-151.5,300.09,-151.15,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra BTUC 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5062','Aratu to SIRGAS 2000 (7)','Derived in 2002. Petrobras preferred transformation for all purposes in the area. May be used as transformation between Aratu and WGS 84 - see tfm code 5063.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4674','EPSG','3696',0.5,-156.8,298.41,-147.41,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra SEAL 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5063','Aratu to WGS 84 (19)','Parameters from Aratu to SIRGAS 2000 (7) (tfm code 5062) assuming that SIRGAS 2000 and WGS 84 are equal within the accuracy of the transformation. Petrobras preferred parameters for all purposes in the area.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','3696',1.0,-156.8,298.41,-147.41,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra SEAL 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5064','Aratu to SIRGAS 2000 (8)','Derived in 2002. Petrobras preferred transformation for all purposes in the area. May be used as transformation between Aratu and WGS 84 - see tfm code 5065.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4674','EPSG','3697',0.5,-157.4,295.05,-150.19,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra PEPB 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5065','Aratu to WGS 84 (20)','Parameters from Aratu to SIRGAS 2000 (8) (tfm code 5064) assuming that SIRGAS 2000 and WGS 84 are equal within the accuracy of the transformation.Petrobras preferred parameters for all purposes in the area.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','3697',1.0,-157.4,295.05,-150.19,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra PEPB 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5066','Aratu to SIRGAS 2000 (9)','Derived in 2002. Petrobras preferred transformation for all purposes in the area. May be used as transformation between Aratu and WGS 84 - see tfm code 5067.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4674','EPSG','3698',0.5,-151.99,287.04,-147.45,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra RNCE 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5067','Aratu to WGS 84 (21)','Parameters from Aratu to SIRGAS 2000 (9) (tfm code 5066) assuming that SIRGAS 2000 and WGS 84 are equal within the accuracy of the transformation. Petrobras preferred parameters for all purposes in the area.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','3698',1.0,-151.99,287.04,-147.45,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra RNCE 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5077','Karbala 1979 to IGRS (1)','Derived at 95 stations mostly south of Baghdad but including 3 in Kirkuk-Erbil area. Maximum residuals 0.3m. May be used as a tfm to WGS 84 - see tfm code 5078.','Accuracy 0.3m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4743','EPSG','3889','EPSG','3625',0.3,70.995,-335.916,262.898,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'MWR-Irq 2009',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5078','Karbala 1979 to WGS 84 (2)','Parameter values from Karbala 1979 to IGRS (1) (tfm code 5077) assuming that IGRS is equivalent to WGS 84 within the accuracy of the transformation. Replaces Karbala 1979 to WGS 84 (1) (tfm code 15872).','Accuracy 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4743','EPSG','4326','EPSG','3625',1.0,70.995,-335.916,262.898,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Irq 2009',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5189','Korean 1985 to Korea 2000 (1)','May be taken as approximate transformation Korean 1985 to WGS 84 - see code 5191.','For accuracies commensurate with mapping at 1/5000 scale.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4162','EPSG','4737','EPSG','3266',1.0,-145.907,505.034,685.756,'EPSG','9001',-1.162,2.347,1.592,'EPSG','9104',6.342,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,-3159521.31,4068151.32,3748113.85,'EPSG','9001','NGII-Kor',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5191','Korean 1985 to WGS 84 (1)','Parameter values from Korean 1985 to Korea 2000 (1) (code 5189). Assumes Korea 2000 and WGS 84 can be considered the same to within the accuracy of the transformation.','Accuracy 1m','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4162','EPSG','4326','EPSG','3266',1.0,-145.907,505.034,685.756,'EPSG','9001',-1.162,2.347,1.592,'EPSG','9104',6.342,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,-3159521.31,4068151.32,3748113.85,'EPSG','9001','OGP-Kor',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5194','VN-2000 to WGS 84 (1)','Used by Total in Mekong delta.','Academic research not officially adopted.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4756','EPSG','4326','EPSG','3770',1.0,-192.873,-39.382,-111.202,'EPSG','9001',0.00205,0.0005,-0.00335,'EPSG','9104',0.0188,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'HCMCTU-Vnm',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5226','S-JTSK/05 to ETRS89 (1)','Derived through the relationship between the R05 realisation of ETRS89 and the astrogeodetic S-JTSK network. Replaces tfm code 1622. May be taken as approximate transformation S-JTSK to WGS 84 - see code 5227.','Defined as exact for S-JTSK/05 (Ferro) / Modified Krovak projCRSs (CRS codes 5224-25).','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','5228','EPSG','4258','EPSG','1079',0.0,572.213,85.334,461.94,'EPSG','9001',-4.9732,-1.529,-5.2484,'EPSG','9104',3.5378,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CUZK-Cze 05',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5227','S-JTSK/05 to WGS 84 (1)','Parameter values from S-JTSK/05 to ETRS89 (1) (code 5226). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation. Replaces tfm code 1622.','For applications to an accuracy of 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','5228','EPSG','4326','EPSG','1079',1.0,572.213,85.334,461.94,'EPSG','9001',-4.9732,-1.529,-5.2484,'EPSG','9104',3.5378,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Cze 05',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5236','SLD99 to WGS 84 (1)','Derived at 58 stations.','Accuracy 14m.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','5233','EPSG','4326','EPSG','3310',14.0,-0.293,766.95,87.713,'EPSG','9001',-0.195704,-1.695068,-3.473016,'EPSG','9104',-0.039338,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GSU-Lka',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5239','S-JTSK to WGS 84 (5)','Parameter values from S-JTSK/05 to WGS 84 (1) (code 5227). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation. Replaces tfm code 1622.','For applications to an accuracy of 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4156','EPSG','4326','EPSG','1079',1.0,572.213,85.334,461.94,'EPSG','9001',-4.9732,-1.529,-5.2484,'EPSG','9104',3.5378,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Cze 05',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5248','Timbalai 1948 to GDBD2009 (1)','','Oil exploration.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4298','EPSG','4326','EPSG','1055',1.0,-689.5937,623.84046,-65.93566,'EPSG','9001',0.02331,-1.17094,0.80054,'EPSG','9104',5.88536,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SD-Brn',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','5249','Timbalai 1948 to WGS 84 (5)','Parameter values taken from Timbalai 1948 to GDBD2009 (1) (code 5878) assuming that GDBD2009 is equivalent to WGS 84 within the accuracy of the transformation.','Oil exploration.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4298','EPSG','4326','EPSG','1055',1.0,-689.5937,623.84046,-65.93566,'EPSG','9001',0.02331,-1.17094,0.80054,'EPSG','9104',5.88536,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Brn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5260','TUREF to ETRS89 (1)','Note: the ETRS89 CRS is not used in Turkey.','Accuracy better than 1dm.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','5252','EPSG','4258','EPSG','1237',0.1,0.023,0.036,-0.068,'EPSG','9001',0.00176,0.00912,-0.01136,'EPSG','9104',0.00439,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GCM-Tur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5261','TUREF to WGS 84 (1)','','Approximation at the +/- 1m level as both TUREF and WGS 84 are realizations of ITRS.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5252','EPSG','4326','EPSG','1237',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Tur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5267','DRUKREF 03 to WGS 84 (1)','DRUKREF 03 and WGS 84 are both realisations of ITRS.','For applications to an accuracy of 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5264','EPSG','4326','EPSG','1048',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Btn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5327','ISN2004 to WGS 84 (1)','For many purposes ISN2004 can be considered to be coincident with WGS 84.','Approximation at the +/- 1m level assuming that ISN2004 is equivalent to WGS 84.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5324','EPSG','4326','EPSG','1120',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Isl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5333','ITRF2005 to ITRF2008 (1)','At epoch 2005.0. Rates dX=-0.0003 m/yr, dy=dz=0.000 m/yr, rX=rY=rZ=0.0"/yr, dS=0.0000 ppm/yr.','Geodesy.','EPSG','1033','Position Vector transformation (geocentric domain)','EPSG','4896','EPSG','5332','EPSG','1262',0.0,0.0005,0.0009,0.0047,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',-0.00094,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','5350','Campo Inchauspe to POSGAR 2007 (1)','Adopted from U.S. Defense Mapping Agency values for Campo Inchauspe to WGS 84 (tfm code 1127) assuming that POSGAR 2007 is equivalent to WGS 84.','Accuracy 5m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4221','EPSG','5340','EPSG','3215',5.0,-148.0,136.0,90.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Arg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5351','POSGAR 2007 to WGS 84 (1)','','Approximation at the sub meter level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5340','EPSG','4326','EPSG','1033',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Arg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5374','MARGEN to WGS 84 (1)','','Accuracy 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5354','EPSG','4326','EPSG','1049',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Bol',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5375','SIRGAS-Chile to WGS 84 (1)','','Accuracy 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','9184','EPSG','4326','EPSG','1066',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Chl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5376','CR05 to WGS 84 (1)','','Accuracy 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5365','EPSG','4326','EPSG','1074',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Cri',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5377','MACARIO SOLIS to WGS 84 (1)','','Accuracy 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5371','EPSG','4326','EPSG','1186',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Pan',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5378','Peru96 to WGS 84 (1)','','Accuracy 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5373','EPSG','4326','EPSG','1189',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Per',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5384','SIRGAS-ROU98 to WGS 84 (1)','','Accuracy 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5381','EPSG','4326','EPSG','1247',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Ury',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5385','Yacare to SIRGAS-ROU98 (1)','Derived at 11 stations during 1998 densification of Uruguay control based on SIRGAS 1995.','Accuracy at stations used for derivation: 0.13 to 1.17m.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4309','EPSG','5381','EPSG','3326',1.5,-124.45,183.74,44.64,'EPSG','9001',-0.4384,0.5446,-0.9706,'EPSG','9104',-2.1365,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SGM-Ury',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5386','Yacare to WGS 84 (2)','Derived at 11 stations during 1998 densification of Uruguay control based on SIRGAS 1995.','Accuracy at stations used for derivation: 0.13 to 1.17m.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4309','EPSG','4326','EPSG','3326',1.5,-124.45,183.74,44.64,'EPSG','9001',-0.4384,0.5446,-0.9706,'EPSG','9104',-2.1365,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SGM-Ury',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5395','SIRGAS_ES2007.8 to WGS 84 (1)','','Accuracy 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5393','EPSG','4326','EPSG','1087',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Slv',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5470','Ocotepeque 1935 to WGS 84 (1)','Parameter values taken from Ocotepeque to CR05 (1) (tfm code 6890) assuming that CR05 is equivalent to WGS 84 within the accuracy of the transformation.','Topographic mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5451','EPSG','4326','EPSG','3232',8.0,213.11,9.37,-74.95,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Cri',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5473','Ocotepeque 1935 to WGS 84 (2)','Rotations in original source given in radians are equivalent to Rx = 2.35", Ry = -0.06", Rz = 6.39".','Topographic mapping.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','5451','EPSG','4326','EPSG','3232',5.0,213.116,9.358,-74.946,'EPSG','9001',1.14e-05,-2.98e-07,3.1e-05,'EPSG','9101',-5.22,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UNA-Cri',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','5474','Ocotepeque 1935 to NAD27 (1)','','Topographic mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5451','EPSG','4326','EPSG','3876',9.0,205.435,-29.099,292.202,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Cri',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','5483','Luxembourg 1930 to ETRS89 (4)','Replaces transformation code 1078, this being derived through more observations. May be taken as approximate transformation Luxembourg 1930 to WGS 84 - see code 5484. For an equivalent transformation using the Coordinate Frame method see code 5485.','For applications to an accuracy of 0.1 metre.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4181','EPSG','4258','EPSG','1146',0.1,-265.8867,76.9851,20.2667,'EPSG','9001',0.33746,3.09264,-2.53861,'EPSG','9104',0.4598,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,4103620.3943,440486.4235,4846923.4558,'EPSG','9001','ACT-Lux MB 2011',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5484','Luxembourg 1930 to WGS 84 (4)','Parameter values from Luxembourg 1930 to ETRS89 (4) (code 5483) assuming ETRS89 and WGS 84 are coincident within the one metre level. Replaces tfm code 1079. For an equivalent transformation using the Coordinate Frame method see code 5486.','For applications to an accuracy of 1 metre.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4181','EPSG','4326','EPSG','1146',1.0,-265.8867,76.9851,20.2667,'EPSG','9001',0.33746,3.09264,-2.53861,'EPSG','9104',0.4598,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,4103620.3943,440486.4235,4846923.4558,'EPSG','9001','OGP-Lux MB 2011',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5485','Luxembourg 1930 to ETRS89 (3)','Replaces transformation code 1642, this being derived through more observations. May be taken as approximate transformation Luxembourg 1930 to WGS 84 - see code 5486. For an equivalent transformation using the Molodensky-Badekas method see code 5483.','For applications to an accuracy of 0.1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4181','EPSG','4258','EPSG','1146',0.1,-189.6806,18.3463,-42.7695,'EPSG','9001',0.33746,3.09264,-2.53861,'EPSG','9104',0.4598,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ACT-Lux CF 2011',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5486','Luxembourg 1930 to WGS 84 (3)','Parameter values from Luxembourg 1930 to ETRS89 (3) (code 5485) assuming ETRS89 and WGS 84 are coincident within the one metre level. Replaces tfm code 1643. For an equivalent transformation using the Molodensky-Badekas method see code 5484.','For applications to an accuracy of 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4181','EPSG','4326','EPSG','1146',1.0,-189.6806,18.3463,-42.7695,'EPSG','9001',0.33746,3.09264,-2.53861,'EPSG','9104',0.4598,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Lux CF 2011',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5491','Martinique 1938 to RGAF09 (1)','','Accuracy +/- 0.1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4625','EPSG','5489','EPSG','3276',0.1,127.744,547.069,118.359,'EPSG','9001',-3.1116,4.9509,-0.8837,'EPSG','9104',14.1012,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Mtq',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5492','Guadeloupe 1948 to RGAF09 (1)','','Accuracy +/- 10 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4622','EPSG','5489','EPSG','2829',10.0,-471.06,-3.212,-305.843,'EPSG','9001',0.4752,-0.9978,0.2068,'EPSG','9104',2.1353,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Glp',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5493','Fort Marigot to RGAF09 (1)','','Accuracy +/- 10 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4621','EPSG','5489','EPSG','2828',10.0,151.613,253.832,-429.084,'EPSG','9001',-0.0506,0.0958,-0.5974,'EPSG','9104',-0.3971,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Glp',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5494','RRAF 1991 to RGAF09 (1)','','Accuracy +/- 0.1 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4558','EPSG','5489','EPSG','1156',0.1,0.7696,-0.8692,-12.0631,'EPSG','9001',-0.32511,-0.21041,-0.0239,'EPSG','9104',0.2829,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Glp',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5495','RRAF 1991 to RGAF09 (2)','','Accuracy +/- 0.1 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4558','EPSG','5489','EPSG','2829',0.1,1.2239,2.4156,-1.7598,'EPSG','9001',0.038,-0.16101,-0.04925,'EPSG','9104',0.2387,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Glp GT',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5496','RRAF 1991 to RGAF09 (3)','','Accuracy +/- 0.1 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4558','EPSG','5489','EPSG','2828',0.1,14.6642,5.2493,0.1981,'EPSG','9001',-0.06838,0.09141,-0.58131,'EPSG','9104',-0.4067,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Glp SM',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5497','POSGAR 2007 to SIRGAS 2000 (1)','','Agreement at the decimeter level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5340','EPSG','4674','EPSG','1033',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Arg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5501','RGAF09 to WGS 84 (1)','Approximation at the +/- 1m level assuming that RGAF09 is equivalent to WGS 84 within the accuracy of the transformation.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5489','EPSG','4326','EPSG','2824',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-FrAnt',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5521','Grand Comoros to WGS 84 (1)','','For military purposes. Accuracy unknown.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4646','EPSG','4326','EPSG','2807',999.0,-963.0,510.0,-359.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SHOM-Com',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5553','PNG94 to WGS 84 (1)','Exact in 1994 but due to significant and variable tectonic activity in PNG, in 2011 PNG94 and WGS 84 differ generally by 2m but in areas of significant tectonic activity differences can exceed 9m.','Approximation at the 2-10m level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5546','EPSG','4326','EPSG','1187',2.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-PNG',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5584','MOLDREF99 to ETRS89 (1)','MOLDREF is a densification of ETRS89 in Moldova.','For applications with an accuracy of 0.1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4023','EPSG','4258','EPSG','1162',0.1,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Mda',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5585','MOLDREF99 to WGS 84 (1)','Parameter values from MOLDREF99 to ETRS89 (1) (code 5584). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications with an accuracy of 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4023','EPSG','4326','EPSG','1162',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Mda',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5586','Pulkovo 1942 to UCS-2000 (1)','UCS-2000 is defined to be approximately consistent with Pulkovo 1942 and this transformation''s accuracy is due to deformation of the Pulkovo system across Ukranian territory.','For applications to an accuracy of 3.5m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4284','EPSG','5561','EPSG','1242',3.5,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Ukr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5590','UCS-2000 to WGS 84 (1)','Derived through concatenation of UCS-2000 to S-42 (1) (tfm code 5586 reversed) [an approximation] and S-42 to WGS 84 (16) (tfm code 15865) [derived for whole FSU rather than Ukraine]. Replaced by UCS-2000 to WGS 84 (2) (tfm code 5840).','Accuracy 5 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','5561','EPSG','4326','EPSG','1242',5.0,25.0,-141.0,-78.5,'EPSG','9001',0.0,-0.35,-0.736,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Ukr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5599','FEH2010 to WGS 84 (1)','','Approximation at the 1m level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5593','EPSG','4326','EPSG','3889',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Dnk-Deu Feh',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5622','OSGB 1936 to WGS 84 (8)','Derived by CGG for 1994 3D seismic survey.','Oil exploration and production.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4277','EPSG','4326','EPSG','3893',3.0,370.936,-108.938,435.682,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'bp-Gbr WytchF',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5630','Nord Sahara 1959 to WGS 84 (8)','Derived at 1 station (L38).','Used by Total in Ahnet licence area.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4307','EPSG','4326','EPSG','3917',5.0,-168.52,-72.05,304.3,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Tot-Dza Ahnet',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5660','Nord Sahara 1959 to WGS 84 (9)','Derived in 2006 at 45 points in north and central Algeria.','Accuracy at 75 common points better than 1m..','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4307','EPSG','4326','EPSG','1026',1.0,-209.3622,-87.8162,404.6198,'EPSG','9001',0.0046,3.4784,0.5805,'EPSG','9104',-1.4547,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'INCT-Dza',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5662','AGD66 to PNG94 (1)','Derived at 25 stations in 2007. Replaced by AGD66 to PNG94 (4) (code 6939).','Accuracy 2m in 2007.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4202','EPSG','5546','EPSG','4013',2.0,-124.0,-60.0,153.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Qcl-Png PFTB 2007',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5822','UCS-2000 to ITRF2005 (1)','May be taken as approximate transformation UCS-2000 to WGS 84 - see code 5840.','For applications to an accuracy of 1 metre.','EPSG','1031','Geocentric translations (geocentric domain)','EPSG','5558','EPSG','4896','EPSG','1242',1.0,24.0,-121.0,-76.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SSGC-Ukr',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','5823','Ukraine 2000 to WGS 84 (1)','Parameter values taken from Ukraine 2000 to ITRF2005 (1) (code 5822) assuming that ITRS2005 is equivalent to WGS 84 within the accuracy of the transformation.','Approximation at the +/- 1m level assuming that ITRS2005 is equivalent to WGS 84.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5561','EPSG','4326','EPSG','1242',1.0,24.0,-121.0,-76.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Ukr',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','5826','DB_REF to ETRS89 (1)','Given with rotation and scale to greater resolution: dX = -1.1155214628", dY = -0.2824339890", dZ = 3.1384490633", dS = 7.992235". The truncated values given by OGP do not impact calculation accuracy.','Engineering survey for railway applications.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','5681','EPSG','4258','EPSG','3339',0.5,584.9636,107.7175,413.8067,'EPSG','9001',-1.1155,-0.2824,3.1384,'EPSG','9104',7.9922,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DB-Deu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5827','AGD66 to GDA94 (19)','Replaces nationally-derived transformation code 1458.','Recommended for mid-accuracy use in A.C.T. 1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4202','EPSG','4283','EPSG','2283',0.5,-129.164,-41.188,130.718,'EPSG','9001',-0.246,-0.374,-0.329,'EPSG','9104',-2.955,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PLA-ACT',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5840','UCS-2000 to WGS 84 (2)','Rounded parameter values taken from UCS-2000 to ITRF2000 (1) (code 7817) assuming that WGS 84 is equivalent to ITRS2000 within the accuracy of the transformation. Replaces UCS-2000 to WGS 84 (1) (tfm code 5590).','Approximation at the +/- 1m level assuming that WGS 84 is equivalent to ITRS2000.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5561','EPSG','4326','EPSG','1242',1.0,24.0,-121.0,-76.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Ukr SSGC',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5841','AGD66 to WGS 84 (19)','Derived at 25 stations in 2007.','Accuracy 2m in 2007. Due to significant tectonic activity in PNG, AGD66 and WGS 84 are separating by approximately 7cm per year.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4202','EPSG','4326','EPSG','4013',2.0,-124.0,-60.0,154.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Qcl-Png PFTB 2007',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5878','Timbalai 1948 to GDBD2009 (1)','May be taken as approximate transformation Timbalai 1948 to WGS 84 - see code 5249.','Oil exploration.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4298','EPSG','5246','EPSG','1055',1.0,-689.5937,623.84046,-65.93566,'EPSG','9001',0.02331,-1.17094,0.80054,'EPSG','9104',5.88536,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SD-Brn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5881','SAD69(96) to SIRGAS 2000 (2)','Parameter values from SAD69 to SIRGAS 2000 (1) (tfm code 15485) assuming that SAD69 and SAD69(96) are equal within the accuracy of the transformation. Used by Petrobras and ANP throughout Brazil from 1994.','Accuracy generally better than 1m except in Amazon basin where it degenerates to 5m. Should be used only to transform data obtained independently of the classical geodetic network (GPS observations conducted after 1994).','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5527','EPSG','4674','EPSG','1053',5.0,-67.35,3.88,-38.22,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IBGE-Bra',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5882','SAD69 to WGS 84 (16)','Parameter values from SAD69 to SIRGAS 2000 (1) (tfm code 15485) assuming that SIRGAS 2000 and WGS 84 are equal within the accuracy of the transformation. Used by ANP and Petrobras throughout Brazil from 1994, replacing use of tfm code 1877.','Accuracy generally better than 1m except in Amazon basin where it degenerates to 5m. Should be used only to transform data obtained independently of the classical geodetic network (GPS observations conducted after 1994).','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','1053',5.0,-67.35,3.88,-38.22,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Bra',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5888','Combani 1950 to RGM04 (1)','','Accuracy +/- 0.3 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4632','EPSG','4470','EPSG','3340',0.3,-599.928,-275.552,-195.665,'EPSG','9001',-0.0835,-0.4715,0.0602,'EPSG','9104',49.2814,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Myt',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','5900','ITRF2005 to ETRF2005 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Definition of ETRF2005.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4896','EPSG','8397','EPSG','1298',0.0,56.0,48.0,-37.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1027',0.054,0.518,-0.781,'EPSG','1032',0.0,'EPSG','1030',1989.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6136','GCGD59 to CIGD11 (1)','May be taken as approximate transformation GCGD61 to WGS 84 - see code 6142.','For applications to an accuracy of 1 foot (0.3m).','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4723','EPSG','6135','EPSG','3185',0.3,-179.483,-69.379,-27.584,'EPSG','9001',7.862,-8.163,-6.042,'EPSG','9104',-13.925,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'LSD-Cym',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6137','SIGD61 to CIGD11 (1)','May be taken as approximate transformation SIGD61 to WGS 84 - see code 6143.','For applications to an accuracy of 0.5 foot (0.15m).','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4726','EPSG','6135','EPSG','3186',0.15,8.853,-52.644,180.304,'EPSG','9001',0.393,2.323,-2.96,'EPSG','9104',-24.081,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'LSD-Cym',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6142','GCGD59 to WGS 84 (2)','Parameter values are taken from GCGD59 to CIGD11 (1) (code 6136) assuming that CIGD11 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1m.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4723','EPSG','4326','EPSG','3185',1.0,-179.483,-69.379,-27.584,'EPSG','9001',7.862,-8.163,-6.042,'EPSG','9104',-13.925,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Cym',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6143','SIGD61 to WGS 84 (3)','Parameter values are taken from SIGD59 to CIGD11 (1) (code 6137) assuming that CIGD11 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1m.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4726','EPSG','4326','EPSG','3186',1.0,8.853,-52.644,180.304,'EPSG','9001',0.393,2.323,-2.96,'EPSG','9104',-24.081,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Cym',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6177','CIGD11 to WGS 84 (1)','Approximation at the +/- 1m level assuming that CIGD11 is equivalent to WGS 84.','Accuracy +/- 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','6135','EPSG','4326','EPSG','1063',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Cym',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6191','Corrego Alegre 1970-72 to SAD69 (1)','Derived by Brazilian Institute of Geography and Statistics (IBGE) in 1983 at Chua origin point.','Medium and small scale mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4225','EPSG','4618','EPSG','1293',5.0,-138.7,164.4,34.4,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGBE-Bra',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6192','Corrego Alegre 1970-72 to WGS 84 (3)','Formed by concatenation of tfms codes 6191 and 1877. Used by Petrobras and ANP until February 2005 when replaced by Corrego Alegre 1970-72 to WGS 84 (4) (tfm code 6194).','Medium and small scale mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4225','EPSG','4326','EPSG','1293',5.0,-205.57,168.77,-4.12,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PBS-Bra 1983',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6193','Corrego Alegre 1970-72 to SIRGAS 2000 (2)','Formed by concatenation of tfms codes 6191 and 15485. May be used as transformation between Corrego Alegre 1970-72 and WGS 84 - see tfm code 6194. Used by Petrobras and ANP from February 2005.','Medium and small scale mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4225','EPSG','4674','EPSG','1293',5.0,-206.05,168.28,-3.82,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PBS-Bra 2005',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6194','Corrego Alegre 1970-72 to WGS 84 (4)','Parameter values from Corrego Alegre to SIRGAS 2000 (2) (tfm code 6193) assuming that SIRGAS 2000 and WGS 84 are equal within the accuracy of the transformation. Used by ANP and Petrobras from February 2005, replacing use of tfm code 6192.','Medium and small scale mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4225','EPSG','4326','EPSG','1293',5.0,-206.05,168.28,-3.82,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PBS-Bra 2005',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6195','SAD69(96) to WGS 84 (2)','Parameter values from SAD69(96) to SIRGAS 2000 (2)) (tfm code 5881) assuming that SIRGAS 2000 and WGS 84 are equal within the accuracy of the transformation, based on SAD69 to SIRGAS 2000 (1)) (tfm code 15485). Used by Petrobras and ANP from 1994.','Accuracy generally better than 1m except in Amazon basin where it degenerates to 5m. Should be used only to transform data obtained independently of the classical geodetic network (GPS observations conducted after 1994).','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5527','EPSG','4326','EPSG','1053',5.0,-67.35,3.88,-38.22,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Bra',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6196','Minna to WGS 84 (16)','Used by Addax for OPL 118 and OML 124. Derived in 1999 at 4 stations during  extension into OPL 118 of control in Chevron block OML 53.','Oil industry exploration and production.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4263','EPSG','4326','EPSG','4127',5.0,-93.179,-87.124,114.338,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ADX-Nga OPL 118',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6205','MGI 1901 to ETRS89 (5)','Derived at 31 stations in July 2010.','1m accuracy. Residuals generally less than +/- 0.7m horizontally.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4258','EPSG','1148',1.0,517.4399,228.7318,579.7954,'EPSG','9001',-4.045,-4.304,15.612,'EPSG','9104',-8.312,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'KAT-Mkd',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6206','MGI 1901 to WGS 84 (10)','Derived at 13 stations.','1m accuracy. Residuals generally less than +/- 1m horizontally and vertically.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4326','EPSG','1148',2.0,521.748,229.489,590.921,'EPSG','9001',-4.029,-4.488,15.521,'EPSG','9104',-9.78,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Kat-Mkd',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6208','Nepal 1981 to WGS 84 (1)','Derived at 11 points.','Topographic mapping. Accuracy 0.26m (1-sigma).','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','6207','EPSG','4326','EPSG','1171',0.3,293.17,726.18,245.36,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SD-Npl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6276','ITRF2008 to GDA94 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy. RMS residuals 5mm north, 8mm east and 28mm vertical, maximum residuals 10mm north, 13mm east and 51mm vertical.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','5332','EPSG','4938','EPSG','1036',0.03,-84.68,-19.42,32.01,'EPSG','1025',-0.4254,2.2578,2.4015,'EPSG','1031',9.71,'EPSG','1028',1.42,1.34,0.9,'EPSG','1027',1.5461,1.182,1.1551,'EPSG','1032',0.109,'EPSG','1030',1994.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'GA-Aus 2010',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6277','ITRF2005 to GDA94 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy. RMS residuals 4mm north, 8mm east and 30mm vertical, maximum residuals 10mm north, 17 mm east and 61mm vertical.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','4896','EPSG','4938','EPSG','1036',0.03,-79.73,-6.86,38.03,'EPSG','1025',-0.0351,2.1211,2.1411,'EPSG','1031',6.636,'EPSG','1028',2.25,-0.62,-0.56,'EPSG','1027',1.4707,1.1443,1.1701,'EPSG','1032',0.294,'EPSG','1030',1994.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'GA-Aus 2010',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6278','ITRF2000 to GDA94 (2)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Replaces 2001 transformation by Dawson and Steed, tfm code 6315.','Geodesy. RMS residuals 3mm north, 8mm east and 55mm vertical, maximum residuals 5mm north, 13mm east and 84mm vertical.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','4919','EPSG','4938','EPSG','1036',0.06,-45.91,-29.85,-20.37,'EPSG','1025',-1.6705,0.4594,1.9356,'EPSG','1031',7.07,'EPSG','1028',-4.66,3.55,11.24,'EPSG','1027',1.7454,1.4868,1.224,'EPSG','1032',0.249,'EPSG','1030',1994.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'GA-Aus 2010',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6279','ITRF97 to GDA94 (2)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Replaces 2001 transformation by Dawson and Steed, tfm code 6392.','Geodesy. RMS residuals 26mm north, 12mm east and 179mm vertical, maximum residuals 49mm north, 24mm east and 464mm vertical.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','4918','EPSG','4938','EPSG','1036',0.18,-14.63,-27.62,-25.32,'EPSG','1025',-1.7893,-0.6047,0.9962,'EPSG','1031',6.695,'EPSG','1028',-8.6,0.36,11.25,'EPSG','1027',1.6394,1.5198,1.3801,'EPSG','1032',0.007,'EPSG','1030',1994.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'GA-Aus 2010',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6280','ITRF96 to GDA94 (2)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Replaces 2001 transformation by Dawson and Steed, code 6313.','Geodesy. RMS residuals 22mm north, 56mm east and 90mm vertical, maximum residuals 49mm north, 126mm east and 193mm vertical.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','4917','EPSG','4938','EPSG','1036',0.11,24.54,-36.43,-68.12,'EPSG','1025',-2.7359,-2.0431,0.3731,'EPSG','1031',6.901,'EPSG','1028',-21.8,4.71,26.27,'EPSG','1027',2.0203,2.1735,1.629,'EPSG','1032',0.388,'EPSG','1030',1994.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'GA-Aus 2010',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6281','ITRF88 to ITRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4910','EPSG','4919','EPSG','1262',0.01,-2.47,-1.15,9.79,'EPSG','1033',-0.1,0.0,0.18,'EPSG','1031',-8.95,'EPSG','1028',0.0,0.06,0.14,'EPSG','1034',0.0,0.0,-0.02,'EPSG','1032',-0.01,'EPSG','1030',1988.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6282','ITRF89 to ITRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4911','EPSG','4919','EPSG','1262',0.01,-2.97,-4.75,7.39,'EPSG','1033',0.0,0.0,0.18,'EPSG','1031',-5.85,'EPSG','1028',0.0,0.6,-3.2,'EPSG','1034',0.0,0.0,-0.02,'EPSG','1032',-0.01,'EPSG','1030',1988.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','6283','ITRF90 to ITRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4912','EPSG','4919','EPSG','1262',0.01,-2.47,-2.35,3.59,'EPSG','1033',0.0,0.0,0.18,'EPSG','1031',-2.45,'EPSG','1028',0.0,0.06,0.14,'EPSG','1034',0.0,0.0,-0.02,'EPSG','1032',-0.01,'EPSG','1030',1988.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6284','ITRF91 to ITRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4913','EPSG','4919','EPSG','1262',0.01,-2.67,-2.75,1.99,'EPSG','1033',0.0,0.0,0.18,'EPSG','1031',-2.15,'EPSG','1028',0.0,0.06,0.14,'EPSG','1034',0.0,0.0,-0.02,'EPSG','1032',-0.01,'EPSG','1030',1988.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6285','ITRF92 to ITRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4914','EPSG','4919','EPSG','1262',0.01,-1.47,-1.35,1.39,'EPSG','1033',0.0,0.0,0.18,'EPSG','1031',-0.75,'EPSG','1028',0.0,0.06,0.14,'EPSG','1034',0.0,0.0,-0.02,'EPSG','1032',-0.01,'EPSG','1030',1988.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6286','ITRF93 to ITRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4915','EPSG','4919','EPSG','1262',0.01,-1.27,-0.65,2.09,'EPSG','1033',0.39,-0.8,1.14,'EPSG','1031',-1.95,'EPSG','1028',0.29,0.02,0.06,'EPSG','1034',0.11,0.19,-0.07,'EPSG','1032',-0.01,'EPSG','1030',1988.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6287','ITRF94 to ITRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4916','EPSG','4919','EPSG','1262',0.01,-0.67,-0.61,1.85,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',-1.55,'EPSG','1028',0.0,0.06,0.14,'EPSG','1034',0.0,0.0,-0.02,'EPSG','1032',-0.01,'EPSG','1030',1997.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6288','ITRF96 to ITRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4917','EPSG','4919','EPSG','1262',0.01,-0.67,-0.61,1.85,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',-1.55,'EPSG','1028',0.0,0.06,0.14,'EPSG','1034',0.0,0.0,-0.02,'EPSG','1032',-0.01,'EPSG','1030',1997.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6289','ITRF97 to ITRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4918','EPSG','4919','EPSG','1262',0.01,-0.67,-0.61,1.85,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',-1.55,'EPSG','1028',0.0,0.06,0.14,'EPSG','1034',0.0,0.0,-0.02,'EPSG','1032',-0.01,'EPSG','1030',1997.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6290','ITRF2000 to ITRF2005 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4919','EPSG','4896','EPSG','1262',0.01,-0.1,0.8,5.8,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',-0.4,'EPSG','1028',0.2,-0.1,0.18,'EPSG','1027',0.0,0.0,-0.02,'EPSG','1032',-0.08,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','6291','ITRF88 to ITRF2008 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4910','EPSG','5332','EPSG','1262',0.01,-22.8,-2.6,125.2,'EPSG','1025',-0.1,0.0,-0.06,'EPSG','1031',-10.41,'EPSG','1028',-0.1,0.5,3.2,'EPSG','1027',0.0,0.0,-0.02,'EPSG','1032',-0.09,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6292','ITRF89 to ITRF2008 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4911','EPSG','5332','EPSG','1262',0.01,-27.8,-38.6,101.2,'EPSG','1025',0.0,0.0,-0.06,'EPSG','1031',-7.31,'EPSG','1028',-0.1,0.5,3.2,'EPSG','1027',0.0,0.0,-0.02,'EPSG','1032',-0.09,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6293','ITRF90 to ITRF2008 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4912','EPSG','5332','EPSG','1262',0.01,-22.8,-14.6,63.2,'EPSG','1025',0.0,0.0,-0.06,'EPSG','1031',-3.91,'EPSG','1028',-0.1,0.5,3.2,'EPSG','1027',0.0,0.0,-0.02,'EPSG','1032',-0.09,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6294','ITRF91 to ITRF2008 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4913','EPSG','5332','EPSG','1262',0.01,-24.8,-18.6,47.2,'EPSG','1025',0.0,0.0,-0.06,'EPSG','1031',-3.61,'EPSG','1028',-0.1,0.5,3.2,'EPSG','1027',0.0,0.0,-0.02,'EPSG','1032',-0.09,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6295','ITRF92 to ITRF2008 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4914','EPSG','5332','EPSG','1262',0.01,-12.8,-4.6,41.2,'EPSG','1025',0.0,0.0,-0.06,'EPSG','1031',-2.21,'EPSG','1028',-0.1,0.5,3.2,'EPSG','1027',0.0,0.0,-0.02,'EPSG','1032',-0.09,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6296','ITRF93 to ITRF2008 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4915','EPSG','5332','EPSG','1262',0.01,24.0,-2.4,38.6,'EPSG','1025',1.71,1.48,0.3,'EPSG','1031',-3.41,'EPSG','1028',2.8,0.1,2.4,'EPSG','1027',0.11,0.19,-0.07,'EPSG','1032',-0.09,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6297','ITRF94 to ITRF2008 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4916','EPSG','5332','EPSG','1262',0.01,-4.8,-2.6,33.2,'EPSG','1025',0.0,0.0,-0.06,'EPSG','1031',-2.92,'EPSG','1028',-0.1,0.5,3.2,'EPSG','1027',0.0,0.0,-0.02,'EPSG','1032',-0.09,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6298','ITRF96 to ITRF2008 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4917','EPSG','5332','EPSG','1262',0.01,-4.8,-2.6,33.2,'EPSG','1025',0.0,0.0,-0.06,'EPSG','1031',-2.92,'EPSG','1028',-0.1,0.5,3.2,'EPSG','1027',0.0,0.0,-0.02,'EPSG','1032',-0.09,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6299','ITRF97 to ITRF2008 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4918','EPSG','5332','EPSG','1262',0.01,-4.8,-2.6,33.2,'EPSG','1025',0.0,0.0,-0.06,'EPSG','1031',-2.92,'EPSG','1028',-0.1,0.5,3.2,'EPSG','1027',0.0,0.0,-0.02,'EPSG','1032',-0.09,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6300','ITRF2000 to ITRF2008 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4919','EPSG','5332','EPSG','1262',0.01,1.9,1.7,10.5,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',-1.34,'EPSG','1028',-0.1,-0.1,1.8,'EPSG','1027',0.0,0.0,0.0,'EPSG','1032',-0.08,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6301','ITRF2005 to ITRF2008 (2)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4896','EPSG','5332','EPSG','1262',0.01,2.0,0.9,4.7,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',-0.94,'EPSG','1028',-0.1,-0.3,0.0,'EPSG','1027',0.0,0.0,0.0,'EPSG','1032',0.0,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld 2008',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','6302','ITRF2000 to ITRF2005 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Estimated using 70 stations.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4919','EPSG','4896','EPSG','1262',0.01,-0.1,0.8,5.8,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',-0.4,'EPSG','1028',0.2,-0.1,1.8,'EPSG','1027',0.0,0.0,0.0,'EPSG','1032',-0.08,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6313','ITRF96 to GDA94 (1)','Replaced by Dawson and Woods transformation of 2010, code 6280.','Geodesy.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','4917','EPSG','4938','EPSG','1036',0.1,-0.014,0.0431,0.201,'EPSG','9001',0.012464,0.012013,0.006434,'EPSG','9104',0.024607,'EPSG','9202',0.0411,0.0218,0.0383,'EPSG','1042',0.002542,0.001431,-0.000234,'EPSG','1043',0.005897,'EPSG','1041',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'GA-Aus 2001',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6314','ITRF97 to GDA94 (1)','Replaced by Dawson and Woods transformation of 2010, tfm code 6279.','Geodesy.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','4918','EPSG','4938','EPSG','1036',999.0,-0.2088,0.0119,0.1805,'EPSG','9001',0.012059,0.013369,0.011825,'EPSG','9104',0.004559,'EPSG','9202',-0.022,0.0049,0.0169,'EPSG','1042',0.00204,0.001782,0.001697,'EPSG','1043',-0.00109,'EPSG','1041',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'GA-Aus 2001',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','6315','ITRF2000 to GDA94 (1)','Replaced by Dawson and Woods transformation of 2010, tfm code 6278.','Geodesy.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','4919','EPSG','4938','EPSG','1036',0.1,-0.0761,-0.0101,0.0444,'EPSG','9001',0.008765,0.009361,0.009325,'EPSG','9104',0.007935,'EPSG','9202',0.011,-0.0045,-0.0174,'EPSG','1042',0.001034,0.000671,0.001039,'EPSG','1043',-0.000538,'EPSG','1041',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'GA-Aus 2001',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6373','Mexico ITRF2008 to WGS 84 (1)','','Accuracy 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','6365','EPSG','4326','EPSG','1160',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Mex',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6388','Ocotepeque 1935 to NAD27 (1)','','Topographic mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5451','EPSG','4267','EPSG','3876',9.0,205.435,-29.099,292.202,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Cri',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','6389','ITRF2005 to ITRF2008 (2)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. IERS also publish parameter values for epoch 2005.0; because most rates are zero all values as above except tX=0.5mm. Estimated using 171 stations at 131 sites.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4896','EPSG','5332','EPSG','1262',0.01,2.0,0.9,4.7,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',-0.94,'EPSG','1028',-0.3,0.0,0.0,'EPSG','1027',0.0,0.0,0.0,'EPSG','1032',0.0,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld 2008',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6392','ITRF97 to GDA94 (1)','Replaced by Dawson and Woods transformation of 2010, tfm code 6279.','Geodesy.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','4918','EPSG','4938','EPSG','1036',0.1,-0.2088,0.0119,0.1855,'EPSG','9001',0.012059,0.013639,0.011825,'EPSG','9104',0.004559,'EPSG','9202',-0.022,0.0049,0.0169,'EPSG','1042',0.00204,0.001782,0.001697,'EPSG','1043',-0.00109,'EPSG','1041',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'GA-Aus 2001',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6698','JGD2000 to JGD2011 (2)','Excludes areas of northern Honshu affected by 2008 Iwate-Miyagi and 2011 Tohoku earthquakes. For these areas use GSI PatchJGD application or JGD2000 to JGD2011 (1) (tfm code 6713).','Approximation at the +/- 1m level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4612','EPSG','6668','EPSG','4163',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Jpn ex N Honshu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6701','GDBD2009 to WGS 84 (1)','Approximation at the +/- 1m level assuming that GDBD2009 is equivalent to WGS 84 within the accuracy of the transformation.','Accuracy 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5246','EPSG','4326','EPSG','1055',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Brn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6710','RDN2008 to ETRS89 (1)','May be taken as approximate transformation RDN2008 to WGS 84 - see code 6711.','RDN2008 is a national realization of ETRS89.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','6706','EPSG','4258','EPSG','1127',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Ita',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6711','RDN2008 to WGS 84 (1)','Approximation at the +/- 1m level assuming that ETRS89 is equivalent to WGS 84. RDN2008 is a regional realisation of ETRS89.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','6706','EPSG','4326','EPSG','1127',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Ita',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6864','ITRF96 to NAD83(CORS96) (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Jointly derived by Canada and US at 12 North American VLBI stations. Replaced by tfm code 6865 from 2000-01-01. See tfm code 8259 for Canadian equivalent.','Geodesy. Definition of NAD83(CORS96) from 1st January 1997 through 31st December 1999 and is therefore treated as errorless.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','4917','EPSG','6781','EPSG','1511',0.0,0.991,-1.9072,-0.5129,'EPSG','9001',25.79,9.65,11.66,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1042',0.0532,-0.7423,-0.0316,'EPSG','1032',0.0,'EPSG','1030',1997.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'NGS-US CORS96',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6865','ITRF97 to NAD83(CORS96) (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. 1996 derivation (see tfm 6864) concatenated with IGS value of ITRF96>ITRF97. Replaced by tfm code 6865 from 2000-01-01. See tfm code 8260 for Canadian equivalent.','Geodesy. Redefinition of NAD83(CORS96) from January 2000 through December 2001.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','4918','EPSG','6781','EPSG','1511',0.0,0.9889,-1.9074,-0.503,'EPSG','9001',25.915,9.426,11.599,'EPSG','1031',-0.93,'EPSG','1028',0.0007,-0.0001,0.0019,'EPSG','1042',0.067,-0.757,-0.031,'EPSG','1032',-0.19,'EPSG','1030',1997.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'NGS-US CORS96',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6866','ITRF2000 to NAD83(CORS96) (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Joint derivation by Canada and US (tfm 6864) concatenated with IGS value for ITRF96>97 and IERS ITRF97>2000 transformations. See tfm 8261 for Canadian equivalent.','Geodesy. Definition of NAD83(CORS96) from 1st January 2002 through 6th September 2011 and is therefore treated as errorless.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','4919','EPSG','6781','EPSG','1511',0.0,0.9956,-1.9013,-0.5215,'EPSG','9001',25.915,9.426,11.599,'EPSG','1031',0.62,'EPSG','1028',0.0007,-0.0007,0.0005,'EPSG','1042',0.067,-0.757,-0.051,'EPSG','1032',-0.18,'EPSG','1030',1997.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'NGS-US CORS96',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6872','Abidjan 1987 to WGS 84 (2)','Derived and used by Western Geophysical for offshore surveys in the 1990s, but exact provenance uncertain. Used by OMV.','Accuracy uncertain but there is some evidence of unknown reliability that suggests accuracy of better than 2m throughout offshore.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4143','EPSG','4326','EPSG','2296',2.0,-123.1,53.2,465.4,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'WGC-Civ',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6873','Tananarive to WGS 84 (2)','Derived at 9 points throughout Madagascar. Adopted by OMV.','For applications with an accuracy of 3m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4297','EPSG','4326','EPSG','1149',3.0,-198.383,-240.517,-107.909,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ROG-Mdg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6888','Ocotepeque 1935 to NAD27 (1)','','Topographic mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5451','EPSG','4267','EPSG','3876',9.0,205.435,-29.099,-292.202,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Cri',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6889','Ocotepeque 1935 to WGS 84 (2)','Rotations in original source given in radians are equivalent to Rx = 2.35", Ry = -0.06", Rz = 6.39".','Topographic mapping.','EPSG','1063','Molodensky-Badekas (PV geog2D domain)','EPSG','5451','EPSG','4326','EPSG','3232',5.0,213.116,9.358,-74.946,'EPSG','9001',1.14e-05,-2.98e-07,3.1e-05,'EPSG','9101',5.22,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,617749.7118,-6250547.7336,1102063.6099,'EPSG','9001','UNA-Cri',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6890','Ocotepeque 1935 to CR05 (1)','May be taken as approximate transformation Ocotepeque to WGS 84 - see code 5470.','Topographic mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5451','EPSG','5365','EPSG','3232',8.0,213.11,9.37,-74.95,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Cri',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6891','Ocotepeque 1935 to WGS 84 (3)','Concatenation (via NAD27) of transformations 6888 and 1171. Accuracy not given, but accuracy of constituent transformations given as 9m and 10m respectively.','For military purposes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5451','EPSG','4326','EPSG','3876',14.0,205.0,96.0,-98.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Cri',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6895','Viti Levu 1912 to WGS 84 (2)','Derived at 9 stations. Replaces Viti Levu 1912 to WGS 84 (1) (code 15897).','For military and topographic mapping. Accuracy +/-3m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4752','EPSG','4326','EPSG','3195',5.0,98.0,390.0,-22.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Fji GeoTrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6896','Accra to WGS 84 (4)','Derived at 4 stations.','For military purposes. Accuracy 3m, 4m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4168','EPSG','4326','EPSG','3252',6.0,-170.0,33.0,326.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Gha GeoTrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6897','St. Lucia 1955 to WGS 84 (2)','Derived at 3 stations.','For military purposes only. Accuracy 1m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4606','EPSG','4326','EPSG','3298',2.0,-153.0,153.0,307.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Lca GeoTrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6898','Lisbon to WGS 84 (5)','Derived at 1 station.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4207','EPSG','4326','EPSG','1294',43.0,-306.0,-62.0,105.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Prt GeoTrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6899','Pulkovo 1942 to WGS 84 (21)','Derived at 19 stations.','For military purposes. Accuracy 2m, 3m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4284','EPSG','4326','EPSG','3246',5.0,22.0,-126.0,-85.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Est GeoTrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6900','Observatario to WGS 84 (1)','Derived at 3 stations.','For military purposes. Accuracy 10m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4129','EPSG','4326','EPSG','1329',17.0,-132.0,-110.0,-335.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Moz Geotrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6901','Tete to WGS 84 (6)','Derived at 4 stations.','For military purposes. Accuracy 10m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4127','EPSG','4326','EPSG','3281',17.0,-80.0,-100.0,-228.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Moz GeoTrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6902','Timbalai 1948 to WGS 84 (6)','Derived at 9 stations.','For military purposes. Accuracy 1m, 6m and 2m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4298','EPSG','4326','EPSG','2349',6.0,-679.0,667.0,-49.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Brn GeoTrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6903','Yoff to WGS 84 (2)','Derived at 7 stations.','For military purposes only. Accuracy 3m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4310','EPSG','4326','EPSG','1207',5.0,-30.0,190.0,89.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Sen GeoTrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6904','Arc 1950 to WGS 84 (11)','Derived at 7 stations. Info source gives source CRS as Arc 1960. From inspection of parameter values, comparison of those from DMA TR8350.2 transformations and geographic applicability of CRS, OGP believes that this should be Arc 1950.','For military purposes only. Accuracy 13m, 25m and 7m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4209','EPSG','4326','EPSG','1150',29.0,-179.0,-81.0,-314.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Mwi GeoTrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6905','AGD66 to WGS 84 (20)','Derived at 161 stations. Replaces AGD66 to WGS 84 (1) (code 1108).','For military purposes only. Accuracy 5m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4202','EPSG','4326','EPSG','2575',9.0,-128.0,-52.0,153.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Aus GeoTrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6906','Arc 1950 to WGS 84 (10)','Derived at 38 stations. Replaces Arc 1950 to WGS 84 (9), tfm code 1121.','For military purposes. Accuracy 10m in each of X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4209','EPSG','4326','EPSG','1261',17.0,-145.0,-97.0,-292.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Zwe GeoTrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6907','Ayabelle Lighthouse to WGS 84 (2)','Derived at 2 stations. Replaces Ayabelle Lighthouse to WGS 84 (1) (code 15800).','For military purposes only. Accuracy 10m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4713','EPSG','4326','EPSG','3238',17.0,-77.0,-128.0,142.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Dji GeoTrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6908','Fahud to WGS 84 (3)','Derived at 11 stations. Replaces Fahud to WGS 84 (1) (code 1256).','For military purposes. Accuracy 3m, 3m and 6m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4232','EPSG','4326','EPSG','4009',7.0,-345.0,3.0,223.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Omn GeoTrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6909','Hjorsey 1955 to WGS 84 (2)','Derived at 16 stations. Replaces Hjorsey 1955 to WGS 84 (1) (code 1951).','Accuracy 3m, 3m and 6m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4658','EPSG','4326','EPSG','3262',7.0,-73.0,47.0,-83.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Isl GeoTrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6910','Aden 1925 to WGS 84 (1)','Derivation not given.','For military purposes. Accuracy not specified.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','6881','EPSG','4326','EPSG','1340',999.0,-24.0,-203.0,268.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Yem GeoTrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6911','Bekaa Valley 1920 to WGS 84 (1)','Derivation not given.','For military purposes. Accuracy not specified.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','6882','EPSG','4326','EPSG','3269',999.0,-183.0,-15.0,273.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Lbn GeoTrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6912','Bioko to WGS 84 (1)','Derived at 6 stations.','For military purposes. Accuracy 5m, 17m and 38m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','6883','EPSG','4326','EPSG','4220',42.0,-235.0,-110.0,393.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Gnq GeoTrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6913','Gambia to WGS 84 (1)','Derived at 1 station.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','6894','EPSG','4326','EPSG','3250',43.0,-63.0,176.0,185.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Gmb GeoTrans3-4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6914','South East Island 1943 to WGS 84 (1)','Derived by UK DOS at 10 stations in 1998, RMS ±0.314m. Also published by NGA in Standard 0036 v1.0.0 of 2014-07-08 and in GeoTrans v3.4 software with parameter values rounded to integer.','Topographic mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','6892','EPSG','4326','EPSG','4183',1.0,-43.685,-179.785,-267.721,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DOS-Syc 3-param',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6926','South East Island 1943 to WGS 84 (2)','Derived by UKHO at 13 stations in 1999, RMS ±0.271m.','Hydrographic survey and charting.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','6892','EPSG','4326','EPSG','4183',1.0,-76.269,-16.683,68.562,'EPSG','9001',-6.275,10.536,-4.286,'EPSG','9104',-13.686,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UKHO-Syc 7-param',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6935','IGS08 to IGRS (1)','Derived by least squares adjustment from the coordinates of the IRAQ-CORS network in both CRSs. Station Baghdad was excluded (high residuals). RMSE = 0.004 m. Application yields identical results to transformation 6936.','Geodetic survey, large scale mapping and engineering surveys.','EPSG','1061','Molodensky-Badekas (PV geocentric domain)','EPSG','6934','EPSG','3887','EPSG','1124',0.05,0.208,-0.012,-0.229,'EPSG','9001',-0.01182,0.00811,-0.01677,'EPSG','9104',-0.0059,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,3777505.028,3779254.396,3471111.632,'EPSG','9001','IRQ-MB(PV)',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6936','IGS08 to IGRS (2)','Derived by least squares adjustment from the coordinates of the IRAQ-CORS network in both CRSs. Station Baghdad was excluded (high residuals). RMSE = 0.004 m. Application yields identical results to transformation 6935.','Geodetic survey, large scale mapping and engineering surveys.','EPSG','1033','Position Vector transformation (geocentric domain)','EPSG','6934','EPSG','3887','EPSG','1124',0.05,-0.214,0.119,0.156,'EPSG','9001',-0.01182,0.00811,-0.01677,'EPSG','9104',-0.0059,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IRQ-7PV',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6937','AGD66 to PNG94 (2)','Derived in 2014 at 38 stations around the PNG mainland. Aligned to the Bevan Rapids Geodetic Origin AA 070 as required by the Papua New Guinea Oil and Gas Act 1998.','Medium accuracy (1m) transformations.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4202','EPSG','5546','EPSG','4214',1.0,-0.41,-2.37,2.0,'EPSG','9001',3.592,3.698,3.989,'EPSG','9104',8.843,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Qcl-Png Mainland 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6938','AGD66 to PNG94 (3)','Derived in 2014 at 38 stations around the PNG mainland. See AGD66 to PNG94 (2) for a more accurate 7-parameter transformation. May be taken as an approximate transformation AGD66 to WGS 84 - see tfm code 6943.','Low accuracy transformation suitable for mapping and navigation purposes only.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4202','EPSG','5546','EPSG','4214',4.0,-129.0,-58.0,152.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Qcl-Png Mainland 4m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6939','AGD66 to PNG94 (4)','Derived in 2014 at 23 stations around the Kutubu oilfields. Aligned to the Bevan Rapids Geodetic Origin AA 070 as required by the Papua New Guinea Oil and Gas Act 1998. Replaces AGD66 to PNG94 (1) (tfm code 5662).','Medium accuracy (1m) transformations.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4202','EPSG','5546','EPSG','4013',1.0,-131.876,-54.554,453.346,'EPSG','9001',-5.2155,-8.2042,0.09,'EPSG','9104',5.02,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Qcl-Png PFTB 2014 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6940','AGD66 to PNG94 (5)','Derived in 2014 at 23 stations around the Kutubu oilfields. See AGD66 to PNG94 (4) for a more accurate 7-parameter transformation. May be taken as an approximate transformation AGD66 to WGS 84 - see tfm code 6944.','Low accuracy transformation suitable for mapping and navigation purposes only.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4202','EPSG','5546','EPSG','4013',2.0,-131.3,-55.3,151.8,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Qcl-Png PFTB 2014 2m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6941','AGD66 to PNG94 (6)','Derived in 2014 at 7 stations in Ningerum and Tabubil (North Fly District).','Medium accuracy (1m) transformations.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4202','EPSG','5546','EPSG','4216',0.5,45.928,-177.212,336.867,'EPSG','9001',-4.6039,-3.0921,0.5729,'EPSG','9104',36.796,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Qcl-Png North Fly 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6942','AGD66 to PNG94 (7)','Derived in 2014 at 7 stations in Ningerum and Tabubil (North Fly District). See AGD66 to PNG94 (6) for a more accurate 7-parameter transformation. May be taken as an approximate transformation AGD66 to WGS 84 - see tfm code 6945.','Low accuracy transformation suitable for mapping and navigation purposes only.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4202','EPSG','5546','EPSG','4216',2.5,-137.4,-58.9,150.4,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Qcl-Png North Fly 3m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6943','AGD66 to WGS 84 (21)','Parameter values taken from AGD66 to PNG94 (3) (code 6938). Approximation at the +/- 5m level assuming that PNG94 is equivalent to WGS 84 within the accuracy of the transformation.','Low accuracy transformation suitable for mapping and navigation purposes only.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4202','EPSG','4326','EPSG','4214',5.0,-129.0,-58.0,152.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Qcl-Png Mainland',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6944','AGD66 to WGS 84 (22)','Parameter values taken from AGD66 to PNG94 (5) (code 6940). Approximation at the +/- 4m level assuming that PNG94 is equivalent to WGS 84 within the accuracy of the transformation.','Low accuracy transformation suitable for mapping and navigation purposes only.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4202','EPSG','4326','EPSG','4013',4.0,-131.3,-55.3,151.8,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Qcl-Png PFTB 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6945','AGD66 to WGS 84 (23)','Parameter values taken from AGD66 to PNG94 (7) (code 6942). Approximation at the +/- 4m level assuming that PNG94 is equivalent to WGS 84 within the accuracy of the transformation.','Low accuracy transformation suitable for mapping and navigation purposes only.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4202','EPSG','4326','EPSG','4216',4.0,-137.4,-58.9,150.4,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Qcl-Png North Fly',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6949','PSAD56 to SIRGAS-Chile (1)','Also used as a transformation from PSAD56 to WGS 84 - see code 6971.','Small and medium scale cartographic mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4248','EPSG','9184','EPSG','4231',5.0,-302.0,272.0,-360.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Chl A',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6950','PSAD56 to SIRGAS-Chile (2)','Also used as a transformation from PSAD56 to WGS 84 - see code 6972.','Small and medium scale cartographic mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4248','EPSG','9184','EPSG','4222',5.0,-328.0,340.0,-329.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Chl B',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6951','PSAD56 to SIRGAS-Chile (3)','Also used as a transformation from PSAD56 to WGS 84 - see code 6973.','Small and medium scale cartographic mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4248','EPSG','9184','EPSG','4221',5.0,-352.0,403.0,-287.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Chl C',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6960','VN-2000 to WGS 84 (2)','','Academic research not officially adopted.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4756','EPSG','4326','EPSG','3328',1.0,-191.90441429,-39.30318279,-111.45032835,'EPSG','9001',-0.00928836,0.01975479,-0.00427372,'EPSG','9104',0.252906278,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DoSM-Vnm',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6963','Albanian 1987 to ETRS89 (1)','Derived using 90 stations, mse 18cm. May be taken as approximate transformation from Albanian 1987 to WGS 84 (see code 6964).','Use only for horizontal coordinates; geoid heights must be calculated with ALBGEO3 software.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4191','EPSG','4258','EPSG','3212',0.2,-44.183,-0.58,-38.489,'EPSG','9001',2.3867,2.7072,-3.5196,'EPSG','9104',-8.2703,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Alb 2D',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','6964','Albanian 1987 to WGS 84 (1)','Parameter values from Albanian 1987 to ETRS89 (1) (code 6963). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','Use only for horizontal coordinates; geoid heights must be calculated with ALBGEO3 software.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4191','EPSG','4326','EPSG','3212',1.0,-44.183,-0.58,-38.489,'EPSG','9001',2.3867,2.7072,-3.5196,'EPSG','9104',-8.2703,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Alb 2D',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','6967','SAD69 to SIRGAS-Chile (1)','Also used as a transformation from SAD69 to WGS 84 - see code 6974. Note: SAD69 adopted in Chile only south of 43°30''S.','Small and medium scale cartographic mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','4232',5.0,-59.0,-11.0,-52.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Chl A',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','6968','SAD69 to SIRGAS-Chile (2)','Also used as a transformation from SAD69 to WGS 84 - see code 6975. Note: SAD69 adopted in Chile only south of 43°30''S.','Small and medium scale cartographic mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','9184','EPSG','4224',5.0,-64.0,0.0,-32.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Chl B',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6969','SAD69 to SIRGAS-Chile (3)','Also used as a transformation from SAD69 to WGS 84 - see code 6976. Note: SAD69 adopted in Chile only south of 43°30''S.','Small and medium scale cartographic mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','4221',5.0,-72.0,10.0,-32.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Chl C',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','6970','SAD69 to SIRGAS-Chile (4)','Also used as a transformation from SAD69 to WGS 84 - see code 6977.','Small and medium scale cartographic mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','9184','EPSG','2805',5.0,-79.0,13.0,-14.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Chl D',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6971','PSAD56 to WGS 84 (15)','Derived at 5 stations. Replaces PSAD56 to WGS 84 (3) (code 1203). Also used as a transformation from PSAD56 to SIRGAS-Chile - see code 6949.','For military purposes. Accuracy 10m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4248','EPSG','4326','EPSG','4231',17.0,-302.0,272.0,-360.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Chl N 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6972','PSAD56 to WGS 84 (16)','Derived at 7 stations. Also used as a transformation from PSAD56 to SIRGAS-Chile - see code 6950.','For military purposes. Accuracy 10m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4248','EPSG','4326','EPSG','4222',17.0,-328.0,340.0,-329.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Chl Cen 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6973','PSAD56 to WGS 84 (17)','Derived at 6 stations. Replaces PSAD56 to WGS 84 (4) (code 1204). Info source gives S limit as 44°S but Chilean IGM states that PSAD56 limit is 43°30''S. Also used as a transformation from PSAD56 to SIRGAS-Chile - see code 6951.','For military purposes. Accuracy 10m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4248','EPSG','4326','EPSG','4221',17.0,-352.0,403.0,-287.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Chl S 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6974','SAD69 to WGS 84 (17)','Derived at 8 stations. Along with transformations 6975 and 6976, replaces SAD69 to WGS 84 (5) (code 1868). Also used as a transformation from SAD69 to SIRGAS-Chile - see code 7448. Note: SAD69 adopted by Chile authorities only south of 43°30''S.','For military purposes only. Accuracy 2m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','4232',4.0,-59.0,-11.0,-52.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Chl 17-32',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6975','SAD69 to WGS 84 (18)','Derived at 6 stations. Along with transformations 6974 and 6976, replaces SAD69 to WGS 84 (5) (code 1868). Also used as a transformation from SAD69 to SIRGAS-Chile - see code 6968. Note: SAD69 adopted by Chile authorities only south of 43°30''S.','For military purposes only. Accuracy 2m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','4224',4.0,-64.0,0.0,-32.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Chile 32-36',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6976','SAD69 to WGS 84 (19)','Derived at 4 stations. Along with transformations 6974 and 6975, replaces SAD69 to WGS 84 (5) (code 1868). Also used as a transformation from SAD69 to SIRGAS-Chile - see code 7449. Note: SAD69 adopted by Chile authorities only south of 43°30''S.','For military purposes only. Accuracy 4m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','4221',7.0,-72.0,10.0,-32.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Chl 36-44',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6977','SAD69 to WGS 84 (20)','Derived at 6 stations. Also used as a transformation from SAD69 to SIRGAS-Chile - see code 6970.  Unlike IGM Chile, NGA extends use of this tfm to all Chile south of 44°S.','For military purposes only. Accuracy 3m, 3m and 4m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4326','EPSG','2805',6.0,-79.0,13.0,-14.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Chile 44-',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6992','IGD05 to IGD05/12','','Geodesy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','7136','EPSG','7139','EPSG','1126',0.05,0.2255,-0.3709,-0.1171,'EPSG','9001',-0.00388,0.00063,-0.0182,'EPSG','9104',0.013443,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SOI-Isr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6993','IGD05/12 to  IG05/12 Intermediate CRS','Replaces IGD05 transformation (code 7140). Defines the IG05/12 Intermediate CRS so is considered errorless. Israeli documentation refers to target CRS as "in GRS80". Use this CT for cadastre and precise engineering but see CTs 9186 or 9189 for GIS use.','Legally-defined transformation between IGD05/12 (ITRF) and Israeli Grid 05/12.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','7139','EPSG','6990','EPSG','2603',0.0,-24.0024,-17.1032,-17.8444,'EPSG','9001',-0.33009,-1.85269,1.66969,'EPSG','9104',5.4248,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SOI-Isr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6998','Nahrwan 1967 to WGS 84 (11)','Derived via WGS 72 but provenance uncertain. In ADMA replaces tfm code 15938. In ADCO replaced by tfm code 6999 from October 2013.','Oil exploration and production.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4270','EPSG','4326','EPSG','4226',5.0,-233.4,-160.7,381.5,'EPSG','9001',0.0,0.0,-0.554,'EPSG','9104',0.2263,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ADNOC-UAE Abd',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','6999','Nahrwan 1967 to WGS 84 (12)','Derived in October 2013 at four control points of the ADCO CRF and evaluated at four others. Estimated horizontal accuracy of 0.14 m at the 95% confidence level.','Oil exploration and production horizontal coordinate transformation. Although a 3D transformation, should not be used for vertical dimension.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4270','EPSG','4326','EPSG','4225',0.15,-253.4392,-148.452,386.5267,'EPSG','9001',-0.15605,-0.43,0.1013,'EPSG','9104',-0.0424,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ADCO-UAE Abd 2013',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7002','Nahrwan 1967 to WGS 84 (13)','','Abu Dhabi Municipality GIS.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4270','EPSG','4326','EPSG','4229',1.0,-246.1633,-152.9047,382.6047,'EPSG','9001',-0.0989,-0.1382,-0.0768,'EPSG','9104',2.1e-06,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ADM-UAE Abd Isl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7003','Nahrwan 1967 to WGS 84 (14)','','Abu Dhabi Municipality GIS.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4270','EPSG','4326','EPSG','1850',1.0,-242.8907,-149.0671,384.416,'EPSG','9001',-0.19044,-0.24987,-0.13925,'EPSG','9104',0.0001746,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ADM-UAE Abd U39',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7004','Nahrwan 1967 to WGS 84 (15)','','Abu Dhabi Municipality GIS.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4270','EPSG','4326','EPSG','4227',1.0,-246.734,-153.4345,382.1477,'EPSG','9001',0.116617,0.165167,0.091327,'EPSG','9104',1.94e-05,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ADM-UAE Abd U40',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7033','Nahrwan 1934 to WGS 84 (6)','Derived by concatenation of parameter values published by IGN Paris from Nahrwan 1934 to WGS 72 at the Nahrwan SE Base station near Baghdad with DMA WGS 72 to WGS 84 parameter values. For more accurate transformation away from origin see codes 7008-7032.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4744','EPSG','4326','EPSG','3625',30.0,-242.2,-144.9,370.3,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Irq',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7083','Perroud 1950 to RGTAAF07 (1)','Derived at three point on Petrels island at which residuals about 20 cm.','Coordinate transformation.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4637','EPSG','7073','EPSG','2817',0.5,324.912,153.282,172.026,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN Ata Petrel',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7140','IGD05 to IG05 Intermediate CRS','Defines the IG05 Intermediate CRS so is considered errorless. Target CRS is referred to in Israeli documentation as "in GRS80". Replaced by IG05/12 transformation (code 6993).','Legally-defined transformation between IGD05 (ITRF) and Israeli Grid 05.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','7136','EPSG','6983','EPSG','2603',0.0,-23.8085,-17.5937,-17.801,'EPSG','9001',-0.3306,-1.85706,1.64828,'EPSG','9104',5.4374,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SOI-Isr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7377','ONGD14 to  WGS 84 (1)','Translations given by information source in mm. Derived at 20 stations, RMS 0.0313m in northing, 0.0377m in easting and 0.0678m in height.','Geodesy.','EPSG','1032','Coordinate Frame rotation (geocentric domain)','EPSG','7371','EPSG','4978','EPSG','1183',0.1,0.819,-0.5762,-1.6446,'EPSG','9001',0.00378,0.03317,-0.00318,'EPSG','9104',0.0693,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NSA-Omn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7442','Nord Sahara 1959 to WGS 84 (10)','Derived at 1 astro station central to concession. Significant and varying differences (>100m) known to exist in neighbouring astro stations.','Oil industry operations.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4307','EPSG','4326','EPSG','4382',100.0,-181.7,64.7,247.2,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Isa-Alg Ain Tsila',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7443','ONGD14 to  WGS 84 (2)','Approximation at the +/- 1m level assuming that ONG14 is equivalent to WGS 84. See transformation code 7377 for authoritative values.','Geodesy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','7373','EPSG','4326','EPSG','1183',2.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Omn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7444','CGRS93 to ETRS89 (1)','Derived at 6 points at epoch 1993.1. May be taken as approximate transformation CGRS93 to WGS 84 - see code 7445.','Small scale hydrographic and aviation  mapping.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','6311','EPSG','4258','EPSG','3236',0.1,8.846,-4.394,-1.122,'EPSG','9001',0.00237,0.146528,-0.130428,'EPSG','9104',0.783926,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DLS-Cyp',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','7445','CGRS93 to WGS 84 (1)','Parameter values from CGRS93 to ETRS89 (1) (code 7444). Approximation at the +/- 1m level assuming that ETRS89 is equivalent to WGS 84.','Small scale hydrographic and aviation  mapping.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','6311','EPSG','4326','EPSG','3236',1.0,8.846,-4.394,-1.122,'EPSG','9001',0.00237,0.146528,-0.130428,'EPSG','9104',0.783926,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Cyp',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','7448','SAD69 to SIRGAS-Chile (1)','Also used as a transformation from SAD69 to WGS 84 - see code 6974. Note: SAD69 adopted in Chile only south of 43°30''S.','Small and medium scale cartographic mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','9184','EPSG','4232',5.0,-59.0,-11.0,-52.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Chl A',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7449','SAD69 to SIRGAS-Chile (3)','Also used as a transformation from SAD69 to WGS 84 - see code 6976. Note: SAD69 adopted in Chile only south of 43°30''S.','Small and medium scale cartographic mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','9184','EPSG','4221',5.0,-72.0,10.0,-32.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Chl C',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7666','WGS 84 (G1762) to ITRF2008 (1)','Defined at epoch 2005.0. Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1032','Coordinate Frame rotation (geocentric domain)','EPSG','7664','EPSG','5332','EPSG','1262',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Wld 2005.0',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7667','WGS 84 (G1674) to WGS 84 (G1762) (1)','Defined at epoch 2005.0. Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1032','Coordinate Frame rotation (geocentric domain)','EPSG','7662','EPSG','7664','EPSG','1262',0.01,-4.0,3.0,4.0,'EPSG','1025',0.27,-0.27,0.38,'EPSG','1031',-6.9,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Wld 2005.0',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7668','WGS 84 (G1150) to WGS 84 (G1762) (1)','Defined at epoch 2001.0. Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1032','Coordinate Frame rotation (geocentric domain)','EPSG','7660','EPSG','7664','EPSG','1262',0.02,-6.0,5.0,20.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',-4.5,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Wld 2001.0',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7669','WGS 84 (G1674) to ITRF2008 (1)','Defined at epoch 2005.0. Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1032','Coordinate Frame rotation (geocentric domain)','EPSG','7662','EPSG','5332','EPSG','1262',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Wld 2005.0',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7670','WGS 84 (G1150) to ITRF2000 (1)','Defined at epoch 2001.0.','Geodesy.','EPSG','1032','Coordinate Frame rotation (geocentric domain)','EPSG','7660','EPSG','4919','EPSG','1262',0.02,0.0,0.0,0.0,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Wld 2001.0',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7671','WGS 84 (G873) to ITRF92 (1)','Defined at epoch 1997.0.','Geodesy','EPSG','1032','Coordinate Frame rotation (geocentric domain)','EPSG','7658','EPSG','4914','EPSG','1262',0.1,0.0,0.0,0.0,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Wld 1997.0',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','7672','WGS 84 (G730) to ITRF92 (1)','Defined at epoch 1994.0.','Geodesy.','EPSG','1032','Coordinate Frame rotation (geocentric domain)','EPSG','7656','EPSG','4914','EPSG','1262',0.2,0.0,0.0,0.0,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Wld 1994.0',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7675','MGI 1901 to ETRS89 (6)','Derived at 5506 points across the Repulic of Serbia. May be taken as approximate transformation MGI 1901 to WGS 84 assuming ETRS89 is equivalent to WGS 84 within the accuracy of the transformation - see tfm code 7676.','0.5m accuracy suitable for large and medium scale mapping.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4258','EPSG','4543',0.5,577.88891,165.22205,391.18289,'EPSG','9001',-4.9145,0.94729,13.05098,'EPSG','9104',7.78664,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'RGZ-Srb',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7676','MGI 1901 to WGS 84 (11)','Parameter values from MGI 1901 to ETRS89 (6) (code 7675). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications with an accuracy of 1m.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4326','EPSG','4543',1.0,577.88891,165.22205,391.18289,'EPSG','9001',-4.9145,0.94729,13.05098,'EPSG','9104',7.78664,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Srb',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7697','Egypt 1907 to WGS 84 (4)','Derived at 30 stations throughout Egypt 1907 network. Accuracy determined at 15 stations 0.7m in each axis.','Unified transformation for whole country. Accuracy under 1m in X, Y and Z axes.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4229','EPSG','4326','EPSG','1086',1.2,-127.535,113.495,-12.7,'EPSG','9001',1.603747,-0.153612,-5.364408,'EPSG','9104',5.33745,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,4854969.728,2945552.013,2868447.61,'EPSG','9001','SRI-Egy',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7698','NAD27 to WGS 84 (89)','Derived at stations in the provinces of Colón, Panamá, Coclé, Veraguas,¶Herrera, Los Santos y Chiriquí. Standard deviation 0.871m in north and 0.531m in east.','Accuracy 1m.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','3290',1.0,-32.3841359,180.4090461,120.8442577,'EPSG','9001',2.1545854,0.1498782,-0.5742915,'EPSG','9104',8.1049164,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGNTG-Pan',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7702','PZ-90 to PZ-90.02 (1)','','Geodesy.','EPSG','1066','Time-specific Coordinate Frame rotation (geocen)','EPSG','4922','EPSG','7677','EPSG','1262',0.17,-1.07,-0.03,0.02,'EPSG','9001',0.0,0.0,-130.0,'EPSG','1031',-0.22,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2002.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'MTD-Rus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7703','PZ-90.02 to PZ-90.11 (1)','','Geodesy.','EPSG','1066','Time-specific Coordinate Frame rotation (geocen)','EPSG','7677','EPSG','7679','EPSG','1262',0.07,-0.373,0.186,0.202,'EPSG','9001',-2.3,3.54,-4.21,'EPSG','1031',-0.008,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'MTD-Rus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7704','PZ-90 to PZ-90.11 (1)','Concatenation of transformations 7702 and 7703.','Geodesy.','EPSG','1032','Coordinate Frame rotation (geocentric domain)','EPSG','4922','EPSG','7679','EPSG','1262',0.2,-1.443,0.156,0.222,'EPSG','9001',-2.3,3.54,-134.21,'EPSG','1031',-0.228,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'MTD-Rus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7705','GSK-2011 to PZ-90.11 (1)','','Geodesy.','EPSG','1066','Time-specific Coordinate Frame rotation (geocen)','EPSG','7681','EPSG','7679','EPSG','1198',0.03,0.0,0.014,-0.008,'EPSG','9001',-0.562,-0.019,0.053,'EPSG','1031',-0.0006,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2011.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'MTD-Rus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7720','CGRS93 to ETRS89 (1)','Derived at 6 points at epoch 1993.1. May be taken as approximate transformation CGRS93 to WGS 84 - see code 7721.','Small scale hydrographic and aviation mapping.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','6311','EPSG','4258','EPSG','3236',0.1,8.846,-4.394,-1.122,'EPSG','9001',0.00237,0.146528,-0.130428,'EPSG','9104',0.783926,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DLS-Cyp',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7721','CGRS93 to WGS 84 (1)','Parameter values from CGRS93 to ETRS89 (1) (code 7720). Approximation at the +/- 1m level assuming that ETRS89 is equivalent to WGS 84.','Small scale hydrographic and aviation  mapping.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','6311','EPSG','4326','EPSG','3236',1.0,8.846,-4.394,-1.122,'EPSG','9001',0.00237,0.146528,-0.130428,'EPSG','9104',0.783926,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Cyp',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7790','ITRF2008 to ITRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Estimated using 127 stations at 125 sites.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','5332','EPSG','7789','EPSG','1262',0.01,-1.6,-1.9,-2.4,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.02,'EPSG','1028',0.0,0.0,0.1,'EPSG','1027',0.0,0.0,0.0,'EPSG','1032',-0.03,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7806','Pulkovo 1942(83) to BGS2005 (1)','Older CRSs (CS30, CS50, CS70) must first be transformed to Pulkovo 1942(83) before this transformation is applied.','Official transformation for converting existing geodetic and cartographic materials to BGS2005.','EPSG','1063','Molodensky-Badekas (PV geog2D domain)','EPSG','4178','EPSG','7798','EPSG','3224',5.0,5.0,-133.0,-104.0,'EPSG','9001',-1.4,-2.0,3.4,'EPSG','9104',-3.9901,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,4223032.0,2032778.0,4309209.0,'EPSG','9001','RD-Bul',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7807','ITRF2008 to NAD83(2011) (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Joint derivation by Canada and US (tfm 6864) concatenated with IGS value for ITRF96>97 and IERS ITRF97>2008 transformations. See tfm 8264 for Canadian equivalent.','Geodesy.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','5332','EPSG','6317','EPSG','1511',0.0,0.99343,-1.90331,-0.52655,'EPSG','9001',25.91467,9.42645,11.59935,'EPSG','1031',1.71504,'EPSG','1028',0.00079,-0.0006,-0.00134,'EPSG','1042',0.06667,-0.75744,-0.05133,'EPSG','1032',-0.10201,'EPSG','1030',1997.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'NGS-NA',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7808','ITRF2008 to NAD83(PA11) (1)','Information source gives IGS08 as source CRS: for most practical purposes IGS08 is equivalent to ITRF2008.','Geodesy.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','5332','EPSG','6320','EPSG','4162',0.0,0.908,-2.0161,-0.5653,'EPSG','9001',27.741,13.469,2.712,'EPSG','1031',1.1,'EPSG','1028',0.0001,0.0001,-0.0018,'EPSG','1042',-0.384,1.007,-2.186,'EPSG','1032',0.08,'EPSG','1030',1997.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'NGS-PA',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7809','ITRF2008 to NAD83(MA11) (1)','Information source gives IGS08 as source CRS: for most practical purposes IGS08 is equivalent to ITRF2008.','Geodesy.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','5332','EPSG','6323','EPSG','4167',0.0,0.908,-2.0161,-0.5653,'EPSG','9001',28.971,10.42,8.928,'EPSG','1031',1.1,'EPSG','1028',0.0001,0.0001,-0.0018,'EPSG','1042',-0.02,0.105,-0.347,'EPSG','1032',0.08,'EPSG','1030',1997.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'NGS-MA',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7814','ITRF89 to ITRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4911','EPSG','4919','EPSG','1262',0.01,-2.97,-4.75,7.39,'EPSG','1033',0.0,0.0,0.18,'EPSG','1031',-5.85,'EPSG','1028',0.0,0.06,0.14,'EPSG','1034',0.0,0.0,-0.02,'EPSG','1032',-0.01,'EPSG','1030',1988.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7817','UCS-2000 to ITRF2000 (1)','Derived for epoch 2005.0 at which time it defines UCS-2000 and is therefore exact (accuracy = 0) at this epoch. May be taken as approximate transformation UCS-2000 to WGS 84 - see code 5840.','For applications to an accuracy of 1 metre.','EPSG','1031','Geocentric translations (geocentric domain)','EPSG','5558','EPSG','4919','EPSG','1242',0.0,24.322,-121.372,-75.847,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SSGC-Ukr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7833','Albanian 1987 to ETRS89 (1)','Derived using 90 stations by Military Geographical Institute of Italy (IGM) on behalf of ASIG. mse = 18cm. May be taken as approximate transformation from Albanian 1987 to WGS 84 (see code 7834).','Use only for horizontal coordinates; geoid heights must be calculated with ALBGEO3 software.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4191','EPSG','4258','EPSG','3212',0.2,-44.183,-0.58,-38.489,'EPSG','9001',-2.3867,-2.7072,3.5196,'EPSG','9104',-8.2703,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Alb 2D',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7834','Albanian 1987 to WGS 84 (1)','Parameter values from Albanian 1987 to ETRS89 (1) (code 7833). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','Use only for horizontal coordinates; geoid heights must be calculated with ALBGEO3 software.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4191','EPSG','4326','EPSG','3212',1.0,-44.183,-0.58,-38.489,'EPSG','9001',-2.3867,-2.7072,3.5196,'EPSG','9104',-8.2703,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Alb 2D',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7835','Pulkovo 1942(58) to WGS 84 (22)','Derived by Deminex for nearshore Rodoni block in 1991-1992. Used by Shell for onshore seismic in 1995.','Oil industry exploration and production.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4179','EPSG','4326','EPSG','4446',2.0,74.5,-112.5,-44.3,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Dmnx-Alb',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7836','Pulkovo 1942(58) to Albanian 1987 (1)','Albanian 1987 may be considered to be approximately equivalent to Pulkovo 1942(58) at the +/- 1m level.','Approximation to +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4179','EPSG','4191','EPSG','1025',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Alb',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7892','SHGD2015 to WGS 84 (1)','SHGD2015 is realized by ITRF2008 at epoch 2015.0 and can be considered coincident with WGS 84 at epoch 2015.0 Accuracy 3 cm at 1/1/2015 then degrades by 3 cm/yr from 1/1/2015 depending upon epoch of WGS 84 due to motion of the Nubian Plate','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','7886','EPSG','4326','EPSG','3183',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ENRD-Shn Hel',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7893','Astro DOS 71 to SHGD2015 (1)','Derived at 19 stations, RMS = 12cm. May be used as an approximate transformation to WGS 84 - see code 7894.','Medium Accuracy transformation to St Helena Geodetic Datum 2015.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4710','EPSG','7886','EPSG','3183',0.15,-323.65,551.39,-491.22,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ENRD-Shn Hel 0.15m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7894','Astro DOS 71 to WGS 84 (2)','Parameter values from Astro DOS 71 to SHGD2015 (1) (tfm code 7893). Assumes SHGD2015 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications requiring an accuracy of better than 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4710','EPSG','4326','EPSG','3183',1.0,-323.65,551.39,-491.22,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ENRD-Shn Hel',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7895','Astro DOS 71 to SHGD2015 (2)','Derived at 19 stations, RMS = 6cm. Note: Because of the large rotations about the Y- and Z-axes this transformation is not reversible. For the reverse transformation use SHGD2015 to Astro DOS 71 (2) (code 7896).','High Accuracy transformation to St Helena Geodetic Datum 2015. Not reversible - see remarks.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4710','EPSG','7886','EPSG','3183',0.1,-112.854,12.27,-18.913,'EPSG','9001',2.1692,16.8896,17.1961,'EPSG','9104',-19.54517,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ENRD-Shn Hel 0.1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7896','SHGD2015 to Astro DOS 71 (2)','Derived at 19 stations, RMS = 6cm. Note: Because of the large rotations about the Y- and Z-axes this transformation is not reversible. For the reverse transformation use Astro DOS 71 to SHGD2015 (2) (code 7895).','High Accuracy transformation from St Helena Geodetic Datum 2015. Not reversible - see remarks.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4710','EPSG','4710','EPSG','3183',0.1,112.771,-12.282,18.935,'EPSG','9001',-2.1692,-16.8896,-17.1961,'EPSG','9104',19.54517,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ENRD-Shn Hel 0.1m Rev',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7897','St. Helena Tritan to SHGD2015 (1)','Derived at 19 stations, RMS = 5cm. May be used as an approximate transformation to WGS 84 - see code 7898.','High Accuracy transformation to St Helena Geodetic Datum 2015.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','7881','EPSG','7886','EPSG','3183',0.05,-0.077,0.079,0.086,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ENRD-Shn Hel',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7898','St. Helena Tritan to WGS 84 (1)','Parameter values from Tritan St. Helena to SHGD2015 (1) (tfm code 7897). Assumes Tritan St. Helena and SHGD2015 can be considered the same to within the accuracy of the transformation.','For applications requiring an accuracy of better than 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','7881','EPSG','4326','EPSG','3183',1.0,-0.077,0.079,0.086,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ENRD-Shn Hel',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7932','ITRF89 to ETRF89 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Definition of ETRF89.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4911','EPSG','7914','EPSG','1298',0.0,0.0,0.0,0.0,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1034',0.11,0.57,-0.71,'EPSG','1032',0.0,'EPSG','1030',1989.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7933','ITRF90 to ETRF90 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Definition of ETRF90.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4912','EPSG','7916','EPSG','1298',0.0,1.9,2.8,-2.3,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1034',0.11,0.57,-0.71,'EPSG','1032',0.0,'EPSG','1030',1989.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7934','ITRF91 to ETRF91 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Definition of ETRF91.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4913','EPSG','7918','EPSG','1298',0.0,2.1,2.5,-3.7,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1034',0.21,0.52,-0.68,'EPSG','1032',0.0,'EPSG','1030',1989.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7935','ITRF92 to ETRF92 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Definition of ETRF92.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4914','EPSG','7920','EPSG','1298',0.0,3.8,4.0,-3.7,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1034',0.21,0.52,-0.68,'EPSG','1032',0.0,'EPSG','1030',1989.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7936','ITRF93 to ETRF93 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Definition of ETRF93.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4915','EPSG','7922','EPSG','1298',0.0,1.9,5.3,-2.1,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1034',0.32,0.78,-0.67,'EPSG','1032',0.0,'EPSG','1030',1989.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7937','ITRF94 to ETRF94 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Definition of ETRF94.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4916','EPSG','7924','EPSG','1298',0.0,4.1,4.1,-4.9,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1034',0.2,0.5,-0.65,'EPSG','1032',0.0,'EPSG','1030',1989.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7938','ITRF96 to ETRF96 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Definition of ETRF96.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4917','EPSG','7926','EPSG','1298',0.0,4.1,4.1,-4.9,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1034',0.2,0.5,-0.65,'EPSG','1032',0.0,'EPSG','1030',1989.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7939','ITRF97 to ETRF97 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Definition of ETRF97.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4918','EPSG','7928','EPSG','1298',0.0,4.1,4.1,-4.9,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1034',0.2,0.5,-0.65,'EPSG','1032',0.0,'EPSG','1030',1989.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7940','ITRF2000 to ETRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. See ITRF2000 to ETRF2000 (2) (code 7941) for an exactly equivalent transformation but with the transformation''s parameter values at epoch 2000.00.','Definition of ETRF2000.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4919','EPSG','7930','EPSG','1298',0.0,5.4,5.1,-4.8,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1034',0.081,0.49,-0.792,'EPSG','1032',0.0,'EPSG','1030',1989.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7941','ITRF2000 to ETRF2000 (2)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. See ITRF2000 to ETRF2000 (1) (code 7940) for transformation which defines ETRF2000. 7941 is equivalent but with the transformation''s parameters at epoch 2000.00.','Realization of ETRS89 from ITRF2000 through ETRF2000.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4919','EPSG','7930','EPSG','1298',0.0,54.0,51.0,-48.0,'EPSG','1025',0.891,5.39,-8.712,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1027',0.081,0.49,-0.792,'EPSG','1032',0.0,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7942','ITRF89 to ETRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF89 through ETRF2000.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4911','EPSG','7930','EPSG','1298',0.0,24.3,10.7,42.7,'EPSG','1025',0.891,5.39,-8.772,'EPSG','1031',-5.97,'EPSG','1028',0.0,0.6,1.4,'EPSG','1027',0.081,0.49,-0.812,'EPSG','1032',-0.01,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7943','ITRF90 to ETRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF90 through ETRF2000.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4912','EPSG','7930','EPSG','1298',0.0,29.3,34.7,4.7,'EPSG','1025',0.891,5.39,-8.772,'EPSG','1031',-2.57,'EPSG','1028',0.0,0.6,1.4,'EPSG','1027',0.081,0.49,-0.812,'EPSG','1032',-0.01,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7944','ITRF91 to ETRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF91 through ETRF2000.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4913','EPSG','7930','EPSG','1298',0.0,27.3,30.7,-11.3,'EPSG','1025',0.891,5.39,-8.772,'EPSG','1031',-2.27,'EPSG','1028',0.0,0.6,1.4,'EPSG','1027',0.081,0.49,-0.812,'EPSG','1032',-0.01,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7945','ITRF92 to ETRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF92 through ETRF2000.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4914','EPSG','7930','EPSG','1298',0.0,39.3,44.7,-17.3,'EPSG','1025',0.891,5.39,-8.772,'EPSG','1031',-0.87,'EPSG','1028',0.0,0.6,1.4,'EPSG','1027',0.081,0.49,-0.812,'EPSG','1032',-0.01,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7946','ITRF93 to ETRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF93 through ETRF2000.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4915','EPSG','7930','EPSG','1298',0.0,76.1,46.9,-19.9,'EPSG','1025',2.601,6.87,-8.412,'EPSG','1031',-2.07,'EPSG','1028',2.9,0.2,0.6,'EPSG','1027',0.191,0.68,-0.862,'EPSG','1032',-0.01,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7947','ITRF94 to ETRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF94 through ETRF2000.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4916','EPSG','7930','EPSG','1298',0.0,47.3,46.7,-25.3,'EPSG','1025',0.891,5.39,-8.772,'EPSG','1031',-1.58,'EPSG','1028',0.0,0.6,1.4,'EPSG','1027',0.081,0.49,-0.812,'EPSG','1032',-0.01,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7948','ITRF96 to ETRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF96 through ETRF2000.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4917','EPSG','7930','EPSG','1298',0.0,47.3,46.7,-25.3,'EPSG','1025',0.891,5.39,-8.772,'EPSG','1031',-1.58,'EPSG','1028',0.0,0.6,1.4,'EPSG','1027',0.081,0.49,-0.812,'EPSG','1032',-0.01,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7949','ITRF97 to ETRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF97 through ETRF2000.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4918','EPSG','7930','EPSG','1298',0.0,47.3,46.7,-25.3,'EPSG','1025',0.891,5.39,-8.772,'EPSG','1031',-1.58,'EPSG','1028',0.0,0.6,1.4,'EPSG','1027',0.081,0.49,-0.812,'EPSG','1032',-0.01,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7950','ITRF2005 to ETRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF2005 through ETRF2000.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4896','EPSG','7930','EPSG','1298',0.0,54.1,50.2,-53.8,'EPSG','1025',0.891,5.39,-8.712,'EPSG','1031',0.4,'EPSG','1028',-0.2,0.1,-1.8,'EPSG','1027',0.081,0.49,-0.792,'EPSG','1032',0.08,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7951','ITRF2008 to ETRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF2008 through ETRF2000.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','5332','EPSG','7930','EPSG','1298',0.0,52.1,49.3,-58.5,'EPSG','1025',0.891,5.39,-8.712,'EPSG','1031',1.34,'EPSG','1028',0.1,0.1,-1.8,'EPSG','1027',0.081,0.49,-0.792,'EPSG','1032',0.08,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7960','PZ-90.11 to ITRF2008 (1)','','Geodesy.','EPSG','1066','Time-specific Coordinate Frame rotation (geocen)','EPSG','7679','EPSG','5332','EPSG','1262',0.004,-0.003,-0.001,0.0,'EPSG','9001',0.019,-0.042,0.002,'EPSG','1031',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'MTD-Rus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','7961','WGS 84 (G1150) to PZ-90.02 (1)','','Geodesy.','EPSG','1066','Time-specific Coordinate Frame rotation (geocen)','EPSG','7660','EPSG','7677','EPSG','1262',0.17,0.36,-0.08,-0.18,'EPSG','9001',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2002.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'MTD-Rus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8048','GDA94 to GDA2020 (1)','Scale difference in ppb where 1/billion = 1E-9. Derivation excluded Cocos, Christmas and Macquarie Islands but is applied there. See codes 8444-46 for equivalents using NTv2 method. See code 8447 for alternative including distortion model for Aus only.','Conformal transformation of GDA94 coordinates that have been derived through GNSS CORS.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4283','EPSG','7844','EPSG','4177',0.01,61.55,-10.87,-40.19,'EPSG','1025',-39.4924,-32.7221,-32.8979,'EPSG','1031',-9.994,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ICSM-Aus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8049','ITRF2014 to GDA2020 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Derived at 109 stations of the Australian Reginal GNSS network (ARGN).','Geodesy. RMS residuals 26mm north, 12mm east and 179mm vertical, maximum residuals 49mm north, 24mm east and 464mm vertical.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','7789','EPSG','7842','EPSG','4177',0.001,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1027',1.50379,1.18346,1.20716,'EPSG','1032',0.0,'EPSG','1030',2020.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'GA-Aus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8069','ITRF88 to ITRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Derived by IERS from previously published information.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4910','EPSG','7789','EPSG','1262',0.01,-25.4,0.5,154.8,'EPSG','1025',-0.1,0.0,-0.26,'EPSG','1031',-11.29,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.0,0.0,-0.02,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8070','ITRF89 to ITRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Derived by IERS from previously published information.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4911','EPSG','7789','EPSG','1262',0.01,-30.4,-35.5,130.8,'EPSG','1025',0.0,0.0,-0.26,'EPSG','1031',-8.19,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.0,0.0,-0.02,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8071','ITRF90 to ITRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Derived by IERS from previously published information.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4912','EPSG','7789','EPSG','1262',0.01,-25.4,-11.5,92.8,'EPSG','1025',0.0,0.0,-0.26,'EPSG','1031',-4.79,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.0,0.0,-0.02,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8072','ITRF91 to ITRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Derived by IERS from previously published information.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4913','EPSG','7789','EPSG','1262',0.01,-27.4,-15.5,76.8,'EPSG','1025',0.0,0.0,-0.26,'EPSG','1031',-4.49,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.0,0.0,-0.02,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8073','ITRF92 to ITRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Derived by IERS from previously published information.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4914','EPSG','7789','EPSG','1262',0.01,-15.4,-1.5,70.8,'EPSG','1025',0.0,0.0,-0.26,'EPSG','1031',-3.09,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.0,0.0,-0.02,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8074','ITRF93 to ITRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Derived by IERS from previously published information.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4915','EPSG','7789','EPSG','1262',0.01,50.4,-3.3,60.2,'EPSG','1025',2.81,3.38,-0.4,'EPSG','1031',-4.29,'EPSG','1028',2.8,0.1,2.5,'EPSG','1027',0.11,0.19,-0.07,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8075','ITRF94 to ITRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Derived by IERS from previously published information.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4916','EPSG','7789','EPSG','1262',0.01,-7.4,0.5,62.8,'EPSG','1025',0.0,0.0,-0.26,'EPSG','1031',-3.8,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.0,0.0,-0.02,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8076','ITRF96 to ITRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Derived by IERS from previously published information.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4917','EPSG','7789','EPSG','1262',0.01,-7.4,0.5,62.8,'EPSG','1025',0.0,0.0,-0.26,'EPSG','1031',-3.8,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.0,0.0,-0.02,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8077','ITRF97 to ITRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Derived by IERS from previously published information.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4918','EPSG','7789','EPSG','1262',0.01,-7.4,0.5,62.8,'EPSG','1025',0.0,0.0,-0.26,'EPSG','1031',-3.8,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.0,0.0,-0.02,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8078','ITRF2000 to ITRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Derived by IERS from previously published information.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4919','EPSG','7789','EPSG','1262',0.01,-0.7,-1.2,26.1,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',-2.12,'EPSG','1028',-0.1,-0.1,1.9,'EPSG','1027',0.0,0.0,0.0,'EPSG','1032',-0.11,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8079','ITRF2005 to ITRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Derived by IERS from previously published information.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4896','EPSG','7789','EPSG','1262',0.01,-2.6,-1.0,2.3,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',-0.92,'EPSG','1028',-0.3,0.0,0.1,'EPSG','1027',0.0,0.0,0.0,'EPSG','1032',-0.03,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8256','ITRF92 to NAD83(CSRS96) (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Superseded by tfm from ITRF93 (see code 8257).','Geodesy. Initial definition of NAD83(CSRS96) and is therefore treated as errorless.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4914','EPSG','8230','EPSG','1061',0.0,0.936,-1.984,-0.543,'EPSG','9001',-27.5,-15.5,-10.7,'EPSG','1031',5.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1042',-0.052,0.742,0.032,'EPSG','1032',0.0,'EPSG','1030',1988.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'NRC-Can CSRS96 92',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8257','ITRF93 to NAD83(CSRS96) (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Superseded by tfm from ITRF94 (see code 8258).','Geodesy. Updates definition of NAD83(CSRS96) and is therefore treated as errorless.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4915','EPSG','8230','EPSG','1061',0.0,0.94,-1.979,-0.534,'EPSG','9001',-27.09,-16.22,-9.87,'EPSG','1031',4.1,'EPSG','1028',0.0023,0.0004,-0.0008,'EPSG','1042',0.078,0.962,-0.008,'EPSG','1032',0.11,'EPSG','1030',1988.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'NRC-Can CSRS96 93',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8258','ITRF94 to NAD83(CSRS96) (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy. Further updates definition of NAD83(CSRS96) and is therefore treated as errorless.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4916','EPSG','8230','EPSG','1061',0.0,0.942,-1.979,-0.534,'EPSG','9001',-27.3,-15.4,-10.7,'EPSG','1031',4.9,'EPSG','1028',-0.0004,0.0004,-0.0008,'EPSG','1042',-0.052,0.762,0.032,'EPSG','1032',0.0,'EPSG','1030',1988.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'NRC-Can CSRS96 94',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8259','ITRF96 to NAD83(CSRS)v2 (1)','Jointly derived by Canada and US at 12 North American VLBI stations. Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. See tfm code 6864 for US equivalent.','Geodesy. Defines NAD83(CSRS98) = NAD83(CSRS)v2 and is therefore treated as errorless.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4917','EPSG','8233','EPSG','1061',0.0,0.991,-1.9072,-0.5129,'EPSG','9001',-25.79,-9.65,-11.66,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1042',-0.0532,0.7423,0.0316,'EPSG','1032',0.0,'EPSG','1030',1997.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'NRC-Can CSRSv2',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8260','ITRF97 to NAD83(CSRS)v3 (1)','Concatenation of joint Canada-US transformation NAD83>ITRF96 (see tfm code 8259) and IGS value for ITRF96>ITRF97 transformation. Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. See tfm 6865 for US equivalent.','Geodesy. Defines NAD83(CSRS)v3 and is therefore treated as errorless.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4918','EPSG','8238','EPSG','1061',0.0,0.9889,-1.9074,-0.503,'EPSG','9001',-25.915,-9.426,-11.599,'EPSG','1031',-0.935,'EPSG','1028',0.0007,-0.0001,0.0019,'EPSG','1042',-0.067,0.757,0.031,'EPSG','1032',-0.192,'EPSG','1030',1997.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'NRC-Can CSRSv3',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8261','ITRF2000 to NAD83(CSRS)v4 (1)','Concatenation of joint Canada-US NAD83>ITRF96 tfm (code 8259) with IGS value of ITRF96>ITRF97 and IERS tfm ITRF97>ITRF2000. Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. See tfm code 6866 for US equivalent.','Geodesy. Defines NAD83(CSRS)v4 and is therefore treated as errorless.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4919','EPSG','8242','EPSG','1061',0.0,0.9956,-1.9013,-0.5214,'EPSG','9001',-25.915,-9.426,-11.599,'EPSG','1031',0.615,'EPSG','1028',0.0007,-0.0007,0.0005,'EPSG','1042',-0.067,0.757,0.051,'EPSG','1032',-0.182,'EPSG','1030',1997.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'NRC-Can CSRSv4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8262','ITRF2005 to NAD83(CSRS)v5 (1)','Concatenation of joint Canada-US NAD83>ITRF96 transformation (code 8259) with IGS value for ITRF96>ITRF97 and IERS transformations ITRF97>ITRF2005. Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy. Defines NAD83(CSRS)v5 and is therefore treated as errorless.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4896','EPSG','8248','EPSG','1061',0.0,0.9963,-1.9024,-0.5219,'EPSG','9001',-25.915,-9.426,-11.599,'EPSG','1031',0.775,'EPSG','1028',0.0005,-0.0006,-0.0013,'EPSG','1042',-0.067,0.757,0.051,'EPSG','1032',-0.102,'EPSG','1030',1997.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'NRC-Can CSRSv5',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8264','ITRF2008 to NAD83(CSRS)v6 (1)','Concatenation of joint Canada-US transformation NAD83>ITRF96 (code 8259) with IGS tfm ITRF96>97 and IERS tfms ITRF97>2008. Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. See tfm code 7807 for US equivalent.','Geodesy. Defines NAD83(CSRS)v6 and is therefore treated as errorless.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','5332','EPSG','8250','EPSG','1061',0.0,0.99343,-1.90331,-0.52655,'EPSG','9001',-25.91467,-9.42645,-11.59935,'EPSG','1031',1.71504,'EPSG','1028',0.00079,-0.0006,-0.00134,'EPSG','1042',-0.06667,0.75744,0.05133,'EPSG','1032',-0.102,'EPSG','1030',1997.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'NRC-Can CSRSv6',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8265','ITRF2014 to NAD83(CSRS)v7 (1)','Concatenation of joint Canada-US tfm NAD83>ITRF96 (see tfm code 8259) with IGS value for ITRF96>ITRF97 and IERS values for ITRF97>ITRF2014 transformations. Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy. Defines NAD83(CSRS)v7 and is therefore treated as errorless.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','7789','EPSG','8253','EPSG','1061',0.0,1.0053,-1.9092,-0.5416,'EPSG','9001',-26.7814,0.4203,-10.9321,'EPSG','1031',0.37,'EPSG','1028',0.0008,-0.0006,-0.0014,'EPSG','1042',-0.0667,0.7574,0.0513,'EPSG','1032',-0.07,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'NRC-Can CSRSv7',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8270','Saint Pierre et Miquelon 1950 to WGS 84 (2)','Replaces Saint Pierre et Miquelon 1950 to WGS 84 (1) (code 1923) from March 2006.','Accuracy +/- 0.5 to 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4638','EPSG','4326','EPSG','3299',1.0,11.363,424.148,373.13,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Spm 2017',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8365','ETRS89 to S-JTSK [JTSK03] (1)','Derived at 684 points with known S-JTSK and ETRS89 (ETRF2000 realization) coordinates. Scale parameter was constrained to be zero. UGKK consider this transformation to not be reversible at the 1mm accuracy level: for reverse see transformation code 8367.','Defines the S-JTSK [JTSK03] realization.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4258','EPSG','8351','EPSG','1211',0.001,-485.014055,-169.473618,-483.842943,'EPSG','9001',7.78625453,4.39770887,4.10248899,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UGKK-Svk',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8366','ITRF2014 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. See ITRF2014 to ETRF2014 (2) (code 8407) for an exactly equivalent transformation but with the transformation''s parameter values at epoch 2010.00.','Definition of ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','7789','EPSG','8401','EPSG','1298',0.0,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1027',0.085,0.531,-0.77,'EPSG','1032',0.0,'EPSG','1030',1989.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8367','S-JTSK [JTSK03] to ETRS89 (1)','Derived at 684 points. At the 1mm accuracy level this transformation is not reversible: for reverse see transformation code 8365. May be taken as approximate transformation to WGS 84 - see code 8368.','Geodesy to 1mm accuracy if ETRS89 coordinates are in ETRF2000 reference frame. (Accuracy is reduced if the coordinates are in other ETRF reference frames).','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','8351','EPSG','4258','EPSG','1211',0.001,485.021,169.465,483.839,'EPSG','9001',-7.786342,-4.397554,-4.102655,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UGKK-Svk',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8368','S-JTSK [JTSK03] to WGS 84 (1)','Parameter values taken from S-JTSK [JTSK03] to ETRS89 (1) (code 8367) assuming that ETRS89 (ETRF2000 realization) is coincident with WGS 84 within the accuracy of the transformation. Within the 1m accuracy of this transformation, it is reversible.','Approximation at the +/- 1m level.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','8351','EPSG','4326','EPSG','1211',1.0,485.021,169.465,483.839,'EPSG','9001',-7.786342,-4.397554,-4.102655,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UGKK-Svk',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8393','Camacupa to WGS 84 (11)','Derived by Univ. of Lisbon for IGCA using 38 REPANGOL points in Angola (except SE) and Cabinda. Application differs from Camacupa to WGS 84 (1) to (10) by approx 25 m. Average horizontal error 1m, vertical 3m; max radial error 6m.  For onshore use only.','Onshore use only.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4220','EPSG','4326','EPSG','4469',3.0,-93.799,-132.737,-219.073,'EPSG','9001',1.844,-0.648,6.37,'EPSG','9104',-0.169,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGCA-Ago',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','8405','ITRF2014 to ETRF2000 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF2014 through ETRF2000.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','7789','EPSG','7930','EPSG','1298',0.0,54.7,52.2,-74.1,'EPSG','1025',1.701,10.29,-16.632,'EPSG','1031',2.12,'EPSG','1028',0.1,0.1,-1.9,'EPSG','1027',0.081,0.49,-0.792,'EPSG','1032',0.11,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8407','ITRF2014 to ETRF2014 (2)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9. See ITRF2014 to ETRF2014 (1) (code 8366) for transformation which defines ETRF2014. Transformation 8407 is equivalent to 8366 but with parameter values at epoch 2010.00.','Realization of ETRS89 from ITRF2014 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','7789','EPSG','7930','EPSG','1298',0.0,0.0,0.0,0.0,'EPSG','1025',1.785,11.151,-16.17,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1027',0.085,0.531,-0.77,'EPSG','1032',0.0,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','8409','ITRF2008 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF2008 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','5332','EPSG','7789','EPSG','1298',0.0,-1.6,-1.9,-2.4,'EPSG','1025',1.785,11.151,-16.17,'EPSG','1031',0.02,'EPSG','1028',0.0,0.0,0.1,'EPSG','1027',0.085,0.531,-0.77,'EPSG','1032',-0.03,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','8410','ITRF2005 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF2005 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4896','EPSG','7789','EPSG','1298',0.0,-2.6,-1.0,-2.3,'EPSG','1025',1.785,11.151,-16.17,'EPSG','1031',-0.92,'EPSG','1028',-0.3,0.0,0.1,'EPSG','1027',0.085,0.531,-0.77,'EPSG','1032',-0.03,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','8411','ITRF2000 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF2000 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4919','EPSG','7789','EPSG','1298',0.0,-0.7,-1.2,26.1,'EPSG','1025',1.785,11.151,-16.17,'EPSG','1031',-2.12,'EPSG','1028',-0.1,-0.1,1.9,'EPSG','1027',0.085,0.531,-0.77,'EPSG','1032',-0.11,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','8412','ITRF97 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF97 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4918','EPSG','7789','EPSG','1298',0.0,-7.4,0.5,62.8,'EPSG','1025',1.785,11.151,-16.43,'EPSG','1031',-3.8,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.085,0.531,-0.79,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','8413','ITRF96 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF96 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4917','EPSG','7789','EPSG','1298',0.0,-7.4,0.5,62.8,'EPSG','1025',1.785,11.151,-16.43,'EPSG','1031',-3.8,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.085,0.531,-0.79,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','8414','ITRF94 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF94 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4916','EPSG','7789','EPSG','1298',0.0,-7.4,0.5,62.8,'EPSG','1025',1.785,11.151,-16.43,'EPSG','1031',-3.8,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.085,0.531,-0.79,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','8415','ITRF93 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF93 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4915','EPSG','7789','EPSG','1298',0.0,50.4,-3.3,60.2,'EPSG','1025',4.595,14.531,-16.57,'EPSG','1031',-4.29,'EPSG','1028',2.8,0.1,2.5,'EPSG','1027',0.195,0.721,-0.84,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','8416','ITRF92 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF92 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4914','EPSG','7789','EPSG','1298',0.0,-15.4,-1.5,70.8,'EPSG','1025',1.785,11.151,-16.43,'EPSG','1031',-3.09,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.085,0.531,-0.79,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','8417','ITRF91 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF91 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4913','EPSG','7789','EPSG','1298',0.0,-27.4,-15.5,76.8,'EPSG','1025',1.785,11.151,-16.43,'EPSG','1031',-4.49,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.085,0.531,-0.79,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','8423','ITRF90 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF90 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4912','EPSG','7789','EPSG','1298',0.0,-25.4,-11.5,92.8,'EPSG','1025',1.785,11.151,-16.43,'EPSG','1031',-4.79,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.085,0.531,-0.79,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','8424','ITRF89 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF89 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4911','EPSG','7789','EPSG','1298',0.0,-30.4,-35.5,130.8,'EPSG','1025',1.785,11.151,-16.43,'EPSG','1031',-8.19,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.085,0.531,-0.79,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','8435','Macao 2008 to Macao 1920 (1)','Derived at 3 stations in 2008. Accuracy not stated.','Transformation of GNSS coordinates to Macao Grid.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','8431','EPSG','8428','EPSG','1147',999.0,202.865,303.99,155.873,'EPSG','9001',34.067,-76.126,-32.647,'EPSG','9104',-6.096,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,-2361757.652,5417232.187,2391453.053,'EPSG','9001','DSCC-Mac',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8436','Macao 2008 to WGS 84 (1)','Approximation at the +/- 1m level assuming that Macao 2008 is equivalent to WGS 84.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','8431','EPSG','4326','EPSG','1147',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Bmu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8437','Hong Kong 1980 to Hong Kong Geodetic CS (1)','Also published as a transformation to WGS 84 using the position vector method - see Hong Kong 1980 to WGS 84 (1) (code 1825).','1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4611','EPSG','8427','EPSG','1118',1.0,-162.619,-276.961,-161.763,'EPSG','9001',0.067741,-2.243649,-1.158827,'EPSG','9104',-1.094239,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'LSD-HKG 2002',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8438','Macao 1920 to WGS 84 (1)','Derived from Macao 2008 to Macao 1920 (1) (code 8435) (reversed) assuming that Macao 2008 is equivalent to WGS 84 within the accuracy of the transformation. Some parameter values differ in the reverse due to the high rotations.','Transformation of GNSS coordinates to Macao Grid.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','8428','EPSG','4326','EPSG','1147',1.0,-202.865,-303.99,-155.873,'EPSG','9001',-34.079,76.126,32.66,'EPSG','9104',6.096,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,-2361554.788,5417536.177,2391608.926,'EPSG','9001','EPSG-Mac',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8439','Hong Kong Geodetic CS to WGS 84 (1)','Approximation at the +/- 1m level assuming that Hong Kong Geodetic CS is equivalent to WGS 84.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','8427','EPSG','4326','EPSG','1118',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Hkg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8448','GDA2020 to WGS 84 (G1762) (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Parameter values taken from ITRF2014 to GDA2020 (1) (code 8049), assuming WGS 84 (G1762) is equivalent to ITRF2014 within the accuracy of the transformation.','Spatial referencing.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','7842','EPSG','7664','EPSG','4177',0.2,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1027',-1.50379,-1.18346,-1.20716,'EPSG','1032',0.0,'EPSG','1030',2020.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'GA-Aus 0.2m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8450','GDA2020 to WGS 84 (2)','Approximation at the 3m level assuming WGS 84 is equivalent to ITRF2014 within the accuracy of the transformation. See GDA2020 to WGS 84 (G1762) (1) (code 8448) for a better approximation and ITRF2014 to GDA2020 (1) (code 8049) for actual relationship.','Spatial referencing with 3-metre accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','7844','EPSG','4326','EPSG','4177',3.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GA-Aus 3m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8452','Padang to WGS 84 (1)','Note: U.S. Defense Mapping Agency TR8350.2 September 1987 gives source CRS as Batavia and area as Sumatra. The Batavia (Genuk) CRS applies to Java, not Sumatra. EPSG presumes the source CRS should be Padang. Derived at 5 stations.','For military purposes. Accuracy 3m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4280','EPSG','4326','EPSG','1355',6.0,-377.0,681.0,-50.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Idn Sumatra',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8674','La Canoa to PSAD56 (1)','In Venezuela PSAD56 is coincident with La Canoa.','Spatial referencing.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4247','EPSG','4248','EPSG','3327',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'LAG-Ven E',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8680','MGI 1901 to ETRS89 (7)','Derived at 1385 points across the area of Bosnia and Herzegovina. May be taken as approximate transformation MGI 1901 to WGS 84 (see code 8823).','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','3906','EPSG','4258','EPSG','1050',1.0,489.88,183.912,533.711,'EPSG','9001',5.76545,4.69994,-12.58211,'EPSG','9104',1.00646,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'FGA-Bih',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8681','MGI 1901 to WGS 84 (12)','Parameter values from MGI 1901 to ETRS89 (7) (code 8680). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','3906','EPSG','4258','EPSG','1050',1.0,489.88,183.912,533.711,'EPSG','9001',5.76545,4.69994,-12.58211,'EPSG','9104',1.00646,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'FGA-Bih',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','8688','MGI 1901 to WGS 84 (12)','Parameter values from MGI to Slovenia 1996 (12) (tfm code 8689) assuming Slovenia 1996 and WGS 84 can be considered the same to within the accuracy of the transformation.','1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4326','EPSG','3307',1.0,476.08,125.947,417.81,'EPSG','9001',-4.610862,-2.388137,11.942335,'EPSG','9104',9.896638,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn 2010',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8689','MGI 1901 to Slovenia 1996 (12)','Derived at 479 nodes of Delauney triangulation generated from 1958 control points. Replaces MGI 1901 to Slovenia 1996 (1) (code 3916). May be taken as approximate transformation MGI 1901 to WGS 84 (see code 8688).','1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4765','EPSG','3307',1.0,476.08,125.947,417.81,'EPSG','9001',-4.610862,-2.388137,11.942335,'EPSG','9104',9.896638,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn 2010',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8695','Camacupa 1948 to Camacupa 2015 (1)','Concatenation of transformations 1327 and 8882.','Geodesy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4220','EPSG','8694','EPSG','2324',5.8,42.899,-214.863,-11.927,'EPSG','9001',-1.844,0.648,-6.37,'EPSG','9104',0.169,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Ago',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8696','Camacupa 1948 to Camacupa 2015 (2)','Concatenation of transformations 1324 and 8882.','Geodesy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4220','EPSG','8694','EPSG','2322',4.2,45.799,-212.263,-11.927,'EPSG','9001',-1.844,0.648,-6.37,'EPSG','9104',0.169,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Ago B15',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8819','RSAO13 to WGS 84 (1)','Approximation at the +/- 1m level assuming that RSAO13 is equivalent to WGS 84within the accuracy of the transformation.','Approximation at the 1m level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','8699','EPSG','4326','EPSG','1029',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Ago',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8822','MTRF-2000 to WGS 84 (1)','Approximation at the +/- 1m level assuming that MTRF-2000 (ITRF2000 at epoch 2004.00) is equivalent to WGS 84.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','8818','EPSG','4326','EPSG','1206',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Sau',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8823','MGI 1901 to WGS 84 (13)','Parameter values from MGI 1901 to ETRS89 (7) (code 8680). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','3906','EPSG','4326','EPSG','1050',1.0,489.88,183.912,533.711,'EPSG','9001',5.76545,4.69994,-12.58211,'EPSG','9104',1.00646,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'FGA-Bih',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8824','Ain el Abd to MTRF-2000 (1)','Accuracy given as ''several metres''. More precise national cellular transformation parameters were also determined. Software coded for these cellular transformations is available in MOMRA.','National transformation parameters.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4204','EPSG','8818','EPSG','3303',5.0,-61.15,-315.86,-3.51,'EPSG','9001',0.41,0.74,-3.52,'EPSG','9104',1.36,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'MOMRA-Sau',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8827','Camacupa 2015 to RSAO13 (1)','Derived by Univ. of Lisbon for CIDDEMA using 38 REPANGOL points in Angola (except SE) and Cabinda. Average horizontal error 1m, vertical 3m; max radial error 6m.','Demarcation of Angola EEZ.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','8694','EPSG','8699','EPSG','1029',3.0,-93.799,-132.737,-219.073,'EPSG','9001',1.844,-0.648,6.37,'EPSG','9104',-0.169,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CIDDEMA-Ago',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8828','RGPF to WGS 84 (1)','SHOM report gives scale difference as 0.999 999 9907 (wrt unity). Transformation is to original Transit definition of WGS 84. It is consistent with later WGS 84 realisations G730, G873 and G1150 to no better than 1m.','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4687','EPSG','4326','EPSG','1098',0.5,0.072,-0.507,-0.245,'EPSG','9001',0.0183,-0.0003,0.007,'EPSG','9104',-0.0093,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8829','Tahiti 79 to RGPF (1)','','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4690','EPSG','4687','EPSG','3124',0.5,221.525,152.948,176.768,'EPSG','9001',2.3847,1.3896,0.877,'EPSG','9104',11.4741,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8830','Tahiti 79 to WGS 84 (2)','Concatenation of Tahiti 79 to RGPF (1) and RGPF to WGS 84 (1) (CT codes 8829 and 8828).','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4690','EPSG','4326','EPSG','3124',1.0,221.597,152.441,176.523,'EPSG','9001',2.403,1.3893,0.884,'EPSG','9104',11.4648,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8831','Moorea 87 to RGPF (2)','Recalculated in 2009 using corrected coordinates of deriving stations.','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4691','EPSG','4687','EPSG','3125',0.5,218.697,151.257,176.995,'EPSG','9001',3.5048,2.004,1.281,'EPSG','9104',10.991,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8832','Moorea 87 to WGS 84 (2)','Concatenation of Moorea 87 to RGPF (2) and RGPF to WGS 84 (1) (CT codes 8831 and 8828).','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4691','EPSG','4326','EPSG','3125',1.0,218.769,150.75,176.75,'EPSG','9001',3.5231,2.0037,1.288,'EPSG','9104',10.9817,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8833','Tahaa 54 to RGPF (1)','','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4629','EPSG','4687','EPSG','2812',0.5,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8834','Tahaa 54 to WGS 84 (3)','Concatenation of Tahaa 54 to RGPF (1) and RGPF to WGS 84 (1) (CT codes 8833 and 8828).','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4629','EPSG','4326','EPSG','2812',1.0,72.51,345.411,79.241,'EPSG','9001',-1.5862,-0.8826,-0.5495,'EPSG','9104',1.3653,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8835','Fatu Iva 72 to RGPF (1)','','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4688','EPSG','4687','EPSG','3133',2.0,347.103,1078.125,2623.922,'EPSG','9001',33.8875,-70.6773,9.3943,'EPSG','9104',186.074,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8842','Fatu Iva 72 to WGS 84 (2)','Concatenation of Fatu Iva 72 to RGPF (1) and RGPF to WGS 84 (1) (CT codes 8835 and 8828).','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4688','EPSG','4326','EPSG','3133',2.0,347.175,1077.618,2623.677,'EPSG','9001',33.9058,-70.6776,9.4013,'EPSG','9104',186.0647,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8843','IGN63 Hiva Oa to RGPF (1)','','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4689','EPSG','4687','EPSG','3131',0.5,410.721,55.049,80.746,'EPSG','9001',-2.5779,-2.3514,-0.6664,'EPSG','9104',17.3311,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf HivaOa',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8844','IGN63 Hiva Oa to WGS 84 (3)','Concatenation of IGN63 Hiva Oa to RGPF (1) and RGPF to WGS 84 (1) (CT codes 8843 and 8828).','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4689','EPSG','4326','EPSG','3131',2.0,410.793,54.542,80.501,'EPSG','9001',-2.5596,-2.3517,-0.6594,'EPSG','9104',17.3218,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf HivaOa',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8845','IGN63 Hiva Oa to RGPF (2)','','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4689','EPSG','4687','EPSG','3132',2.0,374.715,-58.407,-0.957,'EPSG','9001',-16.2111,-11.4626,-5.5357,'EPSG','9104',-0.5409,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf Tahuata',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8846','IGN63 Hiva Oa to WGS 84 (4)','Concatenation of TIGN63 Hiva Oa to RGPF (2) and RGPF to WGS 84 (1) (CT codes 8845 and 8828).','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4689','EPSG','4326','EPSG','3132',2.0,374.787,-58.914,-1.202,'EPSG','9001',-16.1928,-11.4629,-5.5287,'EPSG','9104',-0.5502,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf Tahuata',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8847','IGN72 Nuku Hiva to RGPF (1)','','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4630','EPSG','4687','EPSG','2810',0.5,165.732,216.72,180.505,'EPSG','9001',-0.6434,-0.4512,-0.0791,'EPSG','9104',7.4204,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf NukuHiva',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8848','IGN72 Nuku Hiva to WGS 84 (5)','Concatenation of IGN72 Nuku Hiva to RGPF (1) and RGPF to WGS 84 (1) (CT codes 8847 and 8828).','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4630','EPSG','4326','EPSG','2810',1.0,165.804,216.213,180.26,'EPSG','9001',-0.6251,-0.4515,-0.0721,'EPSG','9104',7.4111,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf NukuHiva',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8849','IGN72 Nuku Hiva to RGPF (2)','','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4630','EPSG','4687','EPSG','3127',2.0,1363.785,1362.687,398.811,'EPSG','9001',-4.5322,-6.7579,-1.0574,'EPSG','9104',268.361,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf UaHuka',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8850','IGN72 Nuku Hiva to WGS 84 (6)','Concatenation of IGN72 Nuku Hiva to RGPF (2) and RGPF to WGS 84 (1) (CT codes 8849 and 8828).','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4630','EPSG','4326','EPSG','3127',2.0,1363.857,1362.18,398.566,'EPSG','9001',-4.5139,-6.7582,-1.0504,'EPSG','9104',268.3517,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf UaHuka',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8851','IGN72 Nuku Hiva to RGPF (3)','','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4630','EPSG','4687','EPSG','3128',0.5,259.551,297.612,197.833,'EPSG','9001',1.4866,2.1224,0.4612,'EPSG','9104',27.0249,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf UaPou',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8852','IGN72 Nuku Hiva to WGS 84 (7)','Concatenation of IGN72 Nuku Hiva to RGPF (3) and RGPF to WGS 84 (1) (CT codes 8851 and 8828).','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4630','EPSG','4326','EPSG','3128',1.0,259.623,297.105,197.588,'EPSG','9001',1.5049,2.1221,0.4682,'EPSG','9104',27.0156,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf UaPou',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8853','Maupiti 83 to WGS 84 (2)','Concatenation of Maupiti 83 to RGPF (1) and RGPF to WGS 84 (1) (CT codes 15759 and 8828).','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4692','EPSG','4326','EPSG','3126',1.0,217.109,86.452,23.711,'EPSG','9001',0.0183,-0.0003,0.007,'EPSG','9104',-0.0093,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'URB-Pyf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8869','ITRF2008 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF2008 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','5332','EPSG','8401','EPSG','1298',0.0,-1.6,-1.9,-2.4,'EPSG','1025',1.785,11.151,-16.17,'EPSG','1031',0.02,'EPSG','1028',0.0,0.0,0.1,'EPSG','1027',0.085,0.531,-0.77,'EPSG','1032',-0.03,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8870','ITRF2005 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF2005 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4896','EPSG','8401','EPSG','1298',0.0,-2.6,-1.0,2.3,'EPSG','1025',1.785,11.151,-16.17,'EPSG','1031',-0.92,'EPSG','1028',-0.3,0.0,0.1,'EPSG','1027',0.085,0.531,-0.77,'EPSG','1032',-0.03,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8871','ITRF2000 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF2000 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4919','EPSG','8401','EPSG','1298',0.0,-0.7,-1.2,26.1,'EPSG','1025',1.785,11.151,-16.17,'EPSG','1031',-2.12,'EPSG','1028',-0.1,-0.1,1.9,'EPSG','1027',0.085,0.531,-0.77,'EPSG','1032',-0.11,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8872','ITRF97 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF97 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4918','EPSG','8401','EPSG','1298',0.0,-7.4,0.5,62.8,'EPSG','1025',1.785,11.151,-16.43,'EPSG','1031',-3.8,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.085,0.531,-0.79,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8873','ITRF96 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF96 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4917','EPSG','8401','EPSG','1298',0.0,-7.4,0.5,62.8,'EPSG','1025',1.785,11.151,-16.43,'EPSG','1031',-3.8,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.085,0.531,-0.79,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8874','ITRF94 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF94 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4916','EPSG','8401','EPSG','1298',0.0,-7.4,0.5,62.8,'EPSG','1025',1.785,11.151,-16.43,'EPSG','1031',-3.8,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.085,0.531,-0.79,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8875','ITRF93 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF93 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4915','EPSG','8401','EPSG','1298',0.0,50.4,-3.3,60.2,'EPSG','1025',4.595,14.531,-16.57,'EPSG','1031',-4.29,'EPSG','1028',2.8,0.1,2.5,'EPSG','1027',0.195,0.721,-0.84,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8876','ITRF92 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF92 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4914','EPSG','8401','EPSG','1298',0.0,-15.4,-1.5,70.8,'EPSG','1025',1.785,11.151,-16.43,'EPSG','1031',-3.09,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.085,0.531,-0.79,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8877','ITRF91 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF91 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4913','EPSG','8401','EPSG','1298',0.0,-27.4,-15.5,76.8,'EPSG','1025',1.785,11.151,-16.43,'EPSG','1031',-4.49,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.085,0.531,-0.79,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8878','ITRF90 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF90 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4912','EPSG','8401','EPSG','1298',0.0,-25.4,-11.5,92.8,'EPSG','1025',1.785,11.151,-16.43,'EPSG','1031',-4.79,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.085,0.531,-0.79,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8879','ITRF89 to ETRF2014 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Realization of ETRS89 from ITRF89 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4911','EPSG','8401','EPSG','1298',0.0,-30.4,-35.5,130.8,'EPSG','1025',1.785,11.151,-16.43,'EPSG','1031',-8.19,'EPSG','1028',-0.1,0.5,3.3,'EPSG','1027',0.085,0.531,-0.79,'EPSG','1032',-0.12,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8880','ITRF2014 to ETRF2014 (2)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9. See ITRF2014 to ETRF2014 (1) (code 8366) for transformation which defines ETRF2014. Transformation 8407 is equivalent to 8366 but with parameter values at epoch 2010.00.','Realization of ETRS89 from ITRF2014 through ETRF2014.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','7789','EPSG','8401','EPSG','1298',0.0,0.0,0.0,0.0,'EPSG','1025',1.785,11.151,-16.17,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1027',0.085,0.531,-0.77,'EPSG','1032',0.0,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'EUREF-Eur 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8882','Camacupa 2015 to WGS 84 (11)','Derived by Univ. of Lisbon for CIDDEMA using 38 REPANGOL points in Angola (except SE) and Cabinda. Average horizontal error 1m, vertical 3m; max radial error 6m. Application offshore differs from Camacupa 1948 to WGS 84 by approx 25m.','Used by CIDDEMA for delimitation of Angola''s EEZ boundary.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','8694','EPSG','4326','EPSG','1029',3.0,-93.799,-132.737,-219.073,'EPSG','9001',1.844,-0.648,6.37,'EPSG','9104',-0.169,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CIDDEMA-Ago',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8883','Camacupa 1948 to RSAO13 (1)','Parameter values taken from Camacupa 1948 to WGS 84 (7) (code 1324) assuming that RSAO13 is coincident with WGS 84 within the accuracy of the transformation.','Spatial referencing.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4220','EPSG','8699','EPSG','2322',3.0,-48.0,-345.0,-231.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELF-Ago B15',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8884','Camacupa 1948 to RSAO13 (2)','Parameter values taken from Camacupa 1948 to WGS 84 (10) (code 1327) assuming that RSAO13 is coincident with WGS 84 within the accuracy of the transformation.','Spatial referencing.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4220','EPSG','8699','EPSG','2324',5.0,-50.9,-347.6,-231.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Ago N',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8886','SVY21 to WGS 84 (1)','Considered exact at 1994-01-01 when SVY21 aligned to WGS 84 (Transit).','Approximation at the +/- 1m level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4757','EPSG','4326','EPSG','1210',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SLA-sgp',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8887','GDA2020 to WGS 84 (Transit) (1)','Approximation at the 3m level assuming WGS 84 (Transit) is equivalent to ITRF2014 within the accuracy of the transformation.','Spatial referencing with 3-metre accuracy.','EPSG','1031','Geocentric translations (geocentric domain)','EPSG','7842','EPSG','7815','EPSG','4177',3.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GA-Aus 3m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8889','BGS2005 to ETRS89 (1)','BGS2005 is a national realization of ETRS89. May be taken as approximate transformation BGS2005 to WGS 84 - see code 8890.','Pan-European spatial positioning.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','7798','EPSG','4258','EPSG','1056',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Bgr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8890','BGS2005 to WGS 84 (1)','Approximation at the +/- 1m level assuming that ETRS89 is equivalent to WGS 84. BGS2005 is a national realization of ETRS89.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','7798','EPSG','4326','EPSG','1056',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Bgr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8891','LKS92 to ETRS89 (1)','LKS92 is a national realization of ETRS89. May be taken as approximate transformation LKS92 to WGS 84 - see code 1958.','Pan-European spatial positioning.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4661','EPSG','4258','EPSG','1139',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Lva',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8892','LKS94 to ETRS89 (1)','LKS94 is a national realization of ETRS89. May be taken as approximate transformation LKS94 to WGS 84 - see code 1283.','Pan-European spatial positioning.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4669','EPSG','4258','EPSG','1145',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Ltu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8893','SRB_ETRS89 to ETRS89 (1)','SRB_ETRS89 is a national realization of ETRS89. May be taken as approximate transformation SRB_ETRS89 to WGS 84 - see code 8894.','Pan-European spatial positioning.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','8685','EPSG','4258','EPSG','4543',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Sbr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8894','SRB_ETRS89 to WGS 84 (1)','Approximation at the +/- 1m level assuming that ETRS89 is equivalent to WGS 84. SRB_ETRS89 is a national realisation of ETRS89.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','8685','EPSG','4326','EPSG','4543',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Srb',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8895','CHTRF95 to ETRS89 (1)','CHTRF95 is a national realization of ETRS89. May be taken as approximate transformation CHTRF95 to WGS 84 - see code 1511.','Pan-European spatial positioning.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4151','EPSG','4258','EPSG','1286',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Che',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8913','CR05 to CR-SIRGAS (1)','Derived at 16 stations. CR05 is static, CR-SIRGAS is dynamic: transformation is valid at epoch 2014.59 but accuracy will deteriorate due to tectonic motion. May be taken as an approximate transformation to ITRF08 / IGb08 / WGS 84 - see code 8914.','For applications to an accuracy of 0.5 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','5364','EPSG','8906','EPSG','1074',0.5,-0.16959,0.35312,0.51846,'EPSG','9001',-0.03385,0.16325,-0.03446,'EPSG','9104',0.03693,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Cri 2014',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','8914','CR05 to WGS 84 (2)','Parameter vales are from CR05 to CR-SIRGAS (1) (code 8913) assuming that CR-SIRGAS (ITRF08 (IGb08)@2014.59) is equivalent to WGS 84 within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','5364','EPSG','4326','EPSG','1074',1.0,-0.16959,0.35312,0.51846,'EPSG','9001',-0.03385,0.16325,-0.03446,'EPSG','9104',0.03693,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Cri 2014',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','8952','ITRF97 to SIRGAS-CON DGF00P01 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','4918','EPSG','8915','EPSG','4530',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2000.4,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'SIR-SC Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8953','ITRF2000 to SIRGAS-CON DGF01P01 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','4919','EPSG','8917','EPSG','4530',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'SIR-SC Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8954','ITRF2000 to SIRGAS-CON DGF01P02 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','4919','EPSG','8919','EPSG','4530',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1998.4,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'SIR-SC Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8955','ITRF2000 to SIRGAS-CON DGF02P01 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','4919','EPSG','8921','EPSG','4530',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'SIR-SC Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8956','ITRF2000 to SIRGAS-CON DGF04P01 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','4919','EPSG','8923','EPSG','4530',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2003.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'SIR-SC Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8957','ITRF2000 to SIRGAS-CON DGF05P01 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','4919','EPSG','8925','EPSG','4530',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2004.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'SIR-SC Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8958','ITRF2000 to SIRGAS-CON DGF06P01 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','4919','EPSG','8927','EPSG','4530',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2004.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'SIR-SC Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8959','IGS05 to SIRGAS-CON DGF07P01 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','9010','EPSG','8929','EPSG','4530',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2004.5,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'SIR-SC Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8960','IGS05 to SIRGAS-CON DGF08P01 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','9010','EPSG','8931','EPSG','4530',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2004.5,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'SIR-SC Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8961','IGS05 to SIRGAS-CON SIR09P01 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','9010','EPSG','8933','EPSG','4530',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2005.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'SIR-SC Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8962','ITRF2008 to SIRGAS-CON SIR10P01 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','5332','EPSG','8935','EPSG','4530',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2005.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'SIR-SC Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8963','ITRF2008 to SIRGAS-CON SIR11P01 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','5332','EPSG','8937','EPSG','4530',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2005.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'SIR-SC Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8964','IGb08 to SIRGAS-CON SIR13P01 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','9015','EPSG','8939','EPSG','4530',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2012.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'SIR-SC Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8965','IGb08 to SIRGAS-CON SIR14P01 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','9015','EPSG','8941','EPSG','4530',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2013.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'SIR-SC Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8966','IGb08 to SIRGAS-CON SIR15P01 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','9015','EPSG','8943','EPSG','4530',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2013.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'SIR-SC Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8967','IGS14 to SIRGAS-CON SIR17P01 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','8227','EPSG','8945','EPSG','4530',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2015.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'SIR-SC Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8968','CR05 to CR-SIRGAS (1)','Derived at 16 stations. CR05 is static, CR-SIRGAS is dynamic: transformation is valid at epoch 2014.59 but accuracy will deteriorate due to tectonic motion. May be taken as an approximate transformation to ITRF08 / IGb08 / WGS 84 - see code 8969.','For applications to an accuracy of 0.5 metres.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','5365','EPSG','8907','EPSG','1074',0.5,-0.16959,0.35312,0.51846,'EPSG','9001',-0.03385,0.16325,-0.03446,'EPSG','9104',0.03693,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Cri 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8969','CR05 to WGS 84 (2)','Parameter vales are from CR05 to CR-SIRGAS (1) (code 8968) assuming that CR-SIRGAS (ITRF08 (IGb08)@2014.59) is equivalent to WGS 84 within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','5365','EPSG','4326','EPSG','1074',1.0,-0.16959,0.35312,0.51846,'EPSG','9001',-0.03385,0.16325,-0.03446,'EPSG','9104',0.03693,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Cri 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8970','ITRF2014 to NAD83(2011) (1)','Concatenation of joint US-Canada transformation NAD83(CORS96)>ITRF96 (CT code 6864) with IGS value for ITRF96>ITRF97 and IERS values for ITRF97>ITRF2014 CTs. Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Oil and gas exploration and production.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','7789','EPSG','6317','EPSG','1511',0.0,1.0053,-1.9092,-0.5416,'EPSG','9001',26.7814,-0.4203,10.9321,'EPSG','1031',0.37,'EPSG','1028',0.0008,-0.0006,-0.0014,'EPSG','1042',0.0667,-0.7574,-0.0513,'EPSG','1032',-0.07,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IOGP-Usa CONUS-AK PRVI',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','8971','NAD83 to NAD83(2011) (1)','','Oil and gas exploration and production.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4269','EPSG','6318','EPSG','3357',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Usa GoM',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9020','ITRF88 to ITRF89 (1)','Scale difference (dS) in ppb where 1/billion = 1E-9 or nm/m. rX and dS derived through summing CTs to later realizations ITRF2000 (CT 6281 + 7814), ITRF2008 (CT 6291 + 6292) and ITRF2014 (CT 8069 + 8070) are 0.0mas and -3.1ppb: these are recommended.','Geodesy','EPSG','1033','Position Vector transformation (geocentric domain)','EPSG','4910','EPSG','4911','EPSG','1262',0.01,0.5,3.6,2.4,'EPSG','1033',-0.1,0.0,0.0,'EPSG','1031',-3.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9021','ITRF89 to ITRF90 (1)','Scale difference (dS) in ppb where 1/billion = 1E-9 or nm/m. dS derived through summing CTs to later realizations ITRF2000 (CT 6281 + 7814), ITRF2008 (CT 6291 + 6292) and ITRF2014 (CT 8069 + 8070) is -3.4ppb: this value is recommended.','Geodesy.','EPSG','1033','Position Vector transformation (geocentric domain)','EPSG','4911','EPSG','4912','EPSG','1262',0.01,-0.5,-2.4,3.8,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',-3.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9022','ITRF90 to ITRF91 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1033','Position Vector transformation (geocentric domain)','EPSG','4912','EPSG','4913','EPSG','1262',0.007,-0.1,0.4,1.6,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',-0.3,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9023','ITRF91 to ITRF92 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1033','Position Vector transformation (geocentric domain)','EPSG','4913','EPSG','4914','EPSG','1262',0.005,-1.1,-1.4,0.6,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',-1.4,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9024','ITRF92 to ITRF93 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Note: info source gives translation rates in mm/year.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4914','EPSG','4915','EPSG','1262',0.003,-0.2,-0.7,-0.7,'EPSG','1033',-0.39,0.8,-0.96,'EPSG','1031',1.2,'EPSG','1028',-0.29,0.04,0.08,'EPSG','1034',-0.11,-0.19,0.05,'EPSG','1032',0.0,'EPSG','1030',1988.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9025','ITRF93 to ITRF94 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4915','EPSG','4916','EPSG','1262',0.01,-0.6,0.5,1.5,'EPSG','1033',0.39,-0.8,0.96,'EPSG','1031',-0.4,'EPSG','1028',0.29,-0.04,-0.08,'EPSG','1034',0.11,0.19,-0.05,'EPSG','1032',0.0,'EPSG','1030',1988.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9026','ITRF94 to ITRF96 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m. ITRF96 is by definition aligned with ITRF94.','Geodesy','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','4916','EPSG','4917','EPSG','1262',0.0,0.0,0.0,0.0,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1988.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9027','ITRF96 to ITRF97 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m. ITRF97 is by definition aligned with ITRF96.','Geodesy','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','4917','EPSG','4918','EPSG','1262',0.0,0.0,0.0,0.0,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1988.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9028','ITRF97 to IGS97 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m. IGS97 is by definition aligned with ITRF97.','Geodesy','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','4918','EPSG','9001','EPSG','1262',0.0,0.0,0.0,0.0,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1997.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IGS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9029','ITRF2000 to IGS00 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m. IGS00 is by definition aligned with ITRF2000.','Geodesy','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','4919','EPSG','9004','EPSG','1262',0.0,0.0,0.0,0.0,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1998.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IGS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9030','ITRF2005 to IGS05 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m. IGS05 is by definition aligned with ITRF2005.','Geodesy','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','4896','EPSG','9010','EPSG','1262',0.0,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IGS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9031','ITRF2008 to IGS08 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m. IGS08 is by definition aligned with ITRF2008.','Geodesy','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','5332','EPSG','6934','EPSG','1262',0.0,0.0,0.0,0.0,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2005.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IGS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9032','ITRF2014 to IGS14 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m. IGS14 is by definition aligned with ITRF2014.','Geodesy','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','7789','EPSG','8227','EPSG','1262',0.0,0.0,0.0,0.0,'EPSG','1033',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IGS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9033','IGS97 to IGS00 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','9001','EPSG','9004','EPSG','1262',0.007,-6.0,-5.6,20.1,'EPSG','1025',-0.04,0.001,0.043,'EPSG','1031',-1.403,'EPSG','1028',0.4,0.8,1.5,'EPSG','1027',0.004,-0.001,-0.003,'EPSG','1032',-0.012,'EPSG','1030',1998.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IGS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9034','IGS00 to IGb00 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m. IGS00 and IGb00 are both by definition aligned with ITRF2000. The actual IGS00-IGb00 transformation parameter values are not null but are statistically insignificant and treated as null by IGS.','Geodesy','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','9004','EPSG','9007','EPSG','1262',0.0,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1998.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IGS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9035','IGb00 to IGS05 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','9007','EPSG','9010','EPSG','1262',0.001,0.0,1.7,5.3,'EPSG','1025',0.0224,-0.0341,0.0099,'EPSG','1031',-0.8473,'EPSG','1028',0.4,-0.7,1.8,'EPSG','1027',-0.0033,0.0001,0.0161,'EPSG','1032',-0.1748,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IGS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9036','IGS05 to IGS08 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','9010','EPSG','6934','EPSG','1262',0.001,1.5,0.0,5.8,'EPSG','1025',-0.012,0.014,0.014,'EPSG','1031',-1.04,'EPSG','1028',-0.1,0.0,-0.1,'EPSG','1027',-0.002,-0.003,0.001,'EPSG','1032',0.01,'EPSG','1030',2005.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IGS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9037','IGS08 to IGb08 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m. IGS08 and IGb08 are both by definition aligned with ITRF2008.','Geodesy','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','6934','EPSG','9015','EPSG','1262',0.0,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2005.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IGS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9038','IGb08 to IGS14 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Parameter values from ITRS2008 to ITRS2014 (1) (code 7790) as IGb08 is aligned to ITRF2008 and IGS14 is aligned to ITRF2014.','Geodesy','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','9015','EPSG','8227','EPSG','1262',0.01,-1.6,-1.9,-2.4,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.02,'EPSG','1028',0.0,0.0,0.1,'EPSG','1027',0.0,0.0,0.0,'EPSG','1032',-0.03,'EPSG','1030',2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IGS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9051','ITRF94 to SIRGAS 1995 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','4916','EPSG','4974','EPSG','3448',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1995.4,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'SIR-S Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9052','ITRF2000 to SIRGAS 2000 (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','4919','EPSG','4988','EPSG','3418',0.01,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2000.4,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'SIR-SC Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9076','WGS 84 (G873) to ITRF94 (1)','Defined at epoch 1997.0.','Geodesy','EPSG','1032','Coordinate Frame rotation (geocentric domain)','EPSG','7658','EPSG','4916','EPSG','1262',0.1,0.0,0.0,0.0,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NGA-Wld 1997.0',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9077','ITRF2000 to NAD83(MARP00) (1)','Defines NAD83(MARP00). Equivalent transformation published on NGS web site and used in HDTP with rX=28.971 mas, rY=10.420 mas and rZ=8.928 mas at epoch 1997.00.','Geodesy.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','4919','EPSG','9070','EPSG','4167',0.0,0.9102,-2.0141,-0.5602,'EPSG','9001',29.039,10.065,10.101,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1042',-0.02,0.105,-0.347,'EPSG','1032',0.0,'EPSG','1030',1993.62,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'NGS-MA',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9078','ITRF2000 to NAD83(PACP00) (1)','Defines NAD83(PACP00). Equivalent transformation published on NGS web site and used in HDTP with rX=27.741 mas, rY=13.469 mas and rZ=2.712 mas at epoch 1997.00.','Geodesy.','EPSG','1056','Time-dependent Coordinate Frame rotation (geocen)','EPSG','4919','EPSG','9073','EPSG','4162',0.0,0.9102,-2.0141,-0.5602,'EPSG','9001',29.039,10.065,10.101,'EPSG','1031',0.0,'EPSG','1028',0.0,0.0,0.0,'EPSG','1042',-0.384,1.007,-2.186,'EPSG','1032',0.0,'EPSG','1030',1993.62,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'NGS-PA',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9079','ITRF97 to ITRF96 (2)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Uses IGS determination. Used as first step in ITRF97 to NZGD2000 concatenated operations, followed by application of NZGD2000 deformation model.','Geodesy.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4918','EPSG','4917','EPSG','1175',0.01,0.0,-0.51,15.53,'EPSG','1025',-0.16508,0.26897,0.05984,'EPSG','1031',-1.51099,'EPSG','1028',0.69,-0.1,1.86,'EPSG','1027',-0.01347,0.01514,-0.00027,'EPSG','1032',-0.19201,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'LINZ-Nzl 97',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9080','ITRF2000 to ITRF96 (2)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Used as first step in ITRF2000 to NZGD2000 concatenated operations, followed by application of NZGD2000 deformation model.','Geodesy.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4919','EPSG','4917','EPSG','1175',0.01,6.7,3.79,-7.17,'EPSG','1025',-0.16508,0.26897,0.11984,'EPSG','1031',0.06901,'EPSG','1028',0.69,-0.7,0.46,'EPSG','1027',-0.01347,0.01514,0.01973,'EPSG','1032',-0.18201,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'LINZ-Nzl 2000',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9081','ITRF2005 to ITRF96 (1)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Used as first step in ITRF2005 to NZGD2000 concatenated operations, followed by application of NZGD2000 deformation model.','Geodesy.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','4896','EPSG','4917','EPSG','1175',0.01,6.8,2.99,-12.97,'EPSG','1025',-0.16508,0.26897,0.11984,'EPSG','1031',0.46901,'EPSG','1028',0.49,-0.6,-1.34,'EPSG','1027',-0.01347,0.01514,0.01973,'EPSG','1032',-0.10201,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'LINZ-Nzl 2005',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9082','ITRF2008 to ITRF96 (2)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Used as first step in ITRF2008 to NZGD2000 concatenated operations, followed by application of NZGD2000 deformation model.','Geodesy.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','5332','EPSG','4917','EPSG','1175',0.01,4.8,2.09,-17.67,'EPSG','1025',-0.16508,0.26897,0.11984,'EPSG','1031',1.40901,'EPSG','1028',0.79,-0.6,-1.34,'EPSG','1027',-0.01347,0.01514,0.01973,'EPSG','1032',-0.10201,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'LINZ-Nzl 2008',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9083','ITRF2014 to ITRF96 (2)','Scale difference in ppb and scale difference rate in ppb/yr where 1/billion = 1E-9 or nm/m. Used as first step in ITRF2014 to NZGD2000 concatenated operations, followed by application of NZGD2000 deformation model.','Geodesy.','EPSG','1053','Time-dependent Position Vector tfm (geocentric)','EPSG','7789','EPSG','4917','EPSG','1175',0.01,6.4,3.99,-14.27,'EPSG','1025',-0.16508,0.26897,0.11984,'EPSG','1031',1.08901,'EPSG','1028',0.79,-0.6,-1.44,'EPSG','1027',-0.01347,0.01514,0.01973,'EPSG','1032',-0.07201,'EPSG','1030',2000.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'LINZ-Nzl 2014',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9126','NAD83(CSRS)v2 to NAD83(CORS96) (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m. Source and target CRSs defined from ITRF96 by common transformations (codes 6864 and 8259). 6864 defines CORS96 from 1st January 1997 to 31st December 1999.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','8233','EPSG','6781','EPSG','4544',0.0,0.0,0.0,0.0,'EPSG','9001',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1997.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'ISO-N Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9127','NAD83(CSRS)v3 to NAD83(CORS96) (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m. Source and target CRSs defined from ITRF97 by common transformations (codes 6865 and 8260). 6865 defines CORS96 from 1st January 2000 to 31st December 2001.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','8238','EPSG','6781','EPSG','4544',0.0,0.0,0.0,0.0,'EPSG','9001',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1997.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'ISO-N Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9128','NAD83(CSRS)v4 to NAD83(CORS96) (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m. Source and target CRSs defined from ITRF2000 by common transformations (codes 6866 and 8261). 6866 defines CORS96 from 1st January 2002 to 6th September 2011.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','8242','EPSG','6781','EPSG','4544',0.0,0.0,0.0,0.0,'EPSG','9001',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2002.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'ISO-N Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9129','NAD83(CSRS)v6 to NAD83(2011) (1)','Scale difference in ppb where 1/billion = 1E-9 or nm/m. Source and target CRSs defined from ITRF2008 by common transformations (codes 7807 and 8264).','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','8250','EPSG','6317','EPSG','1262',0.0,0.0,0.0,0.0,'EPSG','9001',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','1028',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'ISO-N Am',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9142','MGI 1901 to KOSOVAREF01 (1)','Derived at 18 points across the area of Kosovo. May be taken as approximate transformation MGI 1901 to WGS 84 (see code 9143).','Spatial referencing.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','3906','EPSG','9140','EPSG','4542',1.0,628.54052,192.2538,498.43507,'EPSG','9001',-13.79189,-0.81467,41.21533,'EPSG','9104',-17.40368,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'KCA-Kos',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9143','MGI 1901 to WGS 84 (14)','Parameter values from MGI 1901 to KOSOVAREF01 (1) (code 9142). Assumes KOSOVAREF01 and WGS 84 can be considered the same to within the accuracy of the transformation.','Approximation at the 1m level.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','3906','EPSG','4326','EPSG','4542',1.0,628.54052,192.2538,498.43507,'EPSG','9001',-13.79189,-0.81467,41.21533,'EPSG','9104',-17.40368,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Kos',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9144','KOSOVAREF01 to WGS 84 (1)','Approximation at the +/- 1m level assuming that ETRS89 is equivalent to WGS 84. KOSOVAREF01 is a national realization of ETRS89.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','9140','EPSG','4326','EPSG','4542',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IOGP-Kos',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9145','WGS 84 (Transit) to ITRF90 (1)','','Geodesy','EPSG','1033','Position Vector transformation (geocentric domain)','EPSG','7815','EPSG','4912','EPSG','1262',1.0,-0.06,0.517,0.223,'EPSG','9001',-0.0183,0.0003,-0.007,'EPSG','9104',0.011,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS-Wld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9177','SIRGAS-Chile 2002 to ITRF2000 (1)','Transformation is exact at epoch 2002.00 but accuracy then decreasing with time.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','5358','EPSG','4919','EPSG','1066',0.1,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2002.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IOGP-Chl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9178','SIRGAS-Chile 2010 to IGS08 (1)','Transformation is exact at epoch 2010.00 but accuracy then decreasing with time.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','8947','EPSG','6934','EPSG','1066',0.1,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2010.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IOGP-Chl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9179','SIRGAS-Chile 2013 to IGb08 (1)','Transformation is exact at epoch 2013.00 but accuracy then decreasing with time.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','9146','EPSG','9015','EPSG','1066',0.1,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2013.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IOGP-Chl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9180','SIRGAS-Chile 2016 to IGb08 (1)','Transformation is exact at epoch 2016.00 but accuracy then decreasing with time.','Geodesy.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','9151','EPSG','9015','EPSG','1066',0.1,0.0,0.0,0.0,'EPSG','1025',0.0,0.0,0.0,'EPSG','1031',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2016.0,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'IOGP-Chl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9185','AGD66 to GDA2020 (1)','This transformation is for users wanting to apply a 7-parameter conformal transformation from AGD66 to GDA2020 in the ACT.','Spatial referencing.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4202','EPSG','7844','EPSG','2283',0.05,-136.9703,-37.5638,124.4242,'EPSG','9001',-0.25676,-0.42966,-0.30077,'EPSG','9104',-4.61966,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPD-Aus ACT',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9186','ITRF2008 to IG05/12 Intermediate CRS','Derived from Israeli CORS on ITRF2008 at epoch 2018.50. Updates CT 6993 for approx. 40cm tectonic plate motion 2012 to 2019 for GIS purposes. CT 6993 remains the legal definition of IG05/12 and must be used for cadastral and precise engineering purposes.','GIS. Note: not to be used for cadastre or precise engineering survey: see remarks.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','8999','EPSG','6990','EPSG','2603',0.05,-23.772,-17.49,-17.859,'EPSG','9001',-0.3132,-1.85274,1.67299,'EPSG','9104',5.4262,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SOI-Isr 2019',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9189','WGS 84 to IG05/12 Intermediate CRS','Parameter values from CT code 9186 assuming that WGS 84 is coincident with ITRF2008. Updates CT 6993 for approx. 40cm tectonic plate motion for GIS purposes. CT 6993 remains the legal definition of IG05/12 and must be used for cadastre and engineering.','GIS. Note: not to be used for cadastre or precise engineering survey: see remarks.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4326','EPSG','6990','EPSG','2603',0.1,-23.772,-17.49,-17.859,'EPSG','9001',-0.3132,-1.85274,1.67299,'EPSG','9104',5.4262,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SOI-Isr 2019',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9223','WGS 84 to ETRS89 (2)','Parameter values derived from ITRF2008 to ETRF2000 (1), code 7951, as a time-specific transformation @2014.81, assuming ITRF2008 = WGS 84 (G1762) = WGS 84 and ETRF2000 = ETRS89.','Oil and gas exploration and production.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','4936','EPSG','4978','EPSG','4566',0.1,0.054,0.051,-0.085,'EPSG','9001',0.0021,0.0126,-0.0204,'EPSG','9104',0.0025,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2014.81,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'ONE-Deu/Nld 2014.81',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','9224','ED50 to ETRS89 (15)','Parameter values from ED50 to WGS 84 (36) assuming that ETRS89 is equivalent to WGS 84 at epoch 1989.00..','Oil and gas exploration and production..','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','EPSG','4258','EPSG','4566',1.0,-157.89,-17.16,-78.41,'EPSG','9001',2.118,2.697,-1.434,'EPSG','9104',-5.38,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ONE-Ger Nsea',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','9225','WGS 84 to ETRS89 (2)','Parameter values derived from ITRF2008 to ETRF2000 (1), code 7951, as a time-specific transformation @2014.81, assuming ITRF2008 = WGS 84 (G1762) = WGS 84 and ETRF2000 = ETRS89.','Oil and gas exploration and production.','EPSG','1065','Time-specific Position Vector transform (geocen)','EPSG','4978','EPSG','4936','EPSG','4566',0.1,0.054,0.051,-0.085,'EPSG','9001',0.0021,0.0126,-0.0204,'EPSG','9104',0.0025,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2014.81,'EPSG','1029',NULL,NULL,NULL,NULL,NULL,'ONE-Deu/Nld 2014.81',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','10085','Trinidad 1903 to WGS 84 (2)','Parameter values provided to EOG by Trinidad Ministry of Energy and Energy Industries. Used by EOG offshore Trinidad (including Pelican, Kiskadee and Ibis fields) since 1996.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4302','EPSG','4326','EPSG','1339',3.0,-61.0,285.2,471.6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EOG-Tto Trin',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','10086','JAD69 to WGS 72 (1)','Derived in 1977 through Transit observations at 2 stations by US DMA.','For military mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4242','EPSG','4322','EPSG','3342',15.0,48.0,208.0,382.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SD-Jam',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','10089','Aratu to WGS 84 (5)','Used by ExxonMobil for block BMS1. See WGS 84 (13) (tfm code 5051) which Petrobras now recommends for the area.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','2962',7.0,-163.466,317.396,-147.538,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EXM-Bra Santos',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','10090','Aratu to WGS 84 (6)','Used by ExxonMobil for block BC10. Derived from earlier Shell position vector tfm of dX = -181m, dY = +294m, dZ = -144.5m, rX = rY = 0, rZ = +0.554s, dS = +0.219 ppm. See Aratu to WGS 84 (14) (tfm code 5053) which Petrobras now recommends for the area.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','2963',7.0,-170.0,305.0,-145.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EXM-Bra Campos',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','10091','Aratu to WGS 84 (7)','Used by ExxonMobil for block BMES1. See Aratu to WGS 84 (15) (tfm code 5055) which Petrobras now recommends for the area.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','2964',7.0,-162.904,312.531,-137.109,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EXM-Bra EspS',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','10092','Aratu to WGS 84 (8)','Used by ExxonMobil for block BP1. Also used by BG as part of a concatenated tfm to SAD69 for offshore regional studies. See WGS 84 (13) (tfm code 5051) for transformation Petrobras now recommends for the area.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','2965',7.0,-158.0,309.0,-151.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EXM-Bra Pel',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','10093','Aratu to WGS 84 (9)','Used by ExxonMobil for offshore regional studies. See Aratu to WGS 84 (13) through (21) (tfm codes 5051-67 [odd numbers only]) which Petrobras now recommends for various areas.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','2966',15.0,-161.0,308.0,-142.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EXM-Bra off',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','10094','Nouakchott 1965 to WGS 84 (1)','Derived by IGN in 1992 at 7 stations within Nouakchott city.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','2972',5.0,124.5,-63.5,-281.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Mau',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','10098','KKJ to ETRS89 (2)','May be taken as approximate transformation KKJ to WGS 84 - see code 10099. Replaces KKJ to ETRS89 (1) (code 1638).','In most areas accuracy is approximately 0.5m although in some areas it is in the order of 2m.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4123','EPSG','4258','EPSG','3333',0.5,-96.062,-82.428,-121.753,'EPSG','9001',-4.801,-0.345,1.376,'EPSG','9104',1.496,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NLS-Fin JHS153',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','10099','KKJ to WGS 84 (2)','Parameter values from KKJ to ETRS89 (2) (code 10098). Assumes ETRS89 and WGS 84 can be considered the same to within the accuracy of the transformation. Replaces KKJ to WGS 84 (1) (code 1639).','For applications to an accuracy of 1 to 2 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4123','EPSG','4326','EPSG','3333',1.0,-96.062,-82.428,-121.753,'EPSG','9001',-4.801,-0.345,1.376,'EPSG','9104',1.496,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Fin JHS153',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15483','Tokyo to JGD2000 (1)','Derived at Tokyo datum origin. Also used on remote islands with significantly less accuracy: Io-To 793m, Kitadaito and Minamidaito Jima 642m, Tarama and Minna Shima 560m, Ishigaki and Taketomi Jima 251m, Yonaguni Jima 248m.','Surveying, mapping and civil engineering purposes. Accuracy on main islands 9m, see remarks for accuracy on outlying islands. For an accuracy of a few tens of centimetres on all main and outlying islands use programme TKY2JGD.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4301','EPSG','4612','EPSG','3957',9.0,-146.414,507.337,680.507,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GSI-Jpn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15484','Tokyo to WGS 84 (108)','Parameter values from Tokyo to JGD2000 (1) (code 15483). Assumes JGD2000 and WGS 84 can be considered the same to within the accuracy of the transformation.','Surveying, mapping and civil engineering purposes. Accuracy on main islands 9m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4301','EPSG','4326','EPSG','3957',9.0,-146.414,507.337,680.507,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Jpn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15485','SAD69 to SIRGAS 2000 (1)','May be used as transformations between SAD69(96) and SIRGAS 2000 and between SAD69 and WGS 84 - see tfm codes 5881 and 5882. Used by Petrobras and ANP throughout Brazil from 1994.','Accuracy generally better than 1m except in Amazon basin where it degenerates to 5m. Should be used only to transform data obtained independently of the classical geodetic network (GPS observations conducted after 1994).','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4618','EPSG','4674','EPSG','1053',5.0,-67.35,3.88,-38.22,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IBGE-Bra',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15493','Minna to WGS 84 (15)','Adopted by MPN for all joint venture operations from 1/1/1996.','Oil industry exploration and production.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4263','EPSG','4326','EPSG','3590',5.0,-94.031,-83.317,116.708,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'MPN-Nga',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15494','Kalianpur 1962 to WGS 84 (6)','Derived by Fugro-Geodetic in 2004 at 6 closely-spaced stations. Used by OMV in all blocks in Pakistan where operator.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4145','EPSG','4326','EPSG','3589',3.0,274.164,677.282,226.704,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'omv-Pak Gambat',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15495','Accra to WGS 84 (3)','Derived via WGS 72BE. Found in use within oil industry erroneously concatenated via WGS 72. See tfm code 8571.','Oil industry.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4168','EPSG','4326','EPSG','1505',25.0,-171.16,17.29,325.21,'EPSG','9001',0.0,0.0,0.814,'EPSG','9104',-0.38,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Gha 1',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15496','Pulkovo 1942(58) to WGS 84 (18)','','Oil exploration','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4179','EPSG','4326','EPSG','1197',10.0,44.107,-116.147,-54.648,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Shell-Rom',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15497','Pulkovo 1942(58) to WGS 84 (9)','Derived at 4 stations.','For military purposes. Accuracy 3m, 5m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4179','EPSG','4326','EPSG','1197',7.0,28.0,-121.0,-77.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Rom',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15698','ITRF2000 to ITRF2005 (1)','At epoch 2000.0. Rates dX=0.0002 m/yr, dy=-0.0001 m/yr, dZ=0.0018 m/yr, rX=rY=rZ=0.0"/yr, dS=-0.00008 ppm/yr.','Geodesy.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4919','EPSG','4896','EPSG','1262',0.0,-0.0001,0.0008,0.0058,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',-0.0004,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IERS',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15699','NAD27 to WGS 84 (87)','Developed by John E Chance and Associates at 19°44''N, 92°21''W. Geoid height used =-13.34m.','Oil exploration and production. Horizontal transformation accuracy (1 sigma) is considered to be at the +/- 5 meter level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','3462',5.0,-2.0,124.7,196.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'JECA-Mex GoM CamS',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15700','Gulshan 303 to WGS 84 (1)','Derived at origin station in Dhaka.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4682','EPSG','4326','EPSG','1041',1.0,283.8,735.9,261.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SB-BGD',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15701','Kalianpur 1962 to WGS 84 (2)','Derived at Geodetic Survey office in Karachi in 1997.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4145','EPSG','4326','EPSG','2985',1.0,275.57,676.78,229.6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TFE-Pak Indus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15702','Kalianpur 1962 to WGS 84 (3)','Derived at station S0001, an approximate offset to Survey of India primary station Kat Baman, in 1992 from 180 single point Transit passes observed in 1991 by Fugro-Geodetic for UTP.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4145','EPSG','4326','EPSG','2984',3.0,278.9,684.39,226.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'utp-Pak Badin',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15703','Kalianpur 1962 to WGS 84 (4)','Derived at Chitrawala triangulation station by Fugro-Geodetic for UTP.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4145','EPSG','4326','EPSG','2982',3.0,271.905,669.593,231.495,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'utp-Pak Karachi',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15704','Kalianpur 1962 to WGS 84 (5)','Derived by Western Geophysical for UTP 1996 East Sind 2D survey.','Oil exploration.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4145','EPSG','4326','EPSG','2983',3.0,230.25,632.76,161.03,'EPSG','9001',-1.114,1.115,1.212,'EPSG','9104',12.584,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'utp-Pak E Sind',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15705','Minna to WGS 84 (12)','Derived via WGS 72(BE). Minna to WGS 72(BE) transformation derived in 1981 for Mobil E&P Nigeria (MEPCON) by Geodetic Survey through Transit translocation at six stations in southern Nigeria. Used by MEPCON in blocks OPL 215 and 221.','Oil industry exploration.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4263','EPSG','4326','EPSG','3819',8.0,-83.13,-104.95,114.63,'EPSG','9001',0.0,0.0,0.554,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'WGC-Nga 211',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15706','Minna to WGS 84 (13)','Used by Elf in Blocks OPL 222 and OPL 223 and by Mobil in 1994.','Oil industry exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4263','EPSG','4326','EPSG','1717',7.0,-93.6,-83.7,113.8,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Elf-Nga',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15707','ELD79 to WGS 84 (6)','Used by Petrocanada and previous licence holders in Amal field, concession 12.','Oil exploration and production','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4159','EPSG','4326','EPSG','2987',10.0,-118.996,-111.177,-198.687,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PCan-Lby Amal',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15708','PRS92 to WGS 84 (1)','Derived during GPS campaign which established PRS92 coordinates at 330 first order stations.','Accuracy: 1-10 parts per million.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4683','EPSG','4326','EPSG','1190',0.05,-127.62,-67.24,-47.04,'EPSG','9001',3.068,-4.903,-1.578,'EPSG','9104',-1.06,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGS-Phl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15709','Nouakchott 1965 to WGS 84 (1)','Derived by IGN in 1992 at 7 stations within Nouakchott city.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4680','EPSG','4326','EPSG','2972',5.0,124.5,-63.5,-281.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Mau',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15710','Aratu to WGS 84 (10)','Replaced by Aratu to WGS 84 (14) (tfm code 5053) which Petrobras now recommends for the area.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','2963',5.0,-160.0,315.0,-142.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra Campos',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15711','Aratu to WGS 84 (11)','Replaced by Aratu to WGS 84 (13) (tfm code 5051) which Petrobras now recommends for the area.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','2962',5.0,-158.0,309.0,-147.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra Santos',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15712','Aratu to WGS 84 (12)','Replaced by Aratu to WGS 84 (15) (tfm code 5055) which Petrobras now recommends for the area.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','2964',5.0,-161.0,310.0,-145.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra EspS',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15713','Gan 1970 to WGS 84 (1)','Derived at 1 station.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4684','EPSG','4326','EPSG','3274',44.0,-133.0,-321.0,50.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Mdv',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15714','Bogota 1975 to MAGNA-SIRGAS (1)','May be taken as transformation to WGS 84 - see tfm code 15715. See Bogota 1975 to MAGNA-SIRGAS (9), tfm code 15730, for an equivalent transformation using the Molodenski-Badekas 10-parameter method. OGP recommends this alternative.','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4218','EPSG','4686','EPSG','3082',1.0,-806.413,-263.5,-622.671,'EPSG','9001',6.018583e-05,-1.450001e-05,-0.0001892455,'EPSG','9101',-20.81616,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGAC-Col CF reg 1',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15715','Bogota 1975 to WGS 84 (3)','Approximation at the +/- 1m level assuming that MAGNA-SIRGAS is equivalent to WGS 84. Parameter values taken from Bogota 1975 to MAGNA-SIRGAS (1) (tfm code 15714).','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4218','EPSG','4326','EPSG','3082',1.0,-806.413,-263.5,-622.671,'EPSG','9001',6.018583e-05,-1.450001e-05,-0.0001892455,'EPSG','9101',-20.81616,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Col reg 1',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15716','Bogota 1975 to MAGNA-SIRGAS (2)','May be taken as transformation to WGS 84 - see tfm code 15717. See Bogota 1975 to MAGNA-SIRGAS (10), tfm code 15731, for an equivalent transformation using the Molodenski-Badekas 10-parameter method. OGP recommends this alternative.','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4218','EPSG','4686','EPSG','3083',1.0,100.783,187.382,-47.0,'EPSG','9001',-4.471839e-05,1.175093e-05,-4.027967e-05,'EPSG','9101',-13.56561,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGAC-Col CF reg 2',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15717','Bogota 1975 to WGS 84 (4)','Approximation at the +/- 1m level assuming that MAGNA-SIRGAS is equivalent to WGS 84. Parameter values taken from Bogota 1975 to MAGNA-SIRGAS (2) (tfm code 15716).','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4218','EPSG','4326','EPSG','3083',1.0,100.783,187.382,-47.0,'EPSG','9001',-4.471839e-05,1.175093e-05,-4.027967e-05,'EPSG','9101',-13.56561,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Col reg 2',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15718','Bogota 1975 to MAGNA-SIRGAS (3)','May be taken as transformation to WGS 84 - see tfm code 15719. See Bogota 1975 to MAGNA-SIRGAS (10), tfm code 15732, for an equivalent transformation using the Molodenski-Badekas 10-parameter method. OGP recommends this alternative.','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4218','EPSG','4686','EPSG','3084',1.0,336.026,348.565,252.978,'EPSG','9001',-8.358813e-05,-3.057474e-05,7.573031e-06,'EPSG','9101',-5.771909,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGAC-Col CF reg 3',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15719','Bogota 1975 to WGS 84 (5)','Approximation at the +/- 1m level assuming that MAGNA-SIRGAS is equivalent to WGS 84. Parameter values taken from Bogota 1975 to MAGNA-SIRGAS (3) (tfm code 15718).','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4218','EPSG','4326','EPSG','3084',1.0,336.026,348.565,252.978,'EPSG','9001',-8.358813e-05,-3.057474e-05,7.573031e-06,'EPSG','9101',-5.771909,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Col reg 3',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15720','Bogota 1975 to MAGNA-SIRGAS (4)','May be taken as transformation to WGS 84 - see tfm code 15721. See Bogota 1975 to MAGNA-SIRGAS (10), tfm code 15733, for an equivalent transformation using the Molodenski-Badekas 10-parameter method. OGP recommends this alternative.','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4218','EPSG','4686','EPSG','3085',1.0,963.273,486.386,190.997,'EPSG','9001',-7.992171e-05,-8.090696e-06,0.0001051699,'EPSG','9101',-13.89914,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGAC-Col CF reg 4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15721','Bogota 1975 to WGS 84 (6)','Approximation at the +/- 1m level assuming that MAGNA-SIRGAS is equivalent to WGS 84. Parameter values taken from Bogota 1975 to MAGNA-SIRGAS (4) (tfm code 15720).','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4218','EPSG','4326','EPSG','3085',1.0,963.273,486.386,190.997,'EPSG','9001',-7.992171e-05,-8.090696e-06,0.0001051699,'EPSG','9101',-13.89914,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Col reg 4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15722','Bogota 1975 to MAGNA-SIRGAS (5)','May be taken as transformation to WGS 84 - see tfm code 15723. See Bogota 1975 to MAGNA-SIRGAS (10), tfm code 15734, for an equivalent transformation using the Molodenski-Badekas 10-parameter method. OGP recommends this alternative.','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4218','EPSG','4686','EPSG','3086',1.0,-90.29,247.559,-21.989,'EPSG','9001',-4.216369e-05,-2.030416e-05,-6.209623e-05,'EPSG','9101',2.181658,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGAC-Col CF reg 5',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15723','Bogota 1975 to WGS 84 (7)','Approximation at the +/- 1m level assuming that MAGNA-SIRGAS is equivalent to WGS 84. Parameter values taken from Bogota 1975 to MAGNA-SIRGAS (5) (tfm code 15722).','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4218','EPSG','4326','EPSG','3086',1.0,-90.29,247.559,-21.989,'EPSG','9001',-4.216369e-05,-2.030416e-05,-6.209623e-05,'EPSG','9101',2.181658,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Col reg 5',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15724','Bogota 1975 to MAGNA-SIRGAS (6)','May be taken as transformation to WGS 84 - see tfm code 15725. See Bogota 1975 to MAGNA-SIRGAS (10), tfm code 15735, for an equivalent transformation using the Molodenski-Badekas 10-parameter method. OGP recommends this alternative.','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4218','EPSG','4686','EPSG','3087',1.0,-0.562,244.299,-456.938,'EPSG','9001',3.329153e-05,-4.001009e-05,-4.507206e-05,'EPSG','9101',3.74656,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGAC-Col CF reg 6',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15725','Bogota 1975 to WGS 84 (8)','Approximation at the +/- 1m level assuming that MAGNA-SIRGAS is equivalent to WGS 84. Parameter values taken from Bogota 1975 to MAGNA-SIRGAS (6) (tfm code 15724).','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4218','EPSG','4326','EPSG','3087',1.0,-0.562,244.299,-456.938,'EPSG','9001',3.329153e-05,-4.001009e-05,-4.507206e-05,'EPSG','9101',3.74656,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Col reg 6',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15726','Bogota 1975 to MAGNA-SIRGAS (7)','May be taken as transformation to WGS 84 - see tfm code 15727. See Bogota 1975 to MAGNA-SIRGAS (10), tfm code 15736, for an equivalent transformation using the Molodenski-Badekas 10-parameter method. OGP recommends this alternative.','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4218','EPSG','4686','EPSG','3088',1.0,-305.356,222.004,-30.023,'EPSG','9001',-4.698084e-05,5.003123e-06,-9.578655e-05,'EPSG','9101',6.325747,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGAC-Col CF reg 7',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15727','Bogota 1975 to WGS 84 (9)','Approximation at the +/- 1m level assuming that MAGNA-SIRGAS is equivalent to WGS 84. Parameter values taken from Bogota 1975 to MAGNA-SIRGAS (7) (tfm code 15726).','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4218','EPSG','4326','EPSG','3088',1.0,-305.356,222.004,-30.023,'EPSG','9001',-4.698084e-05,5.003123e-06,-9.578655e-05,'EPSG','9101',6.325747,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Col reg 7',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15728','Bogota 1975 to MAGNA-SIRGAS (8)','May be taken as transformation to WGS 84 - see tfm code 15729. See Bogota 1975 to MAGNA-SIRGAS (10), tfm code 15737, for an equivalent transformation using the Molodenski-Badekas 10-parameter method. OGP recommends this alternative.','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4218','EPSG','4686','EPSG','3089',1.0,221.899,274.136,-397.554,'EPSG','9001',1.361573e-05,-2.174431e-06,-1.36241e-05,'EPSG','9101',-2.199943,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGAC-Col CF reg 8',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15729','Bogota 1975 to WGS 84 (10)','Approximation at the +/- 1m level assuming that MAGNA-SIRGAS is equivalent to WGS 84. Parameter values taken from Bogota 1975 to MAGNA-SIRGAS (8) (tfm code 15728).','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4218','EPSG','4326','EPSG','3089',1.0,221.899,274.136,-397.554,'EPSG','9001',1.361573e-05,-2.174431e-06,-1.36241e-05,'EPSG','9101',-2.199943,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Col reg 8',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15730','Bogota 1975 to MAGNA-SIRGAS (9)','Source also quotes an equivalent transformation using the Coordinate Frame 7-parameter method - see Bogota 1975 to MAGNA-SIRGAS (1), tfm code 15714.','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4218','EPSG','4686','EPSG','3082',1.0,300.449,293.757,-317.306,'EPSG','9001',6.018581e-05,-1.450002e-05,-0.0001892455,'EPSG','9101',-20.81615,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1891881.173,-5961263.267,1248403.057,'EPSG','9001','IGAC-Col MB reg 1',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15731','Bogota 1975 to MAGNA-SIRGAS (10)','Source also quotes an equivalent transformation using the Coordinate Frame 7-parameter method - see Bogota 1975 to MAGNA-SIRGAS (2), tfm code 15716.','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4218','EPSG','4686','EPSG','3083',1.0,308.833,282.519,-314.571,'EPSG','9001',-4.471845e-05,1.175087e-05,-4.027981e-05,'EPSG','9101',-13.56561,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1625036.59,-6054644.061,1172969.151,'EPSG','9001','IGAC-Col MB reg 2',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15732','Bogota 1975 to MAGNA-SIRGAS (11)','Source also quotes an equivalent transformation using the Coordinate Frame 7-parameter method - see Bogota 1975 to MAGNA-SIRGAS (3), tfm code 15718.','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4218','EPSG','4686','EPSG','3084',1.0,311.118,289.167,-310.641,'EPSG','9001',-8.358815e-05,-3.057474e-05,7.573043e-06,'EPSG','9101',-5.771882,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1555622.801,-6105353.313,991255.656,'EPSG','9001','IGAC-Col MB reg 3',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15733','Bogota 1975 to MAGNA-SIRGAS (12)','Source also quotes an equivalent transformation using the Coordinate Frame 7-parameter method - see Bogota 1975 to MAGNA-SIRGAS (4), tfm code 15720.','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4218','EPSG','4686','EPSG','3085',1.0,306.666,315.063,-318.837,'EPSG','9001',-7.992173e-05,-8.090698e-06,0.0001051699,'EPSG','9101',-13.89912,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1845222.398,-6058604.495,769132.398,'EPSG','9001','IGAC-Col MB reg 4',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15734','Bogota 1975 to MAGNA-SIRGAS (13)','Source also quotes an equivalent transformation using the Coordinate Frame 7-parameter method - see Bogota 1975 to MAGNA-SIRGAS (5), see tfm code 15722.','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4218','EPSG','4686','EPSG','3086',1.0,307.871,305.803,-311.992,'EPSG','9001',-4.216368e-05,-2.030416e-05,-6.209624e-05,'EPSG','9101',2.181655,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1594396.206,-6143812.398,648855.829,'EPSG','9001','IGAC-Col MB reg 5',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15735','Bogota 1975 to MAGNA-SIRGAS (14)','Source also quotes an equivalent transformation using the Coordinate Frame 7-parameter method - see Bogota 1975 to MAGNA-SIRGAS (6), tfm code 15724.','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4218','EPSG','4686','EPSG','3087',1.0,302.934,307.805,-312.121,'EPSG','9001',3.329153e-05,-4.001009e-05,-4.507205e-05,'EPSG','9101',3.746562,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1558280.49,-6167355.092,491954.219,'EPSG','9001','IGAC-Col MB reg 6',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15736','Bogota 1975 to MAGNA-SIRGAS (15)','Source also quotes an equivalent transformation using the Coordinate Frame 7-parameter method - see Bogota 1975 to MAGNA-SIRGAS (7), tfm code 15726.','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4218','EPSG','4686','EPSG','3088',1.0,295.282,321.293,-311.001,'EPSG','9001',-4.698084e-05,5.003127e-06,-9.578653e-05,'EPSG','9101',6.325744,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1564000.62,-6180004.879,243257.955,'EPSG','9001','IGAC-Col MB reg 7',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15737','Bogota 1975 to MAGNA-SIRGAS (16)','Source also quotes an equivalent transformation using the Coordinate Frame 7-parameter method - see Bogota 1975 to MAGNA-SIRGAS (8), tfm code 15728.','Accuracy about 1 part in 10^5 of distance between points, depending on relative tectonic motion.','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4218','EPSG','4686','EPSG','3089',1.0,302.529,317.979,-319.08,'EPSG','9001',1.361566e-05,-2.174456e-06,-1.362418e-05,'EPSG','9101',-2.199976,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1738580.767,-6120500.388,491473.306,'EPSG','9001','IGAC-Col MB reg 8',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15738','MAGNA-SIRGAS to WGS 84 (1)','','MAGNA-SIRGAS is a national realization of SIRGAS and coincident with WGS 84 to within 1 metre. This transformation has an accuracy equal to the coincidence figure.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4686','EPSG','4326','EPSG','1070',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15739','Amersfoort to ETRS89 (3)','Replaces Amersfoort to ETRS89 (1) (tfm code 1751). Replaced by Amersfoort to ETRS89 (5) (tfm code 4830). Dutch sources also quote an equivalent transformation using the Molodenski-Badekas 10-parameter method (M-B) - see tfm code 15740.','Accuracy 0.5m','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4289','EPSG','4258','EPSG','1275',0.5,565.2369,50.0087,465.658,'EPSG','9001',1.9725,-1.7004,9.0677,'EPSG','9109',4.0812,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NCG-Nld 2004',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15740','Amersfoort to ETRS89 (4)','Replaces Amersfoort to ETRS89 (2) (tfm code 1066). Replaced by Amersfoort to ETRS89 (6) (tfm code 4831). Dutch sources also quote an equivalent transformation using the Coordinate Frame 7-parameter method - see tfm code 15739.','Accuracy 0.5m','EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4289','EPSG','4258','EPSG','1275',0.5,593.0297,26.0038,478.7534,'EPSG','9001',1.9725,-1.7004,9.0677,'EPSG','9109',4.0812,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,3903453.1482,368135.3134,5012970.3051,'EPSG','9001','NCG-Nld 2004',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15741','Deir ez Zor to WGS 84 (2)','Derived by Elf in 1991 from tfm code 1584 concatenated with a tfm from WGS72BE to WGS84.','Oil exploration. Accuracy 5m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4227','EPSG','4326','EPSG','2329',5.0,-187.5,14.1,237.6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Elf-Syr Deir 1991',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15742','Deir ez Zor to WGS 84 (5)','Derived for 1998 Omar seismic survey and used in 2000 for El Isba seismic survey.','Oil exploration. Accuracy 5m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4227','EPSG','4326','EPSG','3314',5.0,-190.421,8.532,238.69,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CGG-Syr Isba',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15743','Deir ez Zor to WGS 84 (6)','Derived 2005 at 5 triangulation stations and using (EGM96 geoid model +1.15m). Used by Total/DEZPC for Jafra and Mazraa seismic surveys. Can be approximated using geocentric translations of dX=-190.6m, dY=+8.8m, dZ=+239.6m.','Oil exploration. Accuracy 0.5m.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4227','EPSG','4326','EPSG','2329',0.5,-83.58,-397.54,458.78,'EPSG','9001',-17.595,-2.847,4.256,'EPSG','9104',3.225,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Tot-Syr Deir 2005',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15745','ED50(ED77) to WGS 84 (6)','Derived in Tombak district in March 2005. Used for South Pars phase 11.','Petroleum Exploration and Production.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4154','EPSG','4326','EPSG','3140',0.2,-123.02,-158.95,-168.47,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Tot-Irn Spars',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15746','Nakhl-e Ghanem to WGS 84 (6)','Derived in Tombak district in March 2005. Used for South Pars phase 11 and Pars LNG plants.','Petroleum Exploration and Production.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4693','EPSG','4326','EPSG','3141',0.2,0.0,-0.15,0.68,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TFE-Irn Tombak',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15748','BD72 to ETRS89 (2)','May be taken as approximate transformation BD72 to WGS 84 - see code 15749. Scale difference is given by information source as 1.0000012747. Given in this record in ppm to assist application usage.','For applications to an accuracy of 0.2 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4313','EPSG','4258','EPSG','1044',0.2,-106.8686,52.2978,-103.7239,'EPSG','9001',-0.3366,0.457,-1.8422,'EPSG','9104',1.2747,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Bel 0.2m',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15749','BD72 to WGS 84 (3)','Parameter values from BD72 to ETRS89 (2) (code 15748). Scale difference is given by information source as 1.0000012747. Given in this record in ppm to assist application usage.','For applications to an accuracy of 0.5 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4313','EPSG','4326','EPSG','1044',0.2,-106.8686,52.2978,-103.7239,'EPSG','9001',-0.3366,0.457,-1.8422,'EPSG','9104',1.2747,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Bel 0.2m',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15750','St. Kitts 1955 to WGS 84 (2)','Derived at 2 stations.','For military purposes. Accuracy 25m in each of X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4605','EPSG','4326','EPSG','3297',44.0,-7.0,215.0,225.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Kna',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15751','Reunion 1947 to WGS 84 (2)','Derived at 1 station.','For military purposes. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4626','EPSG','4326','EPSG','3337',44.0,94.0,-948.0,-1262.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Reu 30m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15752','ED79 to WGS 84 (1)','Derived at 22 stations.','For military purposes. Accuracy 3m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4668','EPSG','4326','EPSG','1297',6.0,-86.0,-98.0,-119.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Eur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15754','Aratu to WGS 84 (1)','Mean for 3 basins. See Aratu to WGS 84 (10) through (12) (codes 15710-12) for transformations for individual basins. Replaced by Aratu to WGS 84 (13) through (15) (tfm codes 5051, 5053 and 5055) which Petrobras now recommends for the areas.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4208','EPSG','4326','EPSG','2307',10.0,-158.0,315.0,-148.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'PB-Bra BC BS ES',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15755','Minna to WGS 84 (14)','Derived in 1995 at unspecified DMA ADOS stations and Racal stations M101 and ZVS3003. Used by Elf in onshore Block OML 58.','Oil industry exploration and production. Accuracy 0.5m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4263','EPSG','4326','EPSG','3113',7.0,-90.2,-87.32,114.17,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Elf-Nga-OML58',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15756','Tahiti 79 to RGPF (1)','May be taken as approximate transformation Tahiti 79 to WGS 84 - see code 4835.','Accuracy +/- 0.5 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4690','EPSG','4687','EPSG','3124',0.5,221.525,152.948,176.768,'EPSG','9001',2.3847,1.3896,0.877,'EPSG','9104',11.4741,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Pyf',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15757','Moorea 87 to RGPF (1)','May be taken as approximate transformation Moorea 87 to WGS 84 - see code 15769.','Accuracy +/- 0.5 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4691','EPSG','4687','EPSG','3125',0.5,215.525,149.593,176.229,'EPSG','9001',3.2624,1.692,1.1571,'EPSG','9104',10.4773,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Pyf',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15758','Tahaa 54 to RGPF (1)','May be taken as approximate transformation Tahaa 54 to WGS 84 - see code 15770.','Accuracy +/- 0.5 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4629','EPSG','4687','EPSG','2812',0.5,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Pyf',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15759','Maupiti 83 to RGPF (1)','May be taken as approximate transformation Maupiti 83 to WGS 84 - see code 15771.','Accuracy +/- 0.5 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4692','EPSG','4687','EPSG','3126',0.5,217.037,86.959,23.956,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Pyf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15760','Fatu Iva 72 to RGPF (1)','May be taken as approximate transformation Fatu Iva 72 to WGS 84 - see code 15772.','Accuracy +/- 1 to 2 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4688','EPSG','4687','EPSG','3133',2.0,347.103,1078.125,2623.922,'EPSG','9001',33.8875,-70.6773,9.3943,'EPSG','9104',186.074,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Pyf',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15761','IGN63 Hiva Oa to RGPF (1)','May be taken as approximate transformation IGN63 Hiva Oa to WGS 84 - see code 15773.','Accuracy +/- 0.5 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4689','EPSG','4687','EPSG','3131',0.5,410.721,55.049,80.746,'EPSG','9001',-2.5779,-2.3514,-0.6664,'EPSG','9104',17.3311,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Pyf HivaOa',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15762','IGN63 Hiva Oa to RGPF (2)','May be taken as approximate transformation IGN63 Hiva Oa to WGS 84 - see code 15774.','Accuracy +/- 1 to 2 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4689','EPSG','4687','EPSG','3132',2.0,374.715,-58.407,-0.957,'EPSG','9001',-16.2111,-11.4626,-5.5357,'EPSG','9104',-0.5409,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Pyf Tahuata',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15763','IGN72 Nuku Hiva to RGPF (1)','May be taken as approximate transformation IGN72 Nuku Hiva to WGS 84 - see code 15775.','Accuracy +/- 0.5 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4630','EPSG','4687','EPSG','2810',0.5,165.732,216.72,180.505,'EPSG','9001',-0.6434,-0.4512,-0.0791,'EPSG','9104',7.4204,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Pyf NukuHiva',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15764','IGN72 Nuku Hiva to RGPF (2)','May be taken as approximate transformation IGN72 Nuku Hiva to WGS 84 - see code 15776.','Accuracy +/- 1 to 2 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4630','EPSG','4687','EPSG','3127',2.0,1363.785,1362.687,398.811,'EPSG','9001',-4.5322,-6.7579,-1.0574,'EPSG','9104',268.361,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Pyf UaHuka',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15765','IGN72 Nuku Hiva to RGPF (3)','May be taken as approximate transformation IGN72 Nuku Hiva to WGS 84 - see code 15777.','Accuracy +/- 0.5 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4630','EPSG','4687','EPSG','3128',0.5,259.551,297.612,197.833,'EPSG','9001',1.4866,2.1224,0.4612,'EPSG','9104',27.0249,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Pyf UaPou',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15766','RGPF to WGS 84 (1)','Transformation is to original definition of WGS 84. It is consistent with later WGS 84 realisations G730, G873 and G1150 to no better than 1m.','Accuracy +/- 0.5 metre (to original definition of WGS 84 - see remarks).','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4999','EPSG','4979','EPSG','1098',0.5,0.072,-0.507,-0.245,'EPSG','9001',0.0183,-0.0003,0.007,'EPSG','9104',-0.0093,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Pyf',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15767','RGPF to WGS 84 (2)','Approximation at the +/- 1m level assuming that RGPF is equivalent to WGS 84.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4999','EPSG','4979','EPSG','1098',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Pyf',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15768','Tahiti 79 to WGS 84 (1)','Approximation at the +/- 1m level assuming that RGPF is equivalent to WGS 84. Parameter values taken from Tahiti 79 to RGPF (1) (tfm code 15756).','Accuracy +/- 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4690','EPSG','4687','EPSG','3124',1.0,221.525,152.948,176.768,'EPSG','9001',2.3847,1.3896,0.877,'EPSG','9104',11.4741,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Pyf',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15769','Moorea 87 to WGS 84 (1)','Approximation at the +/- 1m level assuming that RGPF is equivalent to WGS 84. Parameter values taken from Moorea 87 to RGPF (1) (tfm code 15757).','Accuracy +/- 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4691','EPSG','4326','EPSG','3125',1.0,215.525,149.593,176.229,'EPSG','9001',3.2624,1.692,1.1571,'EPSG','9104',10.4773,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Pyf',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15770','Tahaa 54 to WGS 84 (2)','Approximation at the +/- 1m level assuming that RGPF is equivalent to WGS 84. Parameter values taken from Tahaa 54 to RGPF (1) (tfm code 15758).','Accuracy +/- 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4629','EPSG','4326','EPSG','2812',1.0,72.438,345.918,79.486,'EPSG','9001',-1.6045,-0.8823,-0.5565,'EPSG','9104',1.3746,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Pyf',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15771','Maupiti 83 to WGS 84 (1)','Approximation at the +/- 1m level assuming that RGPF is equivalent to WGS 84. Parameter values taken from Maupiti 83 to RGPF (1) (tfm code 15759).','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4692','EPSG','4326','EPSG','3126',1.0,217.037,86.959,23.956,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Pyf',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15772','Fatu Iva 72 to WGS 84 (1)','Approximation at the +/- 1m level assuming that RGPF is equivalent to WGS 84. Parameter values taken from Fatu Iva 72 to RGPF (1) (tfm code 15760).','Accuracy +/- 2 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4688','EPSG','4326','EPSG','3133',2.0,347.103,1078.125,2623.922,'EPSG','9001',33.8875,-70.6773,9.3943,'EPSG','9104',186.074,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Pyf',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15773','IGN63 Hiva Oa to WGS 84 (1)','Approximation at the +/- 1m level assuming that RGPF is equivalent to WGS 84. Parameter values taken from IGN63 Hiva Oa to RGPF (1) (tfm code 15761).','Accuracy +/- 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4689','EPSG','4326','EPSG','3131',2.0,410.721,55.049,80.746,'EPSG','9001',-2.5779,-2.3514,-0.6664,'EPSG','9104',17.3311,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Pyf HivaOa',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15774','IGN63 Hiva Oa to WGS 84 (2)','Approximation at the +/- 1m level assuming that RGPF is equivalent to WGS 84. Parameter values taken from IGN63 Hiva Oa to RGPF (2) (tfm code 15762).','Accuracy +/- 2 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4689','EPSG','4326','EPSG','3132',2.0,374.716,-58.407,-0.957,'EPSG','9001',-16.2111,-11.4626,-5.5357,'EPSG','9104',-0.5409,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Pyf Tahuata',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15775','IGN72 Nuku Hiva to WGS 84 (2)','Approximation at the +/- 1m level assuming that RGPF is equivalent to WGS 84. Parameter values taken from IGN72 Nuku Hiva to RGPF (1) (tfm code 15763).','Accuracy +/- 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4630','EPSG','4326','EPSG','2810',1.0,165.732,216.72,180.505,'EPSG','9001',-0.6434,-0.4512,-0.0791,'EPSG','9104',7.4204,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Pyf NukuHiva',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15776','IGN72 Nuku Hiva to WGS 84 (3)','Approximation at the +/- 1m level assuming that RGPF is equivalent to WGS 84. Parameter values taken from IGN72 Nuku Hiva to RGPF (2) (tfm code 15764).','Accuracy +/- 2 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4630','EPSG','4326','EPSG','3127',2.0,1363.785,1362.687,398.811,'EPSG','9001',-4.5322,-6.7579,-1.0574,'EPSG','9104',268.361,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Pyf UaHuka',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15777','IGN72 Nuku Hiva to WGS 84 (4)','Approximation at the +/- 1m level assuming that RGPF is equivalent to WGS 84. Parameter values taken from IGN72 Nuku Hiva to RGPF (2) (tfm code 15765).','Accuracy +/- 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4630','EPSG','4326','EPSG','3128',1.0,259.551,297.612,197.833,'EPSG','9001',1.4866,2.1224,0.4612,'EPSG','9104',27.0249,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Pyf UaPou',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15778','ELD79 to WGS 84 (7)','Derived by Total at stations SDL 130-03, 04 and 05 in May 2005.','Oil exploration and production.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4159','EPSG','4326','EPSG','3142',0.5,-114.7,-98.5,-150.7,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Tot-Lby NC192',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15779','Gulshan 303 to WGS 84 (1)','Derived at origin station in Dhaka. Source information given to 3 decimal places but rounded by OGP to be commensurate with stated accuracy.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4682','EPSG','4326','EPSG','1041',1.0,283.7,735.9,261.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SB-Bgd',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15780','POSGAR 94 to WGS 84 (1)','','Approximation at the +/- 1m level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4190','EPSG','4326','EPSG','1033',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Arg',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15782','Campo Inchauspe to POSGAR 94 (1)','Adopted from U.S. Defense Mapping Agency values for Campo Inchauspe to WGS 84 (tfm code 1127) assuming that POSGAR 94 is equivalent to WGS 84.','Accuracy 5m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4221','EPSG','4694','EPSG','3215',5.0,-148.0,136.0,90.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGM-Arg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15783','IGN53 Mare to WGS 84 (2)','Withdrawn by information source and replaced by improved information from local authority - see tfm code 15901.','Accuracy 5 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4641','EPSG','4326','EPSG','2819',5.0,287.0,178.0,-136.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Ncl Mare',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15784','Le Pouce 1934 to WGS 84 (1)','Derived at 17 stations in 1994 by University of East London. Residuals less than 2m.','Accuracy 2m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4699','EPSG','4326','EPSG','3209',2.0,-770.1,158.4,-498.2,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UEL-Mus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15787','IGCB 1955 to WGS 84 (1)','Derived by Topnav in 1991 at station TSH 85.','Oil exploration. Accuracy 5m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4701','EPSG','4326','EPSG','3171',5.0,-79.9,-158.0,-168.9,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Tot-Cod',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15788','AGD66 to WGS 84 (16)','Parameter values from AGD66 to GDA94 (1) (code 1278). Derived at 162 stations. Assumes GDA94 and WGS 84 can be considered the same to within the accuracy of the transformation.','5m accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4202','EPSG','4326','EPSG','2575',5.0,-127.8,-52.3,152.9,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Aus 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15789','AGD84 to WGS 84 (8)','Parameter values from AGD84 to GDA94 (1) (code 1279). Derived at 327 stations. Assumes GDA94 and WGS 84 can be considered the same to within the accuracy of the tfm. AGD84 officially adopted only in Queensland, South Australia and Western Australia.','5m accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4203','EPSG','4326','EPSG','2576',5.0,-128.5,-53.0,153.4,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Aus 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15790','Mhast (offshore) to WGS 72BE (1)','Derived by Oceaneering for CABGOC in 1979. Mean of parameters derived by single point Transit translocation at 2 stations (Mongo Tando and N''To). Applied to single point Transit translocations at other stations to define Mhast (offshore) coordinates.','Oil industry exploration and production between 1979 and 1987.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4705','EPSG','4324','EPSG','3180',10.0,-255.0,-29.0,-105.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CHV-Ago Cab',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15791','Malongo 1987 to WGS 84 (3)','Derived via WGS 72BE by Geodetic for Chevron in 1987 by single point Transit translocation at 1 station (Malongo Y). Replaced in 1989 by Malongo 1987 to WGS 84 (1) (code 1330).','Oil industry exploration and production between September 1987 and April 1989.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4259','EPSG','4326','EPSG','3180',10.0,-259.99,-5.28,-97.09,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'CHV-Ago Cab87',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15792','Egypt Gulf of Suez S-650 TL to WGS 72BE (1)','Derived by Egypt Surveys Limited through single point Transit translocation at 1 station (S-650).','Oil industry exploration and production between 1980 and 1984.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4706','EPSG','4324','EPSG','2341',5.0,-123.0,98.0,2.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ESL-Egy GoS',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15793','Barbados 1938 to WGS 84 (1)','Derived at 2 stations (S40 and M1, St Annes Tower) in 2004.','Accuracy 2.5m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4212','EPSG','4326','EPSG','3218',3.0,31.95,300.99,419.19,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UKHO-Brb',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15794','Cocos Islands 1965 to WGS 84 (1)','Derived at 1 satellite station.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4708','EPSG','4326','EPSG','1069',44.0,-491.0,-22.0,435.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Cck',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15795','Tern Island 1961 to WGS 84 (1)','Derived at 1 satellite station. Same transformation parameter values related to same datum area given in original 1987 DMA TR8350.2 edition for Sorol Atoll.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4707','EPSG','4326','EPSG','3181',44.0,114.0,-116.0,-333.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Usa HI Tern',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15796','Iwo Jima 1945 to WGS 84 (1)','Derived at 1 satellite station.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4709','EPSG','4326','EPSG','3200',44.0,145.0,75.0,-272.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Jpn IwoJ',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15797','Ascension Island 1958 to WGS 84 (1)','Derived at 2 satellite stations.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4712','EPSG','4326','EPSG','3182',44.0,-205.0,107.0,53.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Shn Asc',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15798','Astro DOS 71 to WGS 84 (1)','Derived at 1 satellite station.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4710','EPSG','4326','EPSG','3183',44.0,-320.0,550.0,-494.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Shn Hel',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15799','Marcus Island 1952 to WGS 84 (1)','Derived at 1 satellite station.','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4711','EPSG','4326','EPSG','1872',44.0,124.0,-234.0,-25.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Jpn Marcus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15800','Ayabelle Lighthouse to WGS 84 (1)','Derived at 1 satellite station. Replaced by Ayabelle Lighthouse to WGS 84 (2) (code 6907).','For military purposes only. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4713','EPSG','4326','EPSG','1081',44.0,-79.0,-129.0,145.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Dji',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15801','Bellevue to WGS 84 (1)','Derived at 3 satellite stations.','Military and topographic mapping; Accuracy +/- 20 m in each axis','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4714','EPSG','4326','EPSG','3193',35.0,-127.0,-769.0,472.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Vut',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15802','Camp Area Astro to WGS 84 (1)','No accuracy estimate available.','Military and scientific mapping.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4715','EPSG','4326','EPSG','3205',999.0,-104.0,-129.0,239.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Ata McMurdo',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15803','Phoenix Islands 1966 to WGS 84 (1)','Derived at 4 satellite stations.','Military and topographic mapping. Accuracy +/- 15 m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4716','EPSG','4326','EPSG','3196',26.0,298.0,-304.0,-375.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Kir Phoenix',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15804','Cape Canaveral to WGS 84 (1)','Derived at 19 satellite stations.','US space and military operations. Accuracy +/- 3 m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4717','EPSG','4326','EPSG','3206',6.0,-2.0,151.0,181.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Bha Usa-FL',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15805','Solomon 1968 to WGS 84 (1)','Derived at 1 satellite station.','Military and topographic mapping. Accuracy +/- 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4718','EPSG','4326','EPSG','3198',44.0,230.0,-199.0,-752.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Slb Gizo',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15806','Easter Island 1967 to WGS 84 (1)','Derived at 1 satellite station.','Military and topographic mapping. Accuracy +/- 25m in each axis','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4719','EPSG','4326','EPSG','3188',44.0,211.0,147.0,111.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Chl Easter',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15807','Solomon 1968 to WGS 84 (2)','Derived at 1 satellite station.','Military and topographic mapping. Accuracy +/- 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4718','EPSG','4326','EPSG','3197',44.0,252.0,-209.0,-751.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Slb Guad',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15808','Diego Garcia 1969 to WGS 84 (1)','Derived at 2 satellite stations.','Military and topographic mapping. Accuracy +/- 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4724','EPSG','4326','EPSG','3189',44.0,208.0,-435.0,-229.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Iot Garcia',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15809','Johnston Island 1961 to WGS 84 (1)','Derived at 2 satellite stations. Note: NGA online html files carry a different dZ value - OGP believe this is an erroneous transcription from the TR8350.2 line above.','Military and topographic mapping. Accuracy +/- 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4725','EPSG','4326','EPSG','3201',44.0,189.0,-79.0,-202.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Umi Johnston',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15810','Kusaie 1951 to WGS 84 (1)','Derived at 1 satellite station.','Military and topographic mapping. Accuracy +/- 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4735','EPSG','4326','EPSG','3192',44.0,647.0,1777.0,-1124.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Fsm Carol',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15811','Antigua 1943 to WGS 84 (2)','Determined from 1 satellite station.','Military mapping. Accuracy +/- 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4601','EPSG','4326','EPSG','1273',44.0,-270.0,13.0,62.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Atg Ant',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15812','Deception Island to WGS 84 (1)','','Scientific mapping. Accuracy +/- 20m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4736','EPSG','4326','EPSG','3204',35.0,260.0,12.0,-147.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Ata Dec',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15813','South Georgia 1968 to WGS 84 (1)','Determined from 1 satellite station.','Military and topographic mapping. Accuracy +/- 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4722','EPSG','4326','EPSG','3529',44.0,-794.0,119.0,-298.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Sgs Sgeorg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15814','SIGD61 to WGS 84 (1)','Determined from 1 satellite station.','Military mapping. Accuracy +/- 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4726','EPSG','4326','EPSG','3186',44.0,42.0,124.0,147.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Cym Little Brac',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15815','Pico de las Nieves 1984 to WGS 84 (1)','Determined at 1 satellite station.','Military and topographic mapping. Accuracy +/- 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4728','EPSG','4326','EPSG','3873',44.0,-307.0,-92.0,127.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Esp Canary',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15816','Tristan 1968 to WGS 84 (1)','Determined at 1 satellite station.','Military and topographic mapping. Accuracy +/- 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4734','EPSG','4326','EPSG','3184',44.0,-632.0,438.0,-609.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Shn Tris',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15817','Midway 1961 to WGS 84 (1)','Derived at 1 satellite station. Information source states "provided for historical purposes only. These parameter [values] should not be used". Replaced by Midway 1961 to WGS 84 (2) (tfm code 15818).','Military and topographic mapping. Accuracy +/- 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4727','EPSG','4326','EPSG','3202',44.0,912.0,-58.0,1227.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Umi Midway 1987',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15818','Midway 1961 to WGS 84 (2)','Derived at 1 satellite station. Replaces Midway 1961 to WGS 84 (1) (tfm code 15817).','Military and topographic mapping. Accuracy +/- 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4727','EPSG','4326','EPSG','3202',44.0,403.0,-81.0,277.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Umi Midway 2003',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15819','Pitcairn 1967 to WGS 84 (1)','Derived at 1 satellite station.','Military and topographic mapping. Accuracy +/- 25 m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4729','EPSG','4326','EPSG','3208',44.0,185.0,165.0,42.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Pcn Pitcairn Isl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15820','Santo 1965 to WGS 84 (1)','Derived at 1 satellite station.','For military and topographic mapping. Accuracy 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4730','EPSG','4326','EPSG','3194',44.0,170.0,42.0,84.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Vut',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15821','Viti Levu 1916 to WGS 84 (1)','Derived at 1 satellite station.','For military and topographic mapping. Accuracy +/-25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4731','EPSG','4326','EPSG','3195',44.0,51.0,391.0,-36.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Fji',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15822','Marshall Islands 1960 to WGS 84 (1)','Derived at 10 satellite stations.','For military and topographic mapping. Accuracy +/-3 m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4732','EPSG','4326','EPSG','3191',6.0,102.0,52.0,-38.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Mhl 1960',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15823','Wake Island 1952 to WGS 84 (1)','Derived at 2 satellite stations.','For military and topographic mapping. Accuracy +/-25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4733','EPSG','4326','EPSG','3190',44.0,276.0,-57.0,149.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Mhl Wake',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15824','Old Hawaiian to WGS 84 (3)','Derived at 15 satellite stations.','Military mapping. Accuracy +/- 25m in X axis, +/- 20m in Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4135','EPSG','4326','EPSG','1334',38.0,61.0,-285.0,-181.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Usa HI 1987',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15825','Old Hawaiian to WGS 84 (4)','Derived at 2 satellite stations.','Military mapping. Accuracy +/- 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4135','EPSG','4326','EPSG','1546',44.0,89.0,-279.0,-183.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Usa HI Haw 1991',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15826','Old Hawaiian to WGS 84 (5)','Derived at 3 satellite stations.','Military mapping. Accuracy +/- 20m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4135','EPSG','4326','EPSG','1549',35.0,45.0,-290.0,-172.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Usa HI Kauai 1991',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15827','Old Hawaiian to WGS 84 (6)','Derived at 2 satellite stations.','Military mapping. Accuracy +/- 25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4135','EPSG','4326','EPSG','1547',44.0,65.0,-290.0,-190.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Usa HI Maui 1991',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15828','Old Hawaiian to WGS 84 (7)','Derived at 8 satellite stations.','Military mapping only. Accuracy +/- 10m in X axis, +/- 6m in Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4135','EPSG','4326','EPSG','1548',14.0,58.0,-283.0,-182.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Usa HI Oahu 1991',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15829','SIGD61 to WGS 84 (2)','Determined from 2 satellite stations.','Topographic survey. Accuracy +/- 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4726','EPSG','4326','EPSG','3186',1.0,44.4,109.0,151.7,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UNO-Cym Little Brac',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15830','GCGD59 to WGS 84 (1)','Determined from 6 satellite stations.','Topographic survey. Accuracy +/- 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4723','EPSG','4326','EPSG','3185',1.0,67.8,106.1,138.8,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UNO-Cym Grand',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15831','Korea 2000 to WGS 84 (1)','Approximation at the +/- 1m level assuming that ITRF2000 is equivalent to WGS 84.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4737','EPSG','4326','EPSG','1135',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Kor',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15832','RGPF to WGS 84 (1)','Transformation is to original definition of WGS 84. It is consistent with later WGS 84 realisations G730, G873 and G1150 to no better than 1m.','Accuracy +/- 0.5 metre (to original definition of WGS 84 - see remarks).','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4687','EPSG','4326','EPSG','1098',0.5,0.072,-0.507,-0.245,'EPSG','9001',0.0183,-0.0003,0.007,'EPSG','9104',-0.0093,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Pyf',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15833','RGPF to WGS 84 (2)','Approximation at the +/- 1m level assuming that RGPF is equivalent to WGS 84.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4687','EPSG','4326','EPSG','1098',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Pyf',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15842','Hong Kong 1963(67) to WGS 84 (1)','Derived at 2 satellite stations. Care: does not use Hong Kong 1963 (code 4838) as the source CRS.','Military mapping. Accuracy +/- 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4739','EPSG','4326','EPSG','1118',1.0,-156.0,-271.0,-189.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UKHO-Hkg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15843','PZ-90 to WGS 84 (1)','Derived through Glonass and GPS at 30 stations throughout USSR - Former Soviet Union (FSU).','Geodetic applications. Accuracy better than 1.5 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4740','EPSG','4326','EPSG','1262',1.5,0.0,0.0,1.5,'EPSG','9001',0.0,0.0,-0.076,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GiK-World',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15844','Pulkovo 1942 to PZ-90 (1)','Derived through Glonass at 30 stations throughout USSR - Former Soviet Union (FSU). Mandated for use in Russia by GosStandard of Russia Decree #327 of August 9, 2001.','Accuracy within area of primary CS42 control = 1 to 2m; accuracy at distant points 3 to 4 m.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4284','EPSG','4740','EPSG','2423',4.0,25.0,-141.0,-80.0,'EPSG','9001',0.0,-0.35,-0.66,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GiK-Rus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15845','Pampa del Castillo to WGS 84 (1)','Transformation parameter precision given to millimetres in information source but due to accuracy rounded to nearest decimetre for EPSG database.','Geodetic surveying within the oil industry. Accuracy 25 m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4161','EPSG','4326','EPSG','1265',25.0,27.5,14.0,186.4,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UNO-Arg ComRiv',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15846','Egypt Gulf of Suez S-650 TL to WGS 84 (2)','Sometime referred to as "Egypt 1907 to WGS 84". However, application to WGS 84 coordinates of the reverse of this tfm results in Gulf of Suez S-650 TL, not Egypt 1907, position. Gulf of Suez S-650 TL and Egypt 1907 CRSs differ by some 20 metres.','Used for oil exploration by GUPCO.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4706','EPSG','4326','EPSG','2341',5.0,-146.21,112.63,4.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Racal-Egy GoS',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15847','MOP78 to WGS 84 (2)','Replaces information from 2001 (tfm code 1925).','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4639','EPSG','4326','EPSG','2815',10.0,253.0,-132.0,-127.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Wlf Wallis',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15848','ST84 Ile des Pins to WGS 84 (2)','','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4642','EPSG','4326','EPSG','2820',10.0,-13.0,-348.0,292.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Ncl Pins',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15849','Beduaram to WGS 84 (2)','Used by Elf / CGG between December 1991 and March 1992. Probably derived from results of concatenated tfm Beduaram to WGS 84 (1) (code 8634).','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4213','EPSG','4326','EPSG','2771',15.0,-106.0,-87.0,188.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ELF-Ner SE 91',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15850','IGN 1962 Kerguelen to WGS 84 (1)','Also published in US NIMA/NGA TR8350.2 which gives accuracy of +/-25m in each axis and states that derived at one station.','Accuracy +/- 10 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4698','EPSG','4326','EPSG','2816',10.0,145.0,-187.0,103.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Atf Kerg',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15852','NAD27 to WGS 84 (80)','Developed by John E Chance and Associates. Replaced by NAD27 to WGS 84 (79) (tfm code 15851).','Oil exploration and production. Horizontal transformation accuracy (1 sigma) is considered to be at the +/- 5 meter level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','3358',5.0,-3.0,154.0,177.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'JECA-Usa GoM E',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15853','NAD27 to WGS 84 (81)','Developed by John E Chance and Associates. Replaced by NAD27 to WGS 84 (79) (tfm code 15851).','Oil exploration and production. Horizontal transformation accuracy (1 sigma) is considered to be at the +/- 5 meter level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','3359',5.0,-7.0,151.0,175.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'JECA-Usa GoM C',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15854','NAD27 to WGS 84 (82)','Developed by John E Chance and Associates. Replaced by NAD27 to WGS 84 (79) (tfm code 15851).','Oil exploration and production. Horizontal transformation accuracy (1 sigma) is considered to be at the +/- 5 meter level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','3360',5.0,-7.0,151.0,178.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'JECA-Usa GoM W',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15855','NAD27 to WGS 84 (83)','Developed by John E Chance and Associates at 21°55''N, 97°20''W. Geoid height used =-17m.','Oil exploration and production. Horizontal transformation accuracy (1 sigma) is considered to be at the +/- 5 meter level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','3361',5.0,-8.0,125.0,190.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'JECA-Mex GoM Tam',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15856','NAD27 to WGS 84 (84)','Developed by EnSoCo Inc. Replaced by NAD27 to WGS 84 (79) (tfm code 15851).','Oil exploration and production. Accuracy 8 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','3357',8.0,-7.0,158.0,172.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ESC-Usa GoM',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15860','Mauritania 1999 to WGS 84 (1)','Mauritania 1999 can be considered to be the same as WGS 84 within the accuracy of this transformation.','Minerals management. Accuracy 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4702','EPSG','4326','EPSG','1157',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Mau',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15865','Pulkovo 1942 to WGS 84 (16)','Derived via PZ-90 at 30 stations throughout USSR (Former Soviet Union, FSU) through concatenation of Pulkovo 1942 to PZ-90 (1) (tfm code 15844) and PZ-90 to WGS 84 (1) (tfm code 15843).','Accuracy 4.5 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4284','EPSG','4326','EPSG','2423',4.5,25.0,-141.0,-78.5,'EPSG','9001',0.0,-0.35,-0.736,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Rus',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15866','FD54 to ED50 (1)','Derived at 3 points in 1976. This transformation then used to define ED50 on the Faroe Islands.','Defines ED50 in the Faroe Islands: transformation therefore considered exact.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4741','EPSG','4230','EPSG','3248',0.0,-153.33,-169.41,86.39,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'KMS-Fro',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15867','PD/83 to ETRS89 (1)','Derived at 10 points of the German GPS Network DREF.','For applications with an accuracy at the sub-metre level','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4746','EPSG','4258','EPSG','2544',1.0,599.4,72.4,419.2,'EPSG','9001',-0.062,-0.022,-2.723,'EPSG','9104',6.46,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BKG-Deu Thur',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15868','RD/83 to ETRS89 (1)','Derived in 2001 at 31 points of the German GPS Network DREF in former East Germany. Although for high accuracy limited to Saxony, may be taken as approximate transformation between DHDN and WGS 84 for all former East German states - see code 15869.','For applications with an accuracy at the sub-metre level.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4745','EPSG','4258','EPSG','2545',1.0,612.4,77.0,440.2,'EPSG','9001',-0.054,0.057,-2.797,'EPSG','9104',2.55,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BKG-Deu Sach',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15869','DHDN to WGS 84 (3)','Parameter values taken from RD/83 to ETRS89 (1) (tfm code 15868) assuming that within the accuracy of the transformation ETRS89 is equivalent to WGS 84 and RD/83 is equivalent to DHDN.','For applications with an accuracy at 2m level','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4314','EPSG','4326','EPSG','1343',2.0,612.4,77.0,440.2,'EPSG','9001',-0.054,0.057,-2.797,'EPSG','9104',2.55,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Deu E',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15870','Jouik 1961 to WGS 84 (1)','Derived at 5 points in 2002.','Hydrographic survey','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4679','EPSG','4326','EPSG','2967',1.0,-80.01,253.26,291.19,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Wood-Mrt',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15871','Nahrwan 1967 to WGS 84 (6)','Derived by concatenation of parameter values published by IGN Paris from Nahrwan 1967 to WGS 72 at the Nahrwan SE Base trig station near Baghdad with DMA WGS 72 to WGS 84 parameter values.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4270','EPSG','4326','EPSG','3625',5.0,-242.2,-144.9,370.3,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Irq',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15872','Karbala 1979 to WGS 84 (1)','Derived from shifts in UTM rectangular coordinates for one point in Basra area provided by Iraq National Oil Exploration Company. Replaced by Karbala 1979 to WGS 84 (2) (tfm code 5078).','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4743','EPSG','4326','EPSG','3397',5.0,84.1,-320.1,218.7,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OEC-Irq Bas',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15873','Douala 1948 to WGS 84 (1)','Derived at Manoca tower assuming the pyramid on the tower and the centre of the tower reservoir are co-located. This assumption carries a few metres uncertainty.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4192','EPSG','4326','EPSG','2555',10.0,-206.1,-174.7,-87.7,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Tot-Cmr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15874','Nord Sahara 1959 to WGS 84 (7)','Derived at 11 stations throughout blocks 317b, 319b, 321b and 322b. Network based on station P4 (horizontal) and benchmark RN51 (vertical) using EGM96 geoid height. Used by Statoil in Hassi Mouina.','Oil exploration and production. Accuracy 5m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4307','EPSG','4326','EPSG','3402',5.0,-169.559,-72.34,303.102,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ENG-Dza Mou',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15875','Fiji 1956 to WGS 84 (1)','Derived at 20 stations. Also published by NGA in GeoTrans v3.4 software with parameter values rounded to integer.','For military purposes. Accuracy 5m, 3m and 2m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4721','EPSG','4326','EPSG','3398',7.0,265.025,384.929,-194.046,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DGC-Fji',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15876','Fiji 1986 to WGS 84 (1)','Approximation at the +/- 2m level assuming that Fiji 1986 is equivalent to WGS 72. Parameter values taken from WGS 72 to WGS 84 (1) (tfm code 1237).','tbc','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4720','EPSG','4326','EPSG','1094',2.0,0.0,0.0,4.5,'EPSG','9001',0.0,0.0,0.554,'EPSG','9104',0.2263,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Fji',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15877','Fiji 1986 to WGS 84 (2)','Suitable for GIS mapping purposes but not rigorous surveying. Very similar results may be obtained through Fiji 1986 to WGS 84 (1) (tfm code 15876).','Horizontal accuracy 2m, vertical accuracy approximately 40 metres..','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4720','EPSG','4326','EPSG','3398',40.0,-35.173,136.571,-36.964,'EPSG','9001',1.37,-0.842,-4.718,'EPSG','9104',-1.537,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'FD-Fji',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15878','Vanua Levu 1915 to WGS 84 (1)','Parameter values taken from Viti Levu 1912 to WGS 84 (1) (tfm code 15897). Approximation at the +/- 50m level assuming that CRS 4748 is equivalent to CRS 4752 within the transformation accuracy. Source CRSs 4748 and 4752 are independent but connected.','For applications with an accuracy of +/-50m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4748','EPSG','4326','EPSG','3401',50.0,51.0,391.0,-36.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Fji',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15879','GR96 to WGS 84 (1)','Approximation at the +/- 1m level assuming that GR96 is equivalent to WGS 84 within the accuracy of the transformation.','For applications with an accuracy of +/- 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4747','EPSG','4326','EPSG','1107',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Grl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15880','RGNC91-93 to WGS 84 (1)','','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4749','EPSG','4326','EPSG','1174',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Ncl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15881','ST87 Ouvea to WGS 84 (2)','Parameter values taken from ST87 Ouvea to RGNC91-93 (1) ( code 15885) assuming that RGNC91-93 is equivalent to WGS 84 to within the accuracy of the transformation.','Accuracy better than +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4750','EPSG','4326','EPSG','2813',1.0,-56.263,16.136,-22.856,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15882','IGN72 Grande Terre to RGNC91-93 (1)','Determined in May 2001. May be taken as approximate transformation to WGS 84 - see IGN72 Grande Terre to WGS 84 (3) (code 15903).','Accuracy better than +/- 2 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4662','EPSG','4749','EPSG','2822',2.0,-11.64,-348.6,291.98,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl 2m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15883','IGN56 Lifou to RGNC91-93 (1)','Determined in April 1993. May be taken as approximate transformation to WGS 84 - see IGN56 Lifou to WGS 84 (3) (code 15902).','Accuracy better than +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4633','EPSG','4749','EPSG','2814',1.0,335.47,222.58,-230.94,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15884','IGN53 Mare to RGNC91-93 (1)','Determined in April 1993, modified in December 1999. May be taken as approximate transformation to WGS 84: see IGN53 Mare to WGS 84 (3) (code 15901).','Accuracy better than +/- 2 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4641','EPSG','4749','EPSG','2819',2.0,287.58,177.78,-135.41,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15885','ST87 Ouvea to RGNC91-93 (1)','Determined in December 1999. May be used as approximate transformation to WGS 84 - see ST87 Ouvea to WGS 84 (2) (code 15881).','Accuracy better than +/- 0.5 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4750','EPSG','4749','EPSG','2813',0.5,-56.263,16.136,-22.856,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15886','NEA74 Noumea to RGNC91-93 (1)','Determined in July 2000. May be taken as approximate transformation to WGS 84 - see NEA74 Noumea to WGS 84 (3) (code 15904).','Accuracy better than +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4644','EPSG','4749','EPSG','2823',1.0,-10.18,-350.43,291.37,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15887','IGN72 Grande Terre to RGNC91-93 (2)','Determined in April 1993.','Accuracy better than +/- 0.3 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4662','EPSG','4749','EPSG','2822',0.3,97.297,-263.243,310.879,'EPSG','9001',1.5999,-0.8387,-3.1409,'EPSG','9104',13.326,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15888','IGN72 Grande Terre to RGNC91-93 (3)','Determined in July 2000','Accuracy better than +/- 0.1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4662','EPSG','4749','EPSG','2823',0.1,48.812,-205.932,343.993,'EPSG','9001',3.4427,0.4999,-4.0878,'EPSG','9104',6.5215,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl Noum 0.1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15889','NEA74 Noumea to RGNC91-93 (2)','Determined in May 2001','Accuracy better than +/- 0.1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4644','EPSG','4749','EPSG','2823',0.1,-166.0684,-154.7826,254.8282,'EPSG','9001',37.546,-7.7018,10.2029,'EPSG','9104',-30.84,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl 0.1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15890','IGN56 Lifou to RGNC91-93 (2)','Determined in April 1993.','Accuracy better than +/- 0.1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4633','EPSG','4749','EPSG','2814',0.1,137.092,131.675,91.478,'EPSG','9001',1.9435,11.5995,4.3316,'EPSG','9104',-7.4801,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl 0.1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15891','IGN53 Mare to RGNC91-93 (2)','Determined in April 1993, modified in December 1999.','Accuracy better than +/- 0.1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4641','EPSG','4749','EPSG','2819',0.1,-408.809,366.857,-412.987,'EPSG','9001',-1.8843,0.5308,-2.1657,'EPSG','9104',-121.0994,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl 0.1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15892','ST87 Ouvea to RGNC91-93 (2)','Determined in December 1999.','Accuracy better than +/- 0.1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4750','EPSG','4749','EPSG','2813',0.1,-122.386,-188.707,103.334,'EPSG','9001',-3.511,4.9665,5.7048,'EPSG','9104',4.4799,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl 0.1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15893','ST84 Ile des Pins to RGNC91-93 (1)','Determined in December 1999.','Accuracy better than +/- 0.1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4642','EPSG','4749','EPSG','2820',0.1,244.42,85.352,168.129,'EPSG','9001',8.936,-7.752,-12.5952,'EPSG','9104',14.2723,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl 0.1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15894','SIRGAS 2000 to WGS 84 (1)','','Accuracy 1m.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4674','EPSG','4326','EPSG','3418',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-C&S America',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15896','Kertau (RSO) to Kertau 1968 (1)','To transform Kertau (RSO) to WGS 84, see concatenated transformation code 8659.','For transformation of MRT68 RSO grid coordinates to other datums.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4751','EPSG','4245','EPSG','1309',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Mys',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15897','Viti Levu 1912 to WGS 84 (1)','Derived at 1 satellite station. Replaced by Viti Levu 1912 to WGS 84 (2) (code 6895).','For military and topographic mapping. Accuracy +/-25m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4752','EPSG','4326','EPSG','3195',44.0,51.0,391.0,-36.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DMA-Fji',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15898','Qornoq to GR96 (1)','Derived via NWL 9D.','For applications with an accuracy of +/- 1m.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4747','EPSG','4747','EPSG','1107',1.0,163.511,127.533,-159.789,'EPSG','9001',0.0,0.0,0.814,'EPSG','9104',-0.6,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'KMS-Grl',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15899','Scoresbysund 1952 to GR96 (1)','Derived via NWL 9D.','For applications with an accuracy of +/- 1m.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4195','EPSG','4747','EPSG','2570',1.0,105.0,326.0,-102.5,'EPSG','9001',0.0,0.0,0.814,'EPSG','9104',-0.6,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'KMS-Grl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15900','Ammassalik 1958 to GR96 (1)','Derived via NWL 9D.','For applications with an accuracy of +/- 1m.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4196','EPSG','4747','EPSG','2571',1.0,-45.0,417.0,-3.5,'EPSG','9001',0.0,0.0,0.814,'EPSG','9104',-0.6,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'KMS-Grl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15901','IGN53 Mare to WGS 84 (3)','Parameter values taken from IGN53 Mare to RGNC91-93 (1) ( code 15884) assuming that RGNC91-93 is equivalent to WGS 84 to within the accuracy of the transformation.','Accuracy 2 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4641','EPSG','4326','EPSG','2819',2.0,287.58,177.78,-135.41,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15902','IGN56 Lifou to WGS 84 (3)','Parameter values taken from IGN56 Lifou to RGNC91-93 (1) ( code 15883) assuming that RGNC91-93 is equivalent to WGS 84 to within the accuracy of the transformation.','Accuracy 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4633','EPSG','4326','EPSG','2814',1.0,335.47,222.58,-230.94,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15903','IGN72 Grande Terre to WGS 84 (3)','Parameter values taken from IGN72 Grande Terre to RGNC91-93 (1) ( code 15882) assuming that RGNC91-93 is equivalent to WGS 84 to within the accuracy of the transformation.','Accuracy +/- 2 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4662','EPSG','4326','EPSG','2822',2.0,-11.64,-348.6,291.98,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15904','NEA74 Noumea to WGS 84 (2)','Parameter values taken from NEA74 Noumea to RGNC91-93 (1) ( code 15886) assuming that RGNC91-93 is equivalent to WGS 84 to within the accuracy of the transformation.','Accuracy 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4644','EPSG','4326','EPSG','2823',1.0,-10.18,-350.43,291.37,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGN-Ncl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15908','LGD2006 to WGS 84 (1)','Derived at 5 stations throughout Libya used to define LGD2006 in May 2006.','For applications to an accuracy of 0.1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4754','EPSG','4326','EPSG','1143',0.1,-208.4058,-109.8777,-2.5764,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SDL-Lby',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15909','ELD79 to WGS 84 (8)','Derived at 29 stations throughout Libya in May 2006.','For applications to an accuracy of 5 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4159','EPSG','4326','EPSG','3271',5.0,-115.8543,-99.0583,-152.4616,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SDL-Lby',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15910','ELD79 to LGD2006 (1)','Derived at 29 stations throughout Libya in May 2006.','For applications to an accuracy of 2 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4159','EPSG','4754','EPSG','3271',5.0,-92.5515,-10.8194,149.8852,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SDL-Lby',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15911','ID74 to DGN95 (1)','Derived at 38 stations. May be taken as a tfm ID74 to WGS 84 - see tfm 1833.','Standard deviations of translations are 1.3, 1.1 and 3.6m, of rotations 0.11, 0.06 and 0.04 sec and ppm 0.18.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4238','EPSG','4755','EPSG','4020',3.0,-1.977,-13.06,-9.993,'EPSG','9001',-0.364,-0.254,-0.689,'EPSG','9104',-1.037,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Bak-Idn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15912','DGN95 to WGS 84 (1)','Approximation at the +/- 1m level assuming that DGN95 is equivalent to WGS 84 within the accuracy of the transformation.','Accuracy 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4755','EPSG','4326','EPSG','1122',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Idn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15913','NAD27 to WGS 84 (86)','Developed by John E Chance and Associates at 21°33''N, 92°33''W. Geoid height used =-16.7m.','Oil exploration and production. Horizontal transformation accuracy (1 sigma) is considered to be at the +/- 5 meter level.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','3461',5.0,0.0,125.0,196.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'JECA-Mex GoM CamN',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15918','Beijing 1954 to WGS 84 (1)','Provided by BGP to TOTAL in June 2006.','Geophysical exploration in Ordos basin. Accuracy stated as 1m within basin.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4214','EPSG','4326','EPSG','3466',1.0,12.646,-155.176,-80.863,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGP-Chn Ord',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15919','Beijing 1954 to WGS 84 (2)','Derived via WGS 72BE. Original transformation derived in 1979 at 4 stations on Yellow Sea coast.','Geophysical exploration in Yellow Sea.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4214','EPSG','4326','EPSG','3469',15.0,15.53,-113.82,-41.38,'EPSG','9001',0.0,0.0,0.814,'EPSG','9104',-0.38,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BP-Chn YS',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15920','Beijing 1954 to WGS 84 (3)','Derived via WGS 72BE. Original transformation derived by GSI in 1980-81. The GSI memo incorrectly gave the parameters as from WGS 72 to Beijing 1954, but it has been determined by the OGP that the memo should have stated from Beijing 1954 to WGS 72BE.','Geophysical exploration in South China Sea.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4214','EPSG','4326','EPSG','3470',15.0,31.4,-144.3,-74.8,'EPSG','9001',0.0,0.0,0.814,'EPSG','9104',-0.38,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GSI-Chn SCS',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15921','Beijing 1954 to WGS 84 (4)','Provided by BGP to ELF in 1994.','Geophysical exploration in Tarim basin. Accuracy stated as 1m within basin.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4214','EPSG','4326','EPSG','3507',1.0,15.8,-154.4,-82.3,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'BGP-Chn Tarim',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15923','ELD79 to WGS 84 (9)','Derived by SDL for Total in Cyrenaica blocks 2 & 4.','Oil and gas exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4159','EPSG','4326','EPSG','3477',2.0,-117.7,-100.3,-152.4,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TOT-Lby Cyr',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15924','ELD79 to LGD2006 (1)','Derived at 29 stations throughout Libya in May 2006.','For applications to an accuracy of 5 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4159','EPSG','4754','EPSG','3271',5.0,92.5515,10.8194,-149.8852,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SDL-Lby',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15925','JAD2001 to WGS 84 (1)','','For all practical purposes JAD2001 can be considered to be coincident with WGS 84.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4758','EPSG','4326','EPSG','1128',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NLA-Jam',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15926','JAD69 to JAD2001 (1)','May be used as tfm to WGS 84 - see JAD69 to WGS 84 (3) (tfm code 15927).','Accuracy 0.3 to 0.5 metres.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4242','EPSG','4758','EPSG','3342',0.5,-33.722,153.789,94.959,'EPSG','9001',8.581,4.478,-4.54,'EPSG','9104',8.95,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NLA-Jam',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15927','JAD69 to WGS 84 (3)','Derived at 4 stations, tested at a further 9. Also used as tfm to JAD69 to JAD2001 (see code 15926).¶Note: Info source paper contains an error in sign of dS, subsequently confirmed by primary author and NLA of Jamaica, and corrected in this record.','For applications requiring 1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4242','EPSG','4326','EPSG','3342',1.0,-33.722,153.789,94.959,'EPSG','9001',8.581,4.478,-4.54,'EPSG','9104',8.95,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'UT-Jam 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15928','BD72 to ETRS89 (2)','May be taken as approximate transformation BD72 to WGS 84 - see code 15929. Scale difference is given by information source as -1.0000012747. Given in this record in ppm to assist application usage.','For applications to an accuracy of 0.2 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4313','EPSG','4258','EPSG','1347',0.2,-106.8686,52.2978,-103.7239,'EPSG','9001',-0.3366,0.457,-1.8422,'EPSG','9104',-1.2747,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Bel 0.2m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15929','BD72 to WGS 84 (3)','Parameter values from BD72 to ETRS89 (2) (code 15928) assuming that ETRS89 is equivalent to WGS 84 within the accuracy of the tfm. Scale difference is given by information source as -1.0000012747; given in this record in ppm to assist application usage.','For applications to an accuracy of 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4313','EPSG','4326','EPSG','1347',1.0,-106.8686,52.2978,-103.7239,'EPSG','9001',-0.3366,0.457,-1.8422,'EPSG','9104',-1.2747,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'IGN-Bel 1m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15930','NAD83(HARN) to NAD83(NSRS2007) (1)','Accuracy 0.1 to 0.2m in California, 0.05-0.11 in Oregon, elsewhere better than 0.05m.','For applications to an accuracy of 0.2 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4152','EPSG','4326','EPSG','1323',0.1,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-USA conus',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15931','NAD83(NSRS2007) to WGS 84 (1)','Approximation at the +/- 1m level assuming that NAD83(NSRS2007) is equivalent to WGS 84 within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4759','EPSG','4326','EPSG','1511',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-USA conus AK',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15934','Amersfoort to WGS 84 (3)','Parameter values from Amersfoort to ETRS89 (3) (tfm code 15739) assuming that ETRS89 is equivalent to WGS 84 within the accuracy of the transformation. Replaces Amersfoort to WGS 84 (2) (code 1672). Replaced by Amersfoort to WGS 84 (4) (tfm code 4833).','Approximation at the +/- 1m level.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4289','EPSG','4326','EPSG','1275',1.0,565.2369,50.0087,465.658,'EPSG','9001',1.9725,-1.7004,9.0677,'EPSG','9109',4.0812,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Nld',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15935','Beijing 1954 to WGS 84 (5)','Concatenated via WGS 72BE. Recomputation by Shelltech in 1981 of SSB 1980 observation.','Geophysical exploration in Bei Bu basin. Accuracy stated as 1m within basin.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4214','EPSG','4326','EPSG','3561',10.0,18.0,-136.8,-73.7,'EPSG','9001',0.0,0.0,0.814,'EPSG','9104',-0.38,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Shlt-Chn BeiBu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15936','Beijing 1954 to WGS 84 (6)','Provided by Sinopec to TOTAL in January 2007.','Geophysical exploration in Ordos basin. Accuracy stated as 1m within basin.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4214','EPSG','4326','EPSG','3466',1.0,11.911,-154.833,-80.079,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Sino-Chn Ord',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15937','Nahrwan 1967 to WGS 84 (7)','Parameter values adopted by Total are mean of those derived by Oceonics and Geoid through ties at station TC58 to 4 IGS stations in March 1995.','Oil exploration.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4270','EPSG','4326','EPSG','3509',2.0,-245.8,-152.2,382.9,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'TOT-UAE Abd',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15938','Nahrwan 1967 to WGS 84 (8)','Derived via WGS 72BE from Transit observations at station TC58 in 1976 by BP for ADMA.','Oil exploration.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4270','EPSG','4326','EPSG','3509',5.0,-225.4,-158.7,380.8,'EPSG','9001',0.0,0.0,0.814,'EPSG','9104',-0.38,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ADMA-UAE Abd',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15952','Nahrwan 1967 to WGS 84 (9)','Used by DPC for Al Fateh field. Applying this transformation gives same result as Nahrwan 1967 to WGS 84 (8) (code 15938).','Oil exploration and production.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4270','EPSG','4326','EPSG','3530',5.0,-244.2,-149.8,379.3,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DPC-UAE Fat',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15953','Nahrwan 1967 to WGS 84 (10)','Used by Dubai Municipality before 1994.','Municipal operations.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4270','EPSG','4326','EPSG','3531',5.0,-250.7,-157.9,380.4,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'Dub-UAE Dub',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15957','Qornoq 1927 to GR96 (1)','Derived via NWL 9D.','For applications with an accuracy of +/- 1m.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4194','EPSG','4747','EPSG','3362',1.0,163.511,127.533,-159.789,'EPSG','9001',0.0,0.0,0.814,'EPSG','9104',-0.6,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'KMS-Grl',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15963','Yacare to SIRGAS (1)','Derived at 11 stations during 1998 densification of Uruguay control based on SIRAGAS 1995.','Accuracy at stations used for derivation: 0.13 to 1.17m.','EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4309','EPSG','4170','EPSG','1247',1.5,-124.45,183.74,44.64,'EPSG','9001',-0.4384,0.5446,-0.9706,'EPSG','9104',-2.1365,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'SGM-Ury',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15964','ED50 to WGS 84 (42)','Developed by the Portuguese Hydrographic Institute and used by the Directorate of Energy and Geology.','Hydrography and minerals management offshore Portugal.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','3537',5.0,-86.277,-108.879,-120.181,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'DGEG-Por off',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15965','S-JTSK to WGS 84 (3)','Derived at 6 stations.','For military purposes. Accuracy 4m, 2m and 3m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4156','EPSG','4326','EPSG','1306',6.0,589.0,76.0,480.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Cze',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15966','HTRS96 to ETRS89 (1)','May be taken as approximate transformation HTRS96 to WGS 84 - see code 15967.','HTRS96 is a national realization of ETRS89.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4761','EPSG','4258','EPSG','1076',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Hrv',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15967','HTRS96 to WGS 84 (1)','Approximation at the +/- 1m level assuming that ETRS89 is equivalent to WGS 84. HTRS96 is a regional realisation of ETRS89.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4761','EPSG','4326','EPSG','1076',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Hrv',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15969','Bermuda 1957 to BDA2000 (1)','Derived in 1998 at 12 stations. May be taken as approximate transformation Bermuda 1957 to WGS 84 - see code 15970.','Accuracy +/- 1 metre. Used for transformation of 1:2500 mapping.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4216','EPSG','4762','EPSG','3221',1.0,-292.295,248.758,429.447,'EPSG','9001',-4.9971,-2.99,-6.6906,'EPSG','9104',1.0289,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'LBS-Bmu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15970','Bermuda 1957 to WGS 84 (2)','Parameter values from Bermuda 1957 to BDA2000 (1) (code 15969). Assumes BDA2000 and WGS 84 can be considered the same to within the accuracy of the transformation.','Accuracy +/- 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4216','EPSG','4326','EPSG','3221',1.0,-292.295,248.758,429.447,'EPSG','9001',-4.9971,-2.99,-6.6906,'EPSG','9104',1.0289,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Bmu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15971','BDA2000 to WGS 84 (1)','Approximation at the +/- 1m level assuming that BDA2000 is equivalent to WGS 84.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4762','EPSG','4326','EPSG','1047',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Bmu',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15972','Pitcairn 2006 to WGS 84 (1)','Approximation at the +/- 1m level assuming that Pitcairn 2006 is equivalent to WGS 84.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4763','EPSG','4326','EPSG','3208',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Pcn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15973','Popular Visualisation CRS to WGS 84 (1)','Executes change of sphere/ellipsoid','Web mapping. Accuracy may be no better than 800 metres.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4055','EPSG','4326','EPSG','1262',800.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-web',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15974','RSRGD2000 to WGS 84 (1)','Approximation at the +/- 1m level assuming that RSRGD2000 is equivalent to WGS 84.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4764','EPSG','4326','EPSG','3558',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Ata',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15975','NZGD49 to WGS 84 (4)','These parameter values are taken from NZGD49 to NZGD2000 (1) (code 1566) and assume that NZGD2000 and WGS 84 are coincident to within the accuracy of the tfm. For better accuracy use NZGD49 to WGS 84 (2) (code 1564) or NZGD49 to WGS 84 (3) (code 1670).','5m accuracy.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4272','EPSG','4326','EPSG','3285',5.0,54.4,-20.1,183.1,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OSG-Nzl 5m',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15976','Slovenia 1996 to WGS 84 (1)','Approximation at the +/- 1m level assuming that ETRS89 is equivalent to WGS 84.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4765','EPSG','4326','EPSG','1212',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Svn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15977','Slovenia 1996 to ETRS89 (1)','Slovenia 1996 is a local densification of ETRS89.','Accuracy +/- 1 metre.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4765','EPSG','4258','EPSG','1212',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Svn',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15978','NAD27 to WGS 84 (88)','','Accuracy 1m.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4267','EPSG','4326','EPSG','1077',1.0,2.478,149.752,197.726,'EPSG','9001',-0.526,-0.498,0.501,'EPSG','9104',0.685,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ONHG-Cub',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15979','AGD66 to GDA94 (12)','Use only offshore: onshore, tfms 1458 (ACT), 1594 (Tas), 1460 (NSW and Vic) and 1595 (NT) are more accurate.May be used as a tfm to WGS 84 - see code 15980.','3m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4202','EPSG','4283','EPSG','3559',3.0,-117.808,-51.536,137.784,'EPSG','9001',-0.303,-0.446,-0.234,'EPSG','9104',-0.29,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ICSM-Aus off',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15980','AGD66 to WGS 84 (18)','Parameter values from AGD66 to GDA94 (12) (code 15979). Assumes GDA94 and WGS 84 can be considered the same to within the accuracy of the transformation. Use only offshore: onshore tfms 1665-68 for ACT, NSW/Vic, Tas and NT respectively are more accurate.','3m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4202','EPSG','4326','EPSG','3559',3.0,-117.808,-51.536,137.784,'EPSG','9001',-0.303,-0.446,-0.234,'EPSG','9104',-0.29,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'EPSG-Aus off',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15981','MGI to Slovenia 1996 (1)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible. May be taken as approximate tfm MGI to WGS 84 (see code 15982)','1m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4312','EPSG','4765','EPSG','1212',1.0,409.545,72.164,486.872,'EPSG','9001',-3.085957,-5.46911,11.020289,'EPSG','9104',17.919665,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15982','MGI to WGS 84 (9)','Parameter values from MGI to Slovenia 1996 (1) (code 15981). Assumes Slovenia 1996 and WGS 84 can be considered the same to within the accuracy of the transformation.','For applications to an accuracy of 1 metre.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4312','EPSG','4326','EPSG','1212',1.0,409.545,72.164,486.872,'EPSG','9001',-3.085957,-5.46911,11.020289,'EPSG','9104',17.919665,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Svn 96',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15983','MGI to Slovenia 1996 (2)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.5m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4312','EPSG','4765','EPSG','3564',0.5,315.393,186.223,499.609,'EPSG','9001',-6.445954,-8.131631,13.208641,'EPSG','9104',23.449046,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn W',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15984','MGI to Slovenia 1996 (3)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.5m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4312','EPSG','4765','EPSG','3565',0.5,464.939,-21.478,504.497,'EPSG','9001',0.403,-4.228747,9.954942,'EPSG','9104',12.795378,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn NE',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15985','MGI to Slovenia 1996 (4)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.5m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4312','EPSG','4765','EPSG','3566',0.5,459.968,82.193,458.756,'EPSG','9001',-3.565234,-3.700593,10.860523,'EPSG','9104',15.507563,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn SE 0.5m',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15986','MGI to Slovenia 1996 (5)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.3m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4312','EPSG','4765','EPSG','3567',0.3,427.914,105.528,510.908,'EPSG','9001',-4.992523,-5.898813,10.306673,'EPSG','9104',12.431493,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn SE 0.3m',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15987','MGI to Slovenia 1996 (6)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.3m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4312','EPSG','4765','EPSG','3568',0.3,468.63,81.389,445.221,'EPSG','9001',-3.839242,-3.262525,10.566866,'EPSG','9104',16.132726,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn Dol',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15988','MGI to Slovenia 1996 (7)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.3m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4312','EPSG','4765','EPSG','3569',0.3,439.5,-11.77,494.976,'EPSG','9001',-0.026585,-4.65641,10.155824,'EPSG','9104',16.270002,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn Staj',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15989','MGI to Slovenia 1996 (8)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.3m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4312','EPSG','4765','EPSG','3570',0.3,524.442,3.275,519.002,'EPSG','9001',0.013287,-3.119714,10.232693,'EPSG','9104',4.184981,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn Pom',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15990','MGI to Slovenia 1996 (9)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.3m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4312','EPSG','4765','EPSG','3571',0.3,281.529,45.963,537.515,'EPSG','9001',-2.570437,-9.648271,10.759507,'EPSG','9104',26.465548,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn Gor',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15991','MGI to Slovenia 1996 (10)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.3m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4312','EPSG','4765','EPSG','3572',0.3,355.845,274.282,462.979,'EPSG','9001',-9.086933,-6.491055,14.502181,'EPSG','9104',20.888647,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn Prim',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15992','MGI to Slovenia 1996 (11)','Info source also gives a separate reverse tfm with slightly different parameter values. Given the tfm accuracy these differences are not significant and this tfm can be considered reversible.','0.3m accuracy.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4312','EPSG','4765','EPSG','3573',0.3,400.629,90.651,472.249,'EPSG','9001',-3.261138,-5.263404,11.83739,'EPSG','9104',20.022676,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'GuRS-Svn cen',1);
INSERT INTO "helmert_transformation" VALUES('EPSG','15993','Pulkovo 1942(58) to ETRS89 (3)','Withdrawn and replaced by S-42 to ETRS89 (4) (tfm code 15994). Consistent with Transdat v2.0 to better than 10m.','Accuracy 5-10m.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4179','EPSG','4258','EPSG','1197',10.0,68.1564,32.7756,80.2249,'EPSG','9001',2.20333014,2.19256447,-2.54166911,'EPSG','9104',-0.14155333,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ANCPI-Rom 2007',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15994','Pulkovo 1942(58) to ETRS89 (4)','Replaces S-42 to ETRS89 (3) (tfm code 15993). Consistent with Transdat v3.0 to better than 0.5m. May be taken as approximate transformation Pulkovo 1942(58) to WGS 84 - see code 15995.','Accuracy of 1.5 to 3 metres horizontal, 3 to 5m vertical.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4179','EPSG','4258','EPSG','1197',3.0,2.3287,-147.0425,-92.0802,'EPSG','9001',0.3092483,-0.32482185,-0.49729934,'EPSG','9104',5.68906266,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'ANCPI-Rom 2008',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15995','Pulkovo 1942(58) to WGS 84 (19)','Parameter values taken from Pulkovo 1942(58) to ETRS89 (4) (code 15994) assuming that ETRS89 is equivalent to WGS 84 within the accuracy of the transformation.','Accuracy of 1.5 to 3 metres horizontal, 3 to 5m vertical.','EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4179','EPSG','4326','EPSG','1197',3.0,2.329,-147.042,-92.08,'EPSG','9001',0.309,-0.325,-0.497,'EPSG','9104',5.69,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'OGP-Rom',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15996','Pulkovo 1942(83) to WGS 84 (3)','Derived at 5 stations.','For military purposes. Accuracy 2m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4178','EPSG','4326','EPSG','1119',4.0,28.0,-121.0,-77.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Hun',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15997','Pulkovo 1942(58) to WGS 84 (4)','Derived at 11 stations.','For military purposes only. Accuracy 4m, 2m and 4m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4179','EPSG','4326','EPSG','3293',6.0,23.0,-124.0,-82.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Pol',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15998','Pulkovo 1942(83) to WGS 84 (5)','Derived at 6 stations.','For military purposes only. Accuracy 3m, 3m and 2m in X, Y and Z axes.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4178','EPSG','4326','EPSG','1306',5.0,26.0,-121.0,-78.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Cze',0);
INSERT INTO "helmert_transformation" VALUES('EPSG','15999','Pulkovo 1942(58) to WGS 84 (8)','Derived at 7 stations.','For military purposes. Accuracy 3m in each axis.','EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4179','EPSG','4326','EPSG','3212',6.0,24.0,-130.0,-92.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,'NIMA-Alb',0);
