--- This file has been generated by scripts/build_db.py. DO NOT EDIT !

INSERT INTO "projected_crs" VALUES('EPSG','2000','Anguilla 1957 / British West Indies Grid',NULL,NULL,'EPSG','4400','EPSG','4600','EPSG','19942','EPSG','3214',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2001','Antigua 1943 / British West Indies Grid',NULL,NULL,'EPSG','4400','EPSG','4601','EPSG','19942','EPSG','1273',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2002','Dominica 1945 / British West Indies Grid',NULL,NULL,'EPSG','4400','EPSG','4602','EPSG','19942','EPSG','3239',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2003','Grenada 1953 / British West Indies Grid',NULL,NULL,'EPSG','4400','EPSG','4603','EPSG','19942','EPSG','1551',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2004','Montserrat 1958 / British West Indies Grid',NULL,NULL,'EPSG','4400','EPSG','4604','EPSG','19942','EPSG','3279',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2005','St. Kitts 1955 / British West Indies Grid',NULL,NULL,'EPSG','4400','EPSG','4605','EPSG','19942','EPSG','3297',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2006','St. Lucia 1955 / British West Indies Grid',NULL,NULL,'EPSG','4400','EPSG','4606','EPSG','19942','EPSG','3298',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2007','St. Vincent 45 / British West Indies Grid',NULL,NULL,'EPSG','4400','EPSG','4607','EPSG','19942','EPSG','3300',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2008','NAD27(CGQ77) / SCoPQ zone 2',NULL,NULL,'EPSG','4499','EPSG','4609','EPSG','17700','EPSG','1420',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2009','NAD27(CGQ77) / SCoPQ zone 3',NULL,NULL,'EPSG','4499','EPSG','4609','EPSG','17703','EPSG','1446',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2010','NAD27(CGQ77) / SCoPQ zone 4',NULL,NULL,'EPSG','4499','EPSG','4609','EPSG','17704','EPSG','1422',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2011','NAD27(CGQ77) / SCoPQ zone 5',NULL,NULL,'EPSG','4499','EPSG','4609','EPSG','17705','EPSG','1423',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2012','NAD27(CGQ77) / SCoPQ zone 6',NULL,NULL,'EPSG','4499','EPSG','4609','EPSG','17706','EPSG','1424',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2013','NAD27(CGQ77) / SCoPQ zone 7',NULL,NULL,'EPSG','4499','EPSG','4609','EPSG','17707','EPSG','1425',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2014','NAD27(CGQ77) / SCoPQ zone 8',NULL,NULL,'EPSG','4499','EPSG','4609','EPSG','17708','EPSG','1426',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2015','NAD27(CGQ77) / SCoPQ zone 9',NULL,NULL,'EPSG','4499','EPSG','4609','EPSG','17709','EPSG','1427',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2016','NAD27(CGQ77) / SCoPQ zone 10',NULL,NULL,'EPSG','4499','EPSG','4609','EPSG','17710','EPSG','1428',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2017','NAD27(76) / MTM zone 8',NULL,NULL,'EPSG','4499','EPSG','4608','EPSG','17708','EPSG','1429',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2018','NAD27(76) / MTM zone 9',NULL,NULL,'EPSG','4499','EPSG','4608','EPSG','17709','EPSG','1430',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2019','NAD27(76) / MTM zone 10',NULL,NULL,'EPSG','4499','EPSG','4608','EPSG','17710','EPSG','1431',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2020','NAD27(76) / MTM zone 11',NULL,NULL,'EPSG','4400','EPSG','4608','EPSG','17711','EPSG','1432',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2021','NAD27(76) / MTM zone 12',NULL,NULL,'EPSG','4400','EPSG','4608','EPSG','17712','EPSG','1433',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2022','NAD27(76) / MTM zone 13',NULL,NULL,'EPSG','4400','EPSG','4608','EPSG','17713','EPSG','1434',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2023','NAD27(76) / MTM zone 14',NULL,NULL,'EPSG','4400','EPSG','4608','EPSG','17714','EPSG','1435',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2024','NAD27(76) / MTM zone 15',NULL,NULL,'EPSG','4400','EPSG','4608','EPSG','17715','EPSG','1436',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2025','NAD27(76) / MTM zone 16',NULL,NULL,'EPSG','4400','EPSG','4608','EPSG','17716','EPSG','1437',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2026','NAD27(76) / MTM zone 17',NULL,NULL,'EPSG','4400','EPSG','4608','EPSG','17717','EPSG','1438',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2027','NAD27(76) / UTM zone 15N',NULL,NULL,'EPSG','4400','EPSG','4608','EPSG','16015','EPSG','1439',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2028','NAD27(76) / UTM zone 16N',NULL,NULL,'EPSG','4400','EPSG','4608','EPSG','16016','EPSG','1440',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2029','NAD27(76) / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4608','EPSG','16017','EPSG','1441',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2030','NAD27(76) / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4608','EPSG','16018','EPSG','1442',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2031','NAD27(CGQ77) / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4609','EPSG','16017','EPSG','1428',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2032','NAD27(CGQ77) / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4609','EPSG','16018','EPSG','1443',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2033','NAD27(CGQ77) / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4609','EPSG','16019','EPSG','1444',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2034','NAD27(CGQ77) / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4609','EPSG','16020','EPSG','1445',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2035','NAD27(CGQ77) / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4609','EPSG','16021','EPSG','1446',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2036','NAD83(CSRS98) / New Brunswick Stereo',NULL,NULL,'EPSG','4500','EPSG','4140','EPSG','19946','EPSG','1447',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2037','NAD83(CSRS98) / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4140','EPSG','16019','EPSG','1448',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2038','NAD83(CSRS98) / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4140','EPSG','16020','EPSG','1449',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2039','Israel 1993 / Israeli TM Grid',NULL,NULL,'EPSG','4400','EPSG','4141','EPSG','18204','EPSG','2603',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2040','Locodjo 1965 / UTM zone 30N',NULL,NULL,'EPSG','4400','EPSG','4142','EPSG','16030','EPSG','1450',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2041','Abidjan 1987 / UTM zone 30N',NULL,NULL,'EPSG','4400','EPSG','4143','EPSG','16030','EPSG','1450',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2042','Locodjo 1965 / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4142','EPSG','16029','EPSG','1451',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2043','Abidjan 1987 / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4143','EPSG','16029','EPSG','1451',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2044','Hanoi 1972 / Gauss-Kruger zone 18',NULL,NULL,'EPSG','4530','EPSG','4147','EPSG','16218','EPSG','1452',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2045','Hanoi 1972 / Gauss-Kruger zone 19',NULL,NULL,'EPSG','4530','EPSG','4147','EPSG','16219','EPSG','1453',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2046','Hartebeesthoek94 / Lo15',NULL,NULL,'EPSG','6503','EPSG','4148','EPSG','17515','EPSG','1454',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2047','Hartebeesthoek94 / Lo17',NULL,NULL,'EPSG','6503','EPSG','4148','EPSG','17517','EPSG','1455',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2048','Hartebeesthoek94 / Lo19',NULL,NULL,'EPSG','6503','EPSG','4148','EPSG','17519','EPSG','1456',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2049','Hartebeesthoek94 / Lo21',NULL,NULL,'EPSG','6503','EPSG','4148','EPSG','17521','EPSG','1457',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2050','Hartebeesthoek94 / Lo23',NULL,NULL,'EPSG','6503','EPSG','4148','EPSG','17523','EPSG','1458',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2051','Hartebeesthoek94 / Lo25',NULL,NULL,'EPSG','6503','EPSG','4148','EPSG','17525','EPSG','1459',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2052','Hartebeesthoek94 / Lo27',NULL,NULL,'EPSG','6503','EPSG','4148','EPSG','17527','EPSG','1460',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2053','Hartebeesthoek94 / Lo29',NULL,NULL,'EPSG','6503','EPSG','4148','EPSG','17529','EPSG','1461',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2054','Hartebeesthoek94 / Lo31',NULL,NULL,'EPSG','6503','EPSG','4148','EPSG','17531','EPSG','1462',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2055','Hartebeesthoek94 / Lo33',NULL,NULL,'EPSG','6503','EPSG','4148','EPSG','17533','EPSG','1463',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2056','CH1903+ / LV95',NULL,NULL,'EPSG','4400','EPSG','4150','EPSG','19950','EPSG','1286',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2057','Rassadiran / Nakhl e Taqi',NULL,NULL,'EPSG','4400','EPSG','4153','EPSG','19951','EPSG','1338',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2058','ED50(ED77) / UTM zone 38N',NULL,NULL,'EPSG','4400','EPSG','4154','EPSG','16038','EPSG','1464',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2059','ED50(ED77) / UTM zone 39N',NULL,NULL,'EPSG','4400','EPSG','4154','EPSG','16039','EPSG','1465',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2060','ED50(ED77) / UTM zone 40N',NULL,NULL,'EPSG','4400','EPSG','4154','EPSG','16040','EPSG','1466',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2061','ED50(ED77) / UTM zone 41N',NULL,NULL,'EPSG','4400','EPSG','4154','EPSG','16041','EPSG','1467',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2062','Madrid 1870 (Madrid) / Spain',NULL,NULL,'EPSG','4499','EPSG','4903','EPSG','19921','EPSG','2366',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2063','Dabola 1981 / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4315','EPSG','16028','EPSG','1468',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2064','Dabola 1981 / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4315','EPSG','16029','EPSG','1469',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2065','S-JTSK (Ferro) / Krovak',NULL,NULL,'EPSG','6501','EPSG','4818','EPSG','19952','EPSG','1306',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2066','Mount Dillon / Tobago Grid',NULL,NULL,'EPSG','4407','EPSG','4157','EPSG','19924','EPSG','1322',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2067','Naparima 1955 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4158','EPSG','16020','EPSG','3143',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2068','ELD79 / Libya zone 5',NULL,NULL,'EPSG','4499','EPSG','4159','EPSG','18240','EPSG','1470',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2069','ELD79 / Libya zone 6',NULL,NULL,'EPSG','4499','EPSG','4159','EPSG','18241','EPSG','1471',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2070','ELD79 / Libya zone 7',NULL,NULL,'EPSG','4499','EPSG','4159','EPSG','18242','EPSG','1472',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2071','ELD79 / Libya zone 8',NULL,NULL,'EPSG','4499','EPSG','4159','EPSG','18243','EPSG','1473',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2072','ELD79 / Libya zone 9',NULL,NULL,'EPSG','4499','EPSG','4159','EPSG','18244','EPSG','1474',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2073','ELD79 / Libya zone 10',NULL,NULL,'EPSG','4499','EPSG','4159','EPSG','18245','EPSG','1475',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2074','ELD79 / Libya zone 11',NULL,NULL,'EPSG','4499','EPSG','4159','EPSG','18246','EPSG','1476',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2075','ELD79 / Libya zone 12',NULL,NULL,'EPSG','4499','EPSG','4159','EPSG','18247','EPSG','1477',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2076','ELD79 / Libya zone 13',NULL,NULL,'EPSG','4499','EPSG','4159','EPSG','18248','EPSG','1478',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2077','ELD79 / UTM zone 32N',NULL,NULL,'EPSG','4400','EPSG','4159','EPSG','16032','EPSG','1479',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2078','ELD79 / UTM zone 33N',NULL,NULL,'EPSG','4400','EPSG','4159','EPSG','16033','EPSG','1480',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2079','ELD79 / UTM zone 34N',NULL,NULL,'EPSG','4400','EPSG','4159','EPSG','16034','EPSG','1481',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2080','ELD79 / UTM zone 35N',NULL,NULL,'EPSG','4400','EPSG','4159','EPSG','16035','EPSG','1478',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2081','Chos Malal 1914 / Argentina 2',NULL,NULL,'EPSG','4530','EPSG','4160','EPSG','18032','EPSG','1483',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2082','Pampa del Castillo / Argentina 2',NULL,NULL,'EPSG','4530','EPSG','4161','EPSG','18032','EPSG','1484',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2083','Hito XVIII 1963 / Argentina 2',NULL,NULL,'EPSG','4530','EPSG','4254','EPSG','18032','EPSG','1485',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2084','Hito XVIII 1963 / UTM zone 19S',NULL,NULL,'EPSG','4400','EPSG','4254','EPSG','16119','EPSG','2596',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2085','NAD27 / Cuba Norte',NULL,NULL,'EPSG','4532','EPSG','4267','EPSG','18061','EPSG','1487',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2086','NAD27 / Cuba Sur',NULL,NULL,'EPSG','4532','EPSG','4267','EPSG','18062','EPSG','1488',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2087','ELD79 / TM 12 NE',NULL,NULL,'EPSG','4400','EPSG','4159','EPSG','16412','EPSG','1482',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2088','Carthage / TM 11 NE',NULL,NULL,'EPSG','4400','EPSG','4223','EPSG','16411','EPSG','1489',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2089','Yemen NGN96 / UTM zone 38N',NULL,NULL,'EPSG','4400','EPSG','4163','EPSG','16038','EPSG','1490',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2090','Yemen NGN96 / UTM zone 39N',NULL,NULL,'EPSG','4400','EPSG','4163','EPSG','16039','EPSG','1491',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2091','South Yemen / Gauss Kruger zone 8',NULL,NULL,'EPSG','4530','EPSG','4164','EPSG','16208','EPSG','1492',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2092','South Yemen / Gauss Kruger zone 9',NULL,NULL,'EPSG','4530','EPSG','4164','EPSG','16209','EPSG','1493',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2093','Hanoi 1972 / GK 106 NE',NULL,NULL,'EPSG','4530','EPSG','4147','EPSG','16586','EPSG','1494',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2094','WGS 72BE / TM 106 NE',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16506','EPSG','1495',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2095','Bissau / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4165','EPSG','16028','EPSG','3258',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2096','Korean 1985 / East Belt',NULL,NULL,'EPSG','4530','EPSG','4162','EPSG','18251','EPSG','1496',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2097','Korean 1985 / Central Belt',NULL,NULL,'EPSG','4530','EPSG','4162','EPSG','18252','EPSG','3730',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2098','Korean 1985 / West Belt',NULL,NULL,'EPSG','4530','EPSG','4162','EPSG','18253','EPSG','1498',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2099','Qatar 1948 / Qatar Grid',NULL,NULL,'EPSG','4400','EPSG','4286','EPSG','19953','EPSG','1346',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2100','GGRS87 / Greek Grid',NULL,NULL,'EPSG','4400','EPSG','4121','EPSG','19930','EPSG','3254',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2101','Lake / Maracaibo Grid M1',NULL,NULL,'EPSG','4499','EPSG','4249','EPSG','18260','EPSG','1319',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2102','Lake / Maracaibo Grid',NULL,NULL,'EPSG','4499','EPSG','4249','EPSG','18261','EPSG','1319',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2103','Lake / Maracaibo Grid M3',NULL,NULL,'EPSG','4499','EPSG','4249','EPSG','18262','EPSG','1319',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2104','Lake / Maracaibo La Rosa Grid',NULL,NULL,'EPSG','4499','EPSG','4249','EPSG','18263','EPSG','1499',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2105','NZGD2000 / Mount Eden 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17931','EPSG','3781',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2106','NZGD2000 / Bay of Plenty 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17932','EPSG','3779',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2107','NZGD2000 / Poverty Bay 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17933','EPSG','3780',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2108','NZGD2000 / Hawkes Bay 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17934','EPSG','3772',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2109','NZGD2000 / Taranaki 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17935','EPSG','3777',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2110','NZGD2000 / Tuhirangi 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17936','EPSG','3778',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2111','NZGD2000 / Wanganui 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17937','EPSG','3776',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2112','NZGD2000 / Wairarapa 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17938','EPSG','3775',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2113','NZGD2000 / Wellington 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17939','EPSG','3774',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2114','NZGD2000 / Collingwood 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17940','EPSG','3782',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2115','NZGD2000 / Nelson 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17941','EPSG','3784',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2116','NZGD2000 / Karamea 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17942','EPSG','3783',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2117','NZGD2000 / Buller 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17943','EPSG','3786',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2118','NZGD2000 / Grey 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17944','EPSG','3787',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2119','NZGD2000 / Amuri 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17945','EPSG','3788',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2120','NZGD2000 / Marlborough 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17946','EPSG','3785',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2121','NZGD2000 / Hokitika 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17947','EPSG','3789',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2122','NZGD2000 / Okarito 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17948','EPSG','3791',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2123','NZGD2000 / Jacksons Bay 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17949','EPSG','3794',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2124','NZGD2000 / Mount Pleasant 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17950','EPSG','3790',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2125','NZGD2000 / Gawler 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17951','EPSG','3792',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2126','NZGD2000 / Timaru 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17952','EPSG','3793',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2127','NZGD2000 / Lindis Peak 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17953','EPSG','3795',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2128','NZGD2000 / Mount Nicholas 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17954','EPSG','3797',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2129','NZGD2000 / Mount York 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17955','EPSG','3799',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2130','NZGD2000 / Observation Point 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17956','EPSG','3796',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2131','NZGD2000 / North Taieri 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17957','EPSG','3798',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2132','NZGD2000 / Bluff 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17958','EPSG','3800',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2133','NZGD2000 / UTM zone 58S',NULL,NULL,'EPSG','4400','EPSG','4167','EPSG','16158','EPSG','1502',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2134','NZGD2000 / UTM zone 59S',NULL,NULL,'EPSG','4400','EPSG','4167','EPSG','16159','EPSG','1503',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2135','NZGD2000 / UTM zone 60S',NULL,NULL,'EPSG','4400','EPSG','4167','EPSG','16160','EPSG','1504',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2136','Accra / Ghana National Grid',NULL,NULL,'EPSG','4404','EPSG','4168','EPSG','19959','EPSG','3252',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2137','Accra / TM 1 NW',NULL,NULL,'EPSG','4400','EPSG','4168','EPSG','17001','EPSG','1505',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2138','NAD27(CGQ77) / Quebec Lambert',NULL,NULL,'EPSG','4499','EPSG','4609','EPSG','19944','EPSG','1368',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2139','NAD83(CSRS98) / SCoPQ zone 2',NULL,NULL,'EPSG','4499','EPSG','4140','EPSG','17700','EPSG','1420',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2140','NAD83(CSRS98) / MTM zone 3',NULL,NULL,'EPSG','4496','EPSG','4140','EPSG','17703','EPSG','1421',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2141','NAD83(CSRS98) / MTM zone 4',NULL,NULL,'EPSG','4496','EPSG','4140','EPSG','17704','EPSG','1422',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2142','NAD83(CSRS98) / MTM zone 5',NULL,NULL,'EPSG','4496','EPSG','4140','EPSG','17705','EPSG','1423',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2143','NAD83(CSRS98) / MTM zone 6',NULL,NULL,'EPSG','4496','EPSG','4140','EPSG','17706','EPSG','1424',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2144','NAD83(CSRS98) / MTM zone 7',NULL,NULL,'EPSG','4496','EPSG','4140','EPSG','17707','EPSG','1425',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2145','NAD83(CSRS98) / MTM zone 8',NULL,NULL,'EPSG','4496','EPSG','4140','EPSG','17708','EPSG','1426',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2146','NAD83(CSRS98) / MTM zone 9',NULL,NULL,'EPSG','4496','EPSG','4140','EPSG','17709','EPSG','1427',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2147','NAD83(CSRS98) / MTM zone 10',NULL,NULL,'EPSG','4496','EPSG','4140','EPSG','17710','EPSG','1428',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2148','NAD83(CSRS98) / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4140','EPSG','16021','EPSG','1446',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2149','NAD83(CSRS98) / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4140','EPSG','16018','EPSG','1443',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2150','NAD83(CSRS98) / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4140','EPSG','16017','EPSG','1428',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2151','NAD83(CSRS98) / UTM zone 13N',NULL,NULL,'EPSG','4400','EPSG','4140','EPSG','16013','EPSG','1506',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2152','NAD83(CSRS98) / UTM zone 12N',NULL,NULL,'EPSG','4400','EPSG','4140','EPSG','16012','EPSG','1507',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2153','NAD83(CSRS98) / UTM zone 11N',NULL,NULL,'EPSG','4400','EPSG','4140','EPSG','16011','EPSG','1508',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2154','RGF93 / Lambert-93',NULL,NULL,'EPSG','4499','EPSG','4171','EPSG','18085','EPSG','1096',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2155','American Samoa 1962 / American Samoa Lambert',NULL,NULL,'EPSG','4497','EPSG','4169','EPSG','15300','EPSG','1027',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2156','NAD83(HARN) / UTM zone 59S',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16159','EPSG','1027',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2157','IRENET95 / Irish Transverse Mercator',NULL,NULL,'EPSG','4400','EPSG','4173','EPSG','19962','EPSG','1305',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2158','IRENET95 / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4173','EPSG','16029','EPSG','1305',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2159','Sierra Leone 1924 / New Colony Grid',NULL,NULL,'EPSG','4404','EPSG','4174','EPSG','19963','EPSG','1342',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2160','Sierra Leone 1924 / New War Office Grid',NULL,NULL,'EPSG','4404','EPSG','4174','EPSG','19964','EPSG','1342',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2161','Sierra Leone 1968 / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4175','EPSG','16028','EPSG','1509',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2162','Sierra Leone 1968 / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4175','EPSG','16029','EPSG','1510',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2163','US National Atlas Equal Area',NULL,NULL,'EPSG','4499','EPSG','4052','EPSG','3899','EPSG','1245',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2164','Locodjo 1965 / TM 5 NW',NULL,NULL,'EPSG','4400','EPSG','4142','EPSG','17005','EPSG','2296',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2165','Abidjan 1987 / TM 5 NW',NULL,NULL,'EPSG','4400','EPSG','4143','EPSG','17005','EPSG','2296',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2166','Pulkovo 1942(83) / Gauss Kruger zone 3',NULL,NULL,'EPSG','4530','EPSG','4178','EPSG','16263','EPSG','1512',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2167','Pulkovo 1942(83) / Gauss Kruger zone 4',NULL,NULL,'EPSG','4530','EPSG','4178','EPSG','16264','EPSG','1513',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2168','Pulkovo 1942(83) / Gauss Kruger zone 5',NULL,NULL,'EPSG','4530','EPSG','4178','EPSG','16265','EPSG','1512',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2169','Luxembourg 1930 / Gauss',NULL,NULL,'EPSG','4530','EPSG','4181','EPSG','19966','EPSG','1146',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2170','MGI / Slovenia Grid',NULL,NULL,'EPSG','4530','EPSG','4312','EPSG','19967','EPSG','1212',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2171','Pulkovo 1942(58) / Poland zone I',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','18281','EPSG','1515',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2172','Pulkovo 1942(58) / Poland zone II',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','18282','EPSG','1516',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2173','Pulkovo 1942(58) / Poland zone III',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','18283','EPSG','1517',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2174','Pulkovo 1942(58) / Poland zone IV',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','18284','EPSG','1518',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2175','Pulkovo 1942(58) / Poland zone V',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','18285','EPSG','1519',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2176','ETRS89 / Poland CS2000 zone 5',NULL,NULL,'EPSG','4531','EPSG','4258','EPSG','18305','EPSG','1520',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2177','ETRS89 / Poland CS2000 zone 6',NULL,NULL,'EPSG','4531','EPSG','4258','EPSG','18306','EPSG','1521',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2178','ETRS89 / Poland CS2000 zone 7',NULL,NULL,'EPSG','4531','EPSG','4258','EPSG','18307','EPSG','1522',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2179','ETRS89 / Poland CS2000 zone 8',NULL,NULL,'EPSG','4531','EPSG','4258','EPSG','18308','EPSG','1523',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2180','ETRS89 / Poland CS92',NULL,NULL,'EPSG','4531','EPSG','4258','EPSG','18300','EPSG','1192',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2188','Azores Occidental 1939 / UTM zone 25N',NULL,NULL,'EPSG','4400','EPSG','4182','EPSG','16025','EPSG','1344',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2189','Azores Central 1948 / UTM zone 26N',NULL,NULL,'EPSG','4400','EPSG','4183','EPSG','16026','EPSG','1301',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2190','Azores Oriental 1940 / UTM zone 26N',NULL,NULL,'EPSG','4400','EPSG','4184','EPSG','16026','EPSG','1345',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2191','Madeira 1936 / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4185','EPSG','16028','EPSG','1314',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2192','ED50 / France EuroLambert',NULL,NULL,'EPSG','4499','EPSG','4230','EPSG','18086','EPSG','1326',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2193','NZGD2000 / New Zealand Transverse Mercator 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','19971','EPSG','3973',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2194','American Samoa 1962 / American Samoa Lambert',NULL,NULL,'EPSG','4497','EPSG','4169','EPSG','15301','EPSG','1027',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2195','NAD83(HARN) / UTM zone 2S',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16102','EPSG','3110',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2196','ETRS89 / Kp2000 Jutland',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','18401','EPSG','2531',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2197','ETRS89 / Kp2000 Zealand',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','18402','EPSG','2532',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2198','ETRS89 / Kp2000 Bornholm',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','18403','EPSG','2533',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2199','Albanian 1987 / Gauss Kruger zone 4',NULL,NULL,'EPSG','4530','EPSG','4191','EPSG','16204','EPSG','1025',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2200','ATS77 / New Brunswick Stereographic (ATS77)',NULL,NULL,'EPSG','4500','EPSG','4122','EPSG','19945','EPSG','1447',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2201','REGVEN / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4189','EPSG','16018','EPSG','1693',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2202','REGVEN / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4189','EPSG','16019','EPSG','3859',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2203','REGVEN / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4189','EPSG','16020','EPSG','3858',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2204','NAD27 / Tennessee',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15302','EPSG','1411',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2205','NAD83 / Kentucky North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15303','EPSG','2202',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2206','ED50 / 3-degree Gauss-Kruger zone 9',NULL,NULL,'EPSG','4530','EPSG','4230','EPSG','16269','EPSG','1524',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2207','ED50 / 3-degree Gauss-Kruger zone 10',NULL,NULL,'EPSG','4530','EPSG','4230','EPSG','16270','EPSG','1525',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2208','ED50 / 3-degree Gauss-Kruger zone 11',NULL,NULL,'EPSG','4530','EPSG','4230','EPSG','16271','EPSG','1526',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2209','ED50 / 3-degree Gauss-Kruger zone 12',NULL,NULL,'EPSG','4530','EPSG','4230','EPSG','16272','EPSG','1527',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2210','ED50 / 3-degree Gauss-Kruger zone 13',NULL,NULL,'EPSG','4530','EPSG','4230','EPSG','16273','EPSG','1528',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2211','ED50 / 3-degree Gauss-Kruger zone 14',NULL,NULL,'EPSG','4530','EPSG','4230','EPSG','16274','EPSG','1529',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2212','ED50 / 3-degree Gauss-Kruger zone 15',NULL,NULL,'EPSG','4530','EPSG','4230','EPSG','16275','EPSG','1530',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2213','ETRS89 / TM 30 NE',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','16430','EPSG','2546',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2214','Douala 1948 / AOF west',NULL,NULL,'EPSG','4400','EPSG','4192','EPSG','18415','EPSG','2555',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2215','Manoca 1962 / UTM zone 32N',NULL,NULL,'EPSG','4400','EPSG','4193','EPSG','16032','EPSG','2555',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2216','Qornoq 1927 / UTM zone 22N',NULL,NULL,'EPSG','4400','EPSG','4194','EPSG','16022','EPSG','2573',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2217','Qornoq 1927 / UTM zone 23N',NULL,NULL,'EPSG','4400','EPSG','4194','EPSG','16023','EPSG','2572',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2218','Scoresbysund 1952 / Greenland zone 5 east',NULL,NULL,'EPSG','1031','EPSG','4195','EPSG','18425','EPSG','3370',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2219','ATS77 / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4122','EPSG','16019','EPSG','1531',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2220','ATS77 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4122','EPSG','16020','EPSG','1532',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2221','Scoresbysund 1952 / Greenland zone 6 east',NULL,NULL,'EPSG','1031','EPSG','4195','EPSG','18426','EPSG','3369',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2222','NAD83 / Arizona East (ft)',NULL,NULL,'EPSG','4495','EPSG','4269','EPSG','15304','EPSG','2167',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2223','NAD83 / Arizona Central (ft)',NULL,NULL,'EPSG','4495','EPSG','4269','EPSG','15305','EPSG','2166',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2224','NAD83 / Arizona West (ft)',NULL,NULL,'EPSG','4495','EPSG','4269','EPSG','15306','EPSG','2168',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2225','NAD83 / California zone 1 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15307','EPSG','2175',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2226','NAD83 / California zone 2 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15308','EPSG','2176',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2227','NAD83 / California zone 3 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15309','EPSG','2177',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2228','NAD83 / California zone 4 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15310','EPSG','2178',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2229','NAD83 / California zone 5 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15311','EPSG','2182',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2230','NAD83 / California zone 6 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15312','EPSG','2180',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2231','NAD83 / Colorado North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15313','EPSG','2184',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2232','NAD83 / Colorado Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15314','EPSG','2183',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2233','NAD83 / Colorado South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15315','EPSG','2185',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2234','NAD83 / Connecticut (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15316','EPSG','1377',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2235','NAD83 / Delaware (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15317','EPSG','1378',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2236','NAD83 / Florida East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15318','EPSG','2186',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2237','NAD83 / Florida West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15319','EPSG','2188',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2238','NAD83 / Florida North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15320','EPSG','2187',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2239','NAD83 / Georgia East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15321','EPSG','2189',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2240','NAD83 / Georgia West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15322','EPSG','2190',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2241','NAD83 / Idaho East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15323','EPSG','2192',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2242','NAD83 / Idaho Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15324','EPSG','2191',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2243','NAD83 / Idaho West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15325','EPSG','2193',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2244','NAD83 / Indiana East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15326','EPSG','2196',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2245','NAD83 / Indiana West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15327','EPSG','2197',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2246','NAD83 / Kentucky North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15328','EPSG','2202',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2247','NAD83 / Kentucky South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15329','EPSG','2203',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2248','NAD83 / Maryland (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15330','EPSG','1389',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2249','NAD83 / Massachusetts Mainland (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15331','EPSG','2209',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2250','NAD83 / Massachusetts Island (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15332','EPSG','2208',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2251','NAD83 / Michigan North (ft)',NULL,NULL,'EPSG','4495','EPSG','4269','EPSG','15333','EPSG','1723',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2252','NAD83 / Michigan Central (ft)',NULL,NULL,'EPSG','4495','EPSG','4269','EPSG','15334','EPSG','1724',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2253','NAD83 / Michigan South (ft)',NULL,NULL,'EPSG','4495','EPSG','4269','EPSG','15335','EPSG','1725',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2254','NAD83 / Mississippi East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15336','EPSG','2216',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2255','NAD83 / Mississippi West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15337','EPSG','2217',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2256','NAD83 / Montana (ft)',NULL,NULL,'EPSG','4495','EPSG','4269','EPSG','15338','EPSG','1395',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2257','NAD83 / New Mexico East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15339','EPSG','2228',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2258','NAD83 / New Mexico Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15340','EPSG','2231',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2259','NAD83 / New Mexico West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15341','EPSG','2232',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2260','NAD83 / New York East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15342','EPSG','2234',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2261','NAD83 / New York Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15343','EPSG','2233',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2262','NAD83 / New York West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15344','EPSG','2236',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2263','NAD83 / New York Long Island (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15345','EPSG','2235',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2264','NAD83 / North Carolina (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15346','EPSG','1402',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2265','NAD83 / North Dakota North (ft)',NULL,NULL,'EPSG','4495','EPSG','4269','EPSG','15347','EPSG','2237',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2266','NAD83 / North Dakota South (ft)',NULL,NULL,'EPSG','4495','EPSG','4269','EPSG','15348','EPSG','2238',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2267','NAD83 / Oklahoma North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15349','EPSG','2241',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2268','NAD83 / Oklahoma South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15350','EPSG','2242',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2269','NAD83 / Oregon North (ft)',NULL,NULL,'EPSG','4495','EPSG','4269','EPSG','15351','EPSG','2243',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2270','NAD83 / Oregon South (ft)',NULL,NULL,'EPSG','4495','EPSG','4269','EPSG','15352','EPSG','2244',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2271','NAD83 / Pennsylvania North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15353','EPSG','2245',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2272','NAD83 / Pennsylvania South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15354','EPSG','2246',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2273','NAD83 / South Carolina (ft)',NULL,NULL,'EPSG','4495','EPSG','4269','EPSG','15355','EPSG','1409',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2274','NAD83 / Tennessee (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15356','EPSG','1411',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2275','NAD83 / Texas North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15357','EPSG','2253',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2276','NAD83 / Texas North Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15358','EPSG','2254',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2277','NAD83 / Texas Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15359','EPSG','2252',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2278','NAD83 / Texas South Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15360','EPSG','2527',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2279','NAD83 / Texas South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15361','EPSG','2528',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2280','NAD83 / Utah North (ft)',NULL,NULL,'EPSG','4495','EPSG','4269','EPSG','15362','EPSG','2258',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2281','NAD83 / Utah Central (ft)',NULL,NULL,'EPSG','4495','EPSG','4269','EPSG','15363','EPSG','2257',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2282','NAD83 / Utah South (ft)',NULL,NULL,'EPSG','4495','EPSG','4269','EPSG','15364','EPSG','2259',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2283','NAD83 / Virginia North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15365','EPSG','2260',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2284','NAD83 / Virginia South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15366','EPSG','2261',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2285','NAD83 / Washington North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15367','EPSG','2273',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2286','NAD83 / Washington South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15368','EPSG','2274',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2287','NAD83 / Wisconsin North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15369','EPSG','2267',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2288','NAD83 / Wisconsin Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15370','EPSG','2266',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2289','NAD83 / Wisconsin South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15371','EPSG','2268',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2290','ATS77 / Prince Edward Isl. Stereographic (ATS77)',NULL,NULL,'EPSG','4496','EPSG','4122','EPSG','19933','EPSG','1533',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2291','NAD83(CSRS98) / Prince Edward Isl. Stereographic (NAD83)',NULL,NULL,'EPSG','4496','EPSG','4122','EPSG','19960','EPSG','1533',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2292','NAD83(CSRS98) / Prince Edward Isl. Stereographic (NAD83)',NULL,NULL,'EPSG','4496','EPSG','4140','EPSG','19960','EPSG','1533',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2294','ATS77 / MTM Nova Scotia zone 4',NULL,NULL,'EPSG','4400','EPSG','4122','EPSG','17794','EPSG','1534',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2295','ATS77 / MTM Nova Scotia zone 5',NULL,NULL,'EPSG','4400','EPSG','4122','EPSG','17795','EPSG','1535',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2296','Ammassalik 1958 / Greenland zone 7 east',NULL,NULL,'EPSG','1031','EPSG','4196','EPSG','18427','EPSG','2571',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2297','Qornoq 1927 / Greenland zone 1 east',NULL,NULL,'EPSG','4501','EPSG','4194','EPSG','18421','EPSG','2556',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2298','Qornoq 1927 / Greenland zone 2 east',NULL,NULL,'EPSG','4501','EPSG','4194','EPSG','18422','EPSG','2557',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2299','Qornoq 1927 / Greenland zone 2 west',NULL,NULL,'EPSG','1031','EPSG','4194','EPSG','18432','EPSG','3368',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2300','Qornoq 1927 / Greenland zone 3 east',NULL,NULL,'EPSG','4501','EPSG','4194','EPSG','18423','EPSG','2558',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2301','Qornoq 1927 / Greenland zone 3 west',NULL,NULL,'EPSG','1031','EPSG','4194','EPSG','18433','EPSG','3367',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2302','Qornoq 1927 / Greenland zone 4 east',NULL,NULL,'EPSG','4501','EPSG','4194','EPSG','18424','EPSG','2559',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2303','Qornoq 1927 / Greenland zone 4 west',NULL,NULL,'EPSG','1031','EPSG','4194','EPSG','18434','EPSG','3366',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2304','Qornoq 1927 / Greenland zone 5 west',NULL,NULL,'EPSG','1031','EPSG','4194','EPSG','18435','EPSG','3365',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2305','Qornoq 1927 / Greenland zone 6 west',NULL,NULL,'EPSG','1031','EPSG','4194','EPSG','18436','EPSG','3364',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2306','Qornoq 1927 / Greenland zone 7 west',NULL,NULL,'EPSG','1031','EPSG','4194','EPSG','18437','EPSG','3363',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2307','Qornoq 1927 / Greenland zone 8 east',NULL,NULL,'EPSG','1031','EPSG','4194','EPSG','18428','EPSG','3846',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2308','Batavia / TM 109 SE',NULL,NULL,'EPSG','4400','EPSG','4211','EPSG','16709','EPSG','2577',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2309','WGS 84 / TM 116 SE',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16716','EPSG','2588',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2310','WGS 84 / TM 132 SE',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16732','EPSG','2589',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2311','WGS 84 / TM 6 NE',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16406','EPSG','2981',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2312','Garoua / UTM zone 33N',NULL,NULL,'EPSG','4400','EPSG','4197','EPSG','16033','EPSG','2590',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2313','Kousseri / UTM zone 33N',NULL,NULL,'EPSG','4400','EPSG','4198','EPSG','16033','EPSG','2591',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2314','Trinidad 1903 / Trinidad Grid (ftCla)',NULL,NULL,'EPSG','4403','EPSG','4302','EPSG','19975','EPSG','1339',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2315','Campo Inchauspe / UTM zone 19S',NULL,NULL,'EPSG','4400','EPSG','4221','EPSG','16119','EPSG','2596',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2316','Campo Inchauspe / UTM zone 20S',NULL,NULL,'EPSG','4400','EPSG','4221','EPSG','16120','EPSG','2597',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2317','PSAD56 / ICN Regional',NULL,NULL,'EPSG','4499','EPSG','4248','EPSG','19976','EPSG','3327',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2318','Ain el Abd / Aramco Lambert',NULL,NULL,'EPSG','4400','EPSG','4204','EPSG','19977','EPSG','3303',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2319','ED50 / TM27',NULL,NULL,'EPSG','4530','EPSG','4230','EPSG','16305','EPSG','1524',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2320','ED50 / TM30',NULL,NULL,'EPSG','4530','EPSG','4230','EPSG','16370','EPSG','1525',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2321','ED50 / TM33',NULL,NULL,'EPSG','4530','EPSG','4230','EPSG','16306','EPSG','1526',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2322','ED50 / TM36',NULL,NULL,'EPSG','4530','EPSG','4230','EPSG','16372','EPSG','1527',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2323','ED50 / TM39',NULL,NULL,'EPSG','4530','EPSG','4230','EPSG','16307','EPSG','1528',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2324','ED50 / TM42',NULL,NULL,'EPSG','4530','EPSG','4230','EPSG','16374','EPSG','1529',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2325','ED50 / TM45',NULL,NULL,'EPSG','4530','EPSG','4230','EPSG','16308','EPSG','1530',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2326','Hong Kong 1980 Grid System',NULL,NULL,'EPSG','4500','EPSG','4611','EPSG','19978','EPSG','1118',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2327','Xian 1980 / Gauss-Kruger zone 13',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16213','EPSG','1587',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2328','Xian 1980 / Gauss-Kruger zone 14',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16214','EPSG','1588',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2329','Xian 1980 / Gauss-Kruger zone 15',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16215','EPSG','1589',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2330','Xian 1980 / Gauss-Kruger zone 16',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16216','EPSG','1590',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2331','Xian 1980 / Gauss-Kruger zone 17',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16217','EPSG','1591',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2332','Xian 1980 / Gauss-Kruger zone 18',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16218','EPSG','1592',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2333','Xian 1980 / Gauss-Kruger zone 19',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16219','EPSG','1593',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2334','Xian 1980 / Gauss-Kruger zone 20',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16220','EPSG','1594',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2335','Xian 1980 / Gauss-Kruger zone 21',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16221','EPSG','1595',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2336','Xian 1980 / Gauss-Kruger zone 22',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16222','EPSG','1596',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2337','Xian 1980 / Gauss-Kruger zone 23',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16223','EPSG','1597',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2338','Xian 1980 / Gauss-Kruger CM 75E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16313','EPSG','1587',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2339','Xian 1980 / Gauss-Kruger CM 81E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16314','EPSG','1588',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2340','Xian 1980 / Gauss-Kruger CM 87E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16315','EPSG','1589',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2341','Xian 1980 / Gauss-Kruger CM 93E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16316','EPSG','1590',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2342','Xian 1980 / Gauss-Kruger CM 99E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16317','EPSG','1591',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2343','Xian 1980 / Gauss-Kruger CM 105E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16318','EPSG','1592',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2344','Xian 1980 / Gauss-Kruger CM 111E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16319','EPSG','1593',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2345','Xian 1980 / Gauss-Kruger CM 117E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16320','EPSG','1594',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2346','Xian 1980 / Gauss-Kruger CM 123E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16321','EPSG','1595',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2347','Xian 1980 / Gauss-Kruger CM 129E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16322','EPSG','1596',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2348','Xian 1980 / Gauss-Kruger CM 135E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16323','EPSG','1597',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2349','Xian 1980 / 3-degree Gauss-Kruger zone 25',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16285','EPSG','2711',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2350','Xian 1980 / 3-degree Gauss-Kruger zone 26',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16286','EPSG','2712',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2351','Xian 1980 / 3-degree Gauss-Kruger zone 27',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16287','EPSG','2713',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2352','Xian 1980 / 3-degree Gauss-Kruger zone 28',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16288','EPSG','2714',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2353','Xian 1980 / 3-degree Gauss-Kruger zone 29',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16289','EPSG','2715',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2354','Xian 1980 / 3-degree Gauss-Kruger zone 30',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16290','EPSG','2716',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2355','Xian 1980 / 3-degree Gauss-Kruger zone 31',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16291','EPSG','2717',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2356','Xian 1980 / 3-degree Gauss-Kruger zone 32',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16292','EPSG','2718',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2357','Xian 1980 / 3-degree Gauss-Kruger zone 33',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16293','EPSG','2719',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2358','Xian 1980 / 3-degree Gauss-Kruger zone 34',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16294','EPSG','2720',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2359','Xian 1980 / 3-degree Gauss-Kruger zone 35',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16295','EPSG','2721',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2360','Xian 1980 / 3-degree Gauss-Kruger zone 36',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16296','EPSG','2722',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2361','Xian 1980 / 3-degree Gauss-Kruger zone 37',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16297','EPSG','2723',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2362','Xian 1980 / 3-degree Gauss-Kruger zone 38',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16298','EPSG','2724',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2363','Xian 1980 / 3-degree Gauss-Kruger zone 39',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16299','EPSG','2725',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2364','Xian 1980 / 3-degree Gauss-Kruger zone 40',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16070','EPSG','2726',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2365','Xian 1980 / 3-degree Gauss-Kruger zone 41',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16071','EPSG','2727',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2366','Xian 1980 / 3-degree Gauss-Kruger zone 42',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16072','EPSG','2728',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2367','Xian 1980 / 3-degree Gauss-Kruger zone 43',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16073','EPSG','2729',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2368','Xian 1980 / 3-degree Gauss-Kruger zone 44',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16074','EPSG','2730',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2369','Xian 1980 / 3-degree Gauss-Kruger zone 45',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16075','EPSG','2731',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2370','Xian 1980 / 3-degree Gauss-Kruger CM 75E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16313','EPSG','2711',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2371','Xian 1980 / 3-degree Gauss-Kruger CM 78E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16386','EPSG','2712',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2372','Xian 1980 / 3-degree Gauss-Kruger CM 81E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16314','EPSG','2713',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2373','Xian 1980 / 3-degree Gauss-Kruger CM 84E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16388','EPSG','2714',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2374','Xian 1980 / 3-degree Gauss-Kruger CM 87E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16315','EPSG','2715',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2375','Xian 1980 / 3-degree Gauss-Kruger CM 90E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16390','EPSG','2716',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2376','Xian 1980 / 3-degree Gauss-Kruger CM 93E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16316','EPSG','2717',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2377','Xian 1980 / 3-degree Gauss-Kruger CM 96E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16392','EPSG','2718',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2378','Xian 1980 / 3-degree Gauss-Kruger CM 99E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16317','EPSG','2719',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2379','Xian 1980 / 3-degree Gauss-Kruger CM 102E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16394','EPSG','2720',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2380','Xian 1980 / 3-degree Gauss-Kruger CM 105E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16318','EPSG','2721',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2381','Xian 1980 / 3-degree Gauss-Kruger CM 108E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16396','EPSG','2722',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2382','Xian 1980 / 3-degree Gauss-Kruger CM 111E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16319','EPSG','2723',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2383','Xian 1980 / 3-degree Gauss-Kruger CM 114E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16398','EPSG','2724',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2384','Xian 1980 / 3-degree Gauss-Kruger CM 117E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16320','EPSG','2725',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2385','Xian 1980 / 3-degree Gauss-Kruger CM 120E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16170','EPSG','2726',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2386','Xian 1980 / 3-degree Gauss-Kruger CM 123E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16321','EPSG','2727',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2387','Xian 1980 / 3-degree Gauss-Kruger CM 126E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16172','EPSG','2728',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2388','Xian 1980 / 3-degree Gauss-Kruger CM 129E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16322','EPSG','2729',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2389','Xian 1980 / 3-degree Gauss-Kruger CM 132E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16174','EPSG','2730',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2390','Xian 1980 / 3-degree Gauss-Kruger CM 135E',NULL,NULL,'EPSG','4530','EPSG','4610','EPSG','16323','EPSG','2731',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2391','KKJ / Finland zone 1',NULL,NULL,'EPSG','4530','EPSG','4123','EPSG','18191','EPSG','1536',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2392','KKJ / Finland zone 2',NULL,NULL,'EPSG','4530','EPSG','4123','EPSG','18192','EPSG','1537',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2393','KKJ / Finland Uniform Coordinate System',NULL,NULL,'EPSG','4530','EPSG','4123','EPSG','18193','EPSG','1538',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2394','KKJ / Finland zone 4',NULL,NULL,'EPSG','4530','EPSG','4123','EPSG','18194','EPSG','1539',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2395','South Yemen / Gauss-Kruger zone 8',NULL,NULL,'EPSG','4530','EPSG','4164','EPSG','16208','EPSG','1492',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2396','South Yemen / Gauss-Kruger zone 9',NULL,NULL,'EPSG','4530','EPSG','4164','EPSG','16209','EPSG','1493',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2397','Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 3',NULL,NULL,'EPSG','4530','EPSG','4178','EPSG','16263','EPSG','1512',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2398','Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 4',NULL,NULL,'EPSG','4530','EPSG','4178','EPSG','16264','EPSG','1513',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2399','Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 5',NULL,NULL,'EPSG','4530','EPSG','4178','EPSG','16265','EPSG','1514',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2400','RT90 2.5 gon W',NULL,NULL,'EPSG','4530','EPSG','4124','EPSG','19929','EPSG','1225',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2401','Beijing 1954 / 3-degree Gauss-Kruger zone 25',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16285','EPSG','2711',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2402','Beijing 1954 / 3-degree Gauss-Kruger zone 26',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16286','EPSG','2712',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2403','Beijing 1954 / 3-degree Gauss-Kruger zone 27',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16287','EPSG','2713',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2404','Beijing 1954 / 3-degree Gauss-Kruger zone 28',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16288','EPSG','2714',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2405','Beijing 1954 / 3-degree Gauss-Kruger zone 29',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16289','EPSG','2715',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2406','Beijing 1954 / 3-degree Gauss-Kruger zone 30',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16290','EPSG','2716',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2407','Beijing 1954 / 3-degree Gauss-Kruger zone 31',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16291','EPSG','2717',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2408','Beijing 1954 / 3-degree Gauss-Kruger zone 32',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16292','EPSG','2718',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2409','Beijing 1954 / 3-degree Gauss-Kruger zone 33',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16293','EPSG','2719',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2410','Beijing 1954 / 3-degree Gauss-Kruger zone 34',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16294','EPSG','2720',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2411','Beijing 1954 / 3-degree Gauss-Kruger zone 35',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16295','EPSG','2721',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2412','Beijing 1954 / 3-degree Gauss-Kruger zone 36',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16296','EPSG','2722',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2413','Beijing 1954 / 3-degree Gauss-Kruger zone 37',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16297','EPSG','2723',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2414','Beijing 1954 / 3-degree Gauss-Kruger zone 38',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16298','EPSG','2724',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2415','Beijing 1954 / 3-degree Gauss-Kruger zone 39',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16299','EPSG','2725',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2416','Beijing 1954 / 3-degree Gauss-Kruger zone 40',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16070','EPSG','2726',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2417','Beijing 1954 / 3-degree Gauss-Kruger zone 41',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16071','EPSG','2727',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2418','Beijing 1954 / 3-degree Gauss-Kruger zone 42',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16072','EPSG','2728',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2419','Beijing 1954 / 3-degree Gauss-Kruger zone 43',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16073','EPSG','2729',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2420','Beijing 1954 / 3-degree Gauss-Kruger zone 44',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16074','EPSG','2730',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2421','Beijing 1954 / 3-degree Gauss-Kruger zone 45',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16075','EPSG','2731',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2422','Beijing 1954 / 3-degree Gauss-Kruger CM 75E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16313','EPSG','2711',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2423','Beijing 1954 / 3-degree Gauss-Kruger CM 78E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16386','EPSG','2712',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2424','Beijing 1954 / 3-degree Gauss-Kruger CM 81E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16314','EPSG','2713',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2425','Beijing 1954 / 3-degree Gauss-Kruger CM 84E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16388','EPSG','2714',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2426','Beijing 1954 / 3-degree Gauss-Kruger CM 87E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16315','EPSG','2715',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2427','Beijing 1954 / 3-degree Gauss-Kruger CM 90E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16390','EPSG','2716',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2428','Beijing 1954 / 3-degree Gauss-Kruger CM 93E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16316','EPSG','2717',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2429','Beijing 1954 / 3-degree Gauss-Kruger CM 96E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16392','EPSG','2718',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2430','Beijing 1954 / 3-degree Gauss-Kruger CM 99E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16317','EPSG','2719',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2431','Beijing 1954 / 3-degree Gauss-Kruger CM 102E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16394','EPSG','2720',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2432','Beijing 1954 / 3-degree Gauss-Kruger CM 105E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16318','EPSG','2721',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2433','Beijing 1954 / 3-degree Gauss-Kruger CM 108E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16396','EPSG','2722',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2434','Beijing 1954 / 3-degree Gauss-Kruger CM 111E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16319','EPSG','2723',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2435','Beijing 1954 / 3-degree Gauss-Kruger CM 114E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16398','EPSG','2724',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2436','Beijing 1954 / 3-degree Gauss-Kruger CM 117E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16320','EPSG','2725',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2437','Beijing 1954 / 3-degree Gauss-Kruger CM 120E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16170','EPSG','2726',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2438','Beijing 1954 / 3-degree Gauss-Kruger CM 123E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16321','EPSG','2727',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2439','Beijing 1954 / 3-degree Gauss-Kruger CM 126E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16172','EPSG','2728',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2440','Beijing 1954 / 3-degree Gauss-Kruger CM 129E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16322','EPSG','2729',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2441','Beijing 1954 / 3-degree Gauss-Kruger CM 132E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16174','EPSG','2730',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2442','Beijing 1954 / 3-degree Gauss-Kruger CM 135E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16323','EPSG','2731',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2443','JGD2000 / Japan Plane Rectangular CS I',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17801','EPSG','1854',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2444','JGD2000 / Japan Plane Rectangular CS II',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17802','EPSG','1855',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2445','JGD2000 / Japan Plane Rectangular CS III',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17803','EPSG','1856',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2446','JGD2000 / Japan Plane Rectangular CS IV',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17804','EPSG','1857',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2447','JGD2000 / Japan Plane Rectangular CS V',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17805','EPSG','1858',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2448','JGD2000 / Japan Plane Rectangular CS VI',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17806','EPSG','1859',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2449','JGD2000 / Japan Plane Rectangular CS VII',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17807','EPSG','1860',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2450','JGD2000 / Japan Plane Rectangular CS VIII',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17808','EPSG','1861',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2451','JGD2000 / Japan Plane Rectangular CS IX',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17809','EPSG','1862',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2452','JGD2000 / Japan Plane Rectangular CS X',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17810','EPSG','1863',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2453','JGD2000 / Japan Plane Rectangular CS XI',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17811','EPSG','1864',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2454','JGD2000 / Japan Plane Rectangular CS XII',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17812','EPSG','1865',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2455','JGD2000 / Japan Plane Rectangular CS XIII',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17813','EPSG','1866',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2456','JGD2000 / Japan Plane Rectangular CS XIV',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17814','EPSG','1867',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2457','JGD2000 / Japan Plane Rectangular CS XV',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17815','EPSG','1868',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2458','JGD2000 / Japan Plane Rectangular CS XVI',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17816','EPSG','1869',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2459','JGD2000 / Japan Plane Rectangular CS XVII',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17817','EPSG','1870',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2460','JGD2000 / Japan Plane Rectangular CS XVIII',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17818','EPSG','1871',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2461','JGD2000 / Japan Plane Rectangular CS XIX',NULL,NULL,'EPSG','4530','EPSG','4612','EPSG','17819','EPSG','1872',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2462','Albanian 1987 / Gauss-Kruger zone 4',NULL,NULL,'EPSG','4530','EPSG','4191','EPSG','16204','EPSG','3212',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2463','Pulkovo 1995 / Gauss-Kruger CM 21E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16304','EPSG','1763',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2464','Pulkovo 1995 / Gauss-Kruger CM 27E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16305','EPSG','1764',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2465','Pulkovo 1995 / Gauss-Kruger CM 33E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16306','EPSG','1765',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2466','Pulkovo 1995 / Gauss-Kruger CM 39E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16307','EPSG','1766',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2467','Pulkovo 1995 / Gauss-Kruger CM 45E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16308','EPSG','1767',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2468','Pulkovo 1995 / Gauss-Kruger CM 51E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16309','EPSG','1768',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2469','Pulkovo 1995 / Gauss-Kruger CM 57E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16310','EPSG','1769',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2470','Pulkovo 1995 / Gauss-Kruger CM 63E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16311','EPSG','1770',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2471','Pulkovo 1995 / Gauss-Kruger CM 69E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16312','EPSG','1771',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2472','Pulkovo 1995 / Gauss-Kruger CM 75E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16313','EPSG','1772',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2473','Pulkovo 1995 / Gauss-Kruger CM 81E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16314','EPSG','1773',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2474','Pulkovo 1995 / Gauss-Kruger CM 87E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16315','EPSG','1774',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2475','Pulkovo 1995 / Gauss-Kruger CM 93E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16316','EPSG','1775',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2476','Pulkovo 1995 / Gauss-Kruger CM 99E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16317','EPSG','1776',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2477','Pulkovo 1995 / Gauss-Kruger CM 105E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16318','EPSG','1777',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2478','Pulkovo 1995 / Gauss-Kruger CM 111E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16319','EPSG','1778',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2479','Pulkovo 1995 / Gauss-Kruger CM 117E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16320','EPSG','1779',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2480','Pulkovo 1995 / Gauss-Kruger CM 123E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16321','EPSG','1780',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2481','Pulkovo 1995 / Gauss-Kruger CM 129E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16322','EPSG','1781',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2482','Pulkovo 1995 / Gauss-Kruger CM 135E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16323','EPSG','1782',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2483','Pulkovo 1995 / Gauss-Kruger CM 141E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16324','EPSG','1783',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2484','Pulkovo 1995 / Gauss-Kruger CM 147E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16325','EPSG','1784',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2485','Pulkovo 1995 / Gauss-Kruger CM 153E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16326','EPSG','1785',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2486','Pulkovo 1995 / Gauss-Kruger CM 159E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16327','EPSG','1786',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2487','Pulkovo 1995 / Gauss-Kruger CM 165E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16328','EPSG','1787',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2488','Pulkovo 1995 / Gauss-Kruger CM 171E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16329','EPSG','1788',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2489','Pulkovo 1995 / Gauss-Kruger CM 177E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16330','EPSG','1789',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2490','Pulkovo 1995 / Gauss-Kruger CM 177W',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16331','EPSG','1790',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2491','Pulkovo 1995 / Gauss-Kruger CM 171W',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16332','EPSG','1791',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2492','Pulkovo 1942 / Gauss-Kruger CM 9E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16302','EPSG','1805',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2493','Pulkovo 1942 / Gauss-Kruger CM 15E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16303','EPSG','1792',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2494','Pulkovo 1942 / Gauss-Kruger CM 21E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16304','EPSG','1793',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2495','Pulkovo 1942 / Gauss-Kruger CM 27E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16305','EPSG','1794',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2496','Pulkovo 1942 / Gauss-Kruger CM 33E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16306','EPSG','1795',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2497','Pulkovo 1942 / Gauss-Kruger CM 39E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16307','EPSG','1796',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2498','Pulkovo 1942 / Gauss-Kruger CM 45E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16308','EPSG','1797',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2499','Pulkovo 1942 / Gauss-Kruger CM 51E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16309','EPSG','1798',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2500','Pulkovo 1942 / Gauss-Kruger CM 57E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16310','EPSG','1799',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2501','Pulkovo 1942 / Gauss-Kruger CM 63E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16311','EPSG','1800',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2502','Pulkovo 1942 / Gauss-Kruger CM 69E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16312','EPSG','1801',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2503','Pulkovo 1942 / Gauss-Kruger CM 75E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16313','EPSG','1802',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2504','Pulkovo 1942 / Gauss-Kruger CM 81E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16314','EPSG','1803',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2505','Pulkovo 1942 / Gauss-Kruger CM 87E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16315','EPSG','1804',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2506','Pulkovo 1942 / Gauss-Kruger CM 93E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16316','EPSG','1775',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2507','Pulkovo 1942 / Gauss-Kruger CM 99E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16317','EPSG','1776',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2508','Pulkovo 1942 / Gauss-Kruger CM 105E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16318','EPSG','1777',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2509','Pulkovo 1942 / Gauss-Kruger CM 111E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16319','EPSG','1778',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2510','Pulkovo 1942 / Gauss-Kruger CM 117E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16320','EPSG','1779',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2511','Pulkovo 1942 / Gauss-Kruger CM 123E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16321','EPSG','1780',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2512','Pulkovo 1942 / Gauss-Kruger CM 129E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16322','EPSG','1781',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2513','Pulkovo 1942 / Gauss-Kruger CM 135E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16323','EPSG','1782',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2514','Pulkovo 1942 / Gauss-Kruger CM 141E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16324','EPSG','1783',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2515','Pulkovo 1942 / Gauss-Kruger CM 147E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16325','EPSG','1784',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2516','Pulkovo 1942 / Gauss-Kruger CM 153E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16326','EPSG','1785',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2517','Pulkovo 1942 / Gauss-Kruger CM 159E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16327','EPSG','1786',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2518','Pulkovo 1942 / Gauss-Kruger CM 165E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16328','EPSG','1787',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2519','Pulkovo 1942 / Gauss-Kruger CM 171E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16329','EPSG','1788',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2520','Pulkovo 1942 / Gauss-Kruger CM 177E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16330','EPSG','1789',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2521','Pulkovo 1942 / Gauss-Kruger CM 177W',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16331','EPSG','1790',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2522','Pulkovo 1942 / Gauss-Kruger CM 171W',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16332','EPSG','1791',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2523','Pulkovo 1942 / 3-degree Gauss-Kruger zone 7',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16267','EPSG','2653',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2524','Pulkovo 1942 / 3-degree Gauss-Kruger zone 8',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16268','EPSG','2654',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2525','Pulkovo 1942 / 3-degree Gauss-Kruger zone 9',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16269','EPSG','2655',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2526','Pulkovo 1942 / 3-degree Gauss-Kruger zone 10',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16270','EPSG','2656',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2527','Pulkovo 1942 / 3-degree Gauss-Kruger zone 11',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16271','EPSG','2657',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2528','Pulkovo 1942 / 3-degree Gauss-Kruger zone 12',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16272','EPSG','2658',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2529','Pulkovo 1942 / 3-degree Gauss-Kruger zone 13',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16273','EPSG','2659',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2530','Pulkovo 1942 / 3-degree Gauss-Kruger zone 14',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16274','EPSG','2660',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2531','Pulkovo 1942 / 3-degree Gauss-Kruger zone 15',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16275','EPSG','2661',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2532','Pulkovo 1942 / 3-degree Gauss-Kruger zone 16',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16276','EPSG','2662',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2533','Pulkovo 1942 / 3-degree Gauss-Kruger zone 17',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16277','EPSG','2663',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2534','Pulkovo 1942 / 3-degree Gauss-Kruger zone 18',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16278','EPSG','2664',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2535','Pulkovo 1942 / 3-degree Gauss-Kruger zone 19',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16279','EPSG','2665',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2536','Pulkovo 1942 / 3-degree Gauss-Kruger zone 20',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16280','EPSG','2666',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2537','Pulkovo 1942 / 3-degree Gauss-Kruger zone 21',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16281','EPSG','2667',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2538','Pulkovo 1942 / 3-degree Gauss-Kruger zone 22',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16282','EPSG','2668',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2539','Pulkovo 1942 / 3-degree Gauss-Kruger zone 23',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16283','EPSG','2669',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2540','Pulkovo 1942 / 3-degree Gauss-Kruger zone 24',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16284','EPSG','2670',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2541','Pulkovo 1942 / 3-degree Gauss-Kruger zone 25',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16285','EPSG','2671',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2542','Pulkovo 1942 / 3-degree Gauss-Kruger zone 26',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16286','EPSG','2672',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2543','Pulkovo 1942 / 3-degree Gauss-Kruger zone 27',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16287','EPSG','2673',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2544','Pulkovo 1942 / 3-degree Gauss-Kruger zone 28',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16288','EPSG','2674',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2545','Pulkovo 1942 / 3-degree Gauss-Kruger zone 29',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16289','EPSG','2675',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2546','Pulkovo 1942 / 3-degree Gauss-Kruger zone 30',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16290','EPSG','2676',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2547','Pulkovo 1942 / 3-degree Gauss-Kruger zone 31',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16291','EPSG','2677',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2548','Pulkovo 1942 / 3-degree Gauss-Kruger zone 32',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16292','EPSG','2678',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2549','Pulkovo 1942 / 3-degree Gauss-Kruger zone 33',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16293','EPSG','2679',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2550','Samboja / UTM zone 50S',NULL,NULL,'EPSG','4400','EPSG','4125','EPSG','16150','EPSG','1328',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2551','Pulkovo 1942 / 3-degree Gauss-Kruger zone 34',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16294','EPSG','2680',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2552','Pulkovo 1942 / 3-degree Gauss-Kruger zone 35',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16295','EPSG','2681',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2553','Pulkovo 1942 / 3-degree Gauss-Kruger zone 36',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16296','EPSG','2682',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2554','Pulkovo 1942 / 3-degree Gauss-Kruger zone 37',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16297','EPSG','2683',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2555','Pulkovo 1942 / 3-degree Gauss-Kruger zone 38',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16298','EPSG','2684',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2556','Pulkovo 1942 / 3-degree Gauss-Kruger zone 39',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16299','EPSG','2685',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2557','Pulkovo 1942 / 3-degree Gauss-Kruger zone 40',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16070','EPSG','2686',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2558','Pulkovo 1942 / 3-degree Gauss-Kruger zone 41',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16071','EPSG','2687',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2559','Pulkovo 1942 / 3-degree Gauss-Kruger zone 42',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16072','EPSG','2688',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2560','Pulkovo 1942 / 3-degree Gauss-Kruger zone 43',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16073','EPSG','2689',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2561','Pulkovo 1942 / 3-degree Gauss-Kruger zone 44',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16074','EPSG','2690',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2562','Pulkovo 1942 / 3-degree Gauss-Kruger zone 45',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16075','EPSG','2691',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2563','Pulkovo 1942 / 3-degree Gauss-Kruger zone 46',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16076','EPSG','2692',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2564','Pulkovo 1942 / 3-degree Gauss-Kruger zone 47',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16077','EPSG','2693',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2565','Pulkovo 1942 / 3-degree Gauss-Kruger zone 48',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16078','EPSG','2694',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2566','Pulkovo 1942 / 3-degree Gauss-Kruger zone 49',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16079','EPSG','2695',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2567','Pulkovo 1942 / 3-degree Gauss-Kruger zone 50',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16080','EPSG','2696',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2568','Pulkovo 1942 / 3-degree Gauss-Kruger zone 51',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16081','EPSG','2697',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2569','Pulkovo 1942 / 3-degree Gauss-Kruger zone 52',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16082','EPSG','2698',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2570','Pulkovo 1942 / 3-degree Gauss-Kruger zone 53',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16083','EPSG','2699',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2571','Pulkovo 1942 / 3-degree Gauss-Kruger zone 54',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16084','EPSG','2700',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2572','Pulkovo 1942 / 3-degree Gauss-Kruger zone 55',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16085','EPSG','2701',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2573','Pulkovo 1942 / 3-degree Gauss-Kruger zone 56',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16086','EPSG','2702',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2574','Pulkovo 1942 / 3-degree Gauss-Kruger zone 57',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16087','EPSG','2703',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2575','Pulkovo 1942 / 3-degree Gauss-Kruger zone 58',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16088','EPSG','2704',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2576','Pulkovo 1942 / 3-degree Gauss-Kruger zone 59',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16089','EPSG','2705',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2577','Pulkovo 1942 / 3-degree Gauss-Kruger zone 60',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16090','EPSG','2706',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2578','Pulkovo 1942 / 3-degree Gauss-Kruger zone 61',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16091','EPSG','2707',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2579','Pulkovo 1942 / 3-degree Gauss-Kruger zone 62',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16092','EPSG','2708',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2580','Pulkovo 1942 / 3-degree Gauss-Kruger zone 63',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16093','EPSG','2709',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2581','Pulkovo 1942 / 3-degree Gauss-Kruger zone 64',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16094','EPSG','2710',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2582','Pulkovo 1942 / 3-degree Gauss-Kruger CM 21E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16304','EPSG','2653',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2583','Pulkovo 1942 / 3-degree Gauss-Kruger CM 24E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16368','EPSG','2654',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2584','Pulkovo 1942 / 3-degree Gauss-Kruger CM 27E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16305','EPSG','2655',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2585','Pulkovo 1942 / 3-degree Gauss-Kruger CM 30E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16370','EPSG','2656',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2586','Pulkovo 1942 / 3-degree Gauss-Kruger CM 33E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16306','EPSG','2657',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2587','Pulkovo 1942 / 3-degree Gauss-Kruger CM 36E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16372','EPSG','2658',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2588','Pulkovo 1942 / 3-degree Gauss-Kruger CM 39E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16307','EPSG','2659',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2589','Pulkovo 1942 / 3-degree Gauss-Kruger CM 42E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16374','EPSG','2660',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2590','Pulkovo 1942 / 3-degree Gauss-Kruger CM 45E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16308','EPSG','2661',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2591','Pulkovo 1942 / 3-degree Gauss-Kruger CM 48E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16376','EPSG','2662',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2592','Pulkovo 1942 / 3-degree Gauss-Kruger CM 51E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16309','EPSG','2663',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2593','Pulkovo 1942 / 3-degree Gauss-Kruger CM 54E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16378','EPSG','2664',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2594','Pulkovo 1942 / 3-degree Gauss-Kruger CM 57E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16310','EPSG','2665',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2595','Pulkovo 1942 / 3-degree Gauss-Kruger CM 60E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16380','EPSG','2666',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2596','Pulkovo 1942 / 3-degree Gauss-Kruger CM 63E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16311','EPSG','2667',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2597','Pulkovo 1942 / 3-degree Gauss-Kruger CM 66E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16382','EPSG','2668',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2598','Pulkovo 1942 / 3-degree Gauss-Kruger CM 69E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16312','EPSG','2669',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2599','Pulkovo 1942 / 3-degree Gauss-Kruger CM 72E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16384','EPSG','2670',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2600','Lietuvos Koordinoei Sistema 1994',NULL,NULL,'EPSG','4530','EPSG','4669','EPSG','19934','EPSG','1145',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2601','Pulkovo 1942 / 3-degree Gauss-Kruger CM 75E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16313','EPSG','2671',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2602','Pulkovo 1942 / 3-degree Gauss-Kruger CM 78E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16386','EPSG','2672',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2603','Pulkovo 1942 / 3-degree Gauss-Kruger CM 81E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16314','EPSG','2673',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2604','Pulkovo 1942 / 3-degree Gauss-Kruger CM 84E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16388','EPSG','2674',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2605','Pulkovo 1942 / 3-degree Gauss-Kruger CM 87E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16315','EPSG','2675',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2606','Pulkovo 1942 / 3-degree Gauss-Kruger CM 90E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16390','EPSG','2676',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2607','Pulkovo 1942 / 3-degree Gauss-Kruger CM 93E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16316','EPSG','2677',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2608','Pulkovo 1942 / 3-degree Gauss-Kruger CM 96E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16392','EPSG','2678',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2609','Pulkovo 1942 / 3-degree Gauss-Kruger CM 99E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16317','EPSG','2679',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2610','Pulkovo 1942 / 3-degree Gauss-Kruger CM 102E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16394','EPSG','2680',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2611','Pulkovo 1942 / 3-degree Gauss-Kruger CM 105E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16318','EPSG','2681',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2612','Pulkovo 1942 / 3-degree Gauss-Kruger CM 108E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16396','EPSG','2682',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2613','Pulkovo 1942 / 3-degree Gauss-Kruger CM 111E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16319','EPSG','2683',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2614','Pulkovo 1942 / 3-degree Gauss-Kruger CM 114E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16398','EPSG','2684',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2615','Pulkovo 1942 / 3-degree Gauss-Kruger CM 117E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16320','EPSG','2685',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2616','Pulkovo 1942 / 3-degree Gauss-Kruger CM 120E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16170','EPSG','2686',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2617','Pulkovo 1942 / 3-degree Gauss-Kruger CM 123E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16321','EPSG','2687',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2618','Pulkovo 1942 / 3-degree Gauss-Kruger CM 126E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16172','EPSG','2688',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2619','Pulkovo 1942 / 3-degree Gauss-Kruger CM 129E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16322','EPSG','2689',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2620','Pulkovo 1942 / 3-degree Gauss-Kruger CM 132E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16174','EPSG','2690',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2621','Pulkovo 1942 / 3-degree Gauss-Kruger CM 135E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16323','EPSG','2691',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2622','Pulkovo 1942 / 3-degree Gauss-Kruger CM 138E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16176','EPSG','2692',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2623','Pulkovo 1942 / 3-degree Gauss-Kruger CM 141E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16324','EPSG','2693',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2624','Pulkovo 1942 / 3-degree Gauss-Kruger CM 144E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16178','EPSG','2694',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2625','Pulkovo 1942 / 3-degree Gauss-Kruger CM 147E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16325','EPSG','2695',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2626','Pulkovo 1942 / 3-degree Gauss-Kruger CM 150E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16180','EPSG','2696',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2627','Pulkovo 1942 / 3-degree Gauss-Kruger CM 153E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16326','EPSG','2697',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2628','Pulkovo 1942 / 3-degree Gauss-Kruger CM 156E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16182','EPSG','2698',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2629','Pulkovo 1942 / 3-degree Gauss-Kruger CM 159E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16327','EPSG','2699',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2630','Pulkovo 1942 / 3-degree Gauss-Kruger CM 162E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16184','EPSG','2700',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2631','Pulkovo 1942 / 3-degree Gauss-Kruger CM 165E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16328','EPSG','2701',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2632','Pulkovo 1942 / 3-degree Gauss-Kruger CM 168E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16186','EPSG','2702',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2633','Pulkovo 1942 / 3-degree Gauss-Kruger CM 171E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16329','EPSG','2703',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2634','Pulkovo 1942 / 3-degree Gauss-Kruger CM 174E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16188','EPSG','2704',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2635','Pulkovo 1942 / 3-degree Gauss-Kruger CM 177E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16330','EPSG','2705',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2636','Pulkovo 1942 / 3-degree Gauss-Kruger CM 180E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16190','EPSG','2706',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2637','Pulkovo 1942 / 3-degree Gauss-Kruger CM 177W',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16331','EPSG','2707',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2638','Pulkovo 1942 / 3-degree Gauss-Kruger CM 174W',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16192','EPSG','2708',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2639','Pulkovo 1942 / 3-degree Gauss-Kruger CM 171W',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16332','EPSG','2709',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2640','Pulkovo 1942 / 3-degree Gauss-Kruger CM 168W',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16194','EPSG','2710',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2641','Pulkovo 1995 / 3-degree Gauss-Kruger zone 7',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16267','EPSG','2747',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2642','Pulkovo 1995 / 3-degree Gauss-Kruger zone 8',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16268','EPSG','2748',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2643','Pulkovo 1995 / 3-degree Gauss-Kruger zone 9',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16269','EPSG','2749',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2644','Pulkovo 1995 / 3-degree Gauss-Kruger zone 10',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16270','EPSG','2750',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2645','Pulkovo 1995 / 3-degree Gauss-Kruger zone 11',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16271','EPSG','2751',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2646','Pulkovo 1995 / 3-degree Gauss-Kruger zone 12',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16272','EPSG','2752',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2647','Pulkovo 1995 / 3-degree Gauss-Kruger zone 13',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16273','EPSG','2753',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2648','Pulkovo 1995 / 3-degree Gauss-Kruger zone 14',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16274','EPSG','2754',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2649','Pulkovo 1995 / 3-degree Gauss-Kruger zone 15',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16275','EPSG','2755',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2650','Pulkovo 1995 / 3-degree Gauss-Kruger zone 16',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16276','EPSG','2756',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2651','Pulkovo 1995 / 3-degree Gauss-Kruger zone 17',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16277','EPSG','2757',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2652','Pulkovo 1995 / 3-degree Gauss-Kruger zone 18',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16278','EPSG','2758',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2653','Pulkovo 1995 / 3-degree Gauss-Kruger zone 19',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16279','EPSG','2759',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2654','Pulkovo 1995 / 3-degree Gauss-Kruger zone 20',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16280','EPSG','2760',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2655','Pulkovo 1995 / 3-degree Gauss-Kruger zone 21',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16281','EPSG','2761',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2656','Pulkovo 1995 / 3-degree Gauss-Kruger zone 22',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16282','EPSG','2762',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2657','Pulkovo 1995 / 3-degree Gauss-Kruger zone 23',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16283','EPSG','2763',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2658','Pulkovo 1995 / 3-degree Gauss-Kruger zone 24',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16284','EPSG','2764',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2659','Pulkovo 1995 / 3-degree Gauss-Kruger zone 25',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16285','EPSG','2765',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2660','Pulkovo 1995 / 3-degree Gauss-Kruger zone 26',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16286','EPSG','2766',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2661','Pulkovo 1995 / 3-degree Gauss-Kruger zone 27',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16287','EPSG','2767',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2662','Pulkovo 1995 / 3-degree Gauss-Kruger zone 28',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16288','EPSG','2768',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2663','Pulkovo 1995 / 3-degree Gauss-Kruger zone 29',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16289','EPSG','2769',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2664','Pulkovo 1995 / 3-degree Gauss-Kruger zone 30',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16290','EPSG','2676',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2665','Pulkovo 1995 / 3-degree Gauss-Kruger zone 31',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16291','EPSG','2677',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2666','Pulkovo 1995 / 3-degree Gauss-Kruger zone 32',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16292','EPSG','2678',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2667','Pulkovo 1995 / 3-degree Gauss-Kruger zone 33',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16293','EPSG','2679',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2668','Pulkovo 1995 / 3-degree Gauss-Kruger zone 34',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16294','EPSG','2680',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2669','Pulkovo 1995 / 3-degree Gauss-Kruger zone 35',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16295','EPSG','2681',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2670','Pulkovo 1995 / 3-degree Gauss-Kruger zone 36',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16296','EPSG','2682',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2671','Pulkovo 1995 / 3-degree Gauss-Kruger zone 37',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16297','EPSG','2683',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2672','Pulkovo 1995 / 3-degree Gauss-Kruger zone 38',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16298','EPSG','2684',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2673','Pulkovo 1995 / 3-degree Gauss-Kruger zone 39',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16299','EPSG','2685',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2674','Pulkovo 1995 / 3-degree Gauss-Kruger zone 40',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16070','EPSG','2686',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2675','Pulkovo 1995 / 3-degree Gauss-Kruger zone 41',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16071','EPSG','2687',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2676','Pulkovo 1995 / 3-degree Gauss-Kruger zone 42',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16072','EPSG','2688',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2677','Pulkovo 1995 / 3-degree Gauss-Kruger zone 43',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16073','EPSG','2689',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2678','Pulkovo 1995 / 3-degree Gauss-Kruger zone 44',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16074','EPSG','2690',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2679','Pulkovo 1995 / 3-degree Gauss-Kruger zone 45',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16075','EPSG','2691',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2680','Pulkovo 1995 / 3-degree Gauss-Kruger zone 46',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16076','EPSG','2692',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2681','Pulkovo 1995 / 3-degree Gauss-Kruger zone 47',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16077','EPSG','2693',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2682','Pulkovo 1995 / 3-degree Gauss-Kruger zone 48',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16078','EPSG','2694',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2683','Pulkovo 1995 / 3-degree Gauss-Kruger zone 49',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16079','EPSG','2695',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2684','Pulkovo 1995 / 3-degree Gauss-Kruger zone 50',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16080','EPSG','2696',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2685','Pulkovo 1995 / 3-degree Gauss-Kruger zone 51',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16081','EPSG','2697',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2686','Pulkovo 1995 / 3-degree Gauss-Kruger zone 52',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16082','EPSG','2698',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2687','Pulkovo 1995 / 3-degree Gauss-Kruger zone 53',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16083','EPSG','2699',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2688','Pulkovo 1995 / 3-degree Gauss-Kruger zone 54',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16084','EPSG','2700',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2689','Pulkovo 1995 / 3-degree Gauss-Kruger zone 55',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16085','EPSG','2701',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2690','Pulkovo 1995 / 3-degree Gauss-Kruger zone 56',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16086','EPSG','2702',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2691','Pulkovo 1995 / 3-degree Gauss-Kruger zone 57',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16087','EPSG','2703',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2692','Pulkovo 1995 / 3-degree Gauss-Kruger zone 58',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16088','EPSG','2704',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2693','Pulkovo 1995 / 3-degree Gauss-Kruger zone 59',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16089','EPSG','2705',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2694','Pulkovo 1995 / 3-degree Gauss-Kruger zone 60',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16090','EPSG','2706',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2695','Pulkovo 1995 / 3-degree Gauss-Kruger zone 61',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16091','EPSG','2707',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2696','Pulkovo 1995 / 3-degree Gauss-Kruger zone 62',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16092','EPSG','2708',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2697','Pulkovo 1995 / 3-degree Gauss-Kruger zone 63',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16093','EPSG','2709',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2698','Pulkovo 1995 / 3-degree Gauss-Kruger zone 64',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16094','EPSG','2710',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2699','Pulkovo 1995 / 3-degree Gauss-Kruger CM 21E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16304','EPSG','2747',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2700','Pulkovo 1995 / 3-degree Gauss-Kruger CM 24E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16368','EPSG','2748',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2701','Pulkovo 1995 / 3-degree Gauss-Kruger CM 27E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16305','EPSG','2749',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2702','Pulkovo 1995 / 3-degree Gauss-Kruger CM 30E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16370','EPSG','2750',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2703','Pulkovo 1995 / 3-degree Gauss-Kruger CM 33E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16306','EPSG','2751',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2704','Pulkovo 1995 / 3-degree Gauss-Kruger CM 36E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16372','EPSG','2752',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2705','Pulkovo 1995 / 3-degree Gauss-Kruger CM 39E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16307','EPSG','2753',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2706','Pulkovo 1995 / 3-degree Gauss-Kruger CM 42E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16374','EPSG','2754',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2707','Pulkovo 1995 / 3-degree Gauss-Kruger CM 45E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16308','EPSG','2755',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2708','Pulkovo 1995 / 3-degree Gauss-Kruger CM 48E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16376','EPSG','2756',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2709','Pulkovo 1995 / 3-degree Gauss-Kruger CM 51E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16309','EPSG','2757',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2710','Pulkovo 1995 / 3-degree Gauss-Kruger CM 54E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16378','EPSG','2758',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2711','Pulkovo 1995 / 3-degree Gauss-Kruger CM 57E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16310','EPSG','2759',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2712','Pulkovo 1995 / 3-degree Gauss-Kruger CM 60E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16380','EPSG','2760',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2713','Pulkovo 1995 / 3-degree Gauss-Kruger CM 63E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16311','EPSG','2761',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2714','Pulkovo 1995 / 3-degree Gauss-Kruger CM 66E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16382','EPSG','2762',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2715','Pulkovo 1995 / 3-degree Gauss-Kruger CM 69E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16312','EPSG','2763',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2716','Pulkovo 1995 / 3-degree Gauss-Kruger CM 72E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16384','EPSG','2764',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2717','Pulkovo 1995 / 3-degree Gauss-Kruger CM 75E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16313','EPSG','2765',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2718','Pulkovo 1995 / 3-degree Gauss-Kruger CM 78E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16386','EPSG','2766',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2719','Pulkovo 1995 / 3-degree Gauss-Kruger CM 81E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16314','EPSG','2767',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2720','Pulkovo 1995 / 3-degree Gauss-Kruger CM 84E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16388','EPSG','2768',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2721','Pulkovo 1995 / 3-degree Gauss-Kruger CM 87E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16315','EPSG','2769',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2722','Pulkovo 1995 / 3-degree Gauss-Kruger CM 90E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16390','EPSG','2676',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2723','Pulkovo 1995 / 3-degree Gauss-Kruger CM 93E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16316','EPSG','2677',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2724','Pulkovo 1995 / 3-degree Gauss-Kruger CM 96E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16392','EPSG','2678',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2725','Pulkovo 1995 / 3-degree Gauss-Kruger CM 99E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16317','EPSG','2679',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2726','Pulkovo 1995 / 3-degree Gauss-Kruger CM 102E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16394','EPSG','2680',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2727','Pulkovo 1995 / 3-degree Gauss-Kruger CM 105E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16318','EPSG','2681',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2728','Pulkovo 1995 / 3-degree Gauss-Kruger CM 108E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16396','EPSG','2682',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2729','Pulkovo 1995 / 3-degree Gauss-Kruger CM 111E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16319','EPSG','2683',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2730','Pulkovo 1995 / 3-degree Gauss-Kruger CM 114E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16398','EPSG','2684',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2731','Pulkovo 1995 / 3-degree Gauss-Kruger CM 117E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16320','EPSG','2685',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2732','Pulkovo 1995 / 3-degree Gauss-Kruger CM 120E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16170','EPSG','2686',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2733','Pulkovo 1995 / 3-degree Gauss-Kruger CM 123E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16321','EPSG','2687',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2734','Pulkovo 1995 / 3-degree Gauss-Kruger CM 126E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16172','EPSG','2688',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2735','Pulkovo 1995 / 3-degree Gauss-Kruger CM 129E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16322','EPSG','2689',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2736','Tete / UTM zone 36S',NULL,NULL,'EPSG','4400','EPSG','4127','EPSG','16136','EPSG','1540',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2737','Tete / UTM zone 37S',NULL,NULL,'EPSG','4400','EPSG','4127','EPSG','16137','EPSG','1541',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2738','Pulkovo 1995 / 3-degree Gauss-Kruger CM 132E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16174','EPSG','2690',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2739','Pulkovo 1995 / 3-degree Gauss-Kruger CM 135E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16323','EPSG','2691',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2740','Pulkovo 1995 / 3-degree Gauss-Kruger CM 138E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16176','EPSG','2692',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2741','Pulkovo 1995 / 3-degree Gauss-Kruger CM 141E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16324','EPSG','2693',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2742','Pulkovo 1995 / 3-degree Gauss-Kruger CM 144E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16178','EPSG','2694',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2743','Pulkovo 1995 / 3-degree Gauss-Kruger CM 147E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16325','EPSG','2695',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2744','Pulkovo 1995 / 3-degree Gauss-Kruger CM 150E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16180','EPSG','2696',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2745','Pulkovo 1995 / 3-degree Gauss-Kruger CM 153E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16326','EPSG','2697',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2746','Pulkovo 1995 / 3-degree Gauss-Kruger CM 156E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16182','EPSG','2698',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2747','Pulkovo 1995 / 3-degree Gauss-Kruger CM 159E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16327','EPSG','2699',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2748','Pulkovo 1995 / 3-degree Gauss-Kruger CM 162E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16184','EPSG','2700',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2749','Pulkovo 1995 / 3-degree Gauss-Kruger CM 165E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16328','EPSG','2701',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2750','Pulkovo 1995 / 3-degree Gauss-Kruger CM 168E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16186','EPSG','2702',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2751','Pulkovo 1995 / 3-degree Gauss-Kruger CM 171E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16329','EPSG','2703',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2752','Pulkovo 1995 / 3-degree Gauss-Kruger CM 174E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16188','EPSG','2704',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2753','Pulkovo 1995 / 3-degree Gauss-Kruger CM 177E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16330','EPSG','2705',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2754','Pulkovo 1995 / 3-degree Gauss-Kruger CM 180E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16190','EPSG','2706',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2755','Pulkovo 1995 / 3-degree Gauss-Kruger CM 177W',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16331','EPSG','2707',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2756','Pulkovo 1995 / 3-degree Gauss-Kruger CM 174W',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16192','EPSG','2708',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2757','Pulkovo 1995 / 3-degree Gauss-Kruger CM 171W',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16332','EPSG','2709',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2758','Pulkovo 1995 / 3-degree Gauss-Kruger CM 168W',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16194','EPSG','2710',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2759','NAD83(HARN) / Alabama East',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10131','EPSG','2154',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2760','NAD83(HARN) / Alabama West',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10132','EPSG','2155',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2761','NAD83(HARN) / Arizona East',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10231','EPSG','2167',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2762','NAD83(HARN) / Arizona Central',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10232','EPSG','2166',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2763','NAD83(HARN) / Arizona West',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10233','EPSG','2168',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2764','NAD83(HARN) / Arkansas North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10331','EPSG','2169',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2765','NAD83(HARN) / Arkansas South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10332','EPSG','2170',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2766','NAD83(HARN) / California zone 1',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10431','EPSG','2175',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2767','NAD83(HARN) / California zone 2',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10432','EPSG','2176',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2768','NAD83(HARN) / California zone 3',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10433','EPSG','2177',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2769','NAD83(HARN) / California zone 4',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10434','EPSG','2178',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2770','NAD83(HARN) / California zone 5',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10435','EPSG','2182',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2771','NAD83(HARN) / California zone 6',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10436','EPSG','2180',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2772','NAD83(HARN) / Colorado North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10531','EPSG','2184',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2773','NAD83(HARN) / Colorado Central',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10532','EPSG','2183',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2774','NAD83(HARN) / Colorado South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10533','EPSG','2185',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2775','NAD83(HARN) / Connecticut',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10630','EPSG','1377',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2776','NAD83(HARN) / Delaware',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10730','EPSG','1378',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2777','NAD83(HARN) / Florida East',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10931','EPSG','2186',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2778','NAD83(HARN) / Florida West',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10932','EPSG','2188',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2779','NAD83(HARN) / Florida North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10933','EPSG','2187',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2780','NAD83(HARN) / Georgia East',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11031','EPSG','2189',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2781','NAD83(HARN) / Georgia West',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11032','EPSG','2190',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2782','NAD83(HARN) / Hawaii zone 1',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','15131','EPSG','1546',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2783','NAD83(HARN) / Hawaii zone 2',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','15132','EPSG','1547',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2784','NAD83(HARN) / Hawaii zone 3',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','15133','EPSG','1548',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2785','NAD83(HARN) / Hawaii zone 4',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','15134','EPSG','1549',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2786','NAD83(HARN) / Hawaii zone 5',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','15135','EPSG','1550',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2787','NAD83(HARN) / Idaho East',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11131','EPSG','2192',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2788','NAD83(HARN) / Idaho Central',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11132','EPSG','2191',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2789','NAD83(HARN) / Idaho West',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11133','EPSG','2193',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2790','NAD83(HARN) / Illinois East',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11231','EPSG','2194',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2791','NAD83(HARN) / Illinois West',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11232','EPSG','2195',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2792','NAD83(HARN) / Indiana East',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11331','EPSG','2196',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2793','NAD83(HARN) / Indiana West',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11332','EPSG','2197',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2794','NAD83(HARN) / Iowa North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11431','EPSG','2198',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2795','NAD83(HARN) / Iowa South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11432','EPSG','2199',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2796','NAD83(HARN) / Kansas North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11531','EPSG','2200',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2797','NAD83(HARN) / Kansas South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11532','EPSG','2201',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2798','NAD83(HARN) / Kentucky North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','15303','EPSG','2202',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2799','NAD83(HARN) / Kentucky South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11632','EPSG','2203',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2800','NAD83(HARN) / Louisiana North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11731','EPSG','2204',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2801','NAD83(HARN) / Louisiana South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11732','EPSG','2529',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2802','NAD83(HARN) / Maine East',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11831','EPSG','2206',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2803','NAD83(HARN) / Maine West',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11832','EPSG','2207',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2804','NAD83(HARN) / Maryland',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11930','EPSG','1389',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2805','NAD83(HARN) / Massachusetts Mainland',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12031','EPSG','2209',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2806','NAD83(HARN) / Massachusetts Island',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12032','EPSG','2208',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2807','NAD83(HARN) / Michigan North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12141','EPSG','1723',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2808','NAD83(HARN) / Michigan Central',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12142','EPSG','1724',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2809','NAD83(HARN) / Michigan South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12143','EPSG','1725',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2810','NAD83(HARN) / Minnesota North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12231','EPSG','2214',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2811','NAD83(HARN) / Minnesota Central',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12232','EPSG','2213',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2812','NAD83(HARN) / Minnesota South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12233','EPSG','2215',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2813','NAD83(HARN) / Mississippi East',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12331','EPSG','2216',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2814','NAD83(HARN) / Mississippi West',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12332','EPSG','2217',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2815','NAD83(HARN) / Missouri East',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12431','EPSG','2219',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2816','NAD83(HARN) / Missouri Central',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12432','EPSG','2218',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2817','NAD83(HARN) / Missouri West',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12433','EPSG','2220',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2818','NAD83(HARN) / Montana',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12530','EPSG','1395',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2819','NAD83(HARN) / Nebraska',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12630','EPSG','1396',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2820','NAD83(HARN) / Nevada East',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12731','EPSG','2224',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2821','NAD83(HARN) / Nevada Central',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12732','EPSG','2223',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2822','NAD83(HARN) / Nevada West',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12733','EPSG','2225',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2823','NAD83(HARN) / New Hampshire',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12830','EPSG','1398',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2824','NAD83(HARN) / New Jersey',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12930','EPSG','1399',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2825','NAD83(HARN) / New Mexico East',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13031','EPSG','2228',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2826','NAD83(HARN) / New Mexico Central',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13032','EPSG','2231',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2827','NAD83(HARN) / New Mexico West',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13033','EPSG','2232',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2828','NAD83(HARN) / New York East',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13131','EPSG','2234',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2829','NAD83(HARN) / New York Central',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13132','EPSG','2233',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2830','NAD83(HARN) / New York West',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13133','EPSG','2236',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2831','NAD83(HARN) / New York Long Island',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13134','EPSG','2235',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2832','NAD83(HARN) / North Dakota North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13331','EPSG','2237',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2833','NAD83(HARN) / North Dakota South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13332','EPSG','2238',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2834','NAD83(HARN) / Ohio North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13431','EPSG','2239',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2835','NAD83(HARN) / Ohio South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13432','EPSG','2240',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2836','NAD83(HARN) / Oklahoma North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13531','EPSG','2241',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2837','NAD83(HARN) / Oklahoma South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13532','EPSG','2242',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2838','NAD83(HARN) / Oregon North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13631','EPSG','2243',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2839','NAD83(HARN) / Oregon South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13632','EPSG','2244',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2840','NAD83(HARN) / Rhode Island',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13830','EPSG','1408',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2841','NAD83(HARN) / South Dakota North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14031','EPSG','2249',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2842','NAD83(HARN) / South Dakota South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14032','EPSG','2250',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2843','NAD83(HARN) / Tennessee',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14130','EPSG','1411',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2844','NAD83(HARN) / Texas North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14231','EPSG','2253',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2845','NAD83(HARN) / Texas North Central',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14232','EPSG','2254',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2846','NAD83(HARN) / Texas Central',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14233','EPSG','2252',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2847','NAD83(HARN) / Texas South Central',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14234','EPSG','2527',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2848','NAD83(HARN) / Texas South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14235','EPSG','2528',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2849','NAD83(HARN) / Utah North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14331','EPSG','2258',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2850','NAD83(HARN) / Utah Central',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14332','EPSG','2257',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2851','NAD83(HARN) / Utah South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14333','EPSG','2259',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2852','NAD83(HARN) / Vermont',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14430','EPSG','1414',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2853','NAD83(HARN) / Virginia North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14531','EPSG','2260',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2854','NAD83(HARN) / Virginia South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14532','EPSG','2261',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2855','NAD83(HARN) / Washington North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14631','EPSG','2273',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2856','NAD83(HARN) / Washington South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14632','EPSG','2274',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2857','NAD83(HARN) / West Virginia North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14731','EPSG','2264',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2858','NAD83(HARN) / West Virginia South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14732','EPSG','2265',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2859','NAD83(HARN) / Wisconsin North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14831','EPSG','2267',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2860','NAD83(HARN) / Wisconsin Central',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14832','EPSG','2266',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2861','NAD83(HARN) / Wisconsin South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14833','EPSG','2268',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2862','NAD83(HARN) / Wyoming East',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14931','EPSG','2269',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2863','NAD83(HARN) / Wyoming East Central',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14932','EPSG','2270',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2864','NAD83(HARN) / Wyoming West Central',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14933','EPSG','2272',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2865','NAD83(HARN) / Wyoming West',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14934','EPSG','2271',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2866','NAD83(HARN) / Puerto Rico and Virgin Is.',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','15230','EPSG','3634',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2867','NAD83(HARN) / Arizona East (ft)',NULL,NULL,'EPSG','4495','EPSG','4152','EPSG','15304','EPSG','2167',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2868','NAD83(HARN) / Arizona Central (ft)',NULL,NULL,'EPSG','4495','EPSG','4152','EPSG','15305','EPSG','2166',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2869','NAD83(HARN) / Arizona West (ft)',NULL,NULL,'EPSG','4495','EPSG','4152','EPSG','15306','EPSG','2168',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2870','NAD83(HARN) / California zone 1 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15307','EPSG','2175',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2871','NAD83(HARN) / California zone 2 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15308','EPSG','2176',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2872','NAD83(HARN) / California zone 3 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15309','EPSG','2177',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2873','NAD83(HARN) / California zone 4 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15310','EPSG','2178',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2874','NAD83(HARN) / California zone 5 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15311','EPSG','2182',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2875','NAD83(HARN) / California zone 6 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15312','EPSG','2180',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2876','NAD83(HARN) / Colorado North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15313','EPSG','2184',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2877','NAD83(HARN) / Colorado Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15314','EPSG','2183',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2878','NAD83(HARN) / Colorado South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15315','EPSG','2185',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2879','NAD83(HARN) / Connecticut (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15316','EPSG','1377',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2880','NAD83(HARN) / Delaware (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15317','EPSG','1378',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2881','NAD83(HARN) / Florida East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15318','EPSG','2186',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2882','NAD83(HARN) / Florida West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15319','EPSG','2188',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2883','NAD83(HARN) / Florida North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15320','EPSG','2187',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2884','NAD83(HARN) / Georgia East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15321','EPSG','2189',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2885','NAD83(HARN) / Georgia West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15322','EPSG','2190',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2886','NAD83(HARN) / Idaho East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15323','EPSG','2192',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2887','NAD83(HARN) / Idaho Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15324','EPSG','2191',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2888','NAD83(HARN) / Idaho West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15325','EPSG','2193',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2889','NAD83(HARN) / Indiana East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15326','EPSG','2196',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2890','NAD83(HARN) / Indiana West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15327','EPSG','2197',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2891','NAD83(HARN) / Kentucky North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15328','EPSG','2202',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2892','NAD83(HARN) / Kentucky South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15329','EPSG','2203',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2893','NAD83(HARN) / Maryland (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15330','EPSG','1389',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2894','NAD83(HARN) / Massachusetts Mainland (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15331','EPSG','2209',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2895','NAD83(HARN) / Massachusetts Island (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15332','EPSG','2208',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2896','NAD83(HARN) / Michigan North (ft)',NULL,NULL,'EPSG','4495','EPSG','4152','EPSG','15333','EPSG','1723',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2897','NAD83(HARN) / Michigan Central (ft)',NULL,NULL,'EPSG','4495','EPSG','4152','EPSG','15334','EPSG','1724',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2898','NAD83(HARN) / Michigan South (ft)',NULL,NULL,'EPSG','4495','EPSG','4152','EPSG','15335','EPSG','1725',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2899','NAD83(HARN) / Mississippi East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15336','EPSG','2216',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2900','NAD83(HARN) / Mississippi West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15337','EPSG','2217',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2901','NAD83(HARN) / Montana (ft)',NULL,NULL,'EPSG','4495','EPSG','4152','EPSG','15338','EPSG','1395',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2902','NAD83(HARN) / New Mexico East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15339','EPSG','2228',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2903','NAD83(HARN) / New Mexico Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15340','EPSG','2231',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2904','NAD83(HARN) / New Mexico West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15341','EPSG','2232',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2905','NAD83(HARN) / New York East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15342','EPSG','2234',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2906','NAD83(HARN) / New York Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15343','EPSG','2233',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2907','NAD83(HARN) / New York West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15344','EPSG','2236',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2908','NAD83(HARN) / New York Long Island (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15345','EPSG','2235',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2909','NAD83(HARN) / North Dakota North (ft)',NULL,NULL,'EPSG','4495','EPSG','4152','EPSG','15347','EPSG','2237',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2910','NAD83(HARN) / North Dakota South (ft)',NULL,NULL,'EPSG','4495','EPSG','4152','EPSG','15348','EPSG','2238',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2911','NAD83(HARN) / Oklahoma North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15349','EPSG','2241',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2912','NAD83(HARN) / Oklahoma South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15350','EPSG','2242',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2913','NAD83(HARN) / Oregon North (ft)',NULL,NULL,'EPSG','4495','EPSG','4152','EPSG','15351','EPSG','2243',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2914','NAD83(HARN) / Oregon South (ft)',NULL,NULL,'EPSG','4495','EPSG','4152','EPSG','15352','EPSG','2244',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2915','NAD83(HARN) / Tennessee (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15356','EPSG','1411',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2916','NAD83(HARN) / Texas North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15357','EPSG','2253',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2917','NAD83(HARN) / Texas North Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15358','EPSG','2254',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2918','NAD83(HARN) / Texas Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15359','EPSG','2252',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2919','NAD83(HARN) / Texas South Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15360','EPSG','2527',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2920','NAD83(HARN) / Texas South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15361','EPSG','2528',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2921','NAD83(HARN) / Utah North (ft)',NULL,NULL,'EPSG','4495','EPSG','4152','EPSG','15362','EPSG','2258',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2922','NAD83(HARN) / Utah Central (ft)',NULL,NULL,'EPSG','4495','EPSG','4152','EPSG','15363','EPSG','2257',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2923','NAD83(HARN) / Utah South (ft)',NULL,NULL,'EPSG','4495','EPSG','4152','EPSG','15364','EPSG','2259',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2924','NAD83(HARN) / Virginia North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15365','EPSG','2260',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2925','NAD83(HARN) / Virginia South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15366','EPSG','2261',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2926','NAD83(HARN) / Washington North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15367','EPSG','2273',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2927','NAD83(HARN) / Washington South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15368','EPSG','2274',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2928','NAD83(HARN) / Wisconsin North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15369','EPSG','2267',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2929','NAD83(HARN) / Wisconsin Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15370','EPSG','2266',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2930','NAD83(HARN) / Wisconsin South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15371','EPSG','2268',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2931','Beduaram / TM 13 NE',NULL,NULL,'EPSG','4499','EPSG','4213','EPSG','16413','EPSG','2771',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2932','QND95 / Qatar National Grid',NULL,NULL,'EPSG','4400','EPSG','4614','EPSG','19919','EPSG','1346',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2933','Segara / UTM zone 50S',NULL,NULL,'EPSG','4400','EPSG','4613','EPSG','16150','EPSG','1328',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2934','Segara (Jakarta) / NEIEZ',NULL,NULL,'EPSG','4499','EPSG','4820','EPSG','19905','EPSG','1360',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2935','Pulkovo 1942 / CS63 zone A1',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','18441','EPSG','2772',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2936','Pulkovo 1942 / CS63 zone A2',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','18442','EPSG','2773',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2937','Pulkovo 1942 / CS63 zone A3',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','18443','EPSG','2774',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2938','Pulkovo 1942 / CS63 zone A4',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','18444','EPSG','2775',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2939','Pulkovo 1942 / CS63 zone K2',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','18446','EPSG','2776',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2940','Pulkovo 1942 / CS63 zone K3',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','18447','EPSG','2777',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2941','Pulkovo 1942 / CS63 zone K4',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','18448','EPSG','2778',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2942','Porto Santo / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4615','EPSG','16028','EPSG','1314',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2943','Selvagem Grande / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4616','EPSG','16028','EPSG','2779',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2944','NAD83(CSRS) / SCoPQ zone 2',NULL,NULL,'EPSG','4499','EPSG','4617','EPSG','17700','EPSG','1420',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2945','NAD83(CSRS) / MTM zone 3',NULL,NULL,'EPSG','4496','EPSG','4617','EPSG','17703','EPSG','2290',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2946','NAD83(CSRS) / MTM zone 4',NULL,NULL,'EPSG','4496','EPSG','4617','EPSG','17704','EPSG','2276',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2947','NAD83(CSRS) / MTM zone 5',NULL,NULL,'EPSG','4496','EPSG','4617','EPSG','17705','EPSG','2277',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2948','NAD83(CSRS) / MTM zone 6',NULL,NULL,'EPSG','4496','EPSG','4617','EPSG','17706','EPSG','2278',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2949','NAD83(CSRS) / MTM zone 7',NULL,NULL,'EPSG','4496','EPSG','4617','EPSG','17707','EPSG','1425',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2950','NAD83(CSRS) / MTM zone 8',NULL,NULL,'EPSG','4496','EPSG','4617','EPSG','17708','EPSG','2279',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2951','NAD83(CSRS) / MTM zone 9',NULL,NULL,'EPSG','4496','EPSG','4617','EPSG','17709','EPSG','2280',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2952','NAD83(CSRS) / MTM zone 10',NULL,NULL,'EPSG','4496','EPSG','4617','EPSG','17710','EPSG','2281',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2953','NAD83(CSRS) / New Brunswick Stereographic',NULL,NULL,'EPSG','4500','EPSG','4617','EPSG','19946','EPSG','1447',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2954','NAD83(CSRS) / Prince Edward Isl. Stereographic (NAD83)',NULL,NULL,'EPSG','4496','EPSG','4617','EPSG','19960','EPSG','1533',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2955','NAD83(CSRS) / UTM zone 11N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16011','EPSG','3528',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2956','NAD83(CSRS) / UTM zone 12N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16012','EPSG','3527',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2957','NAD83(CSRS) / UTM zone 13N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16013','EPSG','3526',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2958','NAD83(CSRS) / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16017','EPSG','3416',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2959','NAD83(CSRS) / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16018','EPSG','3417',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2960','NAD83(CSRS) / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16019','EPSG','3524',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2961','NAD83(CSRS) / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16020','EPSG','3525',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2962','NAD83(CSRS) / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16021','EPSG','2151',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2963','Lisbon 1890 (Lisbon) / Portugal Bonne',NULL,NULL,'EPSG','6509','EPSG','4904','EPSG','19979','EPSG','1294',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2964','NAD27 / Alaska Albers',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15020','EPSG','1330',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2965','NAD83 / Indiana East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15372','EPSG','2196',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2966','NAD83 / Indiana West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15373','EPSG','2197',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2967','NAD83(HARN) / Indiana East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15372','EPSG','2196',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2968','NAD83(HARN) / Indiana West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15373','EPSG','2197',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2969','Fort Marigot / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4621','EPSG','16020','EPSG','2828',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2970','Guadeloupe 1948 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4622','EPSG','16020','EPSG','2829',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2971','CSG67 / UTM zone 22N',NULL,NULL,'EPSG','4400','EPSG','4623','EPSG','16022','EPSG','3766',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2972','RGFG95 / UTM zone 22N',NULL,NULL,'EPSG','4400','EPSG','4624','EPSG','16022','EPSG','3144',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2973','Martinique 1938 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4625','EPSG','16020','EPSG','3276',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2975','RGR92 / UTM zone 40S',NULL,NULL,'EPSG','4400','EPSG','4627','EPSG','16140','EPSG','3911',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2976','Tahiti 52 / UTM zone 6S',NULL,NULL,'EPSG','4400','EPSG','4628','EPSG','16106','EPSG','2811',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2977','Tahaa 54 / UTM zone 5S',NULL,NULL,'EPSG','4400','EPSG','4629','EPSG','16105','EPSG','2812',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2978','IGN72 Nuku Hiva / UTM zone 7S',NULL,NULL,'EPSG','4400','EPSG','4630','EPSG','16107','EPSG','3129',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2979','K0 1949 / UTM zone 42S',NULL,NULL,'EPSG','4400','EPSG','4631','EPSG','16142','EPSG','2816',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2980','Combani 1950 / UTM zone 38S',NULL,NULL,'EPSG','4400','EPSG','4632','EPSG','16138','EPSG','3340',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2981','IGN56 Lifou / UTM zone 58S',NULL,NULL,'EPSG','4400','EPSG','4633','EPSG','16158','EPSG','2814',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2982','IGN72 Grand Terre / UTM zone 58S',NULL,NULL,'EPSG','4400','EPSG','4634','EPSG','16158','EPSG','2822',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2983','ST87 Ouvea / UTM zone 58S',NULL,NULL,'EPSG','4400','EPSG','4635','EPSG','16158','EPSG','2813',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2984','RGNC 1991 / Lambert New Caledonia',NULL,NULL,'EPSG','4499','EPSG','4645','EPSG','19981','EPSG','1174',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2985','Petrels 1972 / Terre Adelie Polar Stereographic',NULL,NULL,'EPSG','1025','EPSG','4636','EPSG','19983','EPSG','2817',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2986','Perroud 1950 / Terre Adelie Polar Stereographic',NULL,NULL,'EPSG','1025','EPSG','4637','EPSG','19983','EPSG','2818',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2987','Saint Pierre et Miquelon 1950 / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4638','EPSG','16021','EPSG','3299',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2988','MOP78 / UTM zone 1S',NULL,NULL,'EPSG','4400','EPSG','4639','EPSG','16101','EPSG','2815',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2989','RRAF 1991 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4640','EPSG','16020','EPSG','2824',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2990','Reunion 1947 / TM Reunion',NULL,NULL,'EPSG','4499','EPSG','4626','EPSG','19982','EPSG','3337',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','2991','NAD83 / Oregon LCC (m)',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13633','EPSG','1406',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2992','NAD83 / Oregon GIC Lambert (ft)',NULL,NULL,'EPSG','4495','EPSG','4269','EPSG','15374','EPSG','1406',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2993','NAD83(HARN) / Oregon LCC (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13633','EPSG','1406',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2994','NAD83(HARN) / Oregon GIC Lambert (ft)',NULL,NULL,'EPSG','4495','EPSG','4152','EPSG','15374','EPSG','1406',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2995','IGN53 Mare / UTM zone 58S',NULL,NULL,'EPSG','4400','EPSG','4641','EPSG','16158','EPSG','3434',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2996','ST84 Ile des Pins / UTM zone 58S',NULL,NULL,'EPSG','4400','EPSG','4642','EPSG','16158','EPSG','2820',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2997','ST71 Belep / UTM zone 58S',NULL,NULL,'EPSG','4400','EPSG','4643','EPSG','16158','EPSG','2821',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2998','NEA74 Noumea / UTM zone 58S',NULL,NULL,'EPSG','4400','EPSG','4644','EPSG','16158','EPSG','2823',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','2999','Grand Comoros / UTM zone 38S',NULL,NULL,'EPSG','4400','EPSG','4646','EPSG','16138','EPSG','2807',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3000','Segara / NEIEZ',NULL,NULL,'EPSG','4499','EPSG','4613','EPSG','19905','EPSG','1360',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3001','Batavia / NEIEZ',NULL,NULL,'EPSG','4499','EPSG','4211','EPSG','19905','EPSG','1285',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3002','Makassar / NEIEZ',NULL,NULL,'EPSG','4499','EPSG','4257','EPSG','19905','EPSG','1316',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3003','Monte Mario / Italy zone 1',NULL,NULL,'EPSG','4499','EPSG','4265','EPSG','18121','EPSG','1718',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3004','Monte Mario / Italy zone 2',NULL,NULL,'EPSG','4499','EPSG','4265','EPSG','18122','EPSG','1719',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3005','NAD83 / BC Albers',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','19984','EPSG','2832',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3006','SWEREF99 TM',NULL,NULL,'EPSG','4500','EPSG','4619','EPSG','17333','EPSG','1225',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3007','SWEREF99 12 00',NULL,NULL,'EPSG','4500','EPSG','4619','EPSG','17321','EPSG','2833',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3008','SWEREF99 13 30',NULL,NULL,'EPSG','4500','EPSG','4619','EPSG','17322','EPSG','2834',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3009','SWEREF99 15 00',NULL,NULL,'EPSG','4500','EPSG','4619','EPSG','17323','EPSG','2835',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3010','SWEREF99 16 30',NULL,NULL,'EPSG','4500','EPSG','4619','EPSG','17324','EPSG','2836',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3011','SWEREF99 18 00',NULL,NULL,'EPSG','4500','EPSG','4619','EPSG','17325','EPSG','2837',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3012','SWEREF99 14 15',NULL,NULL,'EPSG','4500','EPSG','4619','EPSG','17326','EPSG','2838',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3013','SWEREF99 15 45',NULL,NULL,'EPSG','4500','EPSG','4619','EPSG','17327','EPSG','2839',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3014','SWEREF99 17 15',NULL,NULL,'EPSG','4500','EPSG','4619','EPSG','17328','EPSG','2840',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3015','SWEREF99 18 45',NULL,NULL,'EPSG','4500','EPSG','4619','EPSG','17329','EPSG','2841',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3016','SWEREF99 20 15',NULL,NULL,'EPSG','4500','EPSG','4619','EPSG','17330','EPSG','2842',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3017','SWEREF99 21 45',NULL,NULL,'EPSG','4500','EPSG','4619','EPSG','17331','EPSG','2843',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3018','SWEREF99 23 15',NULL,NULL,'EPSG','4500','EPSG','4619','EPSG','17332','EPSG','2844',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3019','RT90 7.5 gon V',NULL,NULL,'EPSG','4530','EPSG','4124','EPSG','17334','EPSG','2845',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3020','RT90 5 gon V',NULL,NULL,'EPSG','4530','EPSG','4124','EPSG','17335','EPSG','2846',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3021','RT90 2.5 gon V',NULL,NULL,'EPSG','4530','EPSG','4124','EPSG','19929','EPSG','2847',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3022','RT90 0 gon',NULL,NULL,'EPSG','4530','EPSG','4124','EPSG','17336','EPSG','2848',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3023','RT90 2.5 gon O',NULL,NULL,'EPSG','4530','EPSG','4124','EPSG','17337','EPSG','2849',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3024','RT90 5 gon O',NULL,NULL,'EPSG','4530','EPSG','4124','EPSG','17338','EPSG','2850',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3025','RT38 7.5 gon V',NULL,NULL,'EPSG','4530','EPSG','4308','EPSG','17334','EPSG','2845',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3026','RT38 5 gon V',NULL,NULL,'EPSG','4530','EPSG','4308','EPSG','17335','EPSG','2846',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3027','RT38 2.5 gon V',NULL,NULL,'EPSG','4530','EPSG','4308','EPSG','19929','EPSG','2847',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3028','RT38 0 gon',NULL,NULL,'EPSG','4530','EPSG','4308','EPSG','17336','EPSG','2848',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3029','RT38 2.5 gon O',NULL,NULL,'EPSG','4530','EPSG','4308','EPSG','17337','EPSG','2849',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3030','RT38 5 gon O',NULL,NULL,'EPSG','4530','EPSG','4308','EPSG','17338','EPSG','2850',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3031','WGS 84 / Antarctic Polar Stereographic',NULL,NULL,'EPSG','4490','EPSG','4326','EPSG','19992','EPSG','1031',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3032','WGS 84 / Australian Antarctic Polar Stereographic',NULL,NULL,'EPSG','4489','EPSG','4326','EPSG','19993','EPSG','1278',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3033','WGS 84 / Australian Antarctic Lambert',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','19994','EPSG','2880',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3034','ETRS89-extended / LCC Europe',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','19985','EPSG','2881',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3035','ETRS89-extended / LAEA Europe',NULL,NULL,'EPSG','4532','EPSG','4258','EPSG','19986','EPSG','2881',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3036','Moznet / UTM zone 36S',NULL,NULL,'EPSG','4400','EPSG','4130','EPSG','16136','EPSG','3929',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3037','Moznet / UTM zone 37S',NULL,NULL,'EPSG','4400','EPSG','4130','EPSG','16137','EPSG','3931',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3038','ETRS89 / TM26',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','16026','EPSG','2855',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3039','ETRS89 / TM27',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','16027','EPSG','2856',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3040','ETRS89 / UTM zone 28N (N-E)',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','16028','EPSG','2122',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3041','ETRS89 / UTM zone 29N (N-E)',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','16029','EPSG','2123',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3042','ETRS89 / UTM zone 30N (N-E)',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','16030','EPSG','2124',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3043','ETRS89 / UTM zone 31N (N-E)',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','16031','EPSG','2125',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3044','ETRS89 / UTM zone 32N (N-E)',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','16032','EPSG','2126',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3045','ETRS89 / UTM zone 33N (N-E)',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','16033','EPSG','2127',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3046','ETRS89 / UTM zone 34N (N-E)',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','16034','EPSG','2128',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3047','ETRS89 / UTM zone 35N (N-E)',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','16035','EPSG','2129',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3048','ETRS89 / UTM zone 36N (N-E)',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','16036','EPSG','2130',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3049','ETRS89 / UTM zone 37N (N-E)',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','16037','EPSG','2131',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3050','ETRS89 / TM38',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','16038','EPSG','2867',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3051','ETRS89 / TM39',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','16039','EPSG','2868',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3052','Reykjavik 1900 / Lambert 1900',NULL,NULL,'EPSG','4491','EPSG','4657','EPSG','19987','EPSG','3262',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3053','Hjorsey 1955 / Lambert 1955',NULL,NULL,'EPSG','4491','EPSG','4658','EPSG','19988','EPSG','3262',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3054','Hjorsey 1955 / UTM zone 26N',NULL,NULL,'EPSG','4400','EPSG','4658','EPSG','16026','EPSG','2851',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3055','Hjorsey 1955 / UTM zone 27N',NULL,NULL,'EPSG','4400','EPSG','4658','EPSG','16027','EPSG','2852',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3056','Hjorsey 1955 / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4658','EPSG','16028','EPSG','2853',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3057','ISN93 / Lambert 1993',NULL,NULL,'EPSG','4499','EPSG','4659','EPSG','19989','EPSG','1120',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3058','Helle 1954 / Jan Mayen Grid',NULL,NULL,'EPSG','4531','EPSG','4660','EPSG','19991','EPSG','2869',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3059','LKS92 / Latvia TM',NULL,NULL,'EPSG','4530','EPSG','4661','EPSG','19990','EPSG','1139',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3060','IGN72 Grande Terre / UTM zone 58S',NULL,NULL,'EPSG','4400','EPSG','4662','EPSG','16158','EPSG','2822',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3061','Porto Santo 1995 / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4663','EPSG','16028','EPSG','1314',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3062','Azores Oriental 1995 / UTM zone 26N',NULL,NULL,'EPSG','4400','EPSG','4664','EPSG','16026','EPSG','1345',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3063','Azores Central 1995 / UTM zone 26N',NULL,NULL,'EPSG','4400','EPSG','4665','EPSG','16026','EPSG','1301',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3064','IGM95 / UTM zone 32N',NULL,NULL,'EPSG','4400','EPSG','4670','EPSG','16032','EPSG','1718',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3065','IGM95 / UTM zone 33N',NULL,NULL,'EPSG','4400','EPSG','4670','EPSG','16033','EPSG','1719',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3066','ED50 / Jordan TM',NULL,NULL,'EPSG','4400','EPSG','4230','EPSG','19995','EPSG','1130',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3067','ETRS89 / TM35FIN(E,N)',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','16065','EPSG','1095',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3068','DHDN / Soldner Berlin',NULL,NULL,'EPSG','4531','EPSG','4314','EPSG','19996','EPSG','2898',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3069','NAD27 / Wisconsin Transverse Mercator',NULL,NULL,'EPSG','4499','EPSG','4267','EPSG','14811','EPSG','1418',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3070','NAD83 / Wisconsin Transverse Mercator',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14841','EPSG','1418',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3071','NAD83(HARN) / Wisconsin Transverse Mercator',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14841','EPSG','1418',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3072','NAD83 / Maine CS2000 East',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11851','EPSG','2960',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3073','NAD83 / Maine CS2000 Central',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11852','EPSG','2959',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3074','NAD83 / Maine CS2000 West',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11853','EPSG','2958',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3075','NAD83(HARN) / Maine CS2000 East',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11851','EPSG','2960',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3076','NAD83(HARN) / Maine CS2000 Central',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11852','EPSG','2959',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3077','NAD83(HARN) / Maine CS2000 West',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11853','EPSG','2958',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3078','NAD83 / Michigan Oblique Mercator',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12150','EPSG','1391',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3079','NAD83(HARN) / Michigan Oblique Mercator',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12150','EPSG','1391',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3080','NAD27 / Shackleford',NULL,NULL,'EPSG','4495','EPSG','4267','EPSG','14252','EPSG','1412',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3081','NAD83 / Texas State Mapping System',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14251','EPSG','1412',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3082','NAD83 / Texas Centric Lambert Conformal',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14253','EPSG','1412',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3083','NAD83 / Texas Centric Albers Equal Area',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14254','EPSG','1412',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3084','NAD83(HARN) / Texas Centric Lambert Conformal',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14253','EPSG','1412',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3085','NAD83(HARN) / Texas Centric Albers Equal Area',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14254','EPSG','1412',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3086','NAD83 / Florida GDL Albers',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10934','EPSG','1379',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3087','NAD83(HARN) / Florida GDL Albers',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10934','EPSG','1379',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3088','NAD83 / Kentucky Single Zone',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11630','EPSG','1386',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3089','NAD83 / Kentucky Single Zone (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15375','EPSG','1386',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3090','NAD83(HARN) / Kentucky Single Zone',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11630','EPSG','1386',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3091','NAD83(HARN) / Kentucky Single Zone (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15375','EPSG','1386',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3092','Tokyo / UTM zone 51N',NULL,NULL,'EPSG','4400','EPSG','4301','EPSG','16051','EPSG','2951',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3093','Tokyo / UTM zone 52N',NULL,NULL,'EPSG','4400','EPSG','4301','EPSG','16052','EPSG','2952',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3094','Tokyo / UTM zone 53N',NULL,NULL,'EPSG','4400','EPSG','4301','EPSG','16053','EPSG','2953',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3095','Tokyo / UTM zone 54N',NULL,NULL,'EPSG','4400','EPSG','4301','EPSG','16054','EPSG','2954',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3096','Tokyo / UTM zone 55N',NULL,NULL,'EPSG','4400','EPSG','4301','EPSG','16055','EPSG','2955',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3097','JGD2000 / UTM zone 51N',NULL,NULL,'EPSG','4400','EPSG','4612','EPSG','16051','EPSG','3959',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3098','JGD2000 / UTM zone 52N',NULL,NULL,'EPSG','4400','EPSG','4612','EPSG','16052','EPSG','3960',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3099','JGD2000 / UTM zone 53N',NULL,NULL,'EPSG','4400','EPSG','4612','EPSG','16053','EPSG','3961',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3100','JGD2000 / UTM zone 54N',NULL,NULL,'EPSG','4400','EPSG','4612','EPSG','16054','EPSG','3962',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3101','JGD2000 / UTM zone 55N',NULL,NULL,'EPSG','4400','EPSG','4612','EPSG','16055','EPSG','3963',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3102','American Samoa 1962 / American Samoa Lambert',NULL,NULL,'EPSG','4497','EPSG','4169','EPSG','15376','EPSG','3109',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3103','Mauritania 1999 / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4681','EPSG','16028','EPSG','2971',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3104','Mauritania 1999 / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4681','EPSG','16029','EPSG','2970',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3105','Mauritania 1999 / UTM zone 30N',NULL,NULL,'EPSG','4400','EPSG','4681','EPSG','16030','EPSG','2969',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3106','Gulshan 303 / Bangladesh Transverse Mercator',NULL,NULL,'EPSG','4400','EPSG','4682','EPSG','16490','EPSG','1041',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3107','GDA94 / SA Lambert',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','17359','EPSG','2986',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3108','ETRS89 / Guernsey Grid',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','19998','EPSG','2989',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3109','ETRS89 / Jersey Transverse Mercator',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','19999','EPSG','2988',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3110','AGD66 / Vicgrid66',NULL,NULL,'EPSG','4400','EPSG','4202','EPSG','17360','EPSG','2285',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3111','GDA94 / Vicgrid',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','17361','EPSG','2285',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3112','GDA94 / Geoscience Australia Lambert',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','17362','EPSG','2575',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3113','GDA94 / BCSG02',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','17363','EPSG','2990',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3114','MAGNA-SIRGAS / Colombia Far West zone',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','18055','EPSG','3091',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3115','MAGNA-SIRGAS / Colombia West zone',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','18056','EPSG','3090',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3116','MAGNA-SIRGAS / Colombia Bogota zone',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','18057','EPSG','1599',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3117','MAGNA-SIRGAS / Colombia East Central zone',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','18058','EPSG','1600',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3118','MAGNA-SIRGAS / Colombia East zone',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','18059','EPSG','1601',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3119','Douala 1948 / AEF west',NULL,NULL,'EPSG','4400','EPSG','4192','EPSG','18415','EPSG','2555',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3120','Pulkovo 1942(58) / Poland zone I',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','18280','EPSG','1515',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3121','PRS92 / Philippines zone 1',NULL,NULL,'EPSG','4499','EPSG','4683','EPSG','18171','EPSG','1698',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3122','PRS92 / Philippines zone 2',NULL,NULL,'EPSG','4499','EPSG','4683','EPSG','18172','EPSG','1699',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3123','PRS92 / Philippines zone 3',NULL,NULL,'EPSG','4499','EPSG','4683','EPSG','18173','EPSG','1700',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3124','PRS92 / Philippines zone 4',NULL,NULL,'EPSG','4499','EPSG','4683','EPSG','18174','EPSG','1701',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3125','PRS92 / Philippines zone 5',NULL,NULL,'EPSG','4499','EPSG','4683','EPSG','18175','EPSG','1702',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3126','ETRS89 / ETRS-GK19FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','18183','EPSG','3092',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3127','ETRS89 / ETRS-GK20FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','18184','EPSG','3093',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3128','ETRS89 / ETRS-GK21FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','18185','EPSG','3094',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3129','ETRS89 / ETRS-GK22FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','18186','EPSG','3095',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3130','ETRS89 / ETRS-GK23FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','18187','EPSG','3096',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3131','ETRS89 / ETRS-GK24FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','18188','EPSG','3097',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3132','ETRS89 / ETRS-GK25FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','18189','EPSG','3098',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3133','ETRS89 / ETRS-GK26FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','18190','EPSG','3099',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3134','ETRS89 / ETRS-GK27FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','18195','EPSG','3100',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3135','ETRS89 / ETRS-GK28FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','18196','EPSG','3101',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3136','ETRS89 / ETRS-GK29FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','18197','EPSG','3102',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3137','ETRS89 / ETRS-GK30FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','18198','EPSG','3103',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3138','ETRS89 / ETRS-GK31FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','18199','EPSG','3104',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3139','Vanua Levu 1915 / Vanua Levu Grid',NULL,NULL,'EPSG','4533','EPSG','4748','EPSG','19878','EPSG','3401',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3140','Viti Levu 1912 / Viti Levu Grid',NULL,NULL,'EPSG','4533','EPSG','4752','EPSG','19879','EPSG','3195',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3141','Fiji 1956 / UTM zone 60S',NULL,NULL,'EPSG','4400','EPSG','4721','EPSG','16160','EPSG','3399',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3142','Fiji 1956 / UTM zone 1S',NULL,NULL,'EPSG','4400','EPSG','4721','EPSG','16101','EPSG','3400',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3143','Fiji 1986 / Fiji Map Grid',NULL,NULL,'EPSG','4400','EPSG','4720','EPSG','19880','EPSG','1094',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3144','FD54 / Faroe Lambert',NULL,NULL,'EPSG','1031','EPSG','4741','EPSG','19870','EPSG','3248',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3145','ETRS89 / Faroe Lambert',NULL,NULL,'EPSG','1031','EPSG','4258','EPSG','19870','EPSG','3248',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3146','Pulkovo 1942 / 3-degree Gauss-Kruger zone 6',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16266','EPSG','3403',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3147','Pulkovo 1942 / 3-degree Gauss-Kruger CM 18E',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16366','EPSG','3403',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3148','Indian 1960 / UTM zone 48N',NULL,NULL,'EPSG','4400','EPSG','4131','EPSG','16048','EPSG','1542',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3149','Indian 1960 / UTM zone 49N',NULL,NULL,'EPSG','4400','EPSG','4131','EPSG','16049','EPSG','1453',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3150','Pulkovo 1995 / 3-degree Gauss-Kruger zone 6',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16266','EPSG','3403',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3151','Pulkovo 1995 / 3-degree Gauss-Kruger CM 18E',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16366','EPSG','3403',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3152','ST74',NULL,NULL,'EPSG','4531','EPSG','4619','EPSG','19876','EPSG','3408',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3153','NAD83(CSRS) / BC Albers',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','19984','EPSG','2832',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3154','NAD83(CSRS) / UTM zone 7N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16007','EPSG','3409',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3155','NAD83(CSRS) / UTM zone 8N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16008','EPSG','3410',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3156','NAD83(CSRS) / UTM zone 9N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16009','EPSG','3411',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3157','NAD83(CSRS) / UTM zone 10N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16010','EPSG','3412',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3158','NAD83(CSRS) / UTM zone 14N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16014','EPSG','3413',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3159','NAD83(CSRS) / UTM zone 15N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16015','EPSG','3414',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3160','NAD83(CSRS) / UTM zone 16N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16016','EPSG','3415',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3161','NAD83 / Ontario MNR Lambert',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','19875','EPSG','1367',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3162','NAD83(CSRS) / Ontario MNR Lambert',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','19875','EPSG','1367',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3163','RGNC91-93 / Lambert New Caledonia',NULL,NULL,'EPSG','4499','EPSG','4749','EPSG','19981','EPSG','3430',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3164','ST87 Ouvea / UTM zone 58S',NULL,NULL,'EPSG','4400','EPSG','4750','EPSG','16158','EPSG','2813',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3165','NEA74 Noumea / Noumea Lambert',NULL,NULL,'EPSG','4499','EPSG','4644','EPSG','19873','EPSG','2823',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3166','NEA74 Noumea / Noumea Lambert 2',NULL,NULL,'EPSG','4499','EPSG','4644','EPSG','19874','EPSG','2823',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3167','Kertau (RSO) / RSO Malaya (ch)',NULL,NULL,'EPSG','4410','EPSG','4751','EPSG','19871','EPSG','1690',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3168','Kertau (RSO) / RSO Malaya (m)',NULL,NULL,'EPSG','4400','EPSG','4751','EPSG','19872','EPSG','1690',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3169','RGNC91-93 / UTM zone 57S',NULL,NULL,'EPSG','4400','EPSG','4749','EPSG','16157','EPSG','3431',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3170','RGNC91-93 / UTM zone 58S',NULL,NULL,'EPSG','4400','EPSG','4749','EPSG','16158','EPSG','3432',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3171','RGNC91-93 / UTM zone 59S',NULL,NULL,'EPSG','4400','EPSG','4749','EPSG','16159','EPSG','3433',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3172','IGN53 Mare / UTM zone 59S',NULL,NULL,'EPSG','4400','EPSG','4641','EPSG','16159','EPSG','3435',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3173','fk89 / Faroe Lambert FK89',NULL,NULL,'EPSG','1031','EPSG','4753','EPSG','19877','EPSG','3248',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3174','NAD83 / Great Lakes Albers',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15397','EPSG','3467',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3175','NAD83 / Great Lakes and St Lawrence Albers',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15398','EPSG','3468',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3176','Indian 1960 / TM 106 NE',NULL,NULL,'EPSG','4400','EPSG','4131','EPSG','16506','EPSG','1495',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3177','LGD2006 / Libya TM',NULL,NULL,'EPSG','4499','EPSG','4754','EPSG','18319','EPSG','1143',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3178','GR96 / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','16018','EPSG','3449',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3179','GR96 / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','16019','EPSG','3450',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3180','GR96 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','16020','EPSG','3451',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3181','GR96 / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','16021','EPSG','3452',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3182','GR96 / UTM zone 22N',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','16022','EPSG','3453',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3183','GR96 / UTM zone 23N',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','16023','EPSG','3454',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3184','GR96 / UTM zone 24N',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','16024','EPSG','3455',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3185','GR96 / UTM zone 25N',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','16025','EPSG','3456',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3186','GR96 / UTM zone 26N',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','16026','EPSG','3457',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3187','GR96 / UTM zone 27N',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','16027','EPSG','3458',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3188','GR96 / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','16028','EPSG','3459',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3189','GR96 / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','16029','EPSG','3460',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3190','LGD2006 / Libya TM zone 5',NULL,NULL,'EPSG','4499','EPSG','4754','EPSG','18310','EPSG','1470',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3191','LGD2006 / Libya TM zone 6',NULL,NULL,'EPSG','4499','EPSG','4754','EPSG','18311','EPSG','1471',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3192','LGD2006 / Libya TM zone 7',NULL,NULL,'EPSG','4499','EPSG','4754','EPSG','18312','EPSG','1472',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3193','LGD2006 / Libya TM zone 8',NULL,NULL,'EPSG','4499','EPSG','4754','EPSG','18313','EPSG','1473',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3194','LGD2006 / Libya TM zone 9',NULL,NULL,'EPSG','4499','EPSG','4754','EPSG','18314','EPSG','1474',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3195','LGD2006 / Libya TM zone 10',NULL,NULL,'EPSG','4499','EPSG','4754','EPSG','18315','EPSG','1475',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3196','LGD2006 / Libya TM zone 11',NULL,NULL,'EPSG','4499','EPSG','4754','EPSG','18316','EPSG','1476',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3197','LGD2006 / Libya TM zone 12',NULL,NULL,'EPSG','4499','EPSG','4754','EPSG','18317','EPSG','1477',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3198','LGD2006 / Libya TM zone 13',NULL,NULL,'EPSG','4499','EPSG','4754','EPSG','18318','EPSG','1478',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3199','LGD2006 / UTM zone 32N',NULL,NULL,'EPSG','4400','EPSG','4754','EPSG','16032','EPSG','3949',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3200','FD58 / Iraq zone',NULL,NULL,'EPSG','4400','EPSG','4132','EPSG','19906','EPSG','1300',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3201','LGD2006 / UTM zone 33N',NULL,NULL,'EPSG','4400','EPSG','4754','EPSG','16033','EPSG','3950',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3202','LGD2006 / UTM zone 34N',NULL,NULL,'EPSG','4400','EPSG','4754','EPSG','16034','EPSG','3951',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3203','LGD2006 / UTM zone 35N',NULL,NULL,'EPSG','4400','EPSG','4754','EPSG','16035','EPSG','3941',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3204','WGS 84 / SCAR IMW SP19-20',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17204','EPSG','2991',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3205','WGS 84 / SCAR IMW SP21-22',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17205','EPSG','2992',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3206','WGS 84 / SCAR IMW SP23-24',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17206','EPSG','2993',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3207','WGS 84 / SCAR IMW SQ01-02',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17207','EPSG','2994',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3208','WGS 84 / SCAR IMW SQ19-20',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17208','EPSG','2995',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3209','WGS 84 / SCAR IMW SQ21-22',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17209','EPSG','2996',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3210','WGS 84 / SCAR IMW SQ37-38',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17210','EPSG','2997',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3211','WGS 84 / SCAR IMW SQ39-40',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17211','EPSG','2998',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3212','WGS 84 / SCAR IMW SQ41-42',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17212','EPSG','2999',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3213','WGS 84 / SCAR IMW SQ43-44',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17213','EPSG','3000',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3214','WGS 84 / SCAR IMW SQ45-46',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17214','EPSG','3001',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3215','WGS 84 / SCAR IMW SQ47-48',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17215','EPSG','3002',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3216','WGS 84 / SCAR IMW SQ49-50',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17216','EPSG','3003',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3217','WGS 84 / SCAR IMW SQ51-52',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17217','EPSG','3004',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3218','WGS 84 / SCAR IMW SQ53-54',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17218','EPSG','3005',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3219','WGS 84 / SCAR IMW SQ55-56',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17219','EPSG','3006',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3220','WGS 84 / SCAR IMW SQ57-58',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17220','EPSG','3007',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3221','WGS 84 / SCAR IMW SR13-14',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17221','EPSG','3008',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3222','WGS 84 / SCAR IMW SR15-16',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17222','EPSG','3009',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3223','WGS 84 / SCAR IMW SR17-18',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17223','EPSG','3010',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3224','WGS 84 / SCAR IMW SR19-20',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17224','EPSG','3011',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3225','WGS 84 / SCAR IMW SR27-28',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17225','EPSG','3012',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3226','WGS 84 / SCAR IMW SR29-30',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17226','EPSG','3013',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3227','WGS 84 / SCAR IMW SR31-32',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17227','EPSG','3014',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3228','WGS 84 / SCAR IMW SR33-34',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17228','EPSG','3015',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3229','WGS 84 / SCAR IMW SR35-36',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17229','EPSG','3016',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3230','WGS 84 / SCAR IMW SR37-38',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17230','EPSG','3017',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3231','WGS 84 / SCAR IMW SR39-40',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17231','EPSG','3018',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3232','WGS 84 / SCAR IMW SR41-42',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17232','EPSG','3019',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3233','WGS 84 / SCAR IMW SR43-44',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17233','EPSG','3020',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3234','WGS 84 / SCAR IMW SR45-46',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17234','EPSG','3021',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3235','WGS 84 / SCAR IMW SR47-48',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17235','EPSG','3022',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3236','WGS 84 / SCAR IMW SR49-50',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17236','EPSG','3023',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3237','WGS 84 / SCAR IMW SR51-52',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17237','EPSG','3024',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3238','WGS 84 / SCAR IMW SR53-54',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17238','EPSG','3025',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3239','WGS 84 / SCAR IMW SR55-56',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17239','EPSG','3026',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3240','WGS 84 / SCAR IMW SR57-58',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17240','EPSG','3027',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3241','WGS 84 / SCAR IMW SR59-60',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17241','EPSG','3028',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3242','WGS 84 / SCAR IMW SS04-06',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17242','EPSG','3029',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3243','WGS 84 / SCAR IMW SS07-09',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17243','EPSG','3030',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3244','WGS 84 / SCAR IMW SS10-12',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17244','EPSG','3031',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3245','WGS 84 / SCAR IMW SS13-15',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17245','EPSG','3032',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3246','WGS 84 / SCAR IMW SS16-18',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17246','EPSG','3033',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3247','WGS 84 / SCAR IMW SS19-21',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17247','EPSG','3034',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3248','WGS 84 / SCAR IMW SS25-27',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17248','EPSG','3035',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3249','WGS 84 / SCAR IMW SS28-30',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17249','EPSG','3036',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3250','WGS 84 / SCAR IMW SS31-33',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17250','EPSG','3037',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3251','WGS 84 / SCAR IMW SS34-36',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17251','EPSG','3038',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3252','WGS 84 / SCAR IMW SS37-39',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17252','EPSG','3039',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3253','WGS 84 / SCAR IMW SS40-42',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17253','EPSG','3040',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3254','WGS 84 / SCAR IMW SS43-45',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17254','EPSG','3041',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3255','WGS 84 / SCAR IMW SS46-48',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17255','EPSG','3042',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3256','WGS 84 / SCAR IMW SS49-51',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17256','EPSG','3043',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3257','WGS 84 / SCAR IMW SS52-54',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17257','EPSG','3044',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3258','WGS 84 / SCAR IMW SS55-57',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17258','EPSG','3045',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3259','WGS 84 / SCAR IMW SS58-60',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17259','EPSG','3046',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3260','WGS 84 / SCAR IMW ST01-04',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17260','EPSG','3047',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3261','WGS 84 / SCAR IMW ST05-08',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17261','EPSG','3048',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3262','WGS 84 / SCAR IMW ST09-12',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17262','EPSG','3049',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3263','WGS 84 / SCAR IMW ST13-16',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17263','EPSG','3050',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3264','WGS 84 / SCAR IMW ST17-20',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17264','EPSG','3051',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3265','WGS 84 / SCAR IMW ST21-24',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17265','EPSG','3052',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3266','WGS 84 / SCAR IMW ST25-28',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17266','EPSG','3053',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3267','WGS 84 / SCAR IMW ST29-32',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17267','EPSG','3054',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3268','WGS 84 / SCAR IMW ST33-36',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17268','EPSG','3055',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3269','WGS 84 / SCAR IMW ST37-40',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17269','EPSG','3056',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3270','WGS 84 / SCAR IMW ST41-44',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17270','EPSG','3057',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3271','WGS 84 / SCAR IMW ST45-48',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17271','EPSG','3058',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3272','WGS 84 / SCAR IMW ST49-52',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17272','EPSG','3059',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3273','WGS 84 / SCAR IMW ST53-56',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17273','EPSG','3060',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3274','WGS 84 / SCAR IMW ST57-60',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17274','EPSG','3061',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3275','WGS 84 / SCAR IMW SU01-05',NULL,NULL,'EPSG','4471','EPSG','4326','EPSG','17275','EPSG','3062',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3276','WGS 84 / SCAR IMW SU06-10',NULL,NULL,'EPSG','4473','EPSG','4326','EPSG','17276','EPSG','3063',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3277','WGS 84 / SCAR IMW SU11-15',NULL,NULL,'EPSG','4474','EPSG','4326','EPSG','17277','EPSG','3064',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3278','WGS 84 / SCAR IMW SU16-20',NULL,NULL,'EPSG','4476','EPSG','4326','EPSG','17278','EPSG','3065',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3279','WGS 84 / SCAR IMW SU21-25',NULL,NULL,'EPSG','4477','EPSG','4326','EPSG','17279','EPSG','3066',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3280','WGS 84 / SCAR IMW SU26-30',NULL,NULL,'EPSG','4479','EPSG','4326','EPSG','17280','EPSG','3067',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3281','WGS 84 / SCAR IMW SU31-35',NULL,NULL,'EPSG','4480','EPSG','4326','EPSG','17281','EPSG','3068',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3282','WGS 84 / SCAR IMW SU36-40',NULL,NULL,'EPSG','4482','EPSG','4326','EPSG','17282','EPSG','3069',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3283','WGS 84 / SCAR IMW SU41-45',NULL,NULL,'EPSG','4483','EPSG','4326','EPSG','17283','EPSG','3070',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3284','WGS 84 / SCAR IMW SU46-50',NULL,NULL,'EPSG','4485','EPSG','4326','EPSG','17284','EPSG','3071',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3285','WGS 84 / SCAR IMW SU51-55',NULL,NULL,'EPSG','4486','EPSG','4326','EPSG','17285','EPSG','3072',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3286','WGS 84 / SCAR IMW SU56-60',NULL,NULL,'EPSG','4488','EPSG','4326','EPSG','17286','EPSG','3073',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3287','WGS 84 / SCAR IMW SV01-10',NULL,NULL,'EPSG','4472','EPSG','4326','EPSG','17287','EPSG','3074',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3288','WGS 84 / SCAR IMW SV11-20',NULL,NULL,'EPSG','4475','EPSG','4326','EPSG','17288','EPSG','3075',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3289','WGS 84 / SCAR IMW SV21-30',NULL,NULL,'EPSG','4478','EPSG','4326','EPSG','17289','EPSG','3076',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3290','WGS 84 / SCAR IMW SV31-40',NULL,NULL,'EPSG','4481','EPSG','4326','EPSG','17290','EPSG','3077',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3291','WGS 84 / SCAR IMW SV41-50',NULL,NULL,'EPSG','4484','EPSG','4326','EPSG','17291','EPSG','3078',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3292','WGS 84 / SCAR IMW SV51-60',NULL,NULL,'EPSG','4487','EPSG','4326','EPSG','17292','EPSG','3079',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3293','WGS 84 / SCAR IMW SW01-60',NULL,NULL,'EPSG','4490','EPSG','4326','EPSG','17293','EPSG','3080',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3294','WGS 84 / USGS Transantarctic Mountains',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','17294','EPSG','3081',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3295','Guam 1963 / Yap Islands',NULL,NULL,'EPSG','4499','EPSG','4675','EPSG','15399','EPSG','3108',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3296','RGPF / UTM zone 5S',NULL,NULL,'EPSG','4400','EPSG','4687','EPSG','16105','EPSG','3120',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3297','RGPF / UTM zone 6S',NULL,NULL,'EPSG','4400','EPSG','4687','EPSG','16106','EPSG','3121',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3298','RGPF / UTM zone 7S',NULL,NULL,'EPSG','4400','EPSG','4687','EPSG','16107','EPSG','3122',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3299','RGPF / UTM zone 8S',NULL,NULL,'EPSG','4400','EPSG','4687','EPSG','16108','EPSG','3123',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3300','Estonian Coordinate System of 1992',NULL,NULL,'EPSG','4530','EPSG','4133','EPSG','19938','EPSG','3246',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3301','Estonian Coordinate System of 1997',NULL,NULL,'EPSG','4530','EPSG','4180','EPSG','19938','EPSG','1090',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3302','IGN63 Hiva Oa / UTM zone 7S',NULL,NULL,'EPSG','4400','EPSG','4689','EPSG','16107','EPSG','3130',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3303','Fatu Iva 72 / UTM zone 7S',NULL,NULL,'EPSG','4400','EPSG','4688','EPSG','16107','EPSG','3133',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3304','Tahiti 79 / UTM zone 6S',NULL,NULL,'EPSG','4400','EPSG','4690','EPSG','16106','EPSG','3124',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3305','Moorea 87 / UTM zone 6S',NULL,NULL,'EPSG','4400','EPSG','4691','EPSG','16106','EPSG','3125',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3306','Maupiti 83 / UTM zone 5S',NULL,NULL,'EPSG','4400','EPSG','4692','EPSG','16105','EPSG','3126',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3307','Nakhl-e Ghanem / UTM zone 39N',NULL,NULL,'EPSG','4400','EPSG','4693','EPSG','16039','EPSG','2362',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3308','GDA94 / NSW Lambert',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','17364','EPSG','3139',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3309','NAD27 / California Albers',NULL,NULL,'EPSG','4499','EPSG','4267','EPSG','10420','EPSG','1375',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3310','NAD83 / California Albers',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10420','EPSG','1375',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3311','NAD83(HARN) / California Albers',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','10420','EPSG','1375',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3312','CSG67 / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4623','EPSG','16021','EPSG','3765',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3313','RGFG95 / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4624','EPSG','16021','EPSG','3145',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3314','Katanga 1955 / Katanga Lambert',NULL,NULL,'EPSG','4400','EPSG','4695','EPSG','17401','EPSG','3147',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3315','Katanga 1955 / Katanga TM',NULL,NULL,'EPSG','4400','EPSG','4695','EPSG','17402','EPSG','3147',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3316','Kasai 1953 / Congo TM zone 22',NULL,NULL,'EPSG','4400','EPSG','4696','EPSG','17422','EPSG','3163',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3317','Kasai 1953 / Congo TM zone 24',NULL,NULL,'EPSG','4400','EPSG','4696','EPSG','17424','EPSG','3164',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3318','IGC 1962 / Congo TM zone 12',NULL,NULL,'EPSG','4400','EPSG','4697','EPSG','17412','EPSG','3150',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3319','IGC 1962 / Congo TM zone 14',NULL,NULL,'EPSG','4400','EPSG','4697','EPSG','17414','EPSG','3151',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3320','IGC 1962 / Congo TM zone 16',NULL,NULL,'EPSG','4400','EPSG','4697','EPSG','17416','EPSG','3160',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3321','IGC 1962 / Congo TM zone 18',NULL,NULL,'EPSG','4400','EPSG','4697','EPSG','17418','EPSG','3161',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3322','IGC 1962 / Congo TM zone 20',NULL,NULL,'EPSG','4400','EPSG','4697','EPSG','17420','EPSG','3162',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3323','IGC 1962 / Congo TM zone 22',NULL,NULL,'EPSG','4400','EPSG','4697','EPSG','17422','EPSG','3163',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3324','IGC 1962 / Congo TM zone 24',NULL,NULL,'EPSG','4400','EPSG','4697','EPSG','17424','EPSG','3164',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3325','IGC 1962 / Congo TM zone 26',NULL,NULL,'EPSG','4400','EPSG','4697','EPSG','17426','EPSG','3165',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3326','IGC 1962 / Congo TM zone 28',NULL,NULL,'EPSG','4400','EPSG','4697','EPSG','17428','EPSG','3166',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3327','IGC 1962 / Congo TM zone 30',NULL,NULL,'EPSG','4400','EPSG','4697','EPSG','17430','EPSG','3167',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3328','Pulkovo 1942(58) / GUGiK-80',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','18286','EPSG','3293',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3329','Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 5',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','16265','EPSG','3580',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3330','Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 6',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','16266','EPSG','3581',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3331','Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 7',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','16267','EPSG','3583',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3332','Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 8',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','16268','EPSG','3585',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3333','Pulkovo 1942(58) / Gauss-Kruger zone 3',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','16203','EPSG','1792',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3334','Pulkovo 1942(58) / Gauss-Kruger zone 4',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','16204','EPSG','3577',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3335','Pulkovo 1942(58) / Gauss-Kruger zone 5',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','16205','EPSG','3579',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3336','IGN 1962 Kerguelen / UTM zone 42S',NULL,NULL,'EPSG','4400','EPSG','4698','EPSG','16142','EPSG','2816',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3337','Le Pouce 1934 / Mauritius Grid',NULL,NULL,'EPSG','4400','EPSG','4699','EPSG','19899','EPSG','3209',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3338','NAD83 / Alaska Albers',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15021','EPSG','1330',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3339','IGCB 1955 / Congo TM zone 12',NULL,NULL,'EPSG','4400','EPSG','4701','EPSG','17412','EPSG','3150',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3340','IGCB 1955 / Congo TM zone 14',NULL,NULL,'EPSG','4400','EPSG','4701','EPSG','17414','EPSG','3151',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3341','IGCB 1955 / Congo TM zone 16',NULL,NULL,'EPSG','4400','EPSG','4701','EPSG','17416','EPSG','4012',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3342','IGCB 1955 / UTM zone 33S',NULL,NULL,'EPSG','4400','EPSG','4701','EPSG','16133','EPSG','3171',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3343','Mauritania 1999 / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4702','EPSG','16028','EPSG','3938',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3344','Mauritania 1999 / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4702','EPSG','16029','EPSG','2970',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3345','Mauritania 1999 / UTM zone 30N',NULL,NULL,'EPSG','4400','EPSG','4702','EPSG','16030','EPSG','2969',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3346','LKS94 / Lithuania TM',NULL,NULL,'EPSG','4530','EPSG','4669','EPSG','19934','EPSG','1145',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3347','NAD83 / Statistics Canada Lambert',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','19897','EPSG','1061',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3348','NAD83(CSRS) / Statistics Canada Lambert',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','19897','EPSG','1061',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3349','WGS 84 / PDC Mercator',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','19898','EPSG','3172',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3350','Pulkovo 1942 / CS63 zone C0',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','18450','EPSG','3173',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3351','Pulkovo 1942 / CS63 zone C1',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','18451','EPSG','3174',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3352','Pulkovo 1942 / CS63 zone C2',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','18452','EPSG','3175',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3353','Mhast (onshore) / UTM zone 32S',NULL,NULL,'EPSG','4400','EPSG','4704','EPSG','16132','EPSG','3179',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3354','Mhast (offshore) / UTM zone 32S',NULL,NULL,'EPSG','4400','EPSG','4705','EPSG','16132','EPSG','3180',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3355','Egypt Gulf of Suez S-650 TL / Red Belt',NULL,NULL,'EPSG','4400','EPSG','4706','EPSG','18072','EPSG','2341',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3356','Grand Cayman 1959 / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4723','EPSG','16017','EPSG','3185',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3357','Little Cayman 1961 / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4726','EPSG','16017','EPSG','3186',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3358','NAD83(HARN) / North Carolina',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13230','EPSG','1402',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3359','NAD83(HARN) / North Carolina (ftUS)',NULL,NULL,'EPSG','4495','EPSG','4152','EPSG','15346','EPSG','1402',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3360','NAD83(HARN) / South Carolina',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13930','EPSG','1409',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3361','NAD83(HARN) / South Carolina (ft)',NULL,NULL,'EPSG','4495','EPSG','4152','EPSG','15355','EPSG','1409',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3362','NAD83(HARN) / Pennsylvania North',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13731','EPSG','2245',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3363','NAD83(HARN) / Pennsylvania North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15353','EPSG','2245',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3364','NAD83(HARN) / Pennsylvania South',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','13732','EPSG','2246',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3365','NAD83(HARN) / Pennsylvania South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15354','EPSG','2246',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3366','Hong Kong 1963 Grid System',NULL,NULL,'EPSG','4500','EPSG','4738','EPSG','19896','EPSG','1118',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3367','IGN Astro 1960 / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4700','EPSG','16028','EPSG','2971',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3368','IGN Astro 1960 / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4700','EPSG','16029','EPSG','2970',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3369','IGN Astro 1960 / UTM zone 30N',NULL,NULL,'EPSG','4400','EPSG','4700','EPSG','16030','EPSG','2969',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3370','NAD27 / UTM zone 59N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16059','EPSG','3372',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3371','NAD27 / UTM zone 60N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16060','EPSG','3373',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3372','NAD83 / UTM zone 59N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16059','EPSG','3372',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3373','NAD83 / UTM zone 60N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16060','EPSG','3373',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3374','FD54 / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4741','EPSG','16029','EPSG','3248',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3375','GDM2000 / Peninsula RSO',NULL,NULL,'EPSG','4400','EPSG','4742','EPSG','19895','EPSG','3955',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3376','GDM2000 / East Malaysia BRSO',NULL,NULL,'EPSG','4400','EPSG','4742','EPSG','19894','EPSG','3977',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3377','GDM2000 / Johor Grid',NULL,NULL,'EPSG','4400','EPSG','4742','EPSG','19893','EPSG','3376',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3378','GDM2000 / Sembilan and Melaka Grid',NULL,NULL,'EPSG','4400','EPSG','4742','EPSG','19892','EPSG','3377',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3379','GDM2000 / Pahang Grid',NULL,NULL,'EPSG','4400','EPSG','4742','EPSG','19891','EPSG','3378',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3380','GDM2000 / Selangor Grid',NULL,NULL,'EPSG','4400','EPSG','4742','EPSG','19890','EPSG','3379',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3381','GDM2000 / Terengganu Grid',NULL,NULL,'EPSG','4400','EPSG','4742','EPSG','19889','EPSG','3380',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3382','GDM2000 / Pinang Grid',NULL,NULL,'EPSG','4400','EPSG','4742','EPSG','19888','EPSG','3381',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3383','GDM2000 / Kedah and Perlis Grid',NULL,NULL,'EPSG','4400','EPSG','4742','EPSG','19887','EPSG','3382',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3384','GDM2000 / Perak Grid',NULL,NULL,'EPSG','4400','EPSG','4742','EPSG','19886','EPSG','3383',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3385','GDM2000 / Kelantan Grid',NULL,NULL,'EPSG','4400','EPSG','4742','EPSG','19885','EPSG','3384',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3386','KKJ / Finland zone 0',NULL,NULL,'EPSG','4530','EPSG','4123','EPSG','18180','EPSG','3092',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3387','KKJ / Finland zone 5',NULL,NULL,'EPSG','4530','EPSG','4123','EPSG','18205','EPSG','3385',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3388','Pulkovo 1942 / Caspian Sea Mercator',NULL,NULL,'EPSG','4534','EPSG','4284','EPSG','19884','EPSG','1291',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3389','Pulkovo 1942 / 3-degree Gauss-Kruger zone 60',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16099','EPSG','2706',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3390','Pulkovo 1995 / 3-degree Gauss-Kruger zone 60',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16099','EPSG','2706',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3391','Karbala 1979 / UTM zone 37N',NULL,NULL,'EPSG','4400','EPSG','4743','EPSG','16037','EPSG','3387',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3392','Karbala 1979 / UTM zone 38N',NULL,NULL,'EPSG','4400','EPSG','4743','EPSG','16038','EPSG','3388',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3393','Karbala 1979 / UTM zone 39N',NULL,NULL,'EPSG','4400','EPSG','4743','EPSG','16039','EPSG','3389',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3394','Nahrwan 1934 / Iraq zone',NULL,NULL,'EPSG','4400','EPSG','4744','EPSG','19906','EPSG','4238',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3395','WGS 84 / World Mercator',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','19883','EPSG','3391',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3396','PD/83 / 3-degree Gauss-Kruger zone 3',NULL,NULL,'EPSG','4530','EPSG','4746','EPSG','16263','EPSG','3392',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3397','PD/83 / 3-degree Gauss-Kruger zone 4',NULL,NULL,'EPSG','4530','EPSG','4746','EPSG','16264','EPSG','3393',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3398','RD/83 / 3-degree Gauss-Kruger zone 4',NULL,NULL,'EPSG','4530','EPSG','4745','EPSG','16264','EPSG','3395',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3399','RD/83 / 3-degree Gauss-Kruger zone 5',NULL,NULL,'EPSG','4530','EPSG','4745','EPSG','16265','EPSG','3394',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3400','NAD83 / Alberta 10-TM (Forest)',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','19881','EPSG','2376',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3401','NAD83 / Alberta 10-TM (Resource)',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','19882','EPSG','2376',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3402','NAD83(CSRS) / Alberta 10-TM (Forest)',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','19881','EPSG','2376',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3403','NAD83(CSRS) / Alberta 10-TM (Resource)',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','19882','EPSG','2376',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3404','NAD83(HARN) / North Carolina (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15346','EPSG','1402',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3405','VN-2000 / UTM zone 48N',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','16048','EPSG','1452',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3406','VN-2000 / UTM zone 49N',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','16049','EPSG','1453',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3407','Hong Kong 1963 Grid System',NULL,NULL,'EPSG','4502','EPSG','4738','EPSG','19896','EPSG','1118',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3408','NSIDC EASE-Grid North',NULL,NULL,'EPSG','4469','EPSG','4053','EPSG','3897','EPSG','3475',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3409','NSIDC EASE-Grid South',NULL,NULL,'EPSG','4470','EPSG','4053','EPSG','3898','EPSG','3474',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3410','NSIDC EASE-Grid Global',NULL,NULL,'EPSG','4499','EPSG','4053','EPSG','19869','EPSG','3463',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3411','NSIDC Sea Ice Polar Stereographic North',NULL,NULL,'EPSG','4468','EPSG','4054','EPSG','19865','EPSG','1996',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3412','NSIDC Sea Ice Polar Stereographic South',NULL,NULL,'EPSG','4470','EPSG','4054','EPSG','19866','EPSG','1997',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3413','WGS 84 / NSIDC Sea Ice Polar Stereographic North',NULL,NULL,'EPSG','4468','EPSG','4326','EPSG','19865','EPSG','1996',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3414','SVY21 / Singapore TM',NULL,NULL,'EPSG','4500','EPSG','4757','EPSG','19864','EPSG','1210',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3415','WGS 72BE / South China Sea Lambert',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','19863','EPSG','3470',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3416','ETRS89 / Austria Lambert',NULL,NULL,'EPSG','4530','EPSG','4258','EPSG','19947','EPSG','1037',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3417','NAD83 / Iowa North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15377','EPSG','2198',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3418','NAD83 / Iowa South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15378','EPSG','2199',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3419','NAD83 / Kansas North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15379','EPSG','2200',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3420','NAD83 / Kansas South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15380','EPSG','2201',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3421','NAD83 / Nevada East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15381','EPSG','2224',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3422','NAD83 / Nevada Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15382','EPSG','2223',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3423','NAD83 / Nevada West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15383','EPSG','2225',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3424','NAD83 / New Jersey (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15384','EPSG','1399',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3425','NAD83(HARN) / Iowa North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15377','EPSG','2198',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3426','NAD83(HARN) / Iowa South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15378','EPSG','2199',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3427','NAD83(HARN) / Kansas North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15379','EPSG','2200',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3428','NAD83(HARN) / Kansas South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15380','EPSG','2201',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3429','NAD83(HARN) / Nevada East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15381','EPSG','2224',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3430','NAD83(HARN) / Nevada Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15382','EPSG','2223',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3431','NAD83(HARN) / Nevada West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15383','EPSG','2225',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3432','NAD83(HARN) / New Jersey (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15384','EPSG','1399',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3433','NAD83 / Arkansas North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15385','EPSG','2169',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3434','NAD83 / Arkansas South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15386','EPSG','2170',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3435','NAD83 / Illinois East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15387','EPSG','2194',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3436','NAD83 / Illinois West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15388','EPSG','2195',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3437','NAD83 / New Hampshire (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15389','EPSG','1398',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3438','NAD83 / Rhode Island (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15390','EPSG','1408',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3439','PSD93 / UTM zone 39N',NULL,NULL,'EPSG','4400','EPSG','4134','EPSG','16039','EPSG','1544',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3440','PSD93 / UTM zone 40N',NULL,NULL,'EPSG','4400','EPSG','4134','EPSG','16040','EPSG','1545',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3441','NAD83(HARN) / Arkansas North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15385','EPSG','2169',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3442','NAD83(HARN) / Arkansas South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15386','EPSG','2170',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3443','NAD83(HARN) / Illinois East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15387','EPSG','2194',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3444','NAD83(HARN) / Illinois West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15388','EPSG','2195',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3445','NAD83(HARN) / New Hampshire (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15389','EPSG','1398',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3446','NAD83(HARN) / Rhode Island (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15390','EPSG','1408',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3447','ETRS89 / Belgian Lambert 2005',NULL,NULL,'EPSG','4499','EPSG','4258','EPSG','19862','EPSG','1347',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3448','JAD2001 / Jamaica Metric Grid',NULL,NULL,'EPSG','4400','EPSG','4758','EPSG','19860','EPSG','3342',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3449','JAD2001 / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4758','EPSG','16017','EPSG','3478',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3450','JAD2001 / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4758','EPSG','16018','EPSG','3479',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3451','NAD83 / Louisiana North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15391','EPSG','2204',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3452','NAD83 / Louisiana South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15392','EPSG','2529',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3453','NAD83 / Louisiana Offshore (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15393','EPSG','1387',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3454','NAD83 / South Dakota North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15395','EPSG','2249',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3455','NAD83 / South Dakota South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15395','EPSG','2250',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3456','NAD83(HARN) / Louisiana North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15391','EPSG','2204',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3457','NAD83(HARN) / Louisiana South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15392','EPSG','2529',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3458','NAD83(HARN) / South Dakota North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15394','EPSG','2249',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3459','NAD83(HARN) / South Dakota South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15395','EPSG','2250',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3460','Fiji 1986 / Fiji Map Grid',NULL,NULL,'EPSG','4400','EPSG','4720','EPSG','19859','EPSG','1094',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3461','Dabola 1981 / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4155','EPSG','16028','EPSG','1468',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3462','Dabola 1981 / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4155','EPSG','16029','EPSG','1469',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3463','NAD83 / Maine CS2000 Central',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11854','EPSG','2959',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3464','NAD83(HARN) / Maine CS2000 Central',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11854','EPSG','2959',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3465','NAD83(NSRS2007) / Alabama East',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10131','EPSG','2154',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3466','NAD83(NSRS2007) / Alabama West',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10132','EPSG','2155',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3467','NAD83(NSRS2007) / Alaska Albers',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','15021','EPSG','1330',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3468','NAD83(NSRS2007) / Alaska zone 1',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','15031','EPSG','2156',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3469','NAD83(NSRS2007) / Alaska zone 2',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','15032','EPSG','2158',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3470','NAD83(NSRS2007) / Alaska zone 3',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','15033','EPSG','2159',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3471','NAD83(NSRS2007) / Alaska zone 4',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','15034','EPSG','2160',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3472','NAD83(NSRS2007) / Alaska zone 5',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','15035','EPSG','2161',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3473','NAD83(NSRS2007) / Alaska zone 6',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','15036','EPSG','2162',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3474','NAD83(NSRS2007) / Alaska zone 7',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','15037','EPSG','2163',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3475','NAD83(NSRS2007) / Alaska zone 8',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','15038','EPSG','2164',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3476','NAD83(NSRS2007) / Alaska zone 9',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','15039','EPSG','2165',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3477','NAD83(NSRS2007) / Alaska zone 10',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','15040','EPSG','2157',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3478','NAD83(NSRS2007) / Arizona Central',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10232','EPSG','2166',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3479','NAD83(NSRS2007) / Arizona Central (ft)',NULL,NULL,'EPSG','4495','EPSG','4759','EPSG','15305','EPSG','2166',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3480','NAD83(NSRS2007) / Arizona East',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10231','EPSG','2167',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3481','NAD83(NSRS2007) / Arizona East (ft)',NULL,NULL,'EPSG','4495','EPSG','4759','EPSG','15304','EPSG','2167',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3482','NAD83(NSRS2007) / Arizona West',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10233','EPSG','2168',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3483','NAD83(NSRS2007) / Arizona West (ft)',NULL,NULL,'EPSG','4495','EPSG','4759','EPSG','15306','EPSG','2168',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3484','NAD83(NSRS2007) / Arkansas North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10331','EPSG','2169',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3485','NAD83(NSRS2007) / Arkansas North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15385','EPSG','2169',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3486','NAD83(NSRS2007) / Arkansas South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10332','EPSG','2170',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3487','NAD83(NSRS2007) / Arkansas South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15386','EPSG','2170',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3488','NAD83(NSRS2007) / California Albers',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10420','EPSG','1375',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3489','NAD83(NSRS2007) / California zone 1',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10431','EPSG','2175',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3490','NAD83(NSRS2007) / California zone 1 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15307','EPSG','2175',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3491','NAD83(NSRS2007) / California zone 2',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10432','EPSG','2176',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3492','NAD83(NSRS2007) / California zone 2 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15308','EPSG','2176',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3493','NAD83(NSRS2007) / California zone 3',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10433','EPSG','2177',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3494','NAD83(NSRS2007) / California zone 3 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15309','EPSG','2177',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3495','NAD83(NSRS2007) / California zone 4',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10434','EPSG','2178',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3496','NAD83(NSRS2007) / California zone 4 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15310','EPSG','2178',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3497','NAD83(NSRS2007) / California zone 5',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10435','EPSG','2182',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3498','NAD83(NSRS2007) / California zone 5 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15311','EPSG','2182',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3499','NAD83(NSRS2007) / California zone 6',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10436','EPSG','2180',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3500','NAD83(NSRS2007) / California zone 6 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15312','EPSG','2180',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3501','NAD83(NSRS2007) / Colorado Central',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10532','EPSG','2183',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3502','NAD83(NSRS2007) / Colorado Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15314','EPSG','2183',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3503','NAD83(NSRS2007) / Colorado North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10531','EPSG','2184',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3504','NAD83(NSRS2007) / Colorado North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15313','EPSG','2184',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3505','NAD83(NSRS2007) / Colorado South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10533','EPSG','2185',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3506','NAD83(NSRS2007) / Colorado South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15315','EPSG','2185',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3507','NAD83(NSRS2007) / Connecticut',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10630','EPSG','1377',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3508','NAD83(NSRS2007) / Connecticut (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15316','EPSG','1377',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3509','NAD83(NSRS2007) / Delaware',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10730','EPSG','1378',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3510','NAD83(NSRS2007) / Delaware (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15317','EPSG','1378',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3511','NAD83(NSRS2007) / Florida East',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10931','EPSG','2186',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3512','NAD83(NSRS2007) / Florida East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15318','EPSG','2186',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3513','NAD83(NSRS2007) / Florida GDL Albers',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10934','EPSG','1379',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3514','NAD83(NSRS2007) / Florida North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10933','EPSG','2187',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3515','NAD83(NSRS2007) / Florida North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15320','EPSG','2187',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3516','NAD83(NSRS2007) / Florida West',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','10932','EPSG','2188',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3517','NAD83(NSRS2007) / Florida West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15319','EPSG','2188',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3518','NAD83(NSRS2007) / Georgia East',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11031','EPSG','2189',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3519','NAD83(NSRS2007) / Georgia East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15321','EPSG','2189',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3520','NAD83(NSRS2007) / Georgia West',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11032','EPSG','2190',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3521','NAD83(NSRS2007) / Georgia West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15322','EPSG','2190',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3522','NAD83(NSRS2007) / Idaho Central',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11132','EPSG','2191',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3523','NAD83(NSRS2007) / Idaho Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15324','EPSG','2191',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3524','NAD83(NSRS2007) / Idaho East',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11131','EPSG','2192',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3525','NAD83(NSRS2007) / Idaho East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15323','EPSG','2192',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3526','NAD83(NSRS2007) / Idaho West',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11133','EPSG','2193',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3527','NAD83(NSRS2007) / Idaho West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15325','EPSG','2193',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3528','NAD83(NSRS2007) / Illinois East',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11231','EPSG','2194',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3529','NAD83(NSRS2007) / Illinois East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15387','EPSG','2194',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3530','NAD83(NSRS2007) / Illinois West',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11232','EPSG','2195',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3531','NAD83(NSRS2007) / Illinois West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15388','EPSG','2195',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3532','NAD83(NSRS2007) / Indiana East',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11331','EPSG','2196',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3533','NAD83(NSRS2007) / Indiana East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15372','EPSG','2196',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3534','NAD83(NSRS2007) / Indiana West',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11332','EPSG','2197',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3535','NAD83(NSRS2007) / Indiana West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15373','EPSG','2197',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3536','NAD83(NSRS2007) / Iowa North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11431','EPSG','2198',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3537','NAD83(NSRS2007) / Iowa North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15377','EPSG','2198',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3538','NAD83(NSRS2007) / Iowa South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11432','EPSG','2199',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3539','NAD83(NSRS2007) / Iowa South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15378','EPSG','2199',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3540','NAD83(NSRS2007) / Kansas North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11531','EPSG','2200',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3541','NAD83(NSRS2007) / Kansas North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15379','EPSG','2200',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3542','NAD83(NSRS2007) / Kansas South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11532','EPSG','2201',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3543','NAD83(NSRS2007) / Kansas South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15380','EPSG','2201',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3544','NAD83(NSRS2007) / Kentucky North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','15303','EPSG','2202',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3545','NAD83(NSRS2007) / Kentucky North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15328','EPSG','2202',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3546','NAD83(NSRS2007) / Kentucky Single Zone',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11630','EPSG','1386',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3547','NAD83(NSRS2007) / Kentucky Single Zone (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15375','EPSG','1386',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3548','NAD83(NSRS2007) / Kentucky South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11632','EPSG','2203',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3549','NAD83(NSRS2007) / Kentucky South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15329','EPSG','2203',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3550','NAD83(NSRS2007) / Louisiana North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11731','EPSG','2204',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3551','NAD83(NSRS2007) / Louisiana North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15391','EPSG','2204',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3552','NAD83(NSRS2007) / Louisiana South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11732','EPSG','2529',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3553','NAD83(NSRS2007) / Louisiana South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15392','EPSG','2529',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3554','NAD83(NSRS2007) / Maine CS2000 Central',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11854','EPSG','2959',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3555','NAD83(NSRS2007) / Maine CS2000 East',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11851','EPSG','2960',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3556','NAD83(NSRS2007) / Maine CS2000 West',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11853','EPSG','2958',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3557','NAD83(NSRS2007) / Maine East',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11831','EPSG','2206',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3558','NAD83(NSRS2007) / Maine West',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11832','EPSG','2207',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3559','NAD83(NSRS2007) / Maryland',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11930','EPSG','1389',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3560','NAD83 / Utah North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15297','EPSG','2258',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3561','Old Hawaiian / Hawaii zone 1',NULL,NULL,'EPSG','4497','EPSG','4135','EPSG','15101','EPSG','1546',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3562','Old Hawaiian / Hawaii zone 2',NULL,NULL,'EPSG','4497','EPSG','4135','EPSG','15102','EPSG','1547',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3563','Old Hawaiian / Hawaii zone 3',NULL,NULL,'EPSG','4497','EPSG','4135','EPSG','15103','EPSG','1548',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3564','Old Hawaiian / Hawaii zone 4',NULL,NULL,'EPSG','4497','EPSG','4135','EPSG','15104','EPSG','1549',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3565','Old Hawaiian / Hawaii zone 5',NULL,NULL,'EPSG','4497','EPSG','4135','EPSG','15105','EPSG','1550',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3566','NAD83 / Utah Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15298','EPSG','2257',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3567','NAD83 / Utah South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15299','EPSG','2259',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3568','NAD83(HARN) / Utah North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15297','EPSG','2258',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3569','NAD83(HARN) / Utah Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15298','EPSG','2257',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3570','NAD83(HARN) / Utah South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15299','EPSG','2259',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3571','WGS 84 / North Pole LAEA Bering Sea',NULL,NULL,'EPSG','4464','EPSG','4326','EPSG','17295','EPSG','3480',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3572','WGS 84 / North Pole LAEA Alaska',NULL,NULL,'EPSG','4467','EPSG','4326','EPSG','17296','EPSG','3480',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3573','WGS 84 / North Pole LAEA Canada',NULL,NULL,'EPSG','4466','EPSG','4326','EPSG','17297','EPSG','3480',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3574','WGS 84 / North Pole LAEA Atlantic',NULL,NULL,'EPSG','4465','EPSG','4326','EPSG','17298','EPSG','3480',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3575','WGS 84 / North Pole LAEA Europe',NULL,NULL,'EPSG','4463','EPSG','4326','EPSG','17299','EPSG','3480',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3576','WGS 84 / North Pole LAEA Russia',NULL,NULL,'EPSG','1035','EPSG','4326','EPSG','17300','EPSG','3480',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3577','GDA94 / Australian Albers',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','17365','EPSG','2575',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3578','NAD83 / Yukon Albers',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','19858','EPSG','2417',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3579','NAD83(CSRS) / Yukon Albers',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','19858','EPSG','2417',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3580','NAD83 / NWT Lambert',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','19857','EPSG','3481',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3581','NAD83(CSRS) / NWT Lambert',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','19857','EPSG','3481',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3582','NAD83(NSRS2007) / Maryland (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15330','EPSG','1389',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3583','NAD83(NSRS2007) / Massachusetts Island',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12032','EPSG','2208',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3584','NAD83(NSRS2007) / Massachusetts Island (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15332','EPSG','2208',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3585','NAD83(NSRS2007) / Massachusetts Mainland',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12031','EPSG','2209',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3586','NAD83(NSRS2007) / Massachusetts Mainland (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15331','EPSG','2209',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3587','NAD83(NSRS2007) / Michigan Central',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12142','EPSG','1724',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3588','NAD83(NSRS2007) / Michigan Central (ft)',NULL,NULL,'EPSG','4495','EPSG','4759','EPSG','15334','EPSG','1724',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3589','NAD83(NSRS2007) / Michigan North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12141','EPSG','1723',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3590','NAD83(NSRS2007) / Michigan North (ft)',NULL,NULL,'EPSG','4495','EPSG','4759','EPSG','15333','EPSG','1723',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3591','NAD83(NSRS2007) / Michigan Oblique Mercator',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12150','EPSG','1391',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3592','NAD83(NSRS2007) / Michigan South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12143','EPSG','1725',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3593','NAD83(NSRS2007) / Michigan South (ft)',NULL,NULL,'EPSG','4495','EPSG','4759','EPSG','15335','EPSG','1725',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3594','NAD83(NSRS2007) / Minnesota Central',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12232','EPSG','2213',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3595','NAD83(NSRS2007) / Minnesota North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12231','EPSG','2214',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3596','NAD83(NSRS2007) / Minnesota South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12233','EPSG','2215',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3597','NAD83(NSRS2007) / Mississippi East',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12331','EPSG','2216',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3598','NAD83(NSRS2007) / Mississippi East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15336','EPSG','2216',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3599','NAD83(NSRS2007) / Mississippi West',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12332','EPSG','2217',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3600','NAD83(NSRS2007) / Mississippi West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15337','EPSG','2217',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3601','NAD83(NSRS2007) / Missouri Central',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12432','EPSG','2218',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3602','NAD83(NSRS2007) / Missouri East',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12431','EPSG','2219',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3603','NAD83(NSRS2007) / Missouri West',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12433','EPSG','2220',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3604','NAD83(NSRS2007) / Montana',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12530','EPSG','1395',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3605','NAD83(NSRS2007) / Montana (ft)',NULL,NULL,'EPSG','4495','EPSG','4759','EPSG','15338','EPSG','1395',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3606','NAD83(NSRS2007) / Nebraska',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12630','EPSG','1396',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3607','NAD83(NSRS2007) / Nevada Central',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12732','EPSG','2223',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3608','NAD83(NSRS2007) / Nevada Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15382','EPSG','2223',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3609','NAD83(NSRS2007) / Nevada East',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12731','EPSG','2224',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3610','NAD83(NSRS2007) / Nevada East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15381','EPSG','2224',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3611','NAD83(NSRS2007) / Nevada West',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12733','EPSG','2225',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3612','NAD83(NSRS2007) / Nevada West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15383','EPSG','2225',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3613','NAD83(NSRS2007) / New Hampshire',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12830','EPSG','1398',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3614','NAD83(NSRS2007) / New Hampshire (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15389','EPSG','1398',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3615','NAD83(NSRS2007) / New Jersey',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12930','EPSG','1399',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3616','NAD83(NSRS2007) / New Jersey (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15384','EPSG','1399',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3617','NAD83(NSRS2007) / New Mexico Central',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13032','EPSG','2231',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3618','NAD83(NSRS2007) / New Mexico Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15340','EPSG','2231',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3619','NAD83(NSRS2007) / New Mexico East',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13031','EPSG','2228',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3620','NAD83(NSRS2007) / New Mexico East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15339','EPSG','2228',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3621','NAD83(NSRS2007) / New Mexico West',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13033','EPSG','2232',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3622','NAD83(NSRS2007) / New Mexico West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15341','EPSG','2232',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3623','NAD83(NSRS2007) / New York Central',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13132','EPSG','2233',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3624','NAD83(NSRS2007) / New York Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15343','EPSG','2233',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3625','NAD83(NSRS2007) / New York East',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13131','EPSG','2234',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3626','NAD83(NSRS2007) / New York East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15342','EPSG','2234',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3627','NAD83(NSRS2007) / New York Long Island',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13134','EPSG','2235',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3628','NAD83(NSRS2007) / New York Long Island (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15345','EPSG','2235',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3629','NAD83(NSRS2007) / New York West',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13133','EPSG','2236',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3630','NAD83(NSRS2007) / New York West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15344','EPSG','2236',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3631','NAD83(NSRS2007) / North Carolina',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13230','EPSG','1402',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3632','NAD83(NSRS2007) / North Carolina (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15346','EPSG','1402',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3633','NAD83(NSRS2007) / North Dakota North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13331','EPSG','2237',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3634','NAD83(NSRS2007) / North Dakota North (ft)',NULL,NULL,'EPSG','4495','EPSG','4759','EPSG','15347','EPSG','2237',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3635','NAD83(NSRS2007) / North Dakota South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13332','EPSG','2238',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3636','NAD83(NSRS2007) / North Dakota South (ft)',NULL,NULL,'EPSG','4495','EPSG','4759','EPSG','15348','EPSG','2238',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3637','NAD83(NSRS2007) / Ohio North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13431','EPSG','2239',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3638','NAD83(NSRS2007) / Ohio South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13432','EPSG','2240',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3639','NAD83(NSRS2007) / Oklahoma North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13531','EPSG','2241',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3640','NAD83(NSRS2007) / Oklahoma North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15349','EPSG','2241',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3641','NAD83(NSRS2007) / Oklahoma South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13532','EPSG','2242',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3642','NAD83(NSRS2007) / Oklahoma South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15350','EPSG','2242',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3643','NAD83(NSRS2007) / Oregon LCC (m)',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13633','EPSG','1406',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3644','NAD83(NSRS2007) / Oregon GIC Lambert (ft)',NULL,NULL,'EPSG','4495','EPSG','4759','EPSG','15374','EPSG','1406',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3645','NAD83(NSRS2007) / Oregon North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13631','EPSG','2243',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3646','NAD83(NSRS2007) / Oregon North (ft)',NULL,NULL,'EPSG','4495','EPSG','4759','EPSG','15351','EPSG','2243',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3647','NAD83(NSRS2007) / Oregon South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13632','EPSG','2244',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3648','NAD83(NSRS2007) / Oregon South (ft)',NULL,NULL,'EPSG','4495','EPSG','4759','EPSG','15352','EPSG','2244',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3649','NAD83(NSRS2007) / Pennsylvania North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13731','EPSG','2245',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3650','NAD83(NSRS2007) / Pennsylvania North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15353','EPSG','2245',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3651','NAD83(NSRS2007) / Pennsylvania South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13732','EPSG','2246',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3652','NAD83(NSRS2007) / Pennsylvania South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15354','EPSG','2246',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3653','NAD83(NSRS2007) / Rhode Island',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13830','EPSG','1408',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3654','NAD83(NSRS2007) / Rhode Island (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15390','EPSG','1408',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3655','NAD83(NSRS2007) / South Carolina',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','13930','EPSG','1409',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3656','NAD83(NSRS2007) / South Carolina (ft)',NULL,NULL,'EPSG','4495','EPSG','4759','EPSG','15355','EPSG','1409',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3657','NAD83(NSRS2007) / South Dakota North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14031','EPSG','2249',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3658','NAD83(NSRS2007) / South Dakota North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15394','EPSG','2249',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3659','NAD83(NSRS2007) / South Dakota South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14032','EPSG','2250',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3660','NAD83(NSRS2007) / South Dakota South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15395','EPSG','2250',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3661','NAD83(NSRS2007) / Tennessee',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14130','EPSG','1411',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3662','NAD83(NSRS2007) / Tennessee (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15356','EPSG','1411',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3663','NAD83(NSRS2007) / Texas Central',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14233','EPSG','2252',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3664','NAD83(NSRS2007) / Texas Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15359','EPSG','2252',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3665','NAD83(NSRS2007) / Texas Centric Albers Equal Area',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14254','EPSG','1412',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3666','NAD83(NSRS2007) / Texas Centric Lambert Conformal',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14253','EPSG','1412',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3667','NAD83(NSRS2007) / Texas North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14231','EPSG','2253',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3668','NAD83(NSRS2007) / Texas North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15357','EPSG','2253',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3669','NAD83(NSRS2007) / Texas North Central',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14232','EPSG','2254',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3670','NAD83(NSRS2007) / Texas North Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15358','EPSG','2254',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3671','NAD83(NSRS2007) / Texas South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14235','EPSG','2528',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3672','NAD83(NSRS2007) / Texas South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15361','EPSG','2528',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3673','NAD83(NSRS2007) / Texas South Central',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14234','EPSG','2527',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3674','NAD83(NSRS2007) / Texas South Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15360','EPSG','2527',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3675','NAD83(NSRS2007) / Utah Central',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14332','EPSG','2257',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3676','NAD83(NSRS2007) / Utah Central (ft)',NULL,NULL,'EPSG','4495','EPSG','4759','EPSG','15363','EPSG','2257',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3677','NAD83(NSRS2007) / Utah Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15298','EPSG','2257',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3678','NAD83(NSRS2007) / Utah North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14331','EPSG','2258',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3679','NAD83(NSRS2007) / Utah North (ft)',NULL,NULL,'EPSG','4495','EPSG','4759','EPSG','15362','EPSG','2258',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3680','NAD83(NSRS2007) / Utah North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15297','EPSG','2258',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3681','NAD83(NSRS2007) / Utah South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14333','EPSG','2259',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3682','NAD83(NSRS2007) / Utah South (ft)',NULL,NULL,'EPSG','4495','EPSG','4759','EPSG','15364','EPSG','2259',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3683','NAD83(NSRS2007) / Utah South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15299','EPSG','2259',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3684','NAD83(NSRS2007) / Vermont',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14430','EPSG','1414',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3685','NAD83(NSRS2007) / Virginia North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14531','EPSG','2260',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3686','NAD83(NSRS2007) / Virginia North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15365','EPSG','2260',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3687','NAD83(NSRS2007) / Virginia South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14532','EPSG','2261',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3688','NAD83(NSRS2007) / Virginia South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15366','EPSG','2261',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3689','NAD83(NSRS2007) / Washington North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14631','EPSG','2273',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3690','NAD83(NSRS2007) / Washington North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15367','EPSG','2273',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3691','NAD83(NSRS2007) / Washington South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14632','EPSG','2274',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3692','NAD83(NSRS2007) / Washington South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15368','EPSG','2274',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3693','NAD83(NSRS2007) / West Virginia North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14731','EPSG','2264',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3694','NAD83(NSRS2007) / West Virginia South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14732','EPSG','2265',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3695','NAD83(NSRS2007) / Wisconsin Central',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14832','EPSG','2266',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3696','NAD83(NSRS2007) / Wisconsin Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15370','EPSG','2266',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3697','NAD83(NSRS2007) / Wisconsin North',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14831','EPSG','2267',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3698','NAD83(NSRS2007) / Wisconsin North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15369','EPSG','2267',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3699','NAD83(NSRS2007) / Wisconsin South',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14833','EPSG','2268',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3700','NAD83(NSRS2007) / Wisconsin South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15371','EPSG','2268',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3701','NAD83(NSRS2007) / Wisconsin Transverse Mercator',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14841','EPSG','1418',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3702','NAD83(NSRS2007) / Wyoming East',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14931','EPSG','2269',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3703','NAD83(NSRS2007) / Wyoming East Central',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14932','EPSG','2270',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3704','NAD83(NSRS2007) / Wyoming West Central',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14933','EPSG','2272',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3705','NAD83(NSRS2007) / Wyoming West',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14934','EPSG','2271',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3706','NAD83(NSRS2007) / UTM zone 59N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16059','EPSG','3372',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3707','NAD83(NSRS2007) / UTM zone 60N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16060','EPSG','3373',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3708','NAD83(NSRS2007) / UTM zone 1N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16001','EPSG','3374',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3709','NAD83(NSRS2007) / UTM zone 2N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16002','EPSG','3375',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3710','NAD83(NSRS2007) / UTM zone 3N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16003','EPSG','2133',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3711','NAD83(NSRS2007) / UTM zone 4N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16004','EPSG','2134',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3712','NAD83(NSRS2007) / UTM zone 5N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16005','EPSG','2135',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3713','NAD83(NSRS2007) / UTM zone 6N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16006','EPSG','2136',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3714','NAD83(NSRS2007) / UTM zone 7N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16007','EPSG','3494',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3715','NAD83(NSRS2007) / UTM zone 8N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16008','EPSG','3495',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3716','NAD83(NSRS2007) / UTM zone 9N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16009','EPSG','3496',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3717','NAD83(NSRS2007) / UTM zone 10N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16010','EPSG','3497',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3718','NAD83(NSRS2007) / UTM zone 11N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16011','EPSG','3498',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3719','NAD83(NSRS2007) / UTM zone 12N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16012','EPSG','3499',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3720','NAD83(NSRS2007) / UTM zone 13N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16013','EPSG','3500',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3721','NAD83(NSRS2007) / UTM zone 14N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16014','EPSG','3501',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3722','NAD83(NSRS2007) / UTM zone 15N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16015','EPSG','3502',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3723','NAD83(NSRS2007) / UTM zone 16N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16016','EPSG','3503',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3724','NAD83(NSRS2007) / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16017','EPSG','3504',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3725','NAD83(NSRS2007) / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16018','EPSG','3505',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3726','NAD83(NSRS2007) / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16019','EPSG','3506',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3727','Reunion 1947 / TM Reunion',NULL,NULL,'EPSG','4499','EPSG','4626','EPSG','19856','EPSG','3337',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3728','NAD83(NSRS2007) / Ohio North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','13433','EPSG','2239',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3729','NAD83(NSRS2007) / Ohio South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','13434','EPSG','2240',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3730','NAD83(NSRS2007) / Wyoming East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','14935','EPSG','2269',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3731','NAD83(NSRS2007) / Wyoming East Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','14936','EPSG','2270',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3732','NAD83(NSRS2007) / Wyoming West Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','14937','EPSG','2272',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3733','NAD83(NSRS2007) / Wyoming West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','14938','EPSG','2271',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3734','NAD83 / Ohio North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','13433','EPSG','2239',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3735','NAD83 / Ohio South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','13434','EPSG','2240',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3736','NAD83 / Wyoming East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','14935','EPSG','2269',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3737','NAD83 / Wyoming East Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','14936','EPSG','2270',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3738','NAD83 / Wyoming West Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','14937','EPSG','2272',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3739','NAD83 / Wyoming West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','14938','EPSG','2271',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3740','NAD83(HARN) / UTM zone 10N',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16010','EPSG','3857',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3741','NAD83(HARN) / UTM zone 11N',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16011','EPSG','3852',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3742','NAD83(HARN) / UTM zone 12N',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16012','EPSG','3499',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3743','NAD83(HARN) / UTM zone 13N',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16013','EPSG','3500',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3744','NAD83(HARN) / UTM zone 14N',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16014','EPSG','3860',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3745','NAD83(HARN) / UTM zone 15N',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16015','EPSG','3861',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3746','NAD83(HARN) / UTM zone 16N',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16016','EPSG','3862',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3747','NAD83(HARN) / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16017','EPSG','3863',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3748','NAD83(HARN) / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16018','EPSG','3868',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3749','NAD83(HARN) / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16019','EPSG','3871',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3750','NAD83(HARN) / UTM zone 4N',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16004','EPSG','3488',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3751','NAD83(HARN) / UTM zone 5N',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16005','EPSG','3491',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3752','WGS 84 / Mercator 41',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','19855','EPSG','3508',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3753','NAD83(HARN) / Ohio North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','13433','EPSG','2239',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3754','NAD83(HARN) / Ohio South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','13434','EPSG','2240',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3755','NAD83(HARN) / Wyoming East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','14935','EPSG','2269',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3756','NAD83(HARN) / Wyoming East Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','14936','EPSG','2270',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3757','NAD83(HARN) / Wyoming West Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','14937','EPSG','2272',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3758','NAD83(HARN) / Wyoming West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','14938','EPSG','2271',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3759','NAD83 / Hawaii zone 3 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15138','EPSG','1548',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3760','NAD83(HARN) / Hawaii zone 3 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15138','EPSG','1548',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3761','NAD83(CSRS) / UTM zone 22N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16022','EPSG','2152',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3762','WGS 84 / South Georgia Lambert',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','19854','EPSG','3529',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3763','ETRS89 / Portugal TM06',NULL,NULL,'EPSG','4499','EPSG','4258','EPSG','19853','EPSG','1294',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3764','NZGD2000 / Chatham Island Circuit 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17959','EPSG','2889',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3765','HTRS96 / Croatia TM',NULL,NULL,'EPSG','4400','EPSG','4761','EPSG','19851','EPSG','3234',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3766','HTRS96 / Croatia LCC',NULL,NULL,'EPSG','4400','EPSG','4761','EPSG','19852','EPSG','1076',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3767','HTRS96 / UTM zone 33N',NULL,NULL,'EPSG','4400','EPSG','4761','EPSG','16033','EPSG','3539',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3768','HTRS96 / UTM zone 34N',NULL,NULL,'EPSG','4400','EPSG','4761','EPSG','16034','EPSG','3538',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3769','Bermuda 1957 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4216','EPSG','16020','EPSG','3221',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3770','BDA2000 / Bermuda 2000 National Grid',NULL,NULL,'EPSG','4400','EPSG','4762','EPSG','19849','EPSG','1047',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3771','NAD27 / Alberta 3TM ref merid 111 W',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','17722','EPSG','3543',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3772','NAD27 / Alberta 3TM ref merid 114 W',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','17723','EPSG','3542',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3773','NAD27 / Alberta 3TM ref merid 117 W',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','17724','EPSG','3541',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3774','NAD27 / Alberta 3TM ref merid 120 W',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','17725','EPSG','3540',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3775','NAD83 / Alberta 3TM ref merid 111 W',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','17722','EPSG','3543',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3776','NAD83 / Alberta 3TM ref merid 114 W',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','17723','EPSG','3542',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3777','NAD83 / Alberta 3TM ref merid 117 W',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','17724','EPSG','3541',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3778','NAD83 / Alberta 3TM ref merid 120 W',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','17725','EPSG','3540',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3779','NAD83(CSRS) / Alberta 3TM ref merid 111 W',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','17722','EPSG','3543',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3780','NAD83(CSRS) / Alberta 3TM ref merid 114 W',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','17723','EPSG','3542',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3781','NAD83(CSRS) / Alberta 3TM ref merid 117 W',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','17724','EPSG','3541',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3782','NAD83(CSRS) / Alberta 3TM ref merid 120 W',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','17725','EPSG','3540',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3783','Pitcairn 2006 / Pitcairn TM 2006',NULL,NULL,'EPSG','4400','EPSG','4763','EPSG','19848','EPSG','3208',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3784','Pitcairn 1967 / UTM zone 9S',NULL,NULL,'EPSG','4400','EPSG','4729','EPSG','16109','EPSG','3208',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3785','Popular Visualisation CRS / Mercator',NULL,NULL,'EPSG','4499','EPSG','4055','EPSG','19847','EPSG','3544',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3786','World Equidistant Cylindrical (Sphere)',NULL,NULL,'EPSG','4499','EPSG','4047','EPSG','19968','EPSG','1262',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3787','MGI / Slovene National Grid',NULL,NULL,'EPSG','4498','EPSG','4312','EPSG','19845','EPSG','1212',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3788','NZGD2000 / Auckland Islands TM 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17960','EPSG','3554',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3789','NZGD2000 / Campbell Island TM 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17961','EPSG','3555',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3790','NZGD2000 / Antipodes Islands TM 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17962','EPSG','3556',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3791','NZGD2000 / Raoul Island TM 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17963','EPSG','3557',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3793','NZGD2000 / Chatham Islands TM 2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17965','EPSG','2889',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3794','Slovenia 1996 / Slovene National Grid',NULL,NULL,'EPSG','4400','EPSG','4765','EPSG','19845','EPSG','1212',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3795','NAD27 / Cuba Norte',NULL,NULL,'EPSG','4532','EPSG','4267','EPSG','18063','EPSG','1487',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3796','NAD27 / Cuba Sur',NULL,NULL,'EPSG','4532','EPSG','4267','EPSG','18064','EPSG','1488',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3797','NAD27 / MTQ Lambert',NULL,NULL,'EPSG','4499','EPSG','4267','EPSG','19844','EPSG','1368',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3798','NAD83 / MTQ Lambert',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','19844','EPSG','1368',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3799','NAD83(CSRS) / MTQ Lambert',NULL,NULL,'EPSG','4499','EPSG','4617','EPSG','19844','EPSG','1368',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3800','NAD27 / Alberta 3TM ref merid 120 W',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','17726','EPSG','3540',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3801','NAD83 / Alberta 3TM ref merid 120 W',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','17726','EPSG','3540',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3802','NAD83(CSRS) / Alberta 3TM ref merid 120 W',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','17726','EPSG','3540',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3812','ETRS89 / Belgian Lambert 2008',NULL,NULL,'EPSG','4499','EPSG','4258','EPSG','3811','EPSG','1347',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3814','NAD83 / Mississippi TM',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','3813','EPSG','1393',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3815','NAD83(HARN) / Mississippi TM',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','3813','EPSG','1393',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3816','NAD83(NSRS2007) / Mississippi TM',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','3813','EPSG','1393',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3825','TWD97 / TM2 zone 119',NULL,NULL,'EPSG','4499','EPSG','3824','EPSG','3818','EPSG','3563',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3826','TWD97 / TM2 zone 121',NULL,NULL,'EPSG','4499','EPSG','3824','EPSG','3820','EPSG','3562',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3827','TWD67 / TM2 zone 119',NULL,NULL,'EPSG','4499','EPSG','3821','EPSG','3818','EPSG','3591',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3828','TWD67 / TM2 zone 121',NULL,NULL,'EPSG','4499','EPSG','3821','EPSG','3820','EPSG','3982',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3829','Hu Tzu Shan 1950 / UTM zone 51N',NULL,NULL,'EPSG','4400','EPSG','4236','EPSG','16051','EPSG','3315',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3832','WGS 84 / PDC Mercator',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','3831','EPSG','3172',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3833','Pulkovo 1942(58) / Gauss-Kruger zone 2',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','16202','EPSG','3575',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3834','Pulkovo 1942(83) / Gauss-Kruger zone 2',NULL,NULL,'EPSG','4530','EPSG','4178','EPSG','16202','EPSG','3575',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3835','Pulkovo 1942(83) / Gauss-Kruger zone 3',NULL,NULL,'EPSG','4530','EPSG','4178','EPSG','16203','EPSG','3576',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3836','Pulkovo 1942(83) / Gauss-Kruger zone 4',NULL,NULL,'EPSG','4530','EPSG','4178','EPSG','16204','EPSG','3578',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3837','Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 3',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','16263','EPSG','1512',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3838','Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 4',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','16264','EPSG','1513',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3839','Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 9',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','16269','EPSG','3587',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3840','Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 10',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','16270','EPSG','3588',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3841','Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 6',NULL,NULL,'EPSG','4530','EPSG','4178','EPSG','16266','EPSG','3582',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3842','Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 7',NULL,NULL,'EPSG','4530','EPSG','4178','EPSG','16266','EPSG','3584',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3843','Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 8',NULL,NULL,'EPSG','4530','EPSG','4178','EPSG','16266','EPSG','3586',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3844','Pulkovo 1942(58) / Stereo70',NULL,NULL,'EPSG','4530','EPSG','4179','EPSG','19926','EPSG','1197',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3845','SWEREF99 / RT90 7.5 gon V emulation',NULL,NULL,'EPSG','4530','EPSG','4619','EPSG','17339','EPSG','2845',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3846','SWEREF99 / RT90 5 gon V emulation',NULL,NULL,'EPSG','4530','EPSG','4619','EPSG','17340','EPSG','2846',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3847','SWEREF99 / RT90 2.5 gon V emulation',NULL,NULL,'EPSG','4530','EPSG','4619','EPSG','17341','EPSG','2847',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3848','SWEREF99 / RT90 0 gon emulation',NULL,NULL,'EPSG','4530','EPSG','4619','EPSG','17342','EPSG','2848',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3849','SWEREF99 / RT90 2.5 gon O emulation',NULL,NULL,'EPSG','4530','EPSG','4619','EPSG','17343','EPSG','2849',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3850','SWEREF99 / RT90 5 gon O emulation',NULL,NULL,'EPSG','4530','EPSG','4619','EPSG','17344','EPSG','2850',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3851','NZGD2000 / NZCS2000',NULL,NULL,'EPSG','4500','EPSG','4167','EPSG','17964','EPSG','3593',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3852','RSRGD2000 / DGLC2000',NULL,NULL,'EPSG','4500','EPSG','4764','EPSG','17966','EPSG','3592',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3854','County ST74',NULL,NULL,'EPSG','4531','EPSG','4619','EPSG','3853','EPSG','3608',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3857','WGS 84 / Pseudo-Mercator',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','3856','EPSG','3544',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3873','ETRS89 / GK19FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','3860','EPSG','3595',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3874','ETRS89 / GK20FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','3861','EPSG','3596',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3875','ETRS89 / GK21FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','3862','EPSG','3597',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3876','ETRS89 / GK22FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','3863','EPSG','3598',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3877','ETRS89 / GK23FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','3864','EPSG','3599',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3878','ETRS89 / GK24FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','3865','EPSG','3600',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3879','ETRS89 / GK25FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','3866','EPSG','3601',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3880','ETRS89 / GK26FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','3867','EPSG','3602',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3881','ETRS89 / GK27FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','3868','EPSG','3603',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3882','ETRS89 / GK28FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','3869','EPSG','3604',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3883','ETRS89 / GK29FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','3870','EPSG','3605',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3884','ETRS89 / GK30FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','3871','EPSG','3606',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3885','ETRS89 / GK31FIN',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','3872','EPSG','3607',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3890','IGRS / UTM zone 37N',NULL,NULL,'EPSG','4400','EPSG','3889','EPSG','16037','EPSG','3387',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3891','IGRS / UTM zone 38N',NULL,NULL,'EPSG','4400','EPSG','3889','EPSG','16038','EPSG','3388',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3892','IGRS / UTM zone 39N',NULL,NULL,'EPSG','4400','EPSG','3889','EPSG','16039','EPSG','3956',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3893','ED50 / Iraq National Grid',NULL,NULL,'EPSG','4400','EPSG','4230','EPSG','19907','EPSG','3625',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3907','MGI 1901 / Balkans zone 5',NULL,NULL,'EPSG','4530','EPSG','3906','EPSG','18275','EPSG','1709',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3908','MGI 1901 / Balkans zone 6',NULL,NULL,'EPSG','4530','EPSG','3906','EPSG','18276','EPSG','1710',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3909','MGI 1901 / Balkans zone 7',NULL,NULL,'EPSG','4530','EPSG','3906','EPSG','18277','EPSG','1711',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3910','MGI 1901 / Balkans zone 8',NULL,NULL,'EPSG','4530','EPSG','3906','EPSG','18278','EPSG','1712',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3911','MGI 1901 / Slovenia Grid',NULL,NULL,'EPSG','4530','EPSG','3906','EPSG','19967','EPSG','1212',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3912','MGI 1901 / Slovene National Grid',NULL,NULL,'EPSG','4498','EPSG','3906','EPSG','19845','EPSG','1212',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3920','Puerto Rico / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4139','EPSG','16020','EPSG','3329',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3942','RGF93 / CC42',NULL,NULL,'EPSG','4499','EPSG','4171','EPSG','18101','EPSG','3545',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3943','RGF93 / CC43',NULL,NULL,'EPSG','4499','EPSG','4171','EPSG','18102','EPSG','3546',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3944','RGF93 / CC44',NULL,NULL,'EPSG','4499','EPSG','4171','EPSG','18103','EPSG','3547',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3945','RGF93 / CC45',NULL,NULL,'EPSG','4499','EPSG','4171','EPSG','18104','EPSG','3548',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3946','RGF93 / CC46',NULL,NULL,'EPSG','4499','EPSG','4171','EPSG','18105','EPSG','3549',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3947','RGF93 / CC47',NULL,NULL,'EPSG','4499','EPSG','4171','EPSG','18106','EPSG','3550',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3948','RGF93 / CC48',NULL,NULL,'EPSG','4499','EPSG','4171','EPSG','18107','EPSG','3551',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3949','RGF93 / CC49',NULL,NULL,'EPSG','4499','EPSG','4171','EPSG','18108','EPSG','3552',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3950','RGF93 / CC50',NULL,NULL,'EPSG','4499','EPSG','4171','EPSG','18109','EPSG','3553',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3968','NAD83 / Virginia Lambert',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','3967','EPSG','1415',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3969','NAD83(HARN) / Virginia Lambert',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','3967','EPSG','1415',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3970','NAD83(NSRS2007) / Virginia Lambert',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','3967','EPSG','1415',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3973','WGS 84 / NSIDC EASE-Grid North',NULL,NULL,'EPSG','4469','EPSG','4326','EPSG','3897','EPSG','3475',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3974','WGS 84 / NSIDC EASE-Grid South',NULL,NULL,'EPSG','4470','EPSG','4326','EPSG','3898','EPSG','3474',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3975','WGS 84 / NSIDC EASE-Grid Global',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','19869','EPSG','3463',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3976','WGS 84 / NSIDC Sea Ice Polar Stereographic South',NULL,NULL,'EPSG','4470','EPSG','4326','EPSG','19866','EPSG','1997',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3978','NAD83 / Canada Atlas Lambert',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','3977','EPSG','1061',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3979','NAD83(CSRS) / Canada Atlas Lambert',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','3977','EPSG','1061',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3985','Katanga 1955 / Katanga Lambert',NULL,NULL,'EPSG','4499','EPSG','4695','EPSG','3980','EPSG','3147',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','3986','Katanga 1955 / Katanga Gauss zone A',NULL,NULL,'EPSG','4499','EPSG','4695','EPSG','3981','EPSG','3612',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3987','Katanga 1955 / Katanga Gauss zone B',NULL,NULL,'EPSG','4499','EPSG','4695','EPSG','3982','EPSG','3611',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3988','Katanga 1955 / Katanga Gauss zone C',NULL,NULL,'EPSG','4499','EPSG','4695','EPSG','3983','EPSG','3610',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3989','Katanga 1955 / Katanga Gauss zone D',NULL,NULL,'EPSG','4499','EPSG','4695','EPSG','3984','EPSG','3609',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3991','Puerto Rico State Plane CS of 1927',NULL,NULL,'EPSG','4497','EPSG','4139','EPSG','15201','EPSG','3294',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3992','Puerto Rico / St. Croix',NULL,NULL,'EPSG','4497','EPSG','4139','EPSG','15202','EPSG','3330',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3993','Guam 1963 / Guam SPCS',NULL,NULL,'EPSG','4499','EPSG','4675','EPSG','15400','EPSG','3255',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3994','WGS 84 / Mercator 41',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','19843','EPSG','3508',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3995','WGS 84 / Arctic Polar Stereographic',NULL,NULL,'EPSG','4469','EPSG','4326','EPSG','19842','EPSG','1996',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3996','WGS 84 / IBCAO Polar Stereographic',NULL,NULL,'EPSG','4469','EPSG','4326','EPSG','19840','EPSG','1996',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','3997','WGS 84 / Dubai Local TM',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','19839','EPSG','3531',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4026','MOLDREF99 / Moldova TM',NULL,NULL,'EPSG','4530','EPSG','4023','EPSG','3999','EPSG','1162',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4037','WGS 84 / TMzn35N',NULL,NULL,'EPSG','4500','EPSG','4326','EPSG','16035','EPSG','3615',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4038','WGS 84 / TMzn36N',NULL,NULL,'EPSG','4500','EPSG','4326','EPSG','16036','EPSG','3616',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4048','RGRDC 2005 / Congo TM zone 12',NULL,NULL,'EPSG','4499','EPSG','4046','EPSG','17412','EPSG','3937',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4049','RGRDC 2005 / Congo TM zone 14',NULL,NULL,'EPSG','4499','EPSG','4046','EPSG','17414','EPSG','3151',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4050','RGRDC 2005 / Congo TM zone 16',NULL,NULL,'EPSG','4499','EPSG','4046','EPSG','17416','EPSG','3617',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4051','RGRDC 2005 / Congo TM zone 18',NULL,NULL,'EPSG','4499','EPSG','4046','EPSG','17418','EPSG','3618',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4056','RGRDC 2005 / Congo TM zone 20',NULL,NULL,'EPSG','4499','EPSG','4046','EPSG','17420','EPSG','3620',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4057','RGRDC 2005 / Congo TM zone 22',NULL,NULL,'EPSG','4499','EPSG','4046','EPSG','17422','EPSG','3621',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4058','RGRDC 2005 / Congo TM zone 24',NULL,NULL,'EPSG','4499','EPSG','4046','EPSG','17424','EPSG','3622',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4059','RGRDC 2005 / Congo TM zone 26',NULL,NULL,'EPSG','4499','EPSG','4046','EPSG','17426','EPSG','3623',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4060','RGRDC 2005 / Congo TM zone 28',NULL,NULL,'EPSG','4499','EPSG','4046','EPSG','17428','EPSG','3624',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4061','RGRDC 2005 / UTM zone 33S',NULL,NULL,'EPSG','4499','EPSG','4046','EPSG','16133','EPSG','3626',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4062','RGRDC 2005 / UTM zone 34S',NULL,NULL,'EPSG','4499','EPSG','4046','EPSG','16134','EPSG','3627',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4063','RGRDC 2005 / UTM zone 35S',NULL,NULL,'EPSG','4499','EPSG','4046','EPSG','16135','EPSG','3628',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4071','Chua / UTM zone 23S',NULL,NULL,'EPSG','4400','EPSG','4224','EPSG','16123','EPSG','3619',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4082','REGCAN95 / UTM zone 27N',NULL,NULL,'EPSG','4400','EPSG','4081','EPSG','16027','EPSG','3629',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4083','REGCAN95 / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4081','EPSG','16028','EPSG','3630',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4087','WGS 84 / World Equidistant Cylindrical',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','4085','EPSG','1262',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4088','World Equidistant Cylindrical (Sphere)',NULL,NULL,'EPSG','4499','EPSG','4047','EPSG','4086','EPSG','1262',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4093','ETRS89 / DKTM1',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','4089','EPSG','3631',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4094','ETRS89 / DKTM2',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','4090','EPSG','3632',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4095','ETRS89 / DKTM3',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','4091','EPSG','2532',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4096','ETRS89 / DKTM4',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','4092','EPSG','2533',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4217','NAD83 / BLM 59N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','4186','EPSG','3372',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4390','Kertau 1968 / Johor Grid',NULL,NULL,'EPSG','4400','EPSG','4245','EPSG','4114','EPSG','3376',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4391','Kertau 1968 / Sembilan and Melaka Grid',NULL,NULL,'EPSG','4400','EPSG','4245','EPSG','4115','EPSG','3377',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4392','Kertau 1968 / Pahang Grid',NULL,NULL,'EPSG','4400','EPSG','4245','EPSG','4116','EPSG','3378',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4393','Kertau 1968 / Selangor Grid',NULL,NULL,'EPSG','4400','EPSG','4245','EPSG','4117','EPSG','3379',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4394','Kertau 1968 / Terengganu Grid',NULL,NULL,'EPSG','4400','EPSG','4245','EPSG','4177','EPSG','3380',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4395','Kertau 1968 / Pinang Grid',NULL,NULL,'EPSG','4400','EPSG','4245','EPSG','4305','EPSG','3381',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4396','Kertau 1968 / Kedah and Perlis Grid',NULL,NULL,'EPSG','4400','EPSG','4245','EPSG','4320','EPSG','3382',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4397','Kertau 1968 / Perak Revised Grid',NULL,NULL,'EPSG','4400','EPSG','4245','EPSG','4321','EPSG','3383',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4398','Kertau 1968 / Kelantan Grid',NULL,NULL,'EPSG','4400','EPSG','4245','EPSG','4323','EPSG','3384',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4399','NAD27 / BLM 59N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4186','EPSG','3372',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4400','NAD27 / BLM 60N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4187','EPSG','3373',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4401','NAD27 / BLM 1N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4101','EPSG','3374',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4402','NAD27 / BLM 2N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4102','EPSG','3375',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4403','NAD27 / BLM 3N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4103','EPSG','2133',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4404','NAD27 / BLM 4N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4104','EPSG','2134',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4405','NAD27 / BLM 5N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4105','EPSG','2135',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4406','NAD27 / BLM 6N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4106','EPSG','2136',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4407','NAD27 / BLM 7N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4107','EPSG','3494',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4408','NAD27 / BLM 8N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4108','EPSG','3495',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4409','NAD27 / BLM 9N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4109','EPSG','3496',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4410','NAD27 / BLM 10N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4110','EPSG','3497',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4411','NAD27 / BLM 11N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4111','EPSG','3498',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4412','NAD27 / BLM 12N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4112','EPSG','3499',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4413','NAD27 / BLM 13N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4113','EPSG','3500',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4414','NAD83(HARN) / Guam Map Grid',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','4325','EPSG','3255',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4415','Katanga 1955 / Katanga Lambert',NULL,NULL,'EPSG','4499','EPSG','4695','EPSG','4416','EPSG','3147',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4417','Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 7',NULL,NULL,'EPSG','4530','EPSG','4178','EPSG','16267','EPSG','3584',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4418','NAD27 / BLM 18N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4118','EPSG','3505',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4419','NAD27 / BLM 19N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4119','EPSG','3506',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4420','NAD83 / BLM 60N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','4187','EPSG','3373',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4421','NAD83 / BLM 1N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','4101','EPSG','3374',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4422','NAD83 / BLM 2N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','4102','EPSG','3375',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4423','NAD83 / BLM 3N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','4103','EPSG','2133',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4424','NAD83 / BLM 4N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','4104','EPSG','2134',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4425','NAD83 / BLM 5N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','4105','EPSG','2135',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4426','NAD83 / BLM 6N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','4106','EPSG','2136',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4427','NAD83 / BLM 7N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','4107','EPSG','3494',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4428','NAD83 / BLM 8N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','4108','EPSG','3495',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4429','NAD83 / BLM 9N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','4109','EPSG','3496',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4430','NAD83 / BLM 10N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','4110','EPSG','3497',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4431','NAD83 / BLM 11N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','4111','EPSG','3498',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4432','NAD83 / BLM 12N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','4112','EPSG','3499',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4433','NAD83 / BLM 13N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','4113','EPSG','3500',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4434','Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 8',NULL,NULL,'EPSG','4530','EPSG','4178','EPSG','16268','EPSG','3586',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4437','NAD83(NSRS2007) / Puerto Rico and Virgin Is.',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','15230','EPSG','3634',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4438','NAD83 / BLM 18N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','4118','EPSG','3505',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4439','NAD83 / BLM 19N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','4119','EPSG','3506',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4455','NAD27 / Pennsylvania South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4436','EPSG','2246',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4456','NAD27 / New York Long Island',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','4454','EPSG','2235',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4457','NAD83 / South Dakota North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15394','EPSG','2249',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4462','WGS 84 / Australian Centre for Remote Sensing Lambert',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','4460','EPSG','2575',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4467','RGSPM06 / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4463','EPSG','16021','EPSG','1220',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4471','RGM04 / UTM zone 38S',NULL,NULL,'EPSG','4400','EPSG','4470','EPSG','16138','EPSG','1159',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4474','Cadastre 1997 / UTM zone 38S',NULL,NULL,'EPSG','4400','EPSG','4632','EPSG','16138','EPSG','3340',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4484','Mexico ITRF92 / UTM zone 11N',NULL,NULL,'EPSG','4400','EPSG','4483','EPSG','16011','EPSG','3423',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4485','Mexico ITRF92 / UTM zone 12N',NULL,NULL,'EPSG','4400','EPSG','4483','EPSG','16012','EPSG','3424',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4486','Mexico ITRF92 / UTM zone 13N',NULL,NULL,'EPSG','4400','EPSG','4483','EPSG','16013','EPSG','3425',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4487','Mexico ITRF92 / UTM zone 14N',NULL,NULL,'EPSG','4400','EPSG','4483','EPSG','16014','EPSG','3426',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4488','Mexico ITRF92 / UTM zone 15N',NULL,NULL,'EPSG','4400','EPSG','4483','EPSG','16015','EPSG','3633',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4489','Mexico ITRF92 / UTM zone 16N',NULL,NULL,'EPSG','4400','EPSG','4483','EPSG','16016','EPSG','3635',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4491','CGCS2000 / Gauss-Kruger zone 13',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16213','EPSG','1587',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4492','CGCS2000 / Gauss-Kruger zone 14',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16214','EPSG','1588',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4493','CGCS2000 / Gauss-Kruger zone 15',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16215','EPSG','1589',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4494','CGCS2000 / Gauss-Kruger zone 16',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16216','EPSG','1590',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4495','CGCS2000 / Gauss-Kruger zone 17',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16217','EPSG','1591',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4496','CGCS2000 / Gauss-Kruger zone 18',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16218','EPSG','3944',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4497','CGCS2000 / Gauss-Kruger zone 19',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16219','EPSG','3945',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4498','CGCS2000 / Gauss-Kruger zone 20',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16220','EPSG','3946',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4499','CGCS2000 / Gauss-Kruger zone 21',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16221','EPSG','3947',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4500','CGCS2000 / Gauss-Kruger zone 22',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16222','EPSG','3948',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4501','CGCS2000 / Gauss-Kruger zone 23',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16223','EPSG','1597',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4502','CGCS2000 / Gauss-Kruger CM 75E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16313','EPSG','1587',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4503','CGCS2000 / Gauss-Kruger CM 81E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16314','EPSG','1588',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4504','CGCS2000 / Gauss-Kruger CM 87E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16315','EPSG','1589',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4505','CGCS2000 / Gauss-Kruger CM 93E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16316','EPSG','1590',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4506','CGCS2000 / Gauss-Kruger CM 99E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16317','EPSG','1591',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4507','CGCS2000 / Gauss-Kruger CM 105E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16318','EPSG','3944',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4508','CGCS2000 / Gauss-Kruger CM 111E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16319','EPSG','3945',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4509','CGCS2000 / Gauss-Kruger CM 117E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16320','EPSG','3946',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4510','CGCS2000 / Gauss-Kruger CM 123E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16321','EPSG','3947',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4511','CGCS2000 / Gauss-Kruger CM 129E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16322','EPSG','3948',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4512','CGCS2000 / Gauss-Kruger CM 135E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16323','EPSG','1597',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4513','CGCS2000 / 3-degree Gauss-Kruger zone 25',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16285','EPSG','2711',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4514','CGCS2000 / 3-degree Gauss-Kruger zone 26',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16286','EPSG','2712',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4515','CGCS2000 / 3-degree Gauss-Kruger zone 27',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16287','EPSG','2713',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4516','CGCS2000 / 3-degree Gauss-Kruger zone 28',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16288','EPSG','2714',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4517','CGCS2000 / 3-degree Gauss-Kruger zone 29',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16289','EPSG','2715',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4518','CGCS2000 / 3-degree Gauss-Kruger zone 30',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16290','EPSG','2716',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4519','CGCS2000 / 3-degree Gauss-Kruger zone 31',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16291','EPSG','2717',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4520','CGCS2000 / 3-degree Gauss-Kruger zone 32',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16292','EPSG','2718',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4521','CGCS2000 / 3-degree Gauss-Kruger zone 33',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16293','EPSG','2719',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4522','CGCS2000 / 3-degree Gauss-Kruger zone 34',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16294','EPSG','2720',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4523','CGCS2000 / 3-degree Gauss-Kruger zone 35',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16295','EPSG','2721',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4524','CGCS2000 / 3-degree Gauss-Kruger zone 36',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16296','EPSG','2722',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4525','CGCS2000 / 3-degree Gauss-Kruger zone 37',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16297','EPSG','2723',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4526','CGCS2000 / 3-degree Gauss-Kruger zone 38',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16298','EPSG','2724',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4527','CGCS2000 / 3-degree Gauss-Kruger zone 39',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16299','EPSG','2725',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4528','CGCS2000 / 3-degree Gauss-Kruger zone 40',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16070','EPSG','2726',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4529','CGCS2000 / 3-degree Gauss-Kruger zone 41',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16071','EPSG','2727',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4530','CGCS2000 / 3-degree Gauss-Kruger zone 42',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16072','EPSG','2728',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4531','CGCS2000 / 3-degree Gauss-Kruger zone 43',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16073','EPSG','2729',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4532','CGCS2000 / 3-degree Gauss-Kruger zone 44',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16074','EPSG','2730',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4533','CGCS2000 / 3-degree Gauss-Kruger zone 45',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16075','EPSG','2731',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4534','CGCS2000 / 3-degree Gauss-Kruger CM 75E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16313','EPSG','2711',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4535','CGCS2000 / 3-degree Gauss-Kruger CM 78E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16386','EPSG','2712',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4536','CGCS2000 / 3-degree Gauss-Kruger CM 81E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16314','EPSG','2713',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4537','CGCS2000 / 3-degree Gauss-Kruger CM 84E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16388','EPSG','2714',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4538','CGCS2000 / 3-degree Gauss-Kruger CM 87E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16315','EPSG','2715',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4539','CGCS2000 / 3-degree Gauss-Kruger CM 90E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16390','EPSG','2716',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4540','CGCS2000 / 3-degree Gauss-Kruger CM 93E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16316','EPSG','2717',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4541','CGCS2000 / 3-degree Gauss-Kruger CM 96E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16392','EPSG','2718',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4542','CGCS2000 / 3-degree Gauss-Kruger CM 99E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16317','EPSG','2719',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4543','CGCS2000 / 3-degree Gauss-Kruger CM 102E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16394','EPSG','2720',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4544','CGCS2000 / 3-degree Gauss-Kruger CM 105E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16318','EPSG','2721',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4545','CGCS2000 / 3-degree Gauss-Kruger CM 108E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16396','EPSG','2722',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4546','CGCS2000 / 3-degree Gauss-Kruger CM 111E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16319','EPSG','2723',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4547','CGCS2000 / 3-degree Gauss-Kruger CM 114E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16398','EPSG','2724',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4548','CGCS2000 / 3-degree Gauss-Kruger CM 117E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16320','EPSG','2725',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4549','CGCS2000 / 3-degree Gauss-Kruger CM 120E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16170','EPSG','2726',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4550','CGCS2000 / 3-degree Gauss-Kruger CM 123E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16321','EPSG','2727',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4551','CGCS2000 / 3-degree Gauss-Kruger CM 126E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16172','EPSG','2728',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4552','CGCS2000 / 3-degree Gauss-Kruger CM 129E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16322','EPSG','2729',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4553','CGCS2000 / 3-degree Gauss-Kruger CM 132E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16174','EPSG','2730',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4554','CGCS2000 / 3-degree Gauss-Kruger CM 135E',NULL,NULL,'EPSG','4530','EPSG','4490','EPSG','16323','EPSG','2731',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4559','RRAF 1991 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4558','EPSG','16020','EPSG','3825',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4568','New Beijing / Gauss-Kruger zone 13',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16213','EPSG','1587',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4569','New Beijing / Gauss-Kruger zone 14',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16214','EPSG','1588',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4570','New Beijing / Gauss-Kruger zone 15',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16215','EPSG','1589',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4571','New Beijing / Gauss-Kruger zone 16',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16216','EPSG','1590',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4572','New Beijing / Gauss-Kruger zone 17',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16217','EPSG','1591',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4573','New Beijing / Gauss-Kruger zone 18',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16218','EPSG','1592',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4574','New Beijing / Gauss-Kruger zone 19',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16219','EPSG','1593',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4575','New Beijing / Gauss-Kruger zone 20',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16220','EPSG','1594',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4576','New Beijing / Gauss-Kruger zone 21',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16221','EPSG','1595',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4577','New Beijing / Gauss-Kruger zone 22',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16222','EPSG','1596',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4578','New Beijing / Gauss-Kruger zone 23',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16223','EPSG','1597',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4579','New Beijing / Gauss-Kruger CM 75E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16313','EPSG','1587',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4580','New Beijing / Gauss-Kruger CM 81E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16314','EPSG','1588',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4581','New Beijing / Gauss-Kruger CM 87E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16315','EPSG','1589',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4582','New Beijing / Gauss-Kruger CM 93E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16316','EPSG','1590',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4583','New Beijing / Gauss-Kruger CM 99E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16317','EPSG','1591',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4584','New Beijing / Gauss-Kruger CM 105E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16318','EPSG','1592',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4585','New Beijing / Gauss-Kruger CM 111E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16319','EPSG','1593',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4586','New Beijing / Gauss-Kruger CM 117E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16320','EPSG','1594',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4587','New Beijing / Gauss-Kruger CM 123E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16321','EPSG','1595',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4588','New Beijing / Gauss-Kruger CM 129E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16322','EPSG','1596',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4589','New Beijing / Gauss-Kruger CM 135E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16323','EPSG','1597',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4647','ETRS89 / UTM zone 32N (zE-N)',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','4648','EPSG','2861',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4652','New Beijing / 3-degree Gauss-Kruger zone 25',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16285','EPSG','2711',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4653','New Beijing / 3-degree Gauss-Kruger zone 26',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16286','EPSG','2712',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4654','New Beijing / 3-degree Gauss-Kruger zone 27',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16287','EPSG','2713',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4655','New Beijing / 3-degree Gauss-Kruger zone 28',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16288','EPSG','2714',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4656','New Beijing / 3-degree Gauss-Kruger zone 29',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16289','EPSG','2715',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4766','New Beijing / 3-degree Gauss-Kruger zone 30',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16290','EPSG','2716',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4767','New Beijing / 3-degree Gauss-Kruger zone 31',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16291','EPSG','2717',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4768','New Beijing / 3-degree Gauss-Kruger zone 32',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16292','EPSG','2718',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4769','New Beijing / 3-degree Gauss-Kruger zone 33',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16293','EPSG','2719',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4770','New Beijing / 3-degree Gauss-Kruger zone 34',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16294','EPSG','2720',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4771','New Beijing / 3-degree Gauss-Kruger zone 35',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16295','EPSG','2721',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4772','New Beijing / 3-degree Gauss-Kruger zone 36',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16296','EPSG','2722',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4773','New Beijing / 3-degree Gauss-Kruger zone 37',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16297','EPSG','2723',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4774','New Beijing / 3-degree Gauss-Kruger zone 38',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16298','EPSG','2724',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4775','New Beijing / 3-degree Gauss-Kruger zone 39',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16299','EPSG','2725',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4776','New Beijing / 3-degree Gauss-Kruger zone 40',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16070','EPSG','2726',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4777','New Beijing / 3-degree Gauss-Kruger zone 41',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16071','EPSG','2727',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4778','New Beijing / 3-degree Gauss-Kruger zone 42',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16072','EPSG','2728',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4779','New Beijing / 3-degree Gauss-Kruger zone 43',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16073','EPSG','2729',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4780','New Beijing / 3-degree Gauss-Kruger zone 44',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16074','EPSG','2730',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4781','New Beijing / 3-degree Gauss-Kruger zone 45',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16075','EPSG','2731',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4782','New Beijing / 3-degree Gauss-Kruger CM 75E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16313','EPSG','2711',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4783','New Beijing / 3-degree Gauss-Kruger CM 78E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16386','EPSG','2712',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4784','New Beijing / 3-degree Gauss-Kruger CM 81E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16314','EPSG','2713',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4785','New Beijing / 3-degree Gauss-Kruger CM 84E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16388','EPSG','2714',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4786','New Beijing / 3-degree Gauss-Kruger CM 87E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16315','EPSG','2715',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4787','New Beijing / 3-degree Gauss-Kruger CM 90E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16390','EPSG','2716',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4788','New Beijing / 3-degree Gauss-Kruger CM 93E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16316','EPSG','2717',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4789','New Beijing / 3-degree Gauss-Kruger CM 96E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16392','EPSG','2718',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4790','New Beijing / 3-degree Gauss-Kruger CM 99E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16317','EPSG','2719',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4791','New Beijing / 3-degree Gauss-Kruger CM 102E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16394','EPSG','2720',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4792','New Beijing / 3-degree Gauss-Kruger CM 105E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16318','EPSG','2721',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4793','New Beijing / 3-degree Gauss-Kruger CM 108E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16396','EPSG','2722',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4794','New Beijing / 3-degree Gauss-Kruger CM 111E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16319','EPSG','2723',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4795','New Beijing / 3-degree Gauss-Kruger CM 114E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16398','EPSG','2724',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4796','New Beijing / 3-degree Gauss-Kruger CM 117E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16320','EPSG','2725',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4797','New Beijing / 3-degree Gauss-Kruger CM 120E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16170','EPSG','2726',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4798','New Beijing / 3-degree Gauss-Kruger CM 123E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16321','EPSG','2727',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4799','New Beijing / 3-degree Gauss-Kruger CM 126E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16172','EPSG','2728',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4800','New Beijing / 3-degree Gauss-Kruger CM 129E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16322','EPSG','2729',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4812','New Beijing / 3-degree Gauss-Kruger CM 132E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16174','EPSG','2730',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4822','New Beijing / 3-degree Gauss-Kruger CM 135E',NULL,NULL,'EPSG','4530','EPSG','4555','EPSG','16323','EPSG','2731',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4826','WGS 84 / Cape Verde National',NULL,NULL,'EPSG','1024','EPSG','4326','EPSG','4825','EPSG','1062',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4839','ETRS89 / LCC Germany (N-E)',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','4838','EPSG','3339',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','4855','ETRS89 / NTM zone 5',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','4845','EPSG','3636',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4856','ETRS89 / NTM zone 6',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','4846','EPSG','3639',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4857','ETRS89 / NTM zone 7',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','4847','EPSG','3647',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4858','ETRS89 / NTM zone 8',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','4848','EPSG','3648',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4859','ETRS89 / NTM zone 9',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','4849','EPSG','3649',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4860','ETRS89 / NTM zone 10',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','4850','EPSG','3650',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4861','ETRS89 / NTM zone 11',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','4851','EPSG','3651',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4862','ETRS89 / NTM zone 12',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','4852','EPSG','3653',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4863','ETRS89 / NTM zone 13',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','4853','EPSG','3654',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4864','ETRS89 / NTM zone 14',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','4854','EPSG','3655',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4865','ETRS89 / NTM zone 15',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','4841','EPSG','3656',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4866','ETRS89 / NTM zone 16',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','4842','EPSG','3657',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4867','ETRS89 / NTM zone 17',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','4843','EPSG','3658',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4868','ETRS89 / NTM zone 18',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','4844','EPSG','3660',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4869','ETRS89 / NTM zone 19',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','4881','EPSG','3661',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4870','ETRS89 / NTM zone 20',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5000','EPSG','3662',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4871','ETRS89 / NTM zone 21',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5001','EPSG','3663',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4872','ETRS89 / NTM zone 22',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5002','EPSG','3665',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4873','ETRS89 / NTM zone 23',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5003','EPSG','3667',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4874','ETRS89 / NTM zone 24',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5004','EPSG','3668',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4875','ETRS89 / NTM zone 25',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5005','EPSG','3669',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4876','ETRS89 / NTM zone 26',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5006','EPSG','3671',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4877','ETRS89 / NTM zone 27',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5007','EPSG','3672',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4878','ETRS89 / NTM zone 28',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5008','EPSG','3673',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4879','ETRS89 / NTM zone 29',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5009','EPSG','3674',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','4880','ETRS89 / NTM zone 30',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5010','EPSG','3676',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5014','PTRA08 / UTM zone 25N',NULL,NULL,'EPSG','4400','EPSG','5013','EPSG','16025','EPSG','3682',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5015','PTRA08 / UTM zone 26N',NULL,NULL,'EPSG','4400','EPSG','5013','EPSG','16026','EPSG','3677',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5016','PTRA08 / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','5013','EPSG','16028','EPSG','3678',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5017','Lisbon 1890 / Portugal Bonne New',NULL,NULL,'EPSG','6509','EPSG','4666','EPSG','5019','EPSG','1294',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5018','Lisbon / Portuguese Grid New',NULL,NULL,'EPSG','4499','EPSG','4207','EPSG','5020','EPSG','1294',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5041','WGS 84 / UPS North (E,N)',NULL,NULL,'EPSG','1026','EPSG','4326','EPSG','16061','EPSG','1996',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5042','WGS 84 / UPS South (E,N)',NULL,NULL,'EPSG','1027','EPSG','4326','EPSG','16161','EPSG','1997',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5048','ETRS89 / TM35FIN(N,E)',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','16065','EPSG','1095',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5069','NAD27 / Conus Albers',NULL,NULL,'EPSG','4499','EPSG','4267','EPSG','5068','EPSG','1323',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5070','NAD83 / Conus Albers',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','5068','EPSG','1323',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5071','NAD83(HARN) / Conus Albers',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','5068','EPSG','1323',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5072','NAD83(NSRS2007) / Conus Albers',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','5068','EPSG','1323',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5105','ETRS89 / NTM zone 5',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5135','EPSG','3636',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5106','ETRS89 / NTM zone 6',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5136','EPSG','3639',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5107','ETRS89 / NTM zone 7',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5137','EPSG','3647',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5108','ETRS89 / NTM zone 8',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5138','EPSG','3648',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5109','ETRS89 / NTM zone 9',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5139','EPSG','3649',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5110','ETRS89 / NTM zone 10',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5140','EPSG','3650',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5111','ETRS89 / NTM zone 11',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5141','EPSG','3651',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5112','ETRS89 / NTM zone 12',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5142','EPSG','3653',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5113','ETRS89 / NTM zone 13',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5143','EPSG','3654',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5114','ETRS89 / NTM zone 14',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5144','EPSG','3655',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5115','ETRS89 / NTM zone 15',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5145','EPSG','3656',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5116','ETRS89 / NTM zone 16',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5146','EPSG','3657',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5117','ETRS89 / NTM zone 17',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5147','EPSG','3658',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5118','ETRS89 / NTM zone 18',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5148','EPSG','3660',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5119','ETRS89 / NTM zone 19',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5149','EPSG','3661',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5120','ETRS89 / NTM zone 20',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5150','EPSG','3662',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5121','ETRS89 / NTM zone 21',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5151','EPSG','3663',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5122','ETRS89 / NTM zone 22',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5152','EPSG','3665',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5123','ETRS89 / NTM zone 23',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5153','EPSG','3667',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5124','ETRS89 / NTM zone 24',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5154','EPSG','3668',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5125','ETRS89 / NTM zone 25',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5155','EPSG','3669',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5126','ETRS89 / NTM zone 26',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5156','EPSG','3671',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5127','ETRS89 / NTM zone 27',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5157','EPSG','3672',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5128','ETRS89 / NTM zone 28',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5158','EPSG','3673',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5129','ETRS89 / NTM zone 29',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5159','EPSG','3674',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5130','ETRS89 / NTM zone 30',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5160','EPSG','3676',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5167','Korean 1985 / East Sea Belt',NULL,NULL,'EPSG','4530','EPSG','4162','EPSG','5049','EPSG','3720',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5168','Korean 1985 / Central Belt Jeju',NULL,NULL,'EPSG','4530','EPSG','4162','EPSG','5131','EPSG','3721',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5169','Tokyo 1892 / Korea West Belt',NULL,NULL,'EPSG','4530','EPSG','5132','EPSG','18253','EPSG','3713',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5170','Tokyo 1892 / Korea Central Belt',NULL,NULL,'EPSG','4530','EPSG','5132','EPSG','18252','EPSG','3716',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5171','Tokyo 1892 / Korea East Belt',NULL,NULL,'EPSG','4530','EPSG','5132','EPSG','18251','EPSG','3726',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5172','Tokyo 1892 / Korea East Sea Belt',NULL,NULL,'EPSG','4530','EPSG','5132','EPSG','5049','EPSG','3727',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5173','Korean 1985 / Modified West Belt',NULL,NULL,'EPSG','4530','EPSG','4162','EPSG','5161','EPSG','1498',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5174','Korean 1985 / Modified Central Belt',NULL,NULL,'EPSG','4530','EPSG','4162','EPSG','5162','EPSG','3730',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5175','Korean 1985 / Modified Central Belt Jeju',NULL,NULL,'EPSG','4530','EPSG','4162','EPSG','5163','EPSG','3721',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5176','Korean 1985 / Modified East Belt',NULL,NULL,'EPSG','4530','EPSG','4162','EPSG','5164','EPSG','1496',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5177','Korean 1985 / Modified East Sea Belt',NULL,NULL,'EPSG','4530','EPSG','4162','EPSG','5165','EPSG','3720',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5178','Korean 1985 / Unified CS',NULL,NULL,'EPSG','4530','EPSG','4162','EPSG','5100','EPSG','3266',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5179','Korea 2000 / Unified CS',NULL,NULL,'EPSG','4530','EPSG','4737','EPSG','5100','EPSG','1135',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5180','Korea 2000 / West Belt',NULL,NULL,'EPSG','4530','EPSG','4737','EPSG','18253','EPSG','1498',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5181','Korea 2000 / Central Belt',NULL,NULL,'EPSG','4530','EPSG','4737','EPSG','18252','EPSG','3730',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5182','Korea 2000 / Central Belt Jeju',NULL,NULL,'EPSG','4530','EPSG','4737','EPSG','5131','EPSG','3721',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5183','Korea 2000 / East Belt',NULL,NULL,'EPSG','4530','EPSG','4737','EPSG','18251','EPSG','1496',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5184','Korea 2000 / East Sea Belt',NULL,NULL,'EPSG','4530','EPSG','4737','EPSG','5049','EPSG','3720',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5185','Korea 2000 / West Belt 2010',NULL,NULL,'EPSG','4530','EPSG','4737','EPSG','5101','EPSG','1498',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5186','Korea 2000 / Central Belt 2010',NULL,NULL,'EPSG','4530','EPSG','4737','EPSG','5102','EPSG','1497',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5187','Korea 2000 / East Belt 2010',NULL,NULL,'EPSG','4530','EPSG','4737','EPSG','5103','EPSG','1496',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5188','Korea 2000 / East Sea Belt 2010',NULL,NULL,'EPSG','4530','EPSG','4737','EPSG','5104','EPSG','3720',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5221','S-JTSK (Ferro) / Krovak East North',NULL,NULL,'EPSG','4499','EPSG','4818','EPSG','5218','EPSG','1306',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5223','WGS 84 / Gabon TM',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','5222','EPSG','3249',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5224','S-JTSK/05 (Ferro) / Modified Krovak',NULL,NULL,'EPSG','6501','EPSG','5229','EPSG','5219','EPSG','1079',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5225','S-JTSK/05 (Ferro) / Modified Krovak East North',NULL,NULL,'EPSG','4499','EPSG','5229','EPSG','5220','EPSG','1079',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5234','Kandawala / Sri Lanka Grid',NULL,NULL,'EPSG','4400','EPSG','4244','EPSG','5231','EPSG','3310',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5235','SLD99 / Sri Lanka Grid 1999',NULL,NULL,'EPSG','4400','EPSG','5233','EPSG','5232','EPSG','3310',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5243','ETRS89 / LCC Germany (E-N)',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','4838','EPSG','3339',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5247','GDBD2009 / Brunei BRSO',NULL,NULL,'EPSG','4400','EPSG','5246','EPSG','19894','EPSG','1055',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5253','TUREF / TM27',NULL,NULL,'EPSG','4530','EPSG','5252','EPSG','16305','EPSG','1524',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5254','TUREF / TM30',NULL,NULL,'EPSG','4530','EPSG','5252','EPSG','16370','EPSG','1525',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5255','TUREF / TM33',NULL,NULL,'EPSG','4530','EPSG','5252','EPSG','16306','EPSG','1526',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5256','TUREF / TM36',NULL,NULL,'EPSG','4530','EPSG','5252','EPSG','16372','EPSG','1527',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5257','TUREF / TM39',NULL,NULL,'EPSG','4530','EPSG','5252','EPSG','16307','EPSG','1528',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5258','TUREF / TM42',NULL,NULL,'EPSG','4530','EPSG','5252','EPSG','16374','EPSG','1529',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5259','TUREF / TM45',NULL,NULL,'EPSG','4530','EPSG','5252','EPSG','16308','EPSG','1530',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5266','DRUKREF 03 / Bhutan National Grid',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5265','EPSG','1048',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5269','TUREF / 3-degree Gauss-Kruger zone 9',NULL,NULL,'EPSG','4530','EPSG','5252','EPSG','16269','EPSG','1524',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5270','TUREF / 3-degree Gauss-Kruger zone 10',NULL,NULL,'EPSG','4530','EPSG','5252','EPSG','16270','EPSG','1525',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5271','TUREF / 3-degree Gauss-Kruger zone 11',NULL,NULL,'EPSG','4530','EPSG','5252','EPSG','16271','EPSG','1526',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5272','TUREF / 3-degree Gauss-Kruger zone 12',NULL,NULL,'EPSG','4530','EPSG','5252','EPSG','16272','EPSG','1527',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5273','TUREF / 3-degree Gauss-Kruger zone 13',NULL,NULL,'EPSG','4530','EPSG','5252','EPSG','16273','EPSG','1528',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5274','TUREF / 3-degree Gauss-Kruger zone 14',NULL,NULL,'EPSG','4530','EPSG','5252','EPSG','16274','EPSG','1529',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5275','TUREF / 3-degree Gauss-Kruger zone 15',NULL,NULL,'EPSG','4530','EPSG','5252','EPSG','16275','EPSG','1530',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5292','DRUKREF 03 / Bumthang TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5268','EPSG','3734',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5293','DRUKREF 03 / Chhukha TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5276','EPSG','3737',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5294','DRUKREF 03 / Dagana TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5277','EPSG','3738',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5295','DRUKREF 03 / Gasa TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5278','EPSG','3740',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5296','DRUKREF 03 / Ha TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5279','EPSG','3742',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5297','DRUKREF 03 / Lhuentse TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5280','EPSG','3743',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5298','DRUKREF 03 / Mongar TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5281','EPSG','3745',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5299','DRUKREF 03 / Paro TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5282','EPSG','3746',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5300','DRUKREF 03 / Pemagatshel TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5283','EPSG','3747',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5301','DRUKREF 03 / Punakha TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5313','EPSG','3749',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5302','DRUKREF 03 / Samdrup Jongkhar TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5285','EPSG','3750',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5303','DRUKREF 03 / Samtse TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5286','EPSG','3751',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5304','DRUKREF 03 / Sarpang TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5287','EPSG','3752',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5305','DRUKREF 03 / Thimphu TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5312','EPSG','3753',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5306','DRUKREF 03 / Trashigang TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5289','EPSG','3754',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5307','DRUKREF 03 / Trongsa TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5290','EPSG','3755',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5308','DRUKREF 03 / Tsirang TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5284','EPSG','3757',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5309','DRUKREF 03 / Wangdue Phodrang TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5288','EPSG','3758',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5310','DRUKREF 03 / Yangtse TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5314','EPSG','3760',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5311','DRUKREF 03 / Zhemgang TM',NULL,NULL,'EPSG','4400','EPSG','5264','EPSG','5291','EPSG','3761',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5316','ETRS89 / Faroe TM',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','5315','EPSG','1093',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5320','NAD83 / Teranet Ontario Lambert',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','5319','EPSG','1367',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5321','NAD83(CSRS) / Teranet Ontario Lambert',NULL,NULL,'EPSG','4499','EPSG','4617','EPSG','5319','EPSG','1367',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5325','ISN2004 / Lambert 2004',NULL,NULL,'EPSG','4499','EPSG','5324','EPSG','5326','EPSG','1120',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5329','Segara (Jakarta) / NEIEZ',NULL,NULL,'EPSG','4499','EPSG','4820','EPSG','5328','EPSG','1360',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5330','Batavia (Jakarta) / NEIEZ',NULL,NULL,'EPSG','4499','EPSG','4813','EPSG','5328','EPSG','1285',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5331','Makassar (Jakarta) / NEIEZ',NULL,NULL,'EPSG','4499','EPSG','4804','EPSG','5328','EPSG','1316',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5337','Aratu / UTM zone 25S',NULL,NULL,'EPSG','4400','EPSG','4208','EPSG','16125','EPSG','3808',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5343','POSGAR 2007 / Argentina 1',NULL,NULL,'EPSG','4530','EPSG','5340','EPSG','18031','EPSG','1608',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5344','POSGAR 2007 / Argentina 2',NULL,NULL,'EPSG','4530','EPSG','5340','EPSG','18032','EPSG','1609',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5345','POSGAR 2007 / Argentina 3',NULL,NULL,'EPSG','4530','EPSG','5340','EPSG','18033','EPSG','1610',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5346','POSGAR 2007 / Argentina 4',NULL,NULL,'EPSG','4530','EPSG','5340','EPSG','18034','EPSG','1611',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5347','POSGAR 2007 / Argentina 5',NULL,NULL,'EPSG','4530','EPSG','5340','EPSG','18035','EPSG','1612',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5348','POSGAR 2007 / Argentina 6',NULL,NULL,'EPSG','4530','EPSG','5340','EPSG','18036','EPSG','1613',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5349','POSGAR 2007 / Argentina 7',NULL,NULL,'EPSG','4530','EPSG','5340','EPSG','18037','EPSG','1614',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5355','MARGEN / UTM zone 20S',NULL,NULL,'EPSG','4400','EPSG','5354','EPSG','16120','EPSG','1761',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5356','MARGEN / UTM zone 19S',NULL,NULL,'EPSG','4400','EPSG','5354','EPSG','16119','EPSG','3827',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5357','MARGEN / UTM zone 21S',NULL,NULL,'EPSG','4400','EPSG','5354','EPSG','16121','EPSG','3733',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5361','SIRGAS-Chile 2002 / UTM zone 19S',NULL,NULL,'EPSG','4400','EPSG','5360','EPSG','16119','EPSG','3811',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5362','SIRGAS-Chile 2002 / UTM zone 18S',NULL,NULL,'EPSG','4400','EPSG','5360','EPSG','16118','EPSG','3829',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5367','CR05 / CRTM05',NULL,NULL,'EPSG','4500','EPSG','5365','EPSG','5366','EPSG','3849',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5382','SIRGAS-ROU98 / UTM zone 21S',NULL,NULL,'EPSG','4400','EPSG','5381','EPSG','16121','EPSG','3826',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5383','SIRGAS-ROU98 / UTM zone 22S',NULL,NULL,'EPSG','4400','EPSG','5381','EPSG','16122','EPSG','3828',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5387','Peru96 / UTM zone 18S',NULL,NULL,'EPSG','4400','EPSG','5373','EPSG','16118','EPSG','3838',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5388','Peru96 / UTM zone 17S',NULL,NULL,'EPSG','4400','EPSG','5373','EPSG','16017','EPSG','3837',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5389','Peru96 / UTM zone 19S',NULL,NULL,'EPSG','4400','EPSG','5373','EPSG','16119','EPSG','3836',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5396','SIRGAS 2000 / UTM zone 26S',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16126','EPSG','3842',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5456','Ocotepeque 1935 / Costa Rica Norte',NULL,NULL,'EPSG','4499','EPSG','5451','EPSG','5390','EPSG','3869',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5457','Ocotepeque 1935 / Costa Rica Sur',NULL,NULL,'EPSG','4499','EPSG','5451','EPSG','5394','EPSG','3870',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5458','Ocotepeque 1935 / Guatemala Norte',NULL,NULL,'EPSG','4499','EPSG','4267','EPSG','18211','EPSG','2120',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5459','Ocotepeque 1935 / Guatemala Sur',NULL,NULL,'EPSG','4499','EPSG','5451','EPSG','18212','EPSG','2121',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5460','Ocotepeque 1935 / El Salvador Lambert',NULL,NULL,'EPSG','4499','EPSG','5451','EPSG','5399','EPSG','3243',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5461','Ocotepeque 1935 / Nicaragua Norte',NULL,NULL,'EPSG','4499','EPSG','5451','EPSG','5439','EPSG','3844',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5462','Ocotepeque 1935 / Nicaragua Sur',NULL,NULL,'EPSG','4499','EPSG','5451','EPSG','5444','EPSG','3847',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5463','SAD69 / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4618','EPSG','16017','EPSG','3830',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5466','Sibun Gorge 1922 / Colony Grid',NULL,NULL,'EPSG','4499','EPSG','5464','EPSG','5465','EPSG','3219',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5469','Panama-Colon 1911 / Panama Lambert',NULL,NULL,'EPSG','4499','EPSG','5467','EPSG','5468','EPSG','3290',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5472','Panama-Colon 1911 / Panama Polyconic',NULL,NULL,'EPSG','1028','EPSG','5467','EPSG','5471','EPSG','3290',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5479','RSRGD2000 / MSLC2000',NULL,NULL,'EPSG','4500','EPSG','4764','EPSG','5475','EPSG','3853',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5480','RSRGD2000 / BCLC2000',NULL,NULL,'EPSG','4500','EPSG','4764','EPSG','5476','EPSG','3854',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5481','RSRGD2000 / PCLC2000',NULL,NULL,'EPSG','4500','EPSG','4764','EPSG','5477','EPSG','3855',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5482','RSRGD2000 / RSPS2000',NULL,NULL,'EPSG','1044','EPSG','4764','EPSG','5478','EPSG','3856',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5490','RGAF09 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','5489','EPSG','16020','EPSG','3825',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5513','S-JTSK / Krovak',NULL,NULL,'EPSG','6501','EPSG','4156','EPSG','5509','EPSG','1306',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5514','S-JTSK / Krovak East North',NULL,NULL,'EPSG','4499','EPSG','4156','EPSG','5510','EPSG','1306',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5515','S-JTSK/05 / Modified Krovak',NULL,NULL,'EPSG','6501','EPSG','5228','EPSG','5511','EPSG','1079',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5516','S-JTSK/05 / Modified Krovak East North',NULL,NULL,'EPSG','4499','EPSG','5228','EPSG','5512','EPSG','1079',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5518','CI1971 / Chatham Islands Map Grid',NULL,NULL,'EPSG','4500','EPSG','4672','EPSG','5517','EPSG','2889',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5519','CI1979 / Chatham Islands Map Grid',NULL,NULL,'EPSG','4500','EPSG','4673','EPSG','5517','EPSG','2889',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5520','DHDN / 3-degree Gauss-Kruger zone 1',NULL,NULL,'EPSG','4530','EPSG','4314','EPSG','16261','EPSG','3892',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5523','WGS 84 / Gabon TM 2011',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','5522','EPSG','1100',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5530','SAD69(96) / Brazil Polyconic',NULL,NULL,'EPSG','4499','EPSG','5527','EPSG','19941','EPSG','1053',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5531','SAD69(96) / UTM zone 21S',NULL,NULL,'EPSG','4400','EPSG','5527','EPSG','16121','EPSG','3881',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5532','SAD69(96) / UTM zone 22S',NULL,NULL,'EPSG','4400','EPSG','4618','EPSG','16122','EPSG','3878',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5533','SAD69(96) / UTM zone 23S',NULL,NULL,'EPSG','4400','EPSG','5527','EPSG','16123','EPSG','3445',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5534','SAD69(96) / UTM zone 24S',NULL,NULL,'EPSG','4400','EPSG','5527','EPSG','16124','EPSG','3446',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5535','SAD69(96) / UTM zone 25S',NULL,NULL,'EPSG','4400','EPSG','5527','EPSG','16125','EPSG','3447',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5536','Corrego Alegre 1961 / UTM zone 21S',NULL,NULL,'EPSG','4400','EPSG','5524','EPSG','16121','EPSG','3355',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5537','Corrego Alegre 1961 / UTM zone 22S',NULL,NULL,'EPSG','4400','EPSG','5524','EPSG','16122','EPSG','3176',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5538','Corrego Alegre 1961 / UTM zone 23S',NULL,NULL,'EPSG','4400','EPSG','5524','EPSG','16123','EPSG','3177',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5539','Corrego Alegre 1961 / UTM zone 24S',NULL,NULL,'EPSG','4400','EPSG','5524','EPSG','16124','EPSG','3877',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5550','PNG94 / PNGMG94 zone 54',NULL,NULL,'EPSG','4400','EPSG','5546','EPSG','5547','EPSG','3882',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5551','PNG94 / PNGMG94 zone 55',NULL,NULL,'EPSG','4400','EPSG','5546','EPSG','5548','EPSG','3885',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5552','PNG94 / PNGMG94 zone 56',NULL,NULL,'EPSG','4400','EPSG','5546','EPSG','5549','EPSG','3888',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5559','Ocotepeque 1935 / Guatemala Norte',NULL,NULL,'EPSG','4499','EPSG','5451','EPSG','18211','EPSG','2120',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5562','UCS-2000 / Gauss-Kruger zone 4',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16204','EPSG','3895',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5563','UCS-2000 / Gauss-Kruger zone 5',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16205','EPSG','3898',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5564','UCS-2000 / Gauss-Kruger zone 6',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16206','EPSG','3903',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5565','UCS-2000 / Gauss-Kruger zone 7',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16207','EPSG','3905',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5566','UCS-2000 / Gauss-Kruger CM 21E',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16304','EPSG','3895',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5567','UCS-2000 / Gauss-Kruger CM 27E',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16305','EPSG','3898',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5568','UCS-2000 / Gauss-Kruger CM 33E',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16306','EPSG','3903',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5569','UCS-2000 / Gauss-Kruger CM 39E',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16307','EPSG','3905',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5570','UCS-2000 / 3-degree Gauss-Kruger zone 7',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16267','EPSG','3906',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5571','UCS-2000 / 3-degree Gauss-Kruger zone 8',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16268','EPSG','3907',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5572','UCS-2000 / 3-degree Gauss-Kruger zone 9',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16269','EPSG','3908',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5573','UCS-2000 / 3-degree Gauss-Kruger zone 10',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16270','EPSG','3909',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5574','UCS-2000 / 3-degree Gauss-Kruger zone 11',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16271','EPSG','3910',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5575','UCS-2000 / 3-degree Gauss-Kruger zone 12',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16272','EPSG','3912',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5576','UCS-2000 / 3-degree Gauss-Kruger zone 13',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16273','EPSG','3913',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5577','UCS-2000 / 3-degree Gauss-Kruger CM 21E',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16304','EPSG','3906',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5578','UCS-2000 / 3-degree Gauss-Kruger CM 24E',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16368','EPSG','3907',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5579','UCS-2000 / 3-degree Gauss-Kruger CM 27E',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16305','EPSG','3908',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5580','UCS-2000 / 3-degree Gauss-Kruger CM 30E',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16370','EPSG','3909',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5581','UCS-2000 / 3-degree Gauss-Kruger CM 33E',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16306','EPSG','3910',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5582','UCS-2000 / 3-degree Gauss-Kruger CM 36E',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16372','EPSG','3912',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5583','UCS-2000 / 3-degree Gauss-Kruger CM 39E',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','16307','EPSG','3913',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','5588','NAD27 / New Brunswick Stereographic (NAD27)',NULL,NULL,'EPSG','1029','EPSG','4267','EPSG','5587','EPSG','1447',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5589','Sibun Gorge 1922 / Colony Grid',NULL,NULL,'EPSG','4403','EPSG','5464','EPSG','5465','EPSG','3219',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5596','FEH2010 / Fehmarnbelt TM',NULL,NULL,'EPSG','4400','EPSG','5593','EPSG','5595','EPSG','3889',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5623','NAD27 / Michigan East',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12101','EPSG','1720',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5624','NAD27 / Michigan Old Central',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12102','EPSG','1721',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5625','NAD27 / Michigan West',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12103','EPSG','3652',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5627','ED50 / TM 6 NE',NULL,NULL,'EPSG','4400','EPSG','4230','EPSG','16406','EPSG','3897',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5629','Moznet / UTM zone 38S',NULL,NULL,'EPSG','4400','EPSG','4130','EPSG','16138','EPSG','1541',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5631','Pulkovo 1942(58) / Gauss-Kruger zone 2 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4179','EPSG','16202','EPSG','3575',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5632','PTRA08 / LCC Europe',NULL,NULL,'EPSG','4500','EPSG','5013','EPSG','19985','EPSG','3670',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5633','PTRA08 / LAEA Europe',NULL,NULL,'EPSG','4532','EPSG','5013','EPSG','19986','EPSG','3670',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5634','REGCAN95 / LCC Europe',NULL,NULL,'EPSG','4500','EPSG','4081','EPSG','19985','EPSG','3199',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5635','REGCAN95 / LAEA Europe',NULL,NULL,'EPSG','4500','EPSG','4081','EPSG','19986','EPSG','3199',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5636','TUREF / LAEA Europe',NULL,NULL,'EPSG','4532','EPSG','5252','EPSG','19986','EPSG','1237',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5637','TUREF / LCC Europe',NULL,NULL,'EPSG','4500','EPSG','5252','EPSG','19985','EPSG','1237',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5638','ISN2004 / LAEA Europe',NULL,NULL,'EPSG','4532','EPSG','5324','EPSG','19986','EPSG','1120',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5639','ISN2004 / LCC Europe',NULL,NULL,'EPSG','4500','EPSG','5324','EPSG','19985','EPSG','1120',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5641','SIRGAS 2000 / Brazil Mercator',NULL,NULL,'EPSG','4499','EPSG','4674','EPSG','5640','EPSG','3896',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5643','ED50 / SPBA LCC',NULL,NULL,'EPSG','4400','EPSG','4230','EPSG','5642','EPSG','3899',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5644','RGR92 / UTM zone 39S',NULL,NULL,'EPSG','4400','EPSG','4627','EPSG','16139','EPSG','3915',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5646','NAD83 / Vermont (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','5645','EPSG','1414',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5649','ETRS89 / UTM zone 31N (zE-N)',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','5647','EPSG','2860',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5650','ETRS89 / UTM zone 33N (zE-N)',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','5648','EPSG','2862',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5651','ETRS89 / UTM zone 31N (N-zE)',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5647','EPSG','2860',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5652','ETRS89 / UTM zone 32N (N-zE)',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','4648','EPSG','2861',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5653','ETRS89 / UTM zone 33N (N-zE)',NULL,NULL,'EPSG','4500','EPSG','4258','EPSG','5648','EPSG','2862',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5654','NAD83(HARN) / Vermont (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','5645','EPSG','1414',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5655','NAD83(NSRS2007) / Vermont (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','5645','EPSG','1414',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5659','Monte Mario / TM Emilia-Romagna',NULL,NULL,'EPSG','4499','EPSG','4265','EPSG','5658','EPSG','4035',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5663','Pulkovo 1942(58) / Gauss-Kruger zone 3 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4179','EPSG','16203','EPSG','1792',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5664','Pulkovo 1942(83) / Gauss-Kruger zone 2 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4178','EPSG','16202','EPSG','3575',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5665','Pulkovo 1942(83) / Gauss-Kruger zone 3 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4178','EPSG','16203','EPSG','3576',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5666','PD/83 / 3-degree Gauss-Kruger zone 3 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4746','EPSG','16263','EPSG','3392',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5667','PD/83 / 3-degree Gauss-Kruger zone 4 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4746','EPSG','16264','EPSG','3393',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5668','RD/83 / 3-degree Gauss-Kruger zone 4 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4745','EPSG','16264','EPSG','3395',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5669','RD/83 / 3-degree Gauss-Kruger zone 5 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4745','EPSG','16265','EPSG','3394',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5670','Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 3 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4179','EPSG','16263','EPSG','1512',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5671','Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 4 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4179','EPSG','16264','EPSG','1513',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5672','Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 5 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4179','EPSG','16265','EPSG','3580',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5673','Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 3 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4178','EPSG','16263','EPSG','1512',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5674','Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 4 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4178','EPSG','16264','EPSG','1513',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5675','Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 5 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4178','EPSG','16265','EPSG','1514',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5676','DHDN / 3-degree Gauss-Kruger zone 2 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4314','EPSG','16262','EPSG','1624',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5677','DHDN / 3-degree Gauss-Kruger zone 3 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4314','EPSG','16263','EPSG','1625',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5678','DHDN / 3-degree Gauss-Kruger zone 4 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4314','EPSG','16264','EPSG','1626',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5679','DHDN / 3-degree Gauss-Kruger zone 5 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4314','EPSG','16265','EPSG','1627',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5680','DHDN / 3-degree Gauss-Kruger zone 1 (E-N)',NULL,NULL,'EPSG','4400','EPSG','4314','EPSG','16261','EPSG','3892',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5682','DB_REF / 3-degree Gauss-Kruger zone 2 (E-N)',NULL,NULL,'EPSG','4400','EPSG','5681','EPSG','16262','EPSG','1624',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5683','DB_REF / 3-degree Gauss-Kruger zone 3 (E-N)',NULL,NULL,'EPSG','4400','EPSG','5681','EPSG','16263','EPSG','3993',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5684','DB_REF / 3-degree Gauss-Kruger zone 4 (E-N)',NULL,NULL,'EPSG','4400','EPSG','5681','EPSG','16264','EPSG','3996',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5685','DB_REF / 3-degree Gauss-Kruger zone 5 (E-N)',NULL,NULL,'EPSG','4400','EPSG','5681','EPSG','16265','EPSG','3998',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5700','NZGD2000 / UTM zone 1S',NULL,NULL,'EPSG','4400','EPSG','4167','EPSG','16101','EPSG','3992',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5819','EPSG topocentric example A',NULL,NULL,'EPSG','4461','EPSG','4979','EPSG','15594','EPSG','4393',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5820','EPSG topocentric example B',NULL,NULL,'EPSG','4461','EPSG','4978','EPSG','15595','EPSG','4393',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5825','AGD66 / ACT Standard Grid',NULL,NULL,'EPSG','4400','EPSG','4202','EPSG','5824','EPSG','2283',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5836','Yemen NGN96 / UTM zone 37N',NULL,NULL,'EPSG','4400','EPSG','4163','EPSG','16037','EPSG','4006',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5837','Yemen NGN96 / UTM zone 40N',NULL,NULL,'EPSG','4400','EPSG','4163','EPSG','16040','EPSG','4002',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5839','Peru96 / UTM zone 17S',NULL,NULL,'EPSG','4400','EPSG','5373','EPSG','16117','EPSG','3837',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5842','WGS 84 / TM 12 SE',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16612','EPSG','4025',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5844','RGRDC 2005 / Congo TM zone 30',NULL,NULL,'EPSG','4499','EPSG','4046','EPSG','17430','EPSG','4018',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5858','SAD69(96) / UTM zone 22S',NULL,NULL,'EPSG','4400','EPSG','5527','EPSG','16122','EPSG','3878',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5875','SAD69(96) / UTM zone 18S',NULL,NULL,'EPSG','4400','EPSG','5527','EPSG','16118','EPSG','4023',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5876','SAD69(96) / UTM zone 19S',NULL,NULL,'EPSG','4400','EPSG','5527','EPSG','16119','EPSG','4024',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5877','SAD69(96) / UTM zone 20S',NULL,NULL,'EPSG','4400','EPSG','5527','EPSG','16120','EPSG','4026',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5879','Cadastre 1997 / UTM zone 38S',NULL,NULL,'EPSG','4400','EPSG','4475','EPSG','16138','EPSG','3340',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5880','SIRGAS 2000 / Brazil Polyconic',NULL,NULL,'EPSG','4499','EPSG','4674','EPSG','19941','EPSG','1053',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5887','TGD2005 / Tonga Map Grid',NULL,NULL,'EPSG','4400','EPSG','5886','EPSG','5883','EPSG','1234',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5890','JAXA Snow Depth Polar Stereographic North',NULL,NULL,'EPSG','1035','EPSG','4054','EPSG','5889','EPSG','1996',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5896','VN-2000 / TM-3 zone 481',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','5892','EPSG','4193',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5897','VN-2000 / TM-3 zone 482',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','5893','EPSG','4215',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5898','VN-2000 / TM-3 zone 491',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','5894','EPSG','4217',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5899','VN-2000 / TM-3 107-45',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','5895','EPSG','4218',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5921','WGS 84 / EPSG Arctic Regional zone A1',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5906','EPSG','4019',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5922','WGS 84 / EPSG Arctic Regional zone A2',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5907','EPSG','4027',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5923','WGS 84 / EPSG Arctic Regional zone A3',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5908','EPSG','4028',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5924','WGS 84 / EPSG Arctic Regional zone A4',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5909','EPSG','4029',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5925','WGS 84 / EPSG Arctic Regional zone A5',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5910','EPSG','4031',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5926','WGS 84 / EPSG Arctic Regional zone B1',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5911','EPSG','4032',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5927','WGS 84 / EPSG Arctic Regional zone B2',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5912','EPSG','4033',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5928','WGS 84 / EPSG Arctic Regional zone B3',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5913','EPSG','4034',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5929','WGS 84 / EPSG Arctic Regional zone B4',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5914','EPSG','4037',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5930','WGS 84 / EPSG Arctic Regional zone B5',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5915','EPSG','4038',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5931','WGS 84 / EPSG Arctic Regional zone C1',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5916','EPSG','4040',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5932','WGS 84 / EPSG Arctic Regional zone C2',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5917','EPSG','4041',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5933','WGS 84 / EPSG Arctic Regional zone C3',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5918','EPSG','4042',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5934','WGS 84 / EPSG Arctic Regional zone C4',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5919','EPSG','4043',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5935','WGS 84 / EPSG Arctic Regional zone C5',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5920','EPSG','4045',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5936','WGS 84 / EPSG Alaska Polar Stereographic',NULL,NULL,'EPSG','4467','EPSG','4326','EPSG','5901','EPSG','1996',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5937','WGS 84 / EPSG Canada Polar Stereographic',NULL,NULL,'EPSG','4466','EPSG','4326','EPSG','5902','EPSG','1996',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5938','WGS 84 / EPSG Greenland Polar Stereographic',NULL,NULL,'EPSG','1036','EPSG','4326','EPSG','5903','EPSG','1996',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5939','WGS 84 / EPSG Norway Polar Stereographic',NULL,NULL,'EPSG','1037','EPSG','4326','EPSG','5904','EPSG','1996',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','5940','WGS 84 / EPSG Russia Polar Stereographic',NULL,NULL,'EPSG','1038','EPSG','4326','EPSG','5905','EPSG','1996',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6050','GR96 / EPSG Arctic zone 1-25',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','5979','EPSG','4048',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6051','GR96 / EPSG Arctic zone 2-18',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','5987','EPSG','4039',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6052','GR96 / EPSG Arctic zone 2-20',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','5988','EPSG','4046',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6053','GR96 / EPSG Arctic zone 3-29',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','6002','EPSG','4073',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6054','GR96 / EPSG Arctic zone 3-31',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','6003','EPSG','4074',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6055','GR96 / EPSG Arctic zone 3-33',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','6004','EPSG','4075',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6056','GR96 / EPSG Arctic zone 4-20',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','6009','EPSG','4080',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6057','GR96 / EPSG Arctic zone 4-22',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','6010','EPSG','4081',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6058','GR96 / EPSG Arctic zone 4-24',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','6011','EPSG','4082',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6059','GR96 / EPSG Arctic zone 5-41',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','6035','EPSG','4106',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6060','GR96 / EPSG Arctic zone 5-43',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','6036','EPSG','4107',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6061','GR96 / EPSG Arctic zone 5-45',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','6037','EPSG','4108',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6062','GR96 / EPSG Arctic zone 6-26',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','6045','EPSG','4116',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6063','GR96 / EPSG Arctic zone 6-28',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','6046','EPSG','4117',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6064','GR96 / EPSG Arctic zone 6-30',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','6047','EPSG','4118',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6065','GR96 / EPSG Arctic zone 7-11',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','6048','EPSG','4119',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6066','GR96 / EPSG Arctic zone 7-13',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','6049','EPSG','4120',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6067','GR96 / EPSG Arctic zone 8-20',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','5943','EPSG','4123',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6068','GR96 / EPSG Arctic zone 8-22',NULL,NULL,'EPSG','4400','EPSG','4747','EPSG','5944','EPSG','4124',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6069','ETRS89 / EPSG Arctic zone 2-22',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','5989','EPSG','4053',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6070','ETRS89 / EPSG Arctic zone 3-11',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','5993','EPSG','4058',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6071','ETRS89 / EPSG Arctic zone 4-26',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','6012','EPSG','4083',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6072','ETRS89 / EPSG Arctic zone 4-28',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','6013','EPSG','4084',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6073','ETRS89 / EPSG Arctic zone 5-11',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','6020','EPSG','4091',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6074','ETRS89 / EPSG Arctic zone 5-13',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','6021','EPSG','4092',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6075','WGS 84 / EPSG Arctic zone 2-24',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5990','EPSG','4054',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6076','WGS 84 / EPSG Arctic zone 2-26',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5991','EPSG','4055',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6077','WGS 84 / EPSG Arctic zone 3-13',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5994','EPSG','4059',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6078','WGS 84 / EPSG Arctic zone 3-15',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5995','EPSG','4060',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6079','WGS 84 / EPSG Arctic zone 3-17',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5996','EPSG','4061',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6080','WGS 84 / EPSG Arctic zone 3-19',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5997','EPSG','4062',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6081','WGS 84 / EPSG Arctic zone 4-30',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','6014','EPSG','4085',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6082','WGS 84 / EPSG Arctic zone 4-32',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','6015','EPSG','4086',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6083','WGS 84 / EPSG Arctic zone 4-34',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','6016','EPSG','4087',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6084','WGS 84 / EPSG Arctic zone 4-36',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','6017','EPSG','4088',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6085','WGS 84 / EPSG Arctic zone 4-38',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','6018','EPSG','4089',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6086','WGS 84 / EPSG Arctic zone 4-40',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','6019','EPSG','4090',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6087','WGS 84 / EPSG Arctic zone 5-15',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','6022','EPSG','4093',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6088','WGS 84 / EPSG Arctic zone 5-17',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','6023','EPSG','4094',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6089','WGS 84 / EPSG Arctic zone 5-19',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','6024','EPSG','4095',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6090','WGS 84 / EPSG Arctic zone 5-21',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','6025','EPSG','4096',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6091','WGS 84 / EPSG Arctic zone 5-23',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','6026','EPSG','4097',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6092','WGS 84 / EPSG Arctic zone 5-25',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','6027','EPSG','4098',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6093','WGS 84 / EPSG Arctic zone 5-27',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','6028','EPSG','4099',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6094','NAD83(NSRS2007) / EPSG Arctic zone 5-29',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','6029','EPSG','4100',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6095','NAD83(NSRS2007) / EPSG Arctic zone 5-31',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','6030','EPSG','4101',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6096','NAD83(NSRS2007) / EPSG Arctic zone 6-14',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','6039','EPSG','4110',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6097','NAD83(NSRS2007) / EPSG Arctic zone 6-16',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','6040','EPSG','4111',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6098','NAD83(CSRS) / EPSG Arctic zone 1-23',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','5978','EPSG','4047',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6099','NAD83(CSRS) / EPSG Arctic zone 2-14',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','5985','EPSG','4030',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6100','NAD83(CSRS) / EPSG Arctic zone 2-16',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','5986','EPSG','4036',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6101','NAD83(CSRS) / EPSG Arctic zone 3-25',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','6000','EPSG','4065',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6102','NAD83(CSRS) / EPSG Arctic zone 3-27',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','6001','EPSG','4070',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6103','NAD83(CSRS) / EPSG Arctic zone 3-29',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','6002','EPSG','4072',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6104','NAD83(CSRS) / EPSG Arctic zone 4-14',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','6006','EPSG','4077',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6105','NAD83(CSRS) / EPSG Arctic zone 4-16',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','6007','EPSG','4078',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6106','NAD83(CSRS) / EPSG Arctic zone 4-18',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','6008','EPSG','4079',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6107','NAD83(CSRS) / EPSG Arctic zone 5-33',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','6031','EPSG','4102',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6108','NAD83(CSRS) / EPSG Arctic zone 5-35',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','6032','EPSG','4103',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6109','NAD83(CSRS) / EPSG Arctic zone 5-37',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','6033','EPSG','4104',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6110','NAD83(CSRS) / EPSG Arctic zone 5-39',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','6034','EPSG','4105',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6111','NAD83(CSRS) / EPSG Arctic zone 6-18',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','6041','EPSG','4112',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6112','NAD83(CSRS) / EPSG Arctic zone 6-20',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','6042','EPSG','4113',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6113','NAD83(CSRS) / EPSG Arctic zone 6-22',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','6043','EPSG','4114',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6114','NAD83(CSRS) / EPSG Arctic zone 6-24',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','6044','EPSG','4115',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6115','WGS 84 / EPSG Arctic zone 1-27',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5980','EPSG','4049',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6116','WGS 84 / EPSG Arctic zone 1-29',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5981','EPSG','4050',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6117','WGS 84 / EPSG Arctic zone 1-31',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5982','EPSG','4051',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6118','WGS 84 / EPSG Arctic zone 1-21',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5977','EPSG','4044',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6119','WGS 84 / EPSG Arctic zone 2-28',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5992','EPSG','4056',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6120','WGS 84 / EPSG Arctic zone 2-10',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5983','EPSG','4057',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6121','WGS 84 / EPSG Arctic zone 2-12',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5984','EPSG','4052',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6122','WGS 84 / EPSG Arctic zone 3-21',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5998','EPSG','4063',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6123','WGS 84 / EPSG Arctic zone 3-23',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','5999','EPSG','4064',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6124','WGS 84 / EPSG Arctic zone 4-12',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','6005','EPSG','4076',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6125','ETRS89 / EPSG Arctic zone 5-47',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','6038','EPSG','4109',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6128','Grand Cayman National Grid 1959',NULL,NULL,'EPSG','1039','EPSG','4723','EPSG','6127','EPSG','3185',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6129','Sister Islands National Grid 1961',NULL,NULL,'EPSG','1039','EPSG','4726','EPSG','6127','EPSG','3186',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6141','Cayman Islands National Grid 2011',NULL,NULL,'EPSG','1039','EPSG','6135','EPSG','6126','EPSG','1063',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','6200','NAD27 / Michigan North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','6197','EPSG','1723',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','6201','NAD27 / Michigan Central',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','6198','EPSG','1724',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6202','NAD27 / Michigan South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','6199','EPSG','1725',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6204','Macedonia State Coordinate System',NULL,NULL,'EPSG','4498','EPSG','3906','EPSG','6203','EPSG','1148',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6210','SIRGAS 2000 / UTM zone 23N',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16023','EPSG','4129',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6211','SIRGAS 2000 / UTM zone 24N',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16024','EPSG','4133',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6244','MAGNA-SIRGAS / Arauca urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6212','EPSG','4122',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6245','MAGNA-SIRGAS / Armenia urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6213','EPSG','4132',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6246','MAGNA-SIRGAS / Barranquilla urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6214','EPSG','4134',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6247','MAGNA-SIRGAS / Bogota urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6215','EPSG','4135',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6248','MAGNA-SIRGAS / Bucaramanga urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6216','EPSG','4136',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6249','MAGNA-SIRGAS / Cali urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6217','EPSG','4137',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6250','MAGNA-SIRGAS / Cartagena urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6218','EPSG','4138',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6251','MAGNA-SIRGAS / Cucuta urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6219','EPSG','4139',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6252','MAGNA-SIRGAS / Florencia urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6220','EPSG','4140',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6253','MAGNA-SIRGAS / Ibague urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6221','EPSG','4141',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6254','MAGNA-SIRGAS / Inirida urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6222','EPSG','4142',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6255','MAGNA-SIRGAS / Leticia urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6223','EPSG','4143',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6256','MAGNA-SIRGAS / Manizales urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6224','EPSG','4144',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6257','MAGNA-SIRGAS / Medellin urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6225','EPSG','4145',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6258','MAGNA-SIRGAS / Mitu urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6226','EPSG','4146',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6259','MAGNA-SIRGAS / Mocoa urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6227','EPSG','4147',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6260','MAGNA-SIRGAS / Monteria urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6228','EPSG','4148',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6261','MAGNA-SIRGAS / Neiva urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6229','EPSG','4149',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6262','MAGNA-SIRGAS / Pasto urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6230','EPSG','4150',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6263','MAGNA-SIRGAS / Pereira urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6231','EPSG','4151',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6264','MAGNA-SIRGAS / Popayan urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6232','EPSG','4152',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6265','MAGNA-SIRGAS / Puerto Carreno urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6233','EPSG','4153',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6266','MAGNA-SIRGAS / Quibdo urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6234','EPSG','4154',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6267','MAGNA-SIRGAS / Riohacha urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6235','EPSG','4155',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6268','MAGNA-SIRGAS / San Andres urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6236','EPSG','4156',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6269','MAGNA-SIRGAS / San Jose del Guaviare urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6237','EPSG','4157',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6270','MAGNA-SIRGAS / Santa Marta urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6238','EPSG','4128',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6271','MAGNA-SIRGAS / Sucre urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6239','EPSG','4130',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6272','MAGNA-SIRGAS / Tunja urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6240','EPSG','4131',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6273','MAGNA-SIRGAS / Valledupar urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6241','EPSG','4158',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6274','MAGNA-SIRGAS / Villavicencio urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6242','EPSG','4159',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6275','MAGNA-SIRGAS / Yopal urban grid',NULL,NULL,'EPSG','4500','EPSG','4686','EPSG','6243','EPSG','4160',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6307','NAD83(CORS96) / Puerto Rico and Virgin Is.',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','15230','EPSG','3634',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6312','CGRS93 / Cyprus Local Transverse Mercator',NULL,NULL,'EPSG','4400','EPSG','6311','EPSG','6308','EPSG','3236',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6316','MGI 1901 / Balkans zone 7',NULL,NULL,'EPSG','4498','EPSG','3906','EPSG','18277','EPSG','1711',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6328','NAD83(2011) / UTM zone 59N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16059','EPSG','3372',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6329','NAD83(2011) / UTM zone 60N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16060','EPSG','3373',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6330','NAD83(2011) / UTM zone 1N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16001','EPSG','3374',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6331','NAD83(2011) / UTM zone 2N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16002','EPSG','3375',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6332','NAD83(2011) / UTM zone 3N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16003','EPSG','2133',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6333','NAD83(2011) / UTM zone 4N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16004','EPSG','2134',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6334','NAD83(2011) / UTM zone 5N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16005','EPSG','2135',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6335','NAD83(2011) / UTM zone 6N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16006','EPSG','2136',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6336','NAD83(2011) / UTM zone 7N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16007','EPSG','3494',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6337','NAD83(2011) / UTM zone 8N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16008','EPSG','3495',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6338','NAD83(2011) / UTM zone 9N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16009','EPSG','3496',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6339','NAD83(2011) / UTM zone 10N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16010','EPSG','3497',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6340','NAD83(2011) / UTM zone 11N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16011','EPSG','3498',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6341','NAD83(2011) / UTM zone 12N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16012','EPSG','3499',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6342','NAD83(2011) / UTM zone 13N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16013','EPSG','3500',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6343','NAD83(2011) / UTM zone 14N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16014','EPSG','3501',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6344','NAD83(2011) / UTM zone 15N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16015','EPSG','3502',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6345','NAD83(2011) / UTM zone 16N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16016','EPSG','3503',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6346','NAD83(2011) / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16017','EPSG','3504',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6347','NAD83(2011) / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16018','EPSG','3505',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6348','NAD83(2011) / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16019','EPSG','3506',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6350','NAD83(2011) / Conus Albers',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','5068','EPSG','1323',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6351','NAD83(2011) / EPSG Arctic zone 5-29',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','6029','EPSG','4100',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6352','NAD83(2011) / EPSG Arctic zone 5-31',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','6030','EPSG','4101',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6353','NAD83(2011) / EPSG Arctic zone 6-14',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','6039','EPSG','4110',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6354','NAD83(2011) / EPSG Arctic zone 6-16',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','6040','EPSG','4111',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6355','NAD83(2011) / Alabama East',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10131','EPSG','2154',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6356','NAD83(2011) / Alabama West',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10132','EPSG','2155',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6362','Mexico ITRF92 / LCC',NULL,NULL,'EPSG','4500','EPSG','4483','EPSG','6361','EPSG','1160',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6366','Mexico ITRF2008 / UTM zone 11N',NULL,NULL,'EPSG','4400','EPSG','6365','EPSG','16011','EPSG','3423',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6367','Mexico ITRF2008 / UTM zone 12N',NULL,NULL,'EPSG','4400','EPSG','6365','EPSG','16012','EPSG','3424',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6368','Mexico ITRF2008 / UTM zone 13N',NULL,NULL,'EPSG','4400','EPSG','6365','EPSG','16013','EPSG','3425',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6369','Mexico ITRF2008 / UTM zone 14N',NULL,NULL,'EPSG','4400','EPSG','6365','EPSG','16014','EPSG','3426',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6370','Mexico ITRF2008 / UTM zone 15N',NULL,NULL,'EPSG','4400','EPSG','6365','EPSG','16015','EPSG','3633',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6371','Mexico ITRF2008 / UTM zone 16N',NULL,NULL,'EPSG','4400','EPSG','6365','EPSG','16016','EPSG','3635',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6372','Mexico ITRF2008 / LCC',NULL,NULL,'EPSG','4500','EPSG','6365','EPSG','6361','EPSG','1160',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6381','UCS-2000 / Ukraine TM zone 7',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','6374','EPSG','3906',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6382','UCS-2000 / Ukraine TM zone 8',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','6375','EPSG','3907',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6383','UCS-2000 / Ukraine TM zone 9',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','6376','EPSG','3908',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6384','UCS-2000 / Ukraine TM zone 10',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','6377','EPSG','3909',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6385','UCS-2000 / Ukraine TM zone 11',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','6378','EPSG','3910',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6386','UCS-2000 / Ukraine TM zone 12',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','6379','EPSG','3912',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6387','UCS-2000 / Ukraine TM zone 13',NULL,NULL,'EPSG','4530','EPSG','5561','EPSG','6380','EPSG','3913',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6391','Cayman Islands National Grid 2011',NULL,NULL,'EPSG','1039','EPSG','6135','EPSG','6390','EPSG','1063',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6393','NAD83(2011) / Alaska Albers',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','15021','EPSG','1330',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6394','NAD83(2011) / Alaska zone 1',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','15031','EPSG','2156',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6395','NAD83(2011) / Alaska zone 2',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','15032','EPSG','2158',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6396','NAD83(2011) / Alaska zone 3',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','15033','EPSG','2159',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6397','NAD83(2011) / Alaska zone 4',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','15034','EPSG','2160',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6398','NAD83(2011) / Alaska zone 5',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','15035','EPSG','2161',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6399','NAD83(2011) / Alaska zone 6',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','15036','EPSG','2162',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6400','NAD83(2011) / Alaska zone 7',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','15037','EPSG','2163',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6401','NAD83(2011) / Alaska zone 8',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','15038','EPSG','2164',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6402','NAD83(2011) / Alaska zone 9',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','15039','EPSG','2165',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6403','NAD83(2011) / Alaska zone 10',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','15040','EPSG','2157',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6404','NAD83(2011) / Arizona Central',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10232','EPSG','2166',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6405','NAD83(2011) / Arizona Central (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','15305','EPSG','2166',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6406','NAD83(2011) / Arizona East',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10231','EPSG','2167',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6407','NAD83(2011) / Arizona East (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','15304','EPSG','2167',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6408','NAD83(2011) / Arizona West',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10233','EPSG','2168',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6409','NAD83(2011) / Arizona West (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','15306','EPSG','2168',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6410','NAD83(2011) / Arkansas North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10331','EPSG','2169',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6411','NAD83(2011) / Arkansas North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15385','EPSG','2169',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6412','NAD83(2011) / Arkansas South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10332','EPSG','2170',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6413','NAD83(2011) / Arkansas South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15386','EPSG','2170',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6414','NAD83(2011) / California Albers',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10420','EPSG','1375',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6415','NAD83(2011) / California zone 1',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10431','EPSG','2175',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6416','NAD83(2011) / California zone 1 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15307','EPSG','2175',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6417','NAD83(2011) / California zone 2',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10432','EPSG','2176',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6418','NAD83(2011) / California zone 2 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15308','EPSG','2176',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6419','NAD83(2011) / California zone 3',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10433','EPSG','2177',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6420','NAD83(2011) / California zone 3 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15309','EPSG','2177',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6421','NAD83(2011) / California zone 4',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10434','EPSG','2178',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6422','NAD83(2011) / California zone 4 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15310','EPSG','2178',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6423','NAD83(2011) / California zone 5',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10435','EPSG','2182',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6424','NAD83(2011) / California zone 5 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15311','EPSG','2182',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6425','NAD83(2011) / California zone 6',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10436','EPSG','2180',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6426','NAD83(2011) / California zone 6 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15312','EPSG','2180',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6427','NAD83(2011) / Colorado Central',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10532','EPSG','2183',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6428','NAD83(2011) / Colorado Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15314','EPSG','2183',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6429','NAD83(2011) / Colorado North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10531','EPSG','2184',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6430','NAD83(2011) / Colorado North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15313','EPSG','2184',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6431','NAD83(2011) / Colorado South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10533','EPSG','2185',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6432','NAD83(2011) / Colorado South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15315','EPSG','2185',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6433','NAD83(2011) / Connecticut',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10630','EPSG','1377',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6434','NAD83(2011) / Connecticut (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15316','EPSG','1377',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6435','NAD83(2011) / Delaware',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10730','EPSG','1378',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6436','NAD83(2011) / Delaware (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15317','EPSG','1378',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6437','NAD83(2011) / Florida East',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10931','EPSG','2186',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6438','NAD83(2011) / Florida East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15318','EPSG','2186',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6439','NAD83(2011) / Florida GDL Albers',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10934','EPSG','1379',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6440','NAD83(2011) / Florida North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10933','EPSG','2187',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6441','NAD83(2011) / Florida North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15320','EPSG','2187',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6442','NAD83(2011) / Florida West',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','10932','EPSG','2188',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6443','NAD83(2011) / Florida West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15319','EPSG','2188',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6444','NAD83(2011) / Georgia East',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11031','EPSG','2189',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6445','NAD83(2011) / Georgia East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15321','EPSG','2189',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6446','NAD83(2011) / Georgia West',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11032','EPSG','2190',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6447','NAD83(2011) / Georgia West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15322','EPSG','2190',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6448','NAD83(2011) / Idaho Central',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11132','EPSG','2191',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6449','NAD83(2011) / Idaho Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15324','EPSG','2191',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6450','NAD83(2011) / Idaho East',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11131','EPSG','2192',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6451','NAD83(2011) / Idaho East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15323','EPSG','2192',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6452','NAD83(2011) / Idaho West',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11133','EPSG','2193',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6453','NAD83(2011) / Idaho West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15325','EPSG','2193',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6454','NAD83(2011) / Illinois East',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11231','EPSG','2194',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6455','NAD83(2011) / Illinois East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15387','EPSG','2194',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6456','NAD83(2011) / Illinois West',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11232','EPSG','2195',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6457','NAD83(2011) / Illinois West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15388','EPSG','2195',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6458','NAD83(2011) / Indiana East',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11331','EPSG','2196',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6459','NAD83(2011) / Indiana East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15372','EPSG','2196',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6460','NAD83(2011) / Indiana West',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11332','EPSG','2197',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6461','NAD83(2011) / Indiana West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15373','EPSG','2197',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6462','NAD83(2011) / Iowa North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11431','EPSG','2198',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6463','NAD83(2011) / Iowa North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15377','EPSG','2198',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6464','NAD83(2011) / Iowa South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11432','EPSG','2199',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6465','NAD83(2011) / Iowa South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15378','EPSG','2199',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6466','NAD83(2011) / Kansas North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11531','EPSG','2200',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6467','NAD83(2011) / Kansas North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15379','EPSG','2200',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6468','NAD83(2011) / Kansas South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11532','EPSG','2201',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6469','NAD83(2011) / Kansas South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15380','EPSG','2201',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6470','NAD83(2011) / Kentucky North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','15303','EPSG','2202',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6471','NAD83(2011) / Kentucky North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15328','EPSG','2202',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6472','NAD83(2011) / Kentucky Single Zone',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11630','EPSG','1386',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6473','NAD83(2011) / Kentucky Single Zone (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15375','EPSG','1386',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6474','NAD83(2011) / Kentucky South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11632','EPSG','2203',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6475','NAD83(2011) / Kentucky South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15329','EPSG','2203',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6476','NAD83(2011) / Louisiana North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11731','EPSG','2204',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6477','NAD83(2011) / Louisiana North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15391','EPSG','2204',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6478','NAD83(2011) / Louisiana South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11732','EPSG','2529',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6479','NAD83(2011) / Louisiana South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15392','EPSG','2529',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6480','NAD83(2011) / Maine CS2000 Central',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11854','EPSG','2959',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6481','NAD83(2011) / Maine CS2000 East',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11851','EPSG','2960',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6482','NAD83(2011) / Maine CS2000 West',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11853','EPSG','2958',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6483','NAD83(2011) / Maine East',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11831','EPSG','2206',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6484','NAD83(2011) / Maine East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','11833','EPSG','2206',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6485','NAD83(2011) / Maine West',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11832','EPSG','2207',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6486','NAD83(2011) / Maine West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','11834','EPSG','2207',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6487','NAD83(2011) / Maryland',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','11930','EPSG','1389',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6488','NAD83(2011) / Maryland (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15330','EPSG','1389',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6489','NAD83(2011) / Massachusetts Island',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12032','EPSG','2208',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6490','NAD83(2011) / Massachusetts Island (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15332','EPSG','2208',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6491','NAD83(2011) / Massachusetts Mainland',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12031','EPSG','2209',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6492','NAD83(2011) / Massachusetts Mainland (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15331','EPSG','2209',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6493','NAD83(2011) / Michigan Central',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12142','EPSG','1724',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6494','NAD83(2011) / Michigan Central (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','15334','EPSG','1724',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6495','NAD83(2011) / Michigan North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12141','EPSG','1723',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6496','NAD83(2011) / Michigan North (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','15333','EPSG','1723',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6497','NAD83(2011) / Michigan Oblique Mercator',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12150','EPSG','1391',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6498','NAD83(2011) / Michigan South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12143','EPSG','1725',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6499','NAD83(2011) / Michigan South (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','15335','EPSG','1725',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6500','NAD83(2011) / Minnesota Central',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12232','EPSG','2213',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6501','NAD83(2011) / Minnesota Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','12235','EPSG','2213',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6502','NAD83(2011) / Minnesota North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12231','EPSG','2214',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6503','NAD83(2011) / Minnesota North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','12234','EPSG','2214',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6504','NAD83(2011) / Minnesota South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12233','EPSG','2215',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6505','NAD83(2011) / Minnesota South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','12236','EPSG','2215',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6506','NAD83(2011) / Mississippi East',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12331','EPSG','2216',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6507','NAD83(2011) / Mississippi East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15336','EPSG','2216',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6508','NAD83(2011) / Mississippi TM',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','3813','EPSG','1393',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6509','NAD83(2011) / Mississippi West',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12332','EPSG','2217',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6510','NAD83(2011) / Mississippi West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15337','EPSG','2217',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6511','NAD83(2011) / Missouri Central',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12432','EPSG','2218',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6512','NAD83(2011) / Missouri East',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12431','EPSG','2219',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6513','NAD83(2011) / Missouri West',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12433','EPSG','2220',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6514','NAD83(2011) / Montana',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12530','EPSG','1395',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6515','NAD83(2011) / Montana (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','15338','EPSG','1395',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6516','NAD83(2011) / Nebraska',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12630','EPSG','1396',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6517','NAD83(2011) / Nebraska (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15396','EPSG','1396',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','6518','NAD83(2011) / Nevada Central',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12732','EPSG','2223',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6519','NAD83(2011) / Nevada Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15382','EPSG','2223',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6520','NAD83(2011) / Nevada East',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12731','EPSG','2224',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6521','NAD83(2011) / Nevada East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15381','EPSG','2224',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6522','NAD83(2011) / Nevada West',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12733','EPSG','2225',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6523','NAD83(2011) / Nevada West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15383','EPSG','2225',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6524','NAD83(2011) / New Hampshire',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12830','EPSG','1398',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6525','NAD83(2011) / New Hampshire (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15389','EPSG','1398',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6526','NAD83(2011) / New Jersey',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','12930','EPSG','1399',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6527','NAD83(2011) / New Jersey (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15384','EPSG','1399',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6528','NAD83(2011) / New Mexico Central',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13032','EPSG','2231',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6529','NAD83(2011) / New Mexico Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15340','EPSG','2231',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6530','NAD83(2011) / New Mexico East',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13031','EPSG','2228',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6531','NAD83(2011) / New Mexico East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15339','EPSG','2228',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6532','NAD83(2011) / New Mexico West',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13033','EPSG','2232',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6533','NAD83(2011) / New Mexico West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15341','EPSG','2232',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6534','NAD83(2011) / New York Central',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13132','EPSG','2233',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6535','NAD83(2011) / New York Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15343','EPSG','2233',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6536','NAD83(2011) / New York East',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13131','EPSG','2234',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6537','NAD83(2011) / New York East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15342','EPSG','2234',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6538','NAD83(2011) / New York Long Island',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13134','EPSG','2235',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6539','NAD83(2011) / New York Long Island (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15345','EPSG','2235',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6540','NAD83(2011) / New York West',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13133','EPSG','2236',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6541','NAD83(2011) / New York West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15344','EPSG','2236',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6542','NAD83(2011) / North Carolina',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13230','EPSG','1402',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6543','NAD83(2011) / North Carolina (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15346','EPSG','1402',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6544','NAD83(2011) / North Dakota North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13331','EPSG','2237',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6545','NAD83(2011) / North Dakota North (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','15347','EPSG','2237',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6546','NAD83(2011) / North Dakota South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13332','EPSG','2238',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6547','NAD83(2011) / North Dakota South (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','15348','EPSG','2238',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6548','NAD83(2011) / Ohio North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13431','EPSG','2239',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6549','NAD83(2011) / Ohio North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','13433','EPSG','2239',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6550','NAD83(2011) / Ohio South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13432','EPSG','2240',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6551','NAD83(2011) / Ohio South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','13434','EPSG','2240',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6552','NAD83(2011) / Oklahoma North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13531','EPSG','2241',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6553','NAD83(2011) / Oklahoma North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15349','EPSG','2241',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6554','NAD83(2011) / Oklahoma South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13532','EPSG','2242',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6555','NAD83(2011) / Oklahoma South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15350','EPSG','2242',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6556','NAD83(2011) / Oregon LCC (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13633','EPSG','1406',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6557','NAD83(2011) / Oregon GIC Lambert (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','15374','EPSG','1406',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6558','NAD83(2011) / Oregon North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13631','EPSG','2243',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6559','NAD83(2011) / Oregon North (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','15351','EPSG','2243',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6560','NAD83(2011) / Oregon South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13632','EPSG','2244',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6561','NAD83(2011) / Oregon South (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','15352','EPSG','2244',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6562','NAD83(2011) / Pennsylvania North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13731','EPSG','2245',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6563','NAD83(2011) / Pennsylvania North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15353','EPSG','2245',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6564','NAD83(2011) / Pennsylvania South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13732','EPSG','2246',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6565','NAD83(2011) / Pennsylvania South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15354','EPSG','2246',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6566','NAD83(2011) / Puerto Rico and Virgin Is.',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','15230','EPSG','3634',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6567','NAD83(2011) / Rhode Island',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13830','EPSG','1408',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6568','NAD83(2011) / Rhode Island (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15390','EPSG','1408',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6569','NAD83(2011) / South Carolina',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','13930','EPSG','1409',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6570','NAD83(2011) / South Carolina (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','15355','EPSG','1409',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6571','NAD83(2011) / South Dakota North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14031','EPSG','2249',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6572','NAD83(2011) / South Dakota North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15394','EPSG','2249',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6573','NAD83(2011) / South Dakota South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14032','EPSG','2250',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6574','NAD83(2011) / South Dakota South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15395','EPSG','2250',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6575','NAD83(2011) / Tennessee',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14130','EPSG','1411',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6576','NAD83(2011) / Tennessee (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15356','EPSG','1411',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6577','NAD83(2011) / Texas Central',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14233','EPSG','2252',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6578','NAD83(2011) / Texas Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15359','EPSG','2252',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6579','NAD83(2011) / Texas Centric Albers Equal Area',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14254','EPSG','1412',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6580','NAD83(2011) / Texas Centric Lambert Conformal',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14253','EPSG','1412',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6581','NAD83(2011) / Texas North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14231','EPSG','2253',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6582','NAD83(2011) / Texas North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15357','EPSG','2253',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6583','NAD83(2011) / Texas North Central',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14232','EPSG','2254',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6584','NAD83(2011) / Texas North Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15358','EPSG','2254',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6585','NAD83(2011) / Texas South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14235','EPSG','2528',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6586','NAD83(2011) / Texas South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15361','EPSG','2528',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6587','NAD83(2011) / Texas South Central',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14234','EPSG','2527',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6588','NAD83(2011) / Texas South Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15360','EPSG','2527',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6589','NAD83(2011) / Vermont',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14430','EPSG','1414',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6590','NAD83(2011) / Vermont (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','5645','EPSG','1414',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6591','NAD83(2011) / Virginia Lambert',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','3967','EPSG','1415',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6592','NAD83(2011) / Virginia North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14531','EPSG','2260',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6593','NAD83(2011) / Virginia North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15365','EPSG','2260',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6594','NAD83(2011) / Virginia South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14532','EPSG','2261',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6595','NAD83(2011) / Virginia South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15366','EPSG','2261',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6596','NAD83(2011) / Washington North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14631','EPSG','2273',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6597','NAD83(2011) / Washington North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15367','EPSG','2273',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6598','NAD83(2011) / Washington South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14632','EPSG','2274',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6599','NAD83(2011) / Washington South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15368','EPSG','2274',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6600','NAD83(2011) / West Virginia North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14731','EPSG','2264',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6601','NAD83(2011) / West Virginia North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','14735','EPSG','2264',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6602','NAD83(2011) / West Virginia South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14732','EPSG','2265',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6603','NAD83(2011) / West Virginia South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','14736','EPSG','2265',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6604','NAD83(2011) / Wisconsin Central',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14832','EPSG','2266',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','6605','NAD83(2011) / Wisconsin Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15370','EPSG','2266',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6606','NAD83(2011) / Wisconsin North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14831','EPSG','2267',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6607','NAD83(2011) / Wisconsin North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15369','EPSG','2267',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6608','NAD83(2011) / Wisconsin South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14833','EPSG','2268',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6609','NAD83(2011) / Wisconsin South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15371','EPSG','2268',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6610','NAD83(2011) / Wisconsin Transverse Mercator',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14841','EPSG','1418',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6611','NAD83(2011) / Wyoming East',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14931','EPSG','2269',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6612','NAD83(2011) / Wyoming East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','14935','EPSG','2269',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6613','NAD83(2011) / Wyoming East Central',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14932','EPSG','2270',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6614','NAD83(2011) / Wyoming East Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','14936','EPSG','2270',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6615','NAD83(2011) / Wyoming West',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14934','EPSG','2271',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6616','NAD83(2011) / Wyoming West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','14938','EPSG','2271',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6617','NAD83(2011) / Wyoming West Central',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14933','EPSG','2272',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6618','NAD83(2011) / Wyoming West Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','14937','EPSG','2272',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6619','NAD83(2011) / Utah Central',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14332','EPSG','2257',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6620','NAD83(2011) / Utah North',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14331','EPSG','2258',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6621','NAD83(2011) / Utah South',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14333','EPSG','2259',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6622','NAD83(CSRS) / Quebec Lambert',NULL,NULL,'EPSG','4499','EPSG','4617','EPSG','19944','EPSG','1368',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6623','NAD83 / Quebec Albers',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','6645','EPSG','1368',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6624','NAD83(CSRS) / Quebec Albers',NULL,NULL,'EPSG','4499','EPSG','4617','EPSG','6645','EPSG','1368',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6625','NAD83(2011) / Utah Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15298','EPSG','2257',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6626','NAD83(2011) / Utah North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15297','EPSG','2258',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6627','NAD83(2011) / Utah South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15299','EPSG','2259',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6628','NAD83(PA11) / Hawaii zone 1',NULL,NULL,'EPSG','4499','EPSG','6322','EPSG','15131','EPSG','1546',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6629','NAD83(PA11) / Hawaii zone 2',NULL,NULL,'EPSG','4499','EPSG','6322','EPSG','15132','EPSG','1547',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6630','NAD83(PA11) / Hawaii zone 3',NULL,NULL,'EPSG','4499','EPSG','6322','EPSG','15133','EPSG','1548',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6631','NAD83(PA11) / Hawaii zone 4',NULL,NULL,'EPSG','4499','EPSG','6322','EPSG','15134','EPSG','1549',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6632','NAD83(PA11) / Hawaii zone 5',NULL,NULL,'EPSG','4499','EPSG','6322','EPSG','15135','EPSG','1550',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6633','NAD83(PA11) / Hawaii zone 3 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6322','EPSG','15138','EPSG','1548',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6634','NAD83(PA11) / UTM zone 4N',NULL,NULL,'EPSG','4400','EPSG','6322','EPSG','16004','EPSG','3488',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6635','NAD83(PA11) / UTM zone 5N',NULL,NULL,'EPSG','4400','EPSG','6322','EPSG','16005','EPSG','3491',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6636','NAD83(PA11) / UTM zone 2S',NULL,NULL,'EPSG','4400','EPSG','6322','EPSG','16102','EPSG','3110',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6637','NAD83(MA11) / Guam Map Grid',NULL,NULL,'EPSG','4499','EPSG','6325','EPSG','4325','EPSG','3255',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6646','Karbala 1979 / Iraq National Grid',NULL,NULL,'EPSG','4400','EPSG','4743','EPSG','19907','EPSG','3625',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6669','JGD2011 / Japan Plane Rectangular CS I',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17801','EPSG','1854',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6670','JGD2011 / Japan Plane Rectangular CS II',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17802','EPSG','1855',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6671','JGD2011 / Japan Plane Rectangular CS III',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17803','EPSG','1856',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6672','JGD2011 / Japan Plane Rectangular CS IV',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17804','EPSG','1857',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6673','JGD2011 / Japan Plane Rectangular CS V',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17805','EPSG','1858',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6674','JGD2011 / Japan Plane Rectangular CS VI',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17806','EPSG','1859',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6675','JGD2011 / Japan Plane Rectangular CS VII',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17807','EPSG','1860',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6676','JGD2011 / Japan Plane Rectangular CS VIII',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17808','EPSG','1861',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6677','JGD2011 / Japan Plane Rectangular CS IX',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17809','EPSG','1862',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6678','JGD2011 / Japan Plane Rectangular CS X',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17810','EPSG','1863',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6679','JGD2011 / Japan Plane Rectangular CS XI',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17811','EPSG','1864',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6680','JGD2011 / Japan Plane Rectangular CS XII',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17812','EPSG','1865',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6681','JGD2011 / Japan Plane Rectangular CS XIII',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17813','EPSG','1866',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6682','JGD2011 / Japan Plane Rectangular CS XIV',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17814','EPSG','1867',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6683','JGD2011 / Japan Plane Rectangular CS XV',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17815','EPSG','1868',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6684','JGD2011 / Japan Plane Rectangular CS XVI',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17816','EPSG','1869',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6685','JGD2011 / Japan Plane Rectangular CS XVII',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17817','EPSG','1870',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6686','JGD2011 / Japan Plane Rectangular CS XVIII',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17818','EPSG','1871',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6687','JGD2011 / Japan Plane Rectangular CS XIX',NULL,NULL,'EPSG','4530','EPSG','6668','EPSG','17819','EPSG','1872',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6688','JGD2011 / UTM zone 51N',NULL,NULL,'EPSG','4400','EPSG','6668','EPSG','16051','EPSG','3959',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6689','JGD2011 / UTM zone 52N',NULL,NULL,'EPSG','4400','EPSG','6668','EPSG','16052','EPSG','3960',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6690','JGD2011 / UTM zone 53N',NULL,NULL,'EPSG','4400','EPSG','6668','EPSG','16053','EPSG','3961',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6691','JGD2011 / UTM zone 54N',NULL,NULL,'EPSG','4400','EPSG','6668','EPSG','16054','EPSG','3962',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6692','JGD2011 / UTM zone 55N',NULL,NULL,'EPSG','4400','EPSG','6668','EPSG','16055','EPSG','3963',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6703','WGS 84 / TM 60 SW',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','6702','EPSG','4172',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6707','RDN2008 / UTM zone 32N (N-E)',NULL,NULL,'EPSG','4500','EPSG','6706','EPSG','16032','EPSG','1718',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6708','RDN2008 / UTM zone 33N (N-E)',NULL,NULL,'EPSG','4500','EPSG','6706','EPSG','16033','EPSG','4186',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6709','RDN2008 / UTM zone 34N (N-E)',NULL,NULL,'EPSG','4500','EPSG','6706','EPSG','16034','EPSG','4187',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6720','WGS 84 / CIG92',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','6716','EPSG','4169',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6721','GDA94 / CIG94',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','6717','EPSG','4169',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6722','WGS 84 / CKIG92',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','6718','EPSG','1069',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6723','GDA94 / CKIG94',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','6719','EPSG','1069',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6732','GDA94 / MGA zone 41',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','6725','EPSG','4173',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','6733','GDA94 / MGA zone 42',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','6726','EPSG','4181',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','6734','GDA94 / MGA zone 43',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','6727','EPSG','4184',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','6735','GDA94 / MGA zone 44',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','6728','EPSG','4185',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','6736','GDA94 / MGA zone 46',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','6729','EPSG','4189',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6737','GDA94 / MGA zone 47',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','6730','EPSG','4190',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6738','GDA94 / MGA zone 59',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','6731','EPSG','4179',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6784','NAD83(CORS96) / Oregon Baker zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6741','EPSG','4180',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6785','NAD83(CORS96) / Oregon Baker zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6742','EPSG','4180',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6786','NAD83(2011) / Oregon Baker zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6741','EPSG','4180',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6787','NAD83(2011) / Oregon Baker zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6742','EPSG','4180',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6788','NAD83(CORS96) / Oregon Bend-Klamath Falls zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6743','EPSG','4192',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6789','NAD83(CORS96) / Oregon Bend-Klamath Falls zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6744','EPSG','4192',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6790','NAD83(2011) / Oregon Bend-Klamath Falls zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6743','EPSG','4192',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6791','NAD83(2011) / Oregon Bend-Klamath Falls zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6744','EPSG','4192',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6792','NAD83(CORS96) / Oregon Bend-Redmond-Prineville zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6745','EPSG','4195',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6793','NAD83(CORS96) / Oregon Bend-Redmond-Prineville zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6746','EPSG','4195',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6794','NAD83(2011) / Oregon Bend-Redmond-Prineville zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6745','EPSG','4195',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6795','NAD83(2011) / Oregon Bend-Redmond-Prineville zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6746','EPSG','4195',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6796','NAD83(CORS96) / Oregon Bend-Burns zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6747','EPSG','4182',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6797','NAD83(CORS96) / Oregon Bend-Burns zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6748','EPSG','4182',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6798','NAD83(2011) / Oregon Bend-Burns zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6747','EPSG','4182',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6799','NAD83(2011) / Oregon Bend-Burns zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6748','EPSG','4182',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6800','NAD83(CORS96) / Oregon Canyonville-Grants Pass zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6749','EPSG','4199',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6801','NAD83(CORS96) / Oregon Canyonville-Grants Pass zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6750','EPSG','4199',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6802','NAD83(2011) / Oregon Canyonville-Grants Pass zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6749','EPSG','4199',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6803','NAD83(2011) / Oregon Canyonville-Grants Pass zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6750','EPSG','4199',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6804','NAD83(CORS96) / Oregon Columbia River East zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6751','EPSG','4200',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6805','NAD83(CORS96) / Oregon Columbia River East zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6752','EPSG','4200',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6806','NAD83(2011) / Oregon Columbia River East zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6751','EPSG','4200',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6807','NAD83(2011) / Oregon Columbia River East zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6752','EPSG','4200',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6808','NAD83(CORS96) / Oregon Columbia River West zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6753','EPSG','4202',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6809','NAD83(CORS96) / Oregon Columbia River West zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6754','EPSG','4202',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6810','NAD83(2011) / Oregon Columbia River West zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6753','EPSG','4202',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6811','NAD83(2011) / Oregon Columbia River West zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6754','EPSG','4202',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6812','NAD83(CORS96) / Oregon Cottage Grove-Canyonville zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6755','EPSG','4203',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6813','NAD83(CORS96) / Oregon Cottage Grove-Canyonville zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6756','EPSG','4203',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6814','NAD83(2011) / Oregon Cottage Grove-Canyonville zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6755','EPSG','4203',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6815','NAD83(2011) / Oregon Cottage Grove-Canyonville zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6756','EPSG','4203',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6816','NAD83(CORS96) / Oregon Dufur-Madras zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6757','EPSG','4204',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6817','NAD83(CORS96) / Oregon Dufur-Madras zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6758','EPSG','4204',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6818','NAD83(2011) / Oregon Dufur-Madras zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6757','EPSG','4204',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6819','NAD83(2011) / Oregon Dufur-Madras zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6758','EPSG','4204',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6820','NAD83(CORS96) / Oregon Eugene zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6759','EPSG','4197',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6821','NAD83(CORS96) / Oregon Eugene zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6760','EPSG','4197',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6822','NAD83(2011) / Oregon Eugene zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6759','EPSG','4197',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6823','NAD83(2011) / Oregon Eugene zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6760','EPSG','4197',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6824','NAD83(CORS96) / Oregon Grants Pass-Ashland zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6761','EPSG','4198',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6825','NAD83(CORS96) / Oregon Grants Pass-Ashland zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6762','EPSG','4198',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6826','NAD83(2011) / Oregon Grants Pass-Ashland zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6761','EPSG','4198',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6827','NAD83(2011) / Oregon Grants Pass-Ashland zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6762','EPSG','4198',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6828','NAD83(CORS96) / Oregon Gresham-Warm Springs zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6763','EPSG','4201',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6829','NAD83(CORS96) / Oregon Gresham-Warm Springs zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6764','EPSG','4201',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6830','NAD83(2011) / Oregon Gresham-Warm Springs zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6763','EPSG','4201',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6831','NAD83(2011) / Oregon Gresham-Warm Springs zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6764','EPSG','4201',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6832','NAD83(CORS96) / Oregon La Grande zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6765','EPSG','4206',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6833','NAD83(CORS96) / Oregon La Grande zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6766','EPSG','4206',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6834','NAD83(2011) / Oregon La Grande zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6765','EPSG','4206',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6835','NAD83(2011) / Oregon La Grande zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6766','EPSG','4206',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6836','NAD83(CORS96) / Oregon Ontario zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6767','EPSG','4207',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6837','NAD83(CORS96) / Oregon Ontario zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6768','EPSG','4207',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6838','NAD83(2011) / Oregon Ontario zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6767','EPSG','4207',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6839','NAD83(2011) / Oregon Ontario zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6768','EPSG','4207',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6840','NAD83(CORS96) / Oregon Coast zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6769','EPSG','4208',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6841','NAD83(CORS96) / Oregon Coast zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6770','EPSG','4208',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6842','NAD83(2011) / Oregon Coast zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6769','EPSG','4208',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6843','NAD83(2011) / Oregon Coast zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6770','EPSG','4208',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6844','NAD83(CORS96) / Oregon Pendleton zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6771','EPSG','4209',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6845','NAD83(CORS96) / Oregon Pendleton zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6772','EPSG','4209',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6846','NAD83(2011) / Oregon Pendleton zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6771','EPSG','4209',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6847','NAD83(2011) / Oregon Pendleton zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6772','EPSG','4209',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6848','NAD83(CORS96) / Oregon Pendleton-La Grande zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6773','EPSG','4210',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6849','NAD83(CORS96) / Oregon Pendleton-La Grande zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6774','EPSG','4210',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6850','NAD83(2011) / Oregon Pendleton-La Grande zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6773','EPSG','4210',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6851','NAD83(2011) / Oregon Pendleton-La Grande zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6774','EPSG','4210',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6852','NAD83(CORS96) / Oregon Portland zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6775','EPSG','4211',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6853','NAD83(CORS96) / Oregon Portland zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6776','EPSG','4211',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6854','NAD83(2011) / Oregon Portland zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6775','EPSG','4211',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6855','NAD83(2011) / Oregon Portland zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6776','EPSG','4211',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6856','NAD83(CORS96) / Oregon Salem zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6777','EPSG','4212',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6857','NAD83(CORS96) / Oregon Salem zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6778','EPSG','4212',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6858','NAD83(2011) / Oregon Salem zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6777','EPSG','4212',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6859','NAD83(2011) / Oregon Salem zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6778','EPSG','4212',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6860','NAD83(CORS96) / Oregon Santiam Pass zone (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','6779','EPSG','4213',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6861','NAD83(CORS96) / Oregon Santiam Pass zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','6780','EPSG','4213',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6862','NAD83(2011) / Oregon Santiam Pass zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6779','EPSG','4213',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6863','NAD83(2011) / Oregon Santiam Pass zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','6780','EPSG','4213',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6867','NAD83(CORS96) / Oregon LCC (m)',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','13633','EPSG','1406',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6868','NAD83(CORS96) / Oregon GIC Lambert (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','15374','EPSG','1406',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6870','ETRS89 / Albania TM 2010',NULL,NULL,'EPSG','4530','EPSG','4258','EPSG','6869','EPSG','3212',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6875','RDN2008 / Italy zone (N-E)',NULL,NULL,'EPSG','4500','EPSG','6706','EPSG','6877','EPSG','1127',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6876','RDN2008 / Zone 12 (N-E)',NULL,NULL,'EPSG','4500','EPSG','6706','EPSG','6878','EPSG','1127',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6879','NAD83(2011) / Wisconsin Central',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','14832','EPSG','2266',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6880','NAD83(2011) / Nebraska (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','15396','EPSG','1396',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6884','NAD83(CORS96) / Oregon North',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','13631','EPSG','2243',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6885','NAD83(CORS96) / Oregon North (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','15351','EPSG','2243',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6886','NAD83(CORS96) / Oregon South',NULL,NULL,'EPSG','4499','EPSG','6783','EPSG','13632','EPSG','2244',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6887','NAD83(CORS96) / Oregon South (ft)',NULL,NULL,'EPSG','4495','EPSG','6783','EPSG','15352','EPSG','2244',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6915','South East Island 1943 / UTM zone 40N',NULL,NULL,'EPSG','4400','EPSG','6892','EPSG','16040','EPSG','4183',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6922','NAD83 / Kansas LCC',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','6920','EPSG','1385',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6923','NAD83 / Kansas LCC (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','6921','EPSG','1385',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6924','NAD83(2011) / Kansas LCC',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6920','EPSG','1385',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6925','NAD83(2011) / Kansas LCC (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','6921','EPSG','1385',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6931','WGS 84 / NSIDC EASE-Grid 2.0 North',NULL,NULL,'EPSG','4469','EPSG','4326','EPSG','6929','EPSG','3475',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6932','WGS 84 / NSIDC EASE-Grid 2.0 South',NULL,NULL,'EPSG','4470','EPSG','4326','EPSG','6930','EPSG','3474',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6933','WGS 84 / NSIDC EASE-Grid 2.0 Global',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','6928','EPSG','3463',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6956','VN-2000 / TM-3 zone 481',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','6952','EPSG','4193',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','6957','VN-2000 / TM-3 zone 482',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','6953','EPSG','4215',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','6958','VN-2000 / TM-3 zone 491',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','6954','EPSG','4217',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','6959','VN-2000 / TM-3 Da Nang zone',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','6955','EPSG','4218',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','6962','ETRS89 / Albania LCC 2010',NULL,NULL,'EPSG','4530','EPSG','4258','EPSG','6961','EPSG','3212',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6966','NAD27 / Michigan North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','6965','EPSG','1723',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6984','Israeli Grid 05',NULL,NULL,'EPSG','4400','EPSG','6983','EPSG','18204','EPSG','2603',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6991','Israeli Grid 05/12',NULL,NULL,'EPSG','4400','EPSG','6990','EPSG','18204','EPSG','2603',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','6996','NAD83(2011) / San Francisco CS13',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','6994','EPSG','4228',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','6997','NAD83(2011) / San Francisco CS13 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','6995','EPSG','4228',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','7005','Nahrwan 1934 / UTM zone 37N',NULL,NULL,'EPSG','4400','EPSG','4744','EPSG','16037','EPSG','3387',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7006','Nahrwan 1934 / UTM zone 38N',NULL,NULL,'EPSG','4400','EPSG','4744','EPSG','16038','EPSG','3388',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7007','Nahrwan 1934 / UTM zone 39N',NULL,NULL,'EPSG','4400','EPSG','4744','EPSG','16039','EPSG','3956',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7057','NAD83(2011) / IaRCS zone 1',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7043','EPSG','4164',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7058','NAD83(2011) / IaRCS zone 2',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7044','EPSG','4219',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7059','NAD83(2011) / IaRCS zone 3',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7045','EPSG','4230',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7060','NAD83(2011) / IaRCS zone 4',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7046','EPSG','4233',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7061','NAD83(2011) / IaRCS zone 5',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7047','EPSG','4234',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7062','NAD83(2011) / IaRCS zone 6',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7048','EPSG','4235',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7063','NAD83(2011) / IaRCS zone 7',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7049','EPSG','4236',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7064','NAD83(2011) / IaRCS zone 8',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7050','EPSG','4237',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7065','NAD83(2011) / IaRCS zone 9',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7051','EPSG','4239',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7066','NAD83(2011) / IaRCS zone 10',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7052','EPSG','4240',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7067','NAD83(2011) / IaRCS zone 11',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7053','EPSG','4241',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7068','NAD83(2011) / IaRCS zone 12',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7054','EPSG','4242',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7069','NAD83(2011) / IaRCS zone 13',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7055','EPSG','4243',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7070','NAD83(2011) / IaRCS zone 14',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7056','EPSG','4244',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7074','RGTAAF07 / UTM zone 37S',NULL,NULL,'EPSG','4400','EPSG','7073','EPSG','16137','EPSG','3934',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7075','RGTAAF07 / UTM zone 38S',NULL,NULL,'EPSG','4400','EPSG','7073','EPSG','16138','EPSG','4245',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7076','RGTAAF07 / UTM zone 39S',NULL,NULL,'EPSG','4400','EPSG','7073','EPSG','16139','EPSG','4247',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7077','RGTAAF07 / UTM zone 40S',NULL,NULL,'EPSG','4400','EPSG','7073','EPSG','16140','EPSG','4248',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7078','RGTAAF07 / UTM zone 41S',NULL,NULL,'EPSG','4400','EPSG','7073','EPSG','16141','EPSG','4249',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7079','RGTAAF07 / UTM zone 42S',NULL,NULL,'EPSG','4400','EPSG','7073','EPSG','16142','EPSG','4250',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7080','RGTAAF07 / UTM zone 43S',NULL,NULL,'EPSG','4400','EPSG','7073','EPSG','16143','EPSG','4251',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7081','RGTAAF07 / UTM zone 44S',NULL,NULL,'EPSG','4400','EPSG','7073','EPSG','16144','EPSG','4252',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7082','RGTAAF07 / Terre Adelie Polar Stereographic',NULL,NULL,'EPSG','4400','EPSG','7073','EPSG','19983','EPSG','2818',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','7109','NAD83(2011) / RMTCRS St Mary (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7089','EPSG','4310',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7110','NAD83(2011) / RMTCRS Blackfeet (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7091','EPSG','4311',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7111','NAD83(2011) / RMTCRS Milk River (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7093','EPSG','4312',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7112','NAD83(2011) / RMTCRS Fort Belknap (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7095','EPSG','4313',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7113','NAD83(2011) / RMTCRS Fort Peck Assiniboine (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7097','EPSG','4314',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7114','NAD83(2011) / RMTCRS Fort Peck Sioux (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7099','EPSG','4315',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7115','NAD83(2011) / RMTCRS Crow (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7101','EPSG','4316',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7116','NAD83(2011) / RMTCRS Bobcat (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7103','EPSG','4317',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7117','NAD83(2011) / RMTCRS Billings (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7105','EPSG','4318',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7118','NAD83(2011) / RMTCRS Wind River (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7107','EPSG','4319',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7119','NAD83(2011) / RMTCRS St Mary (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','7090','EPSG','4310',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7120','NAD83(2011) / RMTCRS Blackfeet (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','7092','EPSG','4311',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7121','NAD83(2011) / RMTCRS Milk River (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','7094','EPSG','4312',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7122','NAD83(2011) / RMTCRS Fort Belknap (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','7096','EPSG','4313',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7123','NAD83(2011) / RMTCRS Fort Peck Assiniboine (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','7098','EPSG','4314',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7124','NAD83(2011) / RMTCRS Fort Peck Sioux (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','7100','EPSG','4315',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7125','NAD83(2011) / RMTCRS Crow (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','7102','EPSG','4316',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7126','NAD83(2011) / RMTCRS Bobcat (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','7104','EPSG','4317',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7127','NAD83(2011) / RMTCRS Billings (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','7106','EPSG','4318',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7128','NAD83(2011) / RMTCRS Wind River (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7108','EPSG','4319',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7131','NAD83(2011) / San Francisco CS13',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7129','EPSG','4228',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7132','NAD83(2011) / San Francisco CS13 (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7130','EPSG','4228',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7142','Palestine 1923 / Palestine Grid modified',NULL,NULL,'EPSG','4400','EPSG','4281','EPSG','7141','EPSG','1356',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7257','NAD83(2011) / InGCS Adams (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7143','EPSG','4289',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7258','NAD83(2011) / InGCS Adams (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7144','EPSG','4289',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7259','NAD83(2011) / InGCS Allen (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7145','EPSG','4285',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7260','NAD83(2011) / InGCS Allen (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7146','EPSG','4285',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7261','NAD83(2011) / InGCS Bartholomew (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7147','EPSG','4302',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7262','NAD83(2011) / InGCS Bartholomew (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7148','EPSG','4302',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7263','NAD83(2011) / InGCS Benton (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7149','EPSG','4256',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7264','NAD83(2011) / InGCS Benton (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7150','EPSG','4256',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7265','NAD83(2011) / InGCS Blackford-Delaware (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7151','EPSG','4291',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7266','NAD83(2011) / InGCS Blackford-Delaware (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7152','EPSG','4291',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7267','NAD83(2011) / InGCS Boone-Hendricks (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7153','EPSG','4263',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7268','NAD83(2011) / InGCS Boone-Hendricks (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7154','EPSG','4263',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7269','NAD83(2011) / InGCS Brown (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7155','EPSG','4301',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7270','NAD83(2011) / InGCS Brown (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7156','EPSG','4301',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7271','NAD83(2011) / InGCS Carroll (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7157','EPSG','4258',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7272','NAD83(2011) / InGCS Carroll (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7158','EPSG','4258',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7273','NAD83(2011) / InGCS Cass (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7159','EPSG','4286',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7274','NAD83(2011) / InGCS Cass (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7160','EPSG','4286',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7275','NAD83(2011) / InGCS Clark-Floyd-Scott (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7161','EPSG','4308',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7276','NAD83(2011) / InGCS Clark-Floyd-Scott (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7162','EPSG','4308',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7277','NAD83(2011) / InGCS Clay (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7163','EPSG','4265',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7278','NAD83(2011) / InGCS Clay (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7164','EPSG','4265',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7279','NAD83(2011) / InGCS Clinton (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7165','EPSG','4260',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7280','NAD83(2011) / InGCS Clinton (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7166','EPSG','4260',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7281','NAD83(2011) / InGCS Crawford-Lawrence-Orange (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7167','EPSG','4272',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7282','NAD83(2011) / InGCS Crawford-Lawrence-Orange (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7168','EPSG','4272',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7283','NAD83(2011) / InGCS Daviess-Greene (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7169','EPSG','4269',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7284','NAD83(2011) / InGCS Daviess-Greene (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7170','EPSG','4269',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7285','NAD83(2011) / InGCS Dearborn-Ohio-Switzerland (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7171','EPSG','4306',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7286','NAD83(2011) / InGCS Dearborn-Ohio-Switzerland (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7172','EPSG','4306',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7287','NAD83(2011) / InGCS Decatur-Rush (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7173','EPSG','4299',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7288','NAD83(2011) / InGCS Decatur-Rush (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7174','EPSG','4299',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7289','NAD83(2011) / InGCS DeKalb (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7175','EPSG','4283',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7290','NAD83(2011) / InGCS DeKalb (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7176','EPSG','4283',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7291','NAD83(2011) / InGCS Dubois-Martin (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7177','EPSG','4271',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7292','NAD83(2011) / InGCS Dubois-Martin (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7178','EPSG','4271',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7293','NAD83(2011) / InGCS Elkhart-Kosciusko-Wabash (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7179','EPSG','4280',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7294','NAD83(2011) / InGCS Elkhart-Kosciusko-Wabash (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7180','EPSG','4280',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7295','NAD83(2011) / InGCS Fayette-Franklin-Union (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7181','EPSG','4300',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7296','NAD83(2011) / InGCS Fayette-Franklin-Union (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7182','EPSG','4300',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7297','NAD83(2011) / InGCS Fountain-Warren (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7183','EPSG','4259',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7298','NAD83(2011) / InGCS Fountain-Warren (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7184','EPSG','4259',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7299','NAD83(2011) / InGCS Fulton-Marshall-St. Joseph (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7185','EPSG','4279',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7300','NAD83(2011) / InGCS Fulton-Marshall-St. Joseph (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7186','EPSG','4279',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7301','NAD83(2011) / InGCS Gibson (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7187','EPSG','4273',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7302','NAD83(2011) / InGCS Gibson (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7188','EPSG','4273',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7303','NAD83(2011) / InGCS Grant (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7189','EPSG','4290',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7304','NAD83(2011) / InGCS Grant (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7190','EPSG','4290',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7305','NAD83(2011) / InGCS Hamilton-Tipton (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7191','EPSG','4293',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7306','NAD83(2011) / InGCS Hamilton-Tipton (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7192','EPSG','4293',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7307','NAD83(2011) / InGCS Hancock-Madison (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7193','EPSG','4294',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7308','NAD83(2011) / InGCS Hancock-Madison (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7194','EPSG','4294',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7309','NAD83(2011) / InGCS Harrison-Washington (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7195','EPSG','4307',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7310','NAD83(2011) / InGCS Harrison-Washington (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7196','EPSG','4307',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7311','NAD83(2011) / InGCS Henry (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7197','EPSG','4296',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7312','NAD83(2011) / InGCS Henry (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7198','EPSG','4296',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7313','NAD83(2011) / InGCS Howard-Miami (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7199','EPSG','4287',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7314','NAD83(2011) / InGCS Howard-Miami (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7200','EPSG','4287',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7315','NAD83(2011) / InGCS Huntington-Whitley (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7201','EPSG','4284',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7316','NAD83(2011) / InGCS Huntington-Whitley (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7202','EPSG','4284',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7317','NAD83(2011) / InGCS Jackson (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7203','EPSG','4303',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7318','NAD83(2011) / InGCS Jackson (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7204','EPSG','4303',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7319','NAD83(2011) / InGCS Jasper-Porter (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7205','EPSG','4254',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7320','NAD83(2011) / InGCS Jasper-Porter (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7206','EPSG','4254',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7321','NAD83(2011) / InGCS Jay (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7207','EPSG','4292',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7322','NAD83(2011) / InGCS Jay (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7208','EPSG','4292',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7323','NAD83(2011) / InGCS Jefferson (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7209','EPSG','4309',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7324','NAD83(2011) / InGCS Jefferson (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7210','EPSG','4309',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7325','NAD83(2011) / InGCS Jennings (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7211','EPSG','4304',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7326','NAD83(2011) / InGCS Jennings (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7212','EPSG','4304',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7327','NAD83(2011) / InGCS Johnson-Marion (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7213','EPSG','4297',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7328','NAD83(2011) / InGCS Johnson-Marion (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7214','EPSG','4297',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7329','NAD83(2011) / InGCS Knox (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7215','EPSG','4270',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7330','NAD83(2011) / InGCS Knox (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7216','EPSG','4270',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7331','NAD83(2011) / InGCS LaGrange-Noble (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7217','EPSG','4281',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7332','NAD83(2011) / InGCS LaGrange-Noble (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7218','EPSG','4281',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7333','NAD83(2011) / InGCS Lake-Newton (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7219','EPSG','4253',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7334','NAD83(2011) / InGCS Lake-Newton (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7220','EPSG','4253',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7335','NAD83(2011) / InGCS LaPorte-Pulaski-Starke (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7221','EPSG','4255',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7336','NAD83(2011) / InGCS LaPorte-Pulaski-Starke (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7222','EPSG','4255',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7337','NAD83(2011) / InGCS Monroe-Morgan (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7223','EPSG','4267',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7338','NAD83(2011) / InGCS Monroe-Morgan (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7224','EPSG','4267',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7339','NAD83(2011) / InGCS Montgomery-Putnam (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7225','EPSG','4262',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7340','NAD83(2011) / InGCS Montgomery-Putnam (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7226','EPSG','4262',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7341','NAD83(2011) / InGCS Owen (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7227','EPSG','4266',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7342','NAD83(2011) / InGCS Owen (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7228','EPSG','4266',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7343','NAD83(2011) / InGCS Parke-Vermillion (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7229','EPSG','4261',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7344','NAD83(2011) / InGCS Parke-Vermillion (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7230','EPSG','4261',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7345','NAD83(2011) / InGCS Perry (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7231','EPSG','4278',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7346','NAD83(2011) / InGCS Perry (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7232','EPSG','4278',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7347','NAD83(2011) / InGCS Pike-Warrick (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7233','EPSG','4274',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7348','NAD83(2011) / InGCS Pike-Warrick (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7234','EPSG','4274',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7349','NAD83(2011) / InGCS Posey (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7235','EPSG','4275',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7350','NAD83(2011) / InGCS Posey (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7236','EPSG','4275',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7351','NAD83(2011) / InGCS Randolph-Wayne (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7237','EPSG','4295',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7352','NAD83(2011) / InGCS Randolph-Wayne (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7238','EPSG','4295',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7353','NAD83(2011) / InGCS Ripley (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7239','EPSG','4305',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7354','NAD83(2011) / InGCS Ripley (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7240','EPSG','4305',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7355','NAD83(2011) / InGCS Shelby (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7241','EPSG','4298',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7356','NAD83(2011) / InGCS Shelby (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7242','EPSG','4298',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7357','NAD83(2011) / InGCS Spencer (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7243','EPSG','4277',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7358','NAD83(2011) / InGCS Spencer (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7244','EPSG','4277',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7359','NAD83(2011) / InGCS Steuben (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7245','EPSG','4282',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7360','NAD83(2011) / InGCS Steuben (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7246','EPSG','4282',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7361','NAD83(2011) / InGCS Sullivan (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7247','EPSG','4268',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7362','NAD83(2011) / InGCS Sullivan (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7248','EPSG','4268',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7363','NAD83(2011) / InGCS Tippecanoe-White (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7249','EPSG','4257',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7364','NAD83(2011) / InGCS Tippecanoe-White (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7250','EPSG','4257',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7365','NAD83(2011) / InGCS Vanderburgh (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7251','EPSG','4276',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7366','NAD83(2011) / InGCS Vanderburgh (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7252','EPSG','4276',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7367','NAD83(2011) / InGCS Vigo (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7253','EPSG','4264',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7368','NAD83(2011) / InGCS Vigo (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7254','EPSG','4264',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7369','NAD83(2011) / InGCS Wells (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7255','EPSG','4288',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7370','NAD83(2011) / InGCS Wells (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7256','EPSG','4288',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7374','ONGD14 / UTM zone 39N',NULL,NULL,'EPSG','4400','EPSG','7373','EPSG','16039','EPSG','4322',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7375','ONGD14 / UTM zone 40N',NULL,NULL,'EPSG','4400','EPSG','7373','EPSG','16040','EPSG','4323',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7376','ONGD14 / UTM zone 41N',NULL,NULL,'EPSG','4400','EPSG','7373','EPSG','16041','EPSG','4324',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7528','NAD83(2011) / WISCRS Adams and Juneau (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7484','EPSG','4360',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7529','NAD83(2011) / WISCRS Ashland (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7378','EPSG','4320',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7530','NAD83(2011) / WISCRS Barron (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7426','EPSG','4331',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7531','NAD83(2011) / WISCRS Bayfield (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7380','EPSG','4321',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7532','NAD83(2011) / WISCRS Brown (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7428','EPSG','4336',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7533','NAD83(2011) / WISCRS Buffalo (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7430','EPSG','4337',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7534','NAD83(2011) / WISCRS Burnett (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7382','EPSG','4325',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7535','NAD83(2011) / WISCRS Calumet, Fond du Lac, Outagamie and Winnebago (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7486','EPSG','4361',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7536','NAD83(2011) / WISCRS Chippewa (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7432','EPSG','4338',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7537','NAD83(2011) / WISCRS Clark (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7434','EPSG','4339',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7538','NAD83(2011) / WISCRS Columbia (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7488','EPSG','4362',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7539','NAD83(2011) / WISCRS Crawford (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7490','EPSG','4363',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7540','NAD83(2011) / WISCRS Dane (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7492','EPSG','4364',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7541','NAD83(2011) / WISCRS Dodge and Jefferson (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7494','EPSG','4365',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7542','NAD83(2011) / WISCRS Door (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7436','EPSG','4340',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7543','NAD83(2011) / WISCRS Douglas (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7384','EPSG','4326',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7544','NAD83(2011) / WISCRS Dunn (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7438','EPSG','4341',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7545','NAD83(2011) / WISCRS Eau Claire (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7440','EPSG','4342',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7546','NAD83(2011) / WISCRS Florence (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7386','EPSG','4327',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7547','NAD83(2011) / WISCRS Forest (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7388','EPSG','4328',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7548','NAD83(2011) / WISCRS Grant (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7496','EPSG','4366',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7549','NAD83(2011) / WISCRS Green and Lafayette (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7498','EPSG','4367',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7550','NAD83(2011) / WISCRS Green Lake and Marquette (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7500','EPSG','4368',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7551','NAD83(2011) / WISCRS Iowa (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7502','EPSG','4369',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7552','NAD83(2011) / WISCRS Iron (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7390','EPSG','4329',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7553','NAD83(2011) / WISCRS Jackson (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7450','EPSG','4343',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7554','NAD83(2011) / WISCRS Kenosha, Milwaukee, Ozaukee and Racine (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7504','EPSG','4370',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7555','NAD83(2011) / WISCRS Kewaunee, Manitowoc and Sheboygan (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7506','EPSG','4371',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7556','NAD83(2011) / WISCRS La Crosse (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7508','EPSG','4372',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7557','NAD83(2011) / WISCRS Langlade (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7452','EPSG','4344',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7558','NAD83(2011) / WISCRS Lincoln (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7454','EPSG','4345',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7559','NAD83(2011) / WISCRS Marathon (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7456','EPSG','4346',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7560','NAD83(2011) / WISCRS Marinette (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7458','EPSG','4347',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7561','NAD83(2011) / WISCRS Menominee (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7460','EPSG','4348',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7562','NAD83(2011) / WISCRS Monroe (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7510','EPSG','4373',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7563','NAD83(2011) / WISCRS Oconto (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7462','EPSG','4349',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7564','NAD83(2011) / WISCRS Oneida (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7392','EPSG','4330',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7565','NAD83(2011) / WISCRS Pepin and Pierce (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7464','EPSG','4350',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7566','NAD83(2011) / WISCRS Polk (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7466','EPSG','4351',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7567','NAD83(2011) / WISCRS Portage (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7468','EPSG','4352',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7568','NAD83(2011) / WISCRS Price (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7394','EPSG','4332',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7569','NAD83(2011) / WISCRS Richland (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7512','EPSG','4374',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7570','NAD83(2011) / WISCRS Rock (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7514','EPSG','4375',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7571','NAD83(2011) / WISCRS Rusk (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7470','EPSG','4353',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7572','NAD83(2011) / WISCRS Sauk (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7516','EPSG','4376',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7573','NAD83(2011) / WISCRS Sawyer (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7396','EPSG','4333',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7574','NAD83(2011) / WISCRS Shawano (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7472','EPSG','4354',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7575','NAD83(2011) / WISCRS St. Croix (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7474','EPSG','4355',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7576','NAD83(2011) / WISCRS Taylor (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7476','EPSG','4356',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7577','NAD83(2011) / WISCRS Trempealeau (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7478','EPSG','4357',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7578','NAD83(2011) / WISCRS Vernon (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7518','EPSG','4377',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7579','NAD83(2011) / WISCRS Vilas (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7398','EPSG','4334',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7580','NAD83(2011) / WISCRS Walworth (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7520','EPSG','4378',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7581','NAD83(2011) / WISCRS Washburn (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7424','EPSG','4335',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7582','NAD83(2011) / WISCRS Washington (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7522','EPSG','4379',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7583','NAD83(2011) / WISCRS Waukesha (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7524','EPSG','4380',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7584','NAD83(2011) / WISCRS Waupaca (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7480','EPSG','4358',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7585','NAD83(2011) / WISCRS Waushara (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7526','EPSG','4381',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7586','NAD83(2011) / WISCRS Wood (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','7482','EPSG','4359',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7587','NAD83(2011) / WISCRS Adams and Juneau (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7485','EPSG','4360',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7588','NAD83(2011) / WISCRS Ashland (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7379','EPSG','4320',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7589','NAD83(2011) / WISCRS Barron (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7427','EPSG','4331',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7590','NAD83(2011) / WISCRS Bayfield (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7381','EPSG','4321',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7591','NAD83(2011) / WISCRS Brown (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7429','EPSG','4336',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7592','NAD83(2011) / WISCRS Buffalo (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7431','EPSG','4337',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7593','NAD83(2011) / WISCRS Burnett (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7383','EPSG','4325',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7594','NAD83(2011) / WISCRS Calumet, Fond du Lac, Outagamie and Winnebago (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7487','EPSG','4361',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7595','NAD83(2011) / WISCRS Chippewa (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7433','EPSG','4338',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7596','NAD83(2011) / WISCRS Clark (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7435','EPSG','4339',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7597','NAD83(2011) / WISCRS Columbia (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7489','EPSG','4362',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7598','NAD83(2011) / WISCRS Crawford (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7491','EPSG','4363',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7599','NAD83(2011) / WISCRS Dane (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7493','EPSG','4364',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7600','NAD83(2011) / WISCRS Dodge and Jefferson (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7495','EPSG','4365',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7601','NAD83(2011) / WISCRS Door (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7437','EPSG','4340',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7602','NAD83(2011) / WISCRS Douglas (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7385','EPSG','4326',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7603','NAD83(2011) / WISCRS Dunn (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7439','EPSG','4341',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7604','NAD83(2011) / WISCRS Eau Claire (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7441','EPSG','4342',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7605','NAD83(2011) / WISCRS Florence (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7387','EPSG','4327',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7606','NAD83(2011) / WISCRS Forest (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7389','EPSG','4328',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7607','NAD83(2011) / WISCRS Grant (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7497','EPSG','4366',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7608','NAD83(2011) / WISCRS Green and Lafayette (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7499','EPSG','4367',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7609','NAD83(2011) / WISCRS Green Lake and Marquette (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7501','EPSG','4368',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7610','NAD83(2011) / WISCRS Iowa (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7503','EPSG','4369',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7611','NAD83(2011) / WISCRS Iron (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7391','EPSG','4329',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7612','NAD83(2011) / WISCRS Jackson (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7451','EPSG','4343',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7613','NAD83(2011) / WISCRS Kenosha, Milwaukee, Ozaukee and Racine (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7505','EPSG','4370',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7614','NAD83(2011) / WISCRS Kewaunee, Manitowoc and Sheboygan (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7507','EPSG','4371',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7615','NAD83(2011) / WISCRS La Crosse (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7509','EPSG','4372',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7616','NAD83(2011) / WISCRS Langlade (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7453','EPSG','4344',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7617','NAD83(2011) / WISCRS Lincoln (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7455','EPSG','4345',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7618','NAD83(2011) / WISCRS Marathon (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7457','EPSG','4346',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7619','NAD83(2011) / WISCRS Marinette (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7459','EPSG','4347',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7620','NAD83(2011) / WISCRS Menominee (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7461','EPSG','4348',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7621','NAD83(2011) / WISCRS Monroe (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7511','EPSG','4373',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7622','NAD83(2011) / WISCRS Oconto (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7463','EPSG','4349',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7623','NAD83(2011) / WISCRS Oneida (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7393','EPSG','4330',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7624','NAD83(2011) / WISCRS Pepin and Pierce (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7465','EPSG','4350',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7625','NAD83(2011) / WISCRS Polk (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7467','EPSG','4351',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7626','NAD83(2011) / WISCRS Portage (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7469','EPSG','4352',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7627','NAD83(2011) / WISCRS Price (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7395','EPSG','4332',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7628','NAD83(2011) / WISCRS Richland (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7513','EPSG','4374',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7629','NAD83(2011) / WISCRS Rock (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7515','EPSG','4375',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7630','NAD83(2011) / WISCRS Rusk (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7471','EPSG','4353',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7631','NAD83(2011) / WISCRS Sauk (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7517','EPSG','4376',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7632','NAD83(2011) / WISCRS Sawyer (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7397','EPSG','4333',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7633','NAD83(2011) / WISCRS Shawano (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7473','EPSG','4354',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7634','NAD83(2011) / WISCRS St. Croix (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7475','EPSG','4355',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7635','NAD83(2011) / WISCRS Taylor (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7477','EPSG','4356',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7636','NAD83(2011) / WISCRS Trempealeau (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7479','EPSG','4357',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7637','NAD83(2011) / WISCRS Vernon (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7519','EPSG','4377',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7638','NAD83(2011) / WISCRS Vilas (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7399','EPSG','4334',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7639','NAD83(2011) / WISCRS Walworth (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7521','EPSG','4378',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7640','NAD83(2011) / WISCRS Washburn (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7425','EPSG','4335',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7641','NAD83(2011) / WISCRS Washington (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7523','EPSG','4379',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7642','NAD83(2011) / WISCRS Waukesha (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7525','EPSG','4380',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7643','NAD83(2011) / WISCRS Waupaca (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7481','EPSG','4358',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7644','NAD83(2011) / WISCRS Waushara (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7527','EPSG','4381',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7645','NAD83(2011) / WISCRS Wood (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','7483','EPSG','4359',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7692','Kyrg-06 / zone 1',NULL,NULL,'EPSG','4400','EPSG','7686','EPSG','7687','EPSG','4385',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7693','Kyrg-06 / zone 2',NULL,NULL,'EPSG','4400','EPSG','7686','EPSG','7688','EPSG','4386',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7694','Kyrg-06 / zone 3',NULL,NULL,'EPSG','4400','EPSG','7686','EPSG','7689','EPSG','4387',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7695','Kyrg-06 / zone 4',NULL,NULL,'EPSG','4400','EPSG','7686','EPSG','7690','EPSG','4388',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7696','Kyrg-06 / zone 5',NULL,NULL,'EPSG','4400','EPSG','7686','EPSG','7691','EPSG','4389',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7755','WGS 84 / India NSF LCC',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7722','EPSG','1121',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7756','WGS 84 / Andhra Pradesh',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7723','EPSG','4394',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7757','WGS 84 / Arunachal Pradesh',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7724','EPSG','4395',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7758','WGS 84 / Assam',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7725','EPSG','4396',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7759','WGS 84 / Bihar',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7726','EPSG','4397',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7760','WGS 84 / Delhi',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7727','EPSG','4422',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7761','WGS 84 / Gujarat',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7728','EPSG','4400',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7762','WGS 84 / Haryana',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7729','EPSG','4401',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7763','WGS 84 / Himachal Pradesh',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7730','EPSG','4402',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7764','WGS 84 / Jammu and Kashmir',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7731','EPSG','4403',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7765','WGS 84 / Jharkhand',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7732','EPSG','4404',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7766','WGS 84 / Madhya Pradesh',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7733','EPSG','4407',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7767','WGS 84 / Maharashtra',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7734','EPSG','4408',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7768','WGS 84 / Manipur',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7735','EPSG','4409',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7769','WGS 84 / Meghalaya',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7736','EPSG','4410',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7770','WGS 84 / Nagaland',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7737','EPSG','4412',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7771','WGS 84 / India Northeast',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7738','EPSG','4392',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7772','WGS 84 / Orissa',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7739','EPSG','4413',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7773','WGS 84 / Punjab',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7740','EPSG','4414',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7774','WGS 84 / Rajasthan',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7741','EPSG','4415',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7775','WGS 84 / Uttar Pradesh',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7742','EPSG','4419',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7776','WGS 84 / Uttaranchal',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7743','EPSG','4420',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7777','WGS 84 / Andaman and Nicobar',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7744','EPSG','4423',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7778','WGS 84 / Chhattisgarh',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7745','EPSG','4398',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7779','WGS 84 / Goa',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7746','EPSG','4399',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7780','WGS 84 / Karnataka',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7747','EPSG','4405',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7781','WGS 84 / Kerala',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7748','EPSG','4406',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7782','WGS 84 / Lakshadweep',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7749','EPSG','4424',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7783','WGS 84 / Mizoram',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7750','EPSG','4411',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7784','WGS 84 / Sikkim',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7751','EPSG','4416',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7785','WGS 84 / Tamil Nadu',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7752','EPSG','4417',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7786','WGS 84 / Tripura',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7753','EPSG','4418',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7787','WGS 84 / West Bengal',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','7754','EPSG','4421',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7791','RDN2008 / UTM zone 32N',NULL,NULL,'EPSG','4400','EPSG','6706','EPSG','16032','EPSG','1718',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7792','RDN2008 / UTM zone 33N',NULL,NULL,'EPSG','4400','EPSG','6706','EPSG','16033','EPSG','4186',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7793','RDN2008 / UTM zone 34N',NULL,NULL,'EPSG','4400','EPSG','6706','EPSG','16034','EPSG','4187',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7794','RDN2008 / Italy zone (E-N)',NULL,NULL,'EPSG','4400','EPSG','6706','EPSG','6877','EPSG','1127',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7795','RDN2008 / Zone 12 (E-N)',NULL,NULL,'EPSG','4400','EPSG','6706','EPSG','6878','EPSG','1127',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7799','BGS2005 / UTM zone 34N (N-E)',NULL,NULL,'EPSG','4531','EPSG','7798','EPSG','16034','EPSG','4428',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7800','BGS2005 / UTM zone 35N (N-E)',NULL,NULL,'EPSG','4531','EPSG','7798','EPSG','16035','EPSG','4427',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7801','BGS2005 / CCS2005',NULL,NULL,'EPSG','4531','EPSG','7798','EPSG','7802','EPSG','3224',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7803','BGS2005 / UTM zone 34N',NULL,NULL,'EPSG','4400','EPSG','7798','EPSG','16034','EPSG','4428',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7804','BGS2005 / UTM zone 35N',NULL,NULL,'EPSG','4400','EPSG','7798','EPSG','16034','EPSG','4427',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7805','BGS2005 / UTM zone 36N',NULL,NULL,'EPSG','4400','EPSG','7798','EPSG','16036','EPSG','4426',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7825','Pulkovo 1942 / CS63 zone X1',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','7818','EPSG','4435',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7826','Pulkovo 1942 / CS63 zone X2',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','7819','EPSG','4429',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7827','Pulkovo 1942 / CS63 zone X3',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','7820','EPSG','4430',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7828','Pulkovo 1942 / CS63 zone X4',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','7821','EPSG','4431',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7829','Pulkovo 1942 / CS63 zone X5',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','7822','EPSG','4432',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7830','Pulkovo 1942 / CS63 zone X6',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','7823','EPSG','4433',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7831','Pulkovo 1942 / CS63 zone X7',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','7824','EPSG','4434',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7845','GDA2020 / GA LCC',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','17362','EPSG','2575',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7846','GDA2020 / MGA zone 46',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','6729','EPSG','4189',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7847','GDA2020 / MGA zone 47',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','6730','EPSG','4190',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7848','GDA2020 / MGA zone 48',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','17348','EPSG','4191',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7849','GDA2020 / MGA zone 49',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','17349','EPSG','4176',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7850','GDA2020 / MGA zone 50',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','17350','EPSG','4178',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7851','GDA2020 / MGA zone 51',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','17351','EPSG','1559',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7852','GDA2020 / MGA zone 52',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','17352','EPSG','1560',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7853','GDA2020 / MGA zone 53',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','17353','EPSG','1561',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7854','GDA2020 / MGA zone 54',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','17354','EPSG','1562',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7855','GDA2020 / MGA zone 55',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','17355','EPSG','1563',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7856','GDA2020 / MGA zone 56',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','17356','EPSG','1564',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7857','GDA2020 / MGA zone 57',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','17357','EPSG','4196',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7858','GDA2020 / MGA zone 58',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','17358','EPSG','4175',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7859','GDA2020 / MGA zone 59',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','6731','EPSG','4179',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7877','Astro DOS 71 / SHLG71',NULL,NULL,'EPSG','4400','EPSG','4710','EPSG','7875','EPSG','3183',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7878','Astro DOS 71 / UTM zone 30S',NULL,NULL,'EPSG','4400','EPSG','4710','EPSG','16130','EPSG','3183',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7882','St. Helena Tritan / SHLG(Tritan)',NULL,NULL,'EPSG','4400','EPSG','7881','EPSG','7876','EPSG','3183',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7883','St. Helena Tritan / UTM zone 30S',NULL,NULL,'EPSG','4400','EPSG','7881','EPSG','16130','EPSG','3183',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7887','SHMG2015',NULL,NULL,'EPSG','4400','EPSG','7886','EPSG','16130','EPSG','3183',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7899','GDA2020 / Vicgrid',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','17361','EPSG','2285',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7991','NAD27 / MTM zone 10',NULL,NULL,'EPSG','4499','EPSG','4267','EPSG','17710','EPSG','1431',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','7992','Malongo 1987 / UTM zone 33S',NULL,NULL,'EPSG','4400','EPSG','4259','EPSG','16133','EPSG','4447',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8013','GDA2020 / ALB2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','7993','EPSG','4439',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8014','GDA2020 / BIO2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','7994','EPSG','4438',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8015','GDA2020 / BRO2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','7995','EPSG','4441',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8016','GDA2020 / BCG2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','7996','EPSG','4437',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8017','GDA2020 / CARN2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','7997','EPSG','4442',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8018','GDA2020 / CIG2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','7998','EPSG','4169',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8019','GDA2020 / CKIG2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','7999','EPSG','1069',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8020','GDA2020 / COL2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','8000','EPSG','4443',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8021','GDA2020 / ESP2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','8001','EPSG','4445',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8022','GDA2020 / EXM2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','8002','EPSG','4448',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8023','GDA2020 / GCG2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','8003','EPSG','4449',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8024','GDA2020 / GOLD2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','8004','EPSG','4436',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8025','GDA2020 / JCG2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','8005','EPSG','4440',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8026','GDA2020 / KALB2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','8006','EPSG','4444',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8027','GDA2020 / KAR2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','8007','EPSG','4451',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8028','GDA2020 / KUN2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','8008','EPSG','4452',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8029','GDA2020 / LCG2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','8009','EPSG','4453',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8030','GDA2020 / MRCG2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','8010','EPSG','4457',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8031','GDA2020 / PCG2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','8011','EPSG','4462',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8032','GDA2020 / PHG2020',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','8012','EPSG','4466',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8035','WGS 84 / TM Zone 20N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4326','EPSG','8033','EPSG','4467',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8036','WGS 84 / TM Zone 21N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4326','EPSG','8034','EPSG','4468',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8044','Gusterberg Grid (Ferro)',NULL,NULL,'EPSG','6501','EPSG','8042','EPSG','8040','EPSG','4455',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8045','St. Stephen Grid (Ferro)',NULL,NULL,'EPSG','6501','EPSG','8043','EPSG','8041','EPSG','4456',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8058','GDA2020 / NSW Lambert',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','17364','EPSG','3139',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8059','GDA2020 / SA Lambert',NULL,NULL,'EPSG','4400','EPSG','7844','EPSG','17359','EPSG','2986',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8065','NAD83(2011) / PCCS zone 1 (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8061','EPSG','4472',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8066','NAD83(2011) / PCCS zone 2 (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8062','EPSG','4460',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8067','NAD83(2011) / PCCS zone 3 (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8063','EPSG','4450',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8068','NAD83(2011) / PCCS zone 4 (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8064','EPSG','4473',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8082','NAD83(CSRS)v6 / MTM Nova Scotia zone 4',NULL,NULL,'EPSG','4400','EPSG','8252','EPSG','8080','EPSG','1534',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8083','NAD83(CSRS)v6 / MTM Nova Scotia zone 5',NULL,NULL,'EPSG','4400','EPSG','8252','EPSG','8081','EPSG','1535',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8088','ISN2016 / Lambert 2016',NULL,NULL,'EPSG','4499','EPSG','8086','EPSG','8087','EPSG','1120',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8090','NAD83(HARN) / WISCRS Florence (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7386','EPSG','4327',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8091','NAD83(HARN) / WISCRS Florence (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7387','EPSG','4327',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8092','NAD83(HARN) / WISCRS Eau Claire (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7440','EPSG','4342',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8093','NAD83(HARN) / WISCRS Eau Claire (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7441','EPSG','4342',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8095','NAD83(HARN) / WISCRS Wood (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7482','EPSG','4359',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8096','NAD83(HARN) / WISCRS Wood (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7483','EPSG','4359',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8097','NAD83(HARN) / WISCRS Waushara (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7526','EPSG','4381',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8098','NAD83(HARN) / WISCRS Waushara (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7527','EPSG','4381',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8099','NAD83(HARN) / WISCRS Waupaca (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7480','EPSG','4358',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8100','NAD83(HARN) / WISCRS Waupaca (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7481','EPSG','4358',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8101','NAD83(HARN) / WISCRS Waukesha (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7524','EPSG','4380',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8102','NAD83(HARN) / WISCRS Waukesha (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7525','EPSG','4380',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8103','NAD83(HARN) / WISCRS Washington (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7522','EPSG','4379',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8104','NAD83(HARN) / WISCRS Washington (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7523','EPSG','4379',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8105','NAD83(HARN) / WISCRS Washburn (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7424','EPSG','4335',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8106','NAD83(HARN) / WISCRS Washburn (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7425','EPSG','4335',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8107','NAD83(HARN) / WISCRS Walworth (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7520','EPSG','4378',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8108','NAD83(HARN) / WISCRS Walworth (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7521','EPSG','4378',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8109','NAD83(HARN) / WISCRS Vilas (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7398','EPSG','4334',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8110','NAD83(HARN) / WISCRS Vilas (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7399','EPSG','4334',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8111','NAD83(HARN) / WISCRS Vernon (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7518','EPSG','4377',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8112','NAD83(HARN) / WISCRS Vernon (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7519','EPSG','4377',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8113','NAD83(HARN) / WISCRS Trempealeau (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7478','EPSG','4357',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8114','NAD83(HARN) / WISCRS Trempealeau (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7479','EPSG','4357',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8115','NAD83(HARN) / WISCRS Taylor (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7476','EPSG','4356',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8116','NAD83(HARN) / WISCRS Taylor (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7477','EPSG','4356',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8117','NAD83(HARN) / WISCRS St. Croix (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7474','EPSG','4355',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8118','NAD83(HARN) / WISCRS St. Croix (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7475','EPSG','4355',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8119','NAD83(HARN) / WISCRS Shawano (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7472','EPSG','4354',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8120','NAD83(HARN) / WISCRS Shawano (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7473','EPSG','4354',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8121','NAD83(HARN) / WISCRS Sawyer (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7396','EPSG','4333',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8122','NAD83(HARN) / WISCRS Sawyer (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7397','EPSG','4333',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8123','NAD83(HARN) / WISCRS Sauk (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7516','EPSG','4376',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8124','NAD83(HARN) / WISCRS Sauk (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7517','EPSG','4376',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8125','NAD83(HARN) / WISCRS Rusk (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7470','EPSG','4353',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8126','NAD83(HARN) / WISCRS Rusk (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7471','EPSG','4353',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8127','NAD83(HARN) / WISCRS Rock (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7514','EPSG','4375',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8128','NAD83(HARN) / WISCRS Rock (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7515','EPSG','4375',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8129','NAD83(HARN) / WISCRS Richland (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7512','EPSG','4374',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8130','NAD83(HARN) / WISCRS Richland (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7513','EPSG','4374',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8131','NAD83(HARN) / WISCRS Price (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7394','EPSG','4332',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8132','NAD83(HARN) / WISCRS Price (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7395','EPSG','4332',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8133','NAD83(HARN) / WISCRS Portage (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7468','EPSG','4352',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8134','NAD83(HARN) / WISCRS Portage (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7469','EPSG','4352',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8135','NAD83(HARN) / WISCRS Polk (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7466','EPSG','4351',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8136','NAD83(HARN) / WISCRS Polk (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7467','EPSG','4351',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8137','NAD83(HARN) / WISCRS Pepin and Pierce (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7464','EPSG','4350',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8138','NAD83(HARN) / WISCRS Pepin and Pierce (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7465','EPSG','4350',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8139','NAD83(HARN) / WISCRS Oneida (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7392','EPSG','4330',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8140','NAD83(HARN) / WISCRS Oneida (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7393','EPSG','4330',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8141','NAD83(HARN) / WISCRS Oconto (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7462','EPSG','4349',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8142','NAD83(HARN) / WISCRS Oconto (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7463','EPSG','4349',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8143','NAD83(HARN) / WISCRS Monroe (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7510','EPSG','4373',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8144','NAD83(HARN) / WISCRS Monroe (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7511','EPSG','4373',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8145','NAD83(HARN) / WISCRS Menominee (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7460','EPSG','4348',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8146','NAD83(HARN) / WISCRS Menominee (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7461','EPSG','4348',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8147','NAD83(HARN) / WISCRS Marinette (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7458','EPSG','4347',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8148','NAD83(HARN) / WISCRS Marinette (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7459','EPSG','4347',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8149','NAD83(HARN) / WISCRS Marathon (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7456','EPSG','4346',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8150','NAD83(HARN) / WISCRS Marathon (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7457','EPSG','4346',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8151','NAD83(HARN) / WISCRS Lincoln (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7454','EPSG','4345',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8152','NAD83(HARN) / WISCRS Lincoln (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7455','EPSG','4345',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8153','NAD83(HARN) / WISCRS Langlade (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7452','EPSG','4344',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8154','NAD83(HARN) / WISCRS Langlade (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7453','EPSG','4344',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8155','NAD83(HARN) / WISCRS La Crosse (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7508','EPSG','4372',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8156','NAD83(HARN) / WISCRS La Crosse (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7509','EPSG','4372',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8157','NAD83(HARN) / WISCRS Kewaunee, Manitowoc and Sheboygan (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7506','EPSG','4371',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8158','NAD83(HARN) / WISCRS Kewaunee, Manitowoc and Sheboygan (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7507','EPSG','4371',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8159','NAD83(HARN) / WISCRS Kenosha, Milwaukee, Ozaukee and Racine (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7504','EPSG','4370',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8160','NAD83(HARN) / WISCRS Kenosha, Milwaukee, Ozaukee and Racine (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7505','EPSG','4370',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8161','NAD83(HARN) / WISCRS Jackson (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7450','EPSG','4343',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8162','NAD83(HARN) / WISCRS Jackson (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7451','EPSG','4343',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8163','NAD83(HARN) / WISCRS Iron (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7390','EPSG','4329',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8164','NAD83(HARN) / WISCRS Iron (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7391','EPSG','4329',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8165','NAD83(HARN) / WISCRS Iowa (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7502','EPSG','4369',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8166','NAD83(HARN) / WISCRS Iowa (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7503','EPSG','4369',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8167','NAD83(HARN) / WISCRS Green Lake and Marquette (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7500','EPSG','4368',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8168','NAD83(HARN) / WISCRS Green Lake and Marquette (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7501','EPSG','4368',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8169','NAD83(HARN) / WISCRS Green and Lafayette (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7498','EPSG','4367',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8170','NAD83(HARN) / WISCRS Green and Lafayette (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7499','EPSG','4367',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8171','NAD83(HARN) / WISCRS Grant (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7496','EPSG','4366',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8172','NAD83(HARN) / WISCRS Grant (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7497','EPSG','4366',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8173','NAD83(HARN) / WISCRS Forest (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7388','EPSG','4328',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8177','NAD83(HARN) / WISCRS Forest (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7389','EPSG','4328',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8179','NAD83(HARN) / WISCRS Dunn (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7438','EPSG','4341',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8180','NAD83(HARN) / WISCRS Dunn (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7439','EPSG','4341',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8181','NAD83(HARN) / WISCRS Douglas (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7384','EPSG','4326',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8182','NAD83(HARN) / WISCRS Douglas (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7385','EPSG','4326',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8184','NAD83(HARN) / WISCRS Door (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7436','EPSG','4340',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8185','NAD83(HARN) / WISCRS Door (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7437','EPSG','4340',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8187','NAD83(HARN) / WISCRS Dodge and Jefferson (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7494','EPSG','4365',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8189','NAD83(HARN) / WISCRS Dodge and Jefferson (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7495','EPSG','4365',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8191','NAD83(HARN) / WISCRS Dane (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7492','EPSG','4364',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8193','NAD83(HARN) / WISCRS Dane (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7493','EPSG','4364',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8196','NAD83(HARN) / WISCRS Crawford (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7490','EPSG','4363',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8197','NAD83(HARN) / WISCRS Crawford (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7491','EPSG','4363',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8198','NAD83(HARN) / WISCRS Columbia (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7488','EPSG','4362',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8200','NAD83(HARN) / WISCRS Columbia (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7489','EPSG','4362',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8201','NAD83(HARN) / WISCRS Clark (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7434','EPSG','4339',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8202','NAD83(HARN) / WISCRS Clark (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7435','EPSG','4339',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8203','NAD83(HARN) / WISCRS Chippewa (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7432','EPSG','4338',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8204','NAD83(HARN) / WISCRS Chippewa (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7433','EPSG','4338',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8205','NAD83(HARN) / WISCRS Calumet, Fond du Lac, Outagamie and Winnebago (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7486','EPSG','4361',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8206','NAD83(HARN) / WISCRS Calumet, Fond du Lac, Outagamie and Winnebago (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7487','EPSG','4361',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8207','NAD83(HARN) / WISCRS Burnett (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7382','EPSG','4325',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8208','NAD83(HARN) / WISCRS Burnett (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7383','EPSG','4325',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8209','NAD83(HARN) / WISCRS Buffalo (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7430','EPSG','4337',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8210','NAD83(HARN) / WISCRS Buffalo (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7431','EPSG','4337',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8212','NAD83(HARN) / WISCRS Brown (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7428','EPSG','4336',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8213','NAD83(HARN) / WISCRS Brown (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7429','EPSG','4336',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8214','NAD83(HARN) / WISCRS Bayfield (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7380','EPSG','4321',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8216','NAD83(HARN) / WISCRS Bayfield (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7381','EPSG','4321',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8218','NAD83(HARN) / WISCRS Barron (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7426','EPSG','4331',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8220','NAD83(HARN) / WISCRS Barron (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7427','EPSG','4331',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8222','NAD83(HARN) / WISCRS Ashland (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7378','EPSG','4320',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8224','NAD83(HARN) / WISCRS Ashland (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7379','EPSG','4320',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8225','NAD83(HARN) / WISCRS Adams and Juneau (m)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','7484','EPSG','4360',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8226','NAD83(HARN) / WISCRS Adams and Juneau (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','7485','EPSG','4360',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8311','NAD83(2011) / Oregon Burns-Harper zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8273','EPSG','4459',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8312','NAD83(2011) / Oregon Burns-Harper zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8274','EPSG','4459',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8313','NAD83(2011) / Oregon Canyon City-Burns zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8275','EPSG','4465',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8314','NAD83(2011) / Oregon Canyon City-Burns zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8276','EPSG','4465',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8315','NAD83(2011) / Oregon Coast Range North zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8277','EPSG','4471',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8316','NAD83(2011) / Oregon Coast Range North zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8278','EPSG','4471',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8317','NAD83(2011) / Oregon Dayville-Prairie City zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8279','EPSG','4474',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8318','NAD83(2011) / Oregon Dayville-Prairie City zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8280','EPSG','4474',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8319','NAD83(2011) / Oregon Denio-Burns zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8281','EPSG','4475',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8320','NAD83(2011) / Oregon Denio-Burns zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8282','EPSG','4475',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8321','NAD83(2011) / Oregon Halfway zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8283','EPSG','4476',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8322','NAD83(2011) / Oregon Halfway zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8284','EPSG','4476',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8323','NAD83(2011) / Oregon Medford-Diamond Lake zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8285','EPSG','4477',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8324','NAD83(2011) / Oregon Medford-Diamond Lake zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8286','EPSG','4477',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8325','NAD83(2011) / Oregon Mitchell zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8287','EPSG','4478',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8326','NAD83(2011) / Oregon Mitchell zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8288','EPSG','4478',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8327','NAD83(2011) / Oregon North Central zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8289','EPSG','4479',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8328','NAD83(2011) / Oregon North Central zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8290','EPSG','4479',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8329','NAD83(2011) / Oregon Ochoco Summit zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8291','EPSG','4481',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8330','NAD83(2011) / Oregon Ochoco Summit zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8292','EPSG','4481',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8331','NAD83(2011) / Oregon Owyhee zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8293','EPSG','4482',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8332','NAD83(2011) / Oregon Owyhee zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8294','EPSG','4482',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8333','NAD83(2011) / Oregon Pilot Rock-Ukiah zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8295','EPSG','4483',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8334','NAD83(2011) / Oregon Pilot Rock-Ukiah zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8296','EPSG','4483',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8335','NAD83(2011) / Oregon Prairie City-Brogan zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8297','EPSG','4484',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8336','NAD83(2011) / Oregon Prairie City-Brogan zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8298','EPSG','4484',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8337','NAD83(2011) / Oregon Riley-Lakeview zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8299','EPSG','4458',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8338','NAD83(2011) / Oregon Riley-Lakeview zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8300','EPSG','4458',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8339','NAD83(2011) / Oregon Siskiyou Pass zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8301','EPSG','4463',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8340','NAD83(2011) / Oregon Siskiyou Pass zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8302','EPSG','4463',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8341','NAD83(2011) / Oregon Ukiah-Fox zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8303','EPSG','4470',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8342','NAD83(2011) / Oregon Ukiah-Fox zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8304','EPSG','4470',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8343','NAD83(2011) / Oregon Wallowa zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8305','EPSG','4480',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8344','NAD83(2011) / Oregon Wallowa zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8306','EPSG','4480',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8345','NAD83(2011) / Oregon Warner Highway zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8307','EPSG','4486',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8346','NAD83(2011) / Oregon Warner Highway zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8308','EPSG','4486',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8347','NAD83(2011) / Oregon Willamette Pass zone (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8309','EPSG','4488',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8348','NAD83(2011) / Oregon Willamette Pass zone (ft)',NULL,NULL,'EPSG','4495','EPSG','6318','EPSG','8310','EPSG','4488',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8352','S-JTSK [JTSK03] / Krovak',NULL,NULL,'EPSG','6501','EPSG','8351','EPSG','5509','EPSG','1211',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8353','S-JTSK [JTSK03] / Krovak East North',NULL,NULL,'EPSG','4499','EPSG','8351','EPSG','5510','EPSG','1211',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8379','NAD83 / NCRS Las Vegas (m)',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','8373','EPSG','4485',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8380','NAD83 / NCRS Las Vegas (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','8374','EPSG','4485',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8381','NAD83 / NCRS Las Vegas high (m)',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','8375','EPSG','4487',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8382','NAD83 / NCRS Las Vegas high (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','8376','EPSG','4487',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8383','NAD83(2011) / NCRS Las Vegas (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8373','EPSG','4485',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8384','NAD83(2011) / NCRS Las Vegas (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8374','EPSG','4485',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8385','NAD83(2011) / NCRS Las Vegas high (m)',NULL,NULL,'EPSG','4499','EPSG','6318','EPSG','8375','EPSG','4487',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8387','NAD83(2011) / NCRS Las Vegas high (ftUS)',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8376','EPSG','4487',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8391','GDA94 / WEIPA94',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','8389','EPSG','4491',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8395','ETRS89 / Gauss-Kruger CM 9E',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','16302','EPSG','4490',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8433','Macao 1920 / Macao Grid',NULL,NULL,'EPSG','4500','EPSG','8428','EPSG','8432','EPSG','1147',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8441','Tananarive / Laborde Grid',NULL,NULL,'EPSG','4530','EPSG','4297','EPSG','8440','EPSG','3273',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8455','RGTAAF07 / UTM zone 53S',NULL,NULL,'EPSG','4400','EPSG','7073','EPSG','16153','EPSG','4489',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8456','RGTAAF07 / UTM zone 54S',NULL,NULL,'EPSG','4400','EPSG','7073','EPSG','16154','EPSG','4492',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8518','NAD83(2011) / KS RCS zone 1',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8458','EPSG','4495',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8519','NAD83(2011) / KS RCS zone 2',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8459','EPSG','4496',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8520','NAD83(2011) / KS RCS zone 3',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8490','EPSG','4497',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8521','NAD83(2011) / KS RCS zone 4',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8491','EPSG','4494',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8522','NAD83(2011) / KS RCS zone 5',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8492','EPSG','4498',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8523','NAD83(2011) / KS RCS zone 6',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8493','EPSG','4499',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8524','NAD83(2011) / KS RCS zone 7',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8494','EPSG','4500',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8525','NAD83(2011) / KS RCS zone 8',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8495','EPSG','4501',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8526','NAD83(2011) / KS RCS zone 9',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8498','EPSG','4502',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8527','NAD83(2011) / KS RCS zone 10',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8499','EPSG','4503',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8528','NAD83(2011) / KS RCS zone 11',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8500','EPSG','4504',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8529','NAD83(2011) / KS RCS zone 12',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8501','EPSG','4505',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8531','NAD83(2011) / KS RCS zone 13',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8502','EPSG','4506',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8533','NAD83(2011) / KS RCS zone 14',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8503','EPSG','4507',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8534','NAD83(2011) / KS RCS zone 15',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8504','EPSG','4508',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8535','NAD83(2011) / KS RCS zone 16',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8505','EPSG','4509',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8536','NAD83(2011) / KS RCS zone 17',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8506','EPSG','4510',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8538','NAD83(2011) / KS RCS zone 18',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8507','EPSG','4511',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8539','NAD83(2011) / KS RCS zone 19',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8515','EPSG','4512',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8540','NAD83(2011) / KS RCS zone 20',NULL,NULL,'EPSG','4497','EPSG','6318','EPSG','8516','EPSG','4513',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8677','MGI 1901 / Balkans zone 5',NULL,NULL,'EPSG','4498','EPSG','3906','EPSG','18275','EPSG','1709',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8678','MGI 1901 / Balkans zone 6',NULL,NULL,'EPSG','4498','EPSG','3906','EPSG','18276','EPSG','1710',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8679','MGI 1901 / Balkans zone 8',NULL,NULL,'EPSG','4498','EPSG','3906','EPSG','18278','EPSG','1712',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8682','SRB_ETRS89 / UTM zone 34N',NULL,NULL,'EPSG','4400','EPSG','8685','EPSG','16034','EPSG','4543',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8686','MGI 1901 / Slovenia Grid',NULL,NULL,'EPSG','4498','EPSG','3906','EPSG','19967','EPSG','1212',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8687','Slovenia 1996 / UTM zone 33N',NULL,NULL,'EPSG','4400','EPSG','4765','EPSG','16033','EPSG','1212',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8692','NAD83(MA11) / UTM zone 54N',NULL,NULL,'EPSG','4400','EPSG','6325','EPSG','16054','EPSG','4514',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8693','NAD83(MA11) / UTM zone 55N',NULL,NULL,'EPSG','4400','EPSG','6325','EPSG','16055','EPSG','4518',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8826','NAD83 / Idaho Transverse Mercator',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','8825','EPSG','1381',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8836','MTRF-2000 / UTM zone 36N',NULL,NULL,'EPSG','4400','EPSG','8818','EPSG','16036','EPSG','4524',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8837','MTRF-2000 / UTM zone 37N',NULL,NULL,'EPSG','4400','EPSG','8818','EPSG','16037','EPSG','4526',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8838','MTRF-2000 / UTM zone 38N',NULL,NULL,'EPSG','4400','EPSG','8818','EPSG','16038','EPSG','4527',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8839','MTRF-2000 / UTM zone 39N',NULL,NULL,'EPSG','4400','EPSG','8818','EPSG','16039','EPSG','4528',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8840','MTRF-2000 / UTM zone 40N',NULL,NULL,'EPSG','4400','EPSG','8818','EPSG','16040','EPSG','3106',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8857','WGS 84 / Equal Earth Greenwich',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','8854','EPSG','1262',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8858','WGS 84 / Equal Earth Americas',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','8855','EPSG','1262',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8859','WGS 84 / Equal Earth Asia-Pacific',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','8856','EPSG','1262',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8903','RGWF96 / UTM zone 1S',NULL,NULL,'EPSG','4400','EPSG','8900','EPSG','16101','EPSG','1255',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8908','CR-SIRGAS / CRTM05',NULL,NULL,'EPSG','4400','EPSG','8907','EPSG','5366','EPSG','3232',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8909','CR-SIRGAS / UTM zone 16N',NULL,NULL,'EPSG','4400','EPSG','8907','EPSG','16016','EPSG','4532',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8910','CR-SIRGAS / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','8907','EPSG','16017','EPSG','4531',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8950','SIRGAS-Chile 2010 / UTM zone 18S',NULL,NULL,'EPSG','4400','EPSG','8949','EPSG','16118','EPSG','3829',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','8951','SIRGAS-Chile 2010 / UTM zone 19S',NULL,NULL,'EPSG','4400','EPSG','8949','EPSG','16119','EPSG','3811',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9039','ISN2016 / LAEA Europe',NULL,NULL,'EPSG','4532','EPSG','8086','EPSG','19986','EPSG','1120',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9040','ISN2016 / LCC Europe',NULL,NULL,'EPSG','4532','EPSG','8086','EPSG','19985','EPSG','1120',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9141','KOSOVAREF01 / Balkans zone 7',NULL,NULL,'EPSG','4400','EPSG','9140','EPSG','18277','EPSG','4542',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9149','SIRGAS-Chile 2013 / UTM zone 18S',NULL,NULL,'EPSG','4400','EPSG','9148','EPSG','16118','EPSG','3829',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9150','SIRGAS-Chile 2013 / UTM zone 19S',NULL,NULL,'EPSG','4400','EPSG','9148','EPSG','16119','EPSG','3811',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9154','SIRGAS-Chile 2016 / UTM zone 18S',NULL,NULL,'EPSG','4400','EPSG','9153','EPSG','16118','EPSG','3829',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9155','SIRGAS-Chile 2016 / UTM zone 19S',NULL,NULL,'EPSG','4400','EPSG','9153','EPSG','16119','EPSG','3811',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9156','RSAO13 / UTM zone 32S',NULL,NULL,'EPSG','4400','EPSG','8699','EPSG','16132','EPSG','4551',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9157','RSAO13 / UTM zone 33S',NULL,NULL,'EPSG','4400','EPSG','8699','EPSG','16133','EPSG','4555',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9158','RSAO13 / UTM zone 34S',NULL,NULL,'EPSG','4400','EPSG','8699','EPSG','16134','EPSG','4539',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9159','RSAO13 / TM 12 SE',NULL,NULL,'EPSG','4400','EPSG','8699','EPSG','16612','EPSG','1604',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9191','WGS 84 / NIWA Albers',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','9190','EPSG','3508',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9205','VN-2000 / TM-3 103-00',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','9058','EPSG','4541',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9206','VN-2000 / TM-3 104-00',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','9192','EPSG','4538',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9207','VN-2000 / TM-3 104-30',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','9193','EPSG','4545',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9208','VN-2000 / TM-3 104-45',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','9194','EPSG','4546',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9209','VN-2000 / TM-3 105-30',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','9195','EPSG','4548',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9210','VN-2000 / TM-3 105-45',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','9196','EPSG','4549',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9211','VN-2000 / TM-3 106-00',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','9197','EPSG','4550',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9212','VN-2000 / TM-3 106-15',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','9198','EPSG','4552',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9213','VN-2000 / TM-3 106-30',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','9199','EPSG','4553',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9214','VN-2000 / TM-3 107-00',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','9200','EPSG','4554',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9215','VN-2000 / TM-3 107-15',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','9201','EPSG','4556',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9216','VN-2000 / TM-3 107-30',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','9202','EPSG','4557',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9217','VN-2000 / TM-3 108-15',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','9203','EPSG','4559',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9218','VN-2000 / TM-3 108-30',NULL,NULL,'EPSG','4400','EPSG','4756','EPSG','9204','EPSG','4560',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9221','Hartebeesthoek94 / ZAF BSU Albers 25E',NULL,NULL,'EPSG','4500','EPSG','4148','EPSG','9219','EPSG','4567',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','9222','Hartebeesthoek94 / ZAF BSU Albers 44E',NULL,NULL,'EPSG','4500','EPSG','4148','EPSG','9220','EPSG','4568',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20004','Pulkovo 1995 / Gauss-Kruger zone 4',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16204','EPSG','1763',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20005','Pulkovo 1995 / Gauss-Kruger zone 5',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16205','EPSG','1764',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20006','Pulkovo 1995 / Gauss-Kruger zone 6',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16206','EPSG','1765',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20007','Pulkovo 1995 / Gauss-Kruger zone 7',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16207','EPSG','1766',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20008','Pulkovo 1995 / Gauss-Kruger zone 8',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16208','EPSG','1767',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20009','Pulkovo 1995 / Gauss-Kruger zone 9',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16209','EPSG','1768',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20010','Pulkovo 1995 / Gauss-Kruger zone 10',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16210','EPSG','1769',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20011','Pulkovo 1995 / Gauss-Kruger zone 11',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16211','EPSG','1770',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20012','Pulkovo 1995 / Gauss-Kruger zone 12',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16212','EPSG','1771',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20013','Pulkovo 1995 / Gauss-Kruger zone 13',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16213','EPSG','1772',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20014','Pulkovo 1995 / Gauss-Kruger zone 14',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16214','EPSG','1773',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20015','Pulkovo 1995 / Gauss-Kruger zone 15',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16215','EPSG','1774',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20016','Pulkovo 1995 / Gauss-Kruger zone 16',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16216','EPSG','1775',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20017','Pulkovo 1995 / Gauss-Kruger zone 17',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16217','EPSG','1776',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20018','Pulkovo 1995 / Gauss-Kruger zone 18',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16218','EPSG','1777',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20019','Pulkovo 1995 / Gauss-Kruger zone 19',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16219','EPSG','1778',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20020','Pulkovo 1995 / Gauss-Kruger zone 20',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16220','EPSG','1779',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20021','Pulkovo 1995 / Gauss-Kruger zone 21',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16221','EPSG','1780',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20022','Pulkovo 1995 / Gauss-Kruger zone 22',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16222','EPSG','1781',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20023','Pulkovo 1995 / Gauss-Kruger zone 23',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16223','EPSG','1782',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20024','Pulkovo 1995 / Gauss-Kruger zone 24',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16224','EPSG','1783',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20025','Pulkovo 1995 / Gauss-Kruger zone 25',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16225','EPSG','1784',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20026','Pulkovo 1995 / Gauss-Kruger zone 26',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16226','EPSG','1785',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20027','Pulkovo 1995 / Gauss-Kruger zone 27',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16227','EPSG','1786',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20028','Pulkovo 1995 / Gauss-Kruger zone 28',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16228','EPSG','1787',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20029','Pulkovo 1995 / Gauss-Kruger zone 29',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16229','EPSG','1788',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20030','Pulkovo 1995 / Gauss-Kruger zone 30',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16230','EPSG','1789',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20031','Pulkovo 1995 / Gauss-Kruger zone 31',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16231','EPSG','1790',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20032','Pulkovo 1995 / Gauss-Kruger zone 32',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16232','EPSG','1791',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20064','Pulkovo 1995 / Gauss-Kruger 4N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16304','EPSG','1763',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20065','Pulkovo 1995 / Gauss-Kruger 5N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16305','EPSG','1764',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20066','Pulkovo 1995 / Gauss-Kruger 6N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16306','EPSG','1765',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20067','Pulkovo 1995 / Gauss-Kruger 7N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16307','EPSG','1766',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20068','Pulkovo 1995 / Gauss-Kruger 8N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16308','EPSG','1767',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20069','Pulkovo 1995 / Gauss-Kruger 9N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16309','EPSG','1768',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20070','Pulkovo 1995 / Gauss-Kruger 10N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16310','EPSG','1769',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20071','Pulkovo 1995 / Gauss-Kruger 11N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16311','EPSG','1770',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20072','Pulkovo 1995 / Gauss-Kruger 12N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16312','EPSG','1771',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20073','Pulkovo 1995 / Gauss-Kruger 13N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16313','EPSG','1772',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20074','Pulkovo 1995 / Gauss-Kruger 14N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16314','EPSG','1773',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20075','Pulkovo 1995 / Gauss-Kruger 15N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16315','EPSG','1774',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20076','Pulkovo 1995 / Gauss-Kruger 16N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16316','EPSG','1775',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20077','Pulkovo 1995 / Gauss-Kruger 17N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16317','EPSG','1776',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20078','Pulkovo 1995 / Gauss-Kruger 18N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16318','EPSG','1777',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20079','Pulkovo 1995 / Gauss-Kruger 19N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16319','EPSG','1778',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20080','Pulkovo 1995 / Gauss-Kruger 20N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16320','EPSG','1779',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20081','Pulkovo 1995 / Gauss-Kruger 21N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16321','EPSG','1780',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20082','Pulkovo 1995 / Gauss-Kruger 22N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16322','EPSG','1781',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20083','Pulkovo 1995 / Gauss-Kruger 23N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16323','EPSG','1782',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20084','Pulkovo 1995 / Gauss-Kruger 24N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16324','EPSG','1783',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20085','Pulkovo 1995 / Gauss-Kruger 25N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16325','EPSG','1784',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20086','Pulkovo 1995 / Gauss-Kruger 26N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16326','EPSG','1785',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20087','Pulkovo 1995 / Gauss-Kruger 27N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16327','EPSG','1786',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20088','Pulkovo 1995 / Gauss-Kruger 28N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16328','EPSG','1787',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20089','Pulkovo 1995 / Gauss-Kruger 29N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16329','EPSG','1788',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20090','Pulkovo 1995 / Gauss-Kruger 30N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16330','EPSG','1789',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20091','Pulkovo 1995 / Gauss-Kruger 31N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16331','EPSG','1790',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20092','Pulkovo 1995 / Gauss-Kruger 32N',NULL,NULL,'EPSG','4530','EPSG','4200','EPSG','16332','EPSG','1791',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20135','Adindan / UTM zone 35N',NULL,NULL,'EPSG','4400','EPSG','4201','EPSG','16035','EPSG','2827',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20136','Adindan / UTM zone 36N',NULL,NULL,'EPSG','4400','EPSG','4201','EPSG','16036','EPSG','2825',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20137','Adindan / UTM zone 37N',NULL,NULL,'EPSG','4400','EPSG','4201','EPSG','16037','EPSG','1552',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20138','Adindan / UTM zone 38N',NULL,NULL,'EPSG','4400','EPSG','4201','EPSG','16038','EPSG','1553',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20248','AGD66 / AMG zone 48',NULL,NULL,'EPSG','4400','EPSG','4202','EPSG','17448','EPSG','1556',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20249','AGD66 / AMG zone 49',NULL,NULL,'EPSG','4400','EPSG','4202','EPSG','17449','EPSG','1557',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20250','AGD66 / AMG zone 50',NULL,NULL,'EPSG','4400','EPSG','4202','EPSG','17450','EPSG','1558',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20251','AGD66 / AMG zone 51',NULL,NULL,'EPSG','4400','EPSG','4202','EPSG','17451','EPSG','1559',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20252','AGD66 / AMG zone 52',NULL,NULL,'EPSG','4400','EPSG','4202','EPSG','17452','EPSG','1560',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20253','AGD66 / AMG zone 53',NULL,NULL,'EPSG','4400','EPSG','4202','EPSG','17453','EPSG','1561',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20254','AGD66 / AMG zone 54',NULL,NULL,'EPSG','4400','EPSG','4202','EPSG','17454','EPSG','1567',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20255','AGD66 / AMG zone 55',NULL,NULL,'EPSG','4400','EPSG','4202','EPSG','17455','EPSG','1568',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20256','AGD66 / AMG zone 56',NULL,NULL,'EPSG','4400','EPSG','4202','EPSG','17456','EPSG','2291',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20257','AGD66 / AMG zone 57',NULL,NULL,'EPSG','4400','EPSG','4202','EPSG','17457','EPSG','1565',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20258','AGD66 / AMG zone 58',NULL,NULL,'EPSG','4400','EPSG','4202','EPSG','17458','EPSG','1566',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20348','AGD84 / AMG zone 48',NULL,NULL,'EPSG','4400','EPSG','4203','EPSG','17448','EPSG','1556',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20349','AGD84 / AMG zone 49',NULL,NULL,'EPSG','4400','EPSG','4203','EPSG','17449','EPSG','1557',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20350','AGD84 / AMG zone 50',NULL,NULL,'EPSG','4400','EPSG','4203','EPSG','17450','EPSG','1558',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20351','AGD84 / AMG zone 51',NULL,NULL,'EPSG','4400','EPSG','4203','EPSG','17451','EPSG','1559',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20352','AGD84 / AMG zone 52',NULL,NULL,'EPSG','4400','EPSG','4203','EPSG','17452','EPSG','3687',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20353','AGD84 / AMG zone 53',NULL,NULL,'EPSG','4400','EPSG','4203','EPSG','17453','EPSG','3688',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20354','AGD84 / AMG zone 54',NULL,NULL,'EPSG','4400','EPSG','4203','EPSG','17454','EPSG','3689',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20355','AGD84 / AMG zone 55',NULL,NULL,'EPSG','4400','EPSG','4203','EPSG','17455','EPSG','3690',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20356','AGD84 / AMG zone 56',NULL,NULL,'EPSG','4400','EPSG','4203','EPSG','17456','EPSG','3691',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20357','AGD84 / AMG zone 57',NULL,NULL,'EPSG','4400','EPSG','4203','EPSG','17457','EPSG','1565',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20358','AGD84 / AMG zone 58',NULL,NULL,'EPSG','4400','EPSG','4203','EPSG','17458','EPSG','1566',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','20436','Ain el Abd / UTM zone 36N',NULL,NULL,'EPSG','4400','EPSG','4204','EPSG','16036','EPSG','3107',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20437','Ain el Abd / UTM zone 37N',NULL,NULL,'EPSG','4400','EPSG','4204','EPSG','16037','EPSG','1569',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20438','Ain el Abd / UTM zone 38N',NULL,NULL,'EPSG','4400','EPSG','4204','EPSG','16038','EPSG','1571',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20439','Ain el Abd / UTM zone 39N',NULL,NULL,'EPSG','4400','EPSG','4204','EPSG','16039','EPSG','1570',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20440','Ain el Abd / UTM zone 40N',NULL,NULL,'EPSG','4400','EPSG','4204','EPSG','16040','EPSG','3106',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20499','Ain el Abd / Bahrain Grid',NULL,NULL,'EPSG','4400','EPSG','4204','EPSG','19900','EPSG','3943',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20538','Afgooye / UTM zone 38N',NULL,NULL,'EPSG','4400','EPSG','4205','EPSG','16038','EPSG','1554',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20539','Afgooye / UTM zone 39N',NULL,NULL,'EPSG','4400','EPSG','4205','EPSG','16039','EPSG','1555',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20790','Lisbon (Lisbon) / Portuguese National Grid',NULL,NULL,'EPSG','4499','EPSG','4803','EPSG','19936','EPSG','1294',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20791','Lisbon (Lisbon) / Portuguese Grid',NULL,NULL,'EPSG','4499','EPSG','4803','EPSG','19969','EPSG','1294',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20822','Aratu / UTM zone 22S',NULL,NULL,'EPSG','4400','EPSG','4208','EPSG','16122','EPSG','1572',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20823','Aratu / UTM zone 23S',NULL,NULL,'EPSG','4400','EPSG','4208','EPSG','16123','EPSG','1573',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20824','Aratu / UTM zone 24S',NULL,NULL,'EPSG','4400','EPSG','4208','EPSG','16124','EPSG','1574',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20934','Arc 1950 / UTM zone 34S',NULL,NULL,'EPSG','4400','EPSG','4209','EPSG','16134','EPSG','1575',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20935','Arc 1950 / UTM zone 35S',NULL,NULL,'EPSG','4400','EPSG','4209','EPSG','16135','EPSG','1576',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','20936','Arc 1950 / UTM zone 36S',NULL,NULL,'EPSG','4400','EPSG','4209','EPSG','16136','EPSG','1577',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21035','Arc 1960 / UTM zone 35S',NULL,NULL,'EPSG','4400','EPSG','4210','EPSG','16135','EPSG','1579',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21036','Arc 1960 / UTM zone 36S',NULL,NULL,'EPSG','4400','EPSG','4210','EPSG','16136','EPSG','1581',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21037','Arc 1960 / UTM zone 37S',NULL,NULL,'EPSG','4400','EPSG','4210','EPSG','16137','EPSG','1583',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21095','Arc 1960 / UTM zone 35N',NULL,NULL,'EPSG','4400','EPSG','4210','EPSG','16035','EPSG','1578',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21096','Arc 1960 / UTM zone 36N',NULL,NULL,'EPSG','4400','EPSG','4210','EPSG','16036','EPSG','1580',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21097','Arc 1960 / UTM zone 37N',NULL,NULL,'EPSG','4400','EPSG','4210','EPSG','16037','EPSG','1582',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21100','Batavia (Jakarta) / NEIEZ',NULL,NULL,'EPSG','4499','EPSG','4813','EPSG','19905','EPSG','1285',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','21148','Batavia / UTM zone 48S',NULL,NULL,'EPSG','4400','EPSG','4211','EPSG','16148','EPSG','1584',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21149','Batavia / UTM zone 49S',NULL,NULL,'EPSG','4400','EPSG','4211','EPSG','16149','EPSG','1586',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21150','Batavia / UTM zone 50S',NULL,NULL,'EPSG','4400','EPSG','4211','EPSG','16150','EPSG','1585',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21291','Barbados 1938 / British West Indies Grid',NULL,NULL,'EPSG','4400','EPSG','4212','EPSG','19942','EPSG','3218',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21292','Barbados 1938 / Barbados National Grid',NULL,NULL,'EPSG','4400','EPSG','4212','EPSG','19943','EPSG','3218',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21413','Beijing 1954 / Gauss-Kruger zone 13',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16213','EPSG','1587',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21414','Beijing 1954 / Gauss-Kruger zone 14',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16214','EPSG','1588',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21415','Beijing 1954 / Gauss-Kruger zone 15',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16215','EPSG','1589',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21416','Beijing 1954 / Gauss-Kruger zone 16',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16216','EPSG','1590',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21417','Beijing 1954 / Gauss-Kruger zone 17',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16217','EPSG','1591',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21418','Beijing 1954 / Gauss-Kruger zone 18',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16218','EPSG','1592',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21419','Beijing 1954 / Gauss-Kruger zone 19',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16219','EPSG','1593',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21420','Beijing 1954 / Gauss-Kruger zone 20',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16220','EPSG','1594',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21421','Beijing 1954 / Gauss-Kruger zone 21',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16221','EPSG','1595',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21422','Beijing 1954 / Gauss-Kruger zone 22',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16222','EPSG','1596',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21423','Beijing 1954 / Gauss-Kruger zone 23',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16223','EPSG','1597',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21453','Beijing 1954 / Gauss-Kruger CM 75E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16313','EPSG','1587',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21454','Beijing 1954 / Gauss-Kruger CM 81E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16314','EPSG','1588',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21455','Beijing 1954 / Gauss-Kruger CM 87E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16315','EPSG','1589',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21456','Beijing 1954 / Gauss-Kruger CM 93E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16316','EPSG','1590',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21457','Beijing 1954 / Gauss-Kruger CM 99E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16317','EPSG','1591',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21458','Beijing 1954 / Gauss-Kruger CM 105E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16318','EPSG','1592',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21459','Beijing 1954 / Gauss-Kruger CM 111E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16319','EPSG','1593',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21460','Beijing 1954 / Gauss-Kruger CM 117E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16320','EPSG','1594',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21461','Beijing 1954 / Gauss-Kruger CM 123E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16321','EPSG','1595',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21462','Beijing 1954 / Gauss-Kruger CM 129E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16322','EPSG','1596',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21463','Beijing 1954 / Gauss-Kruger CM 135E',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16323','EPSG','1597',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21473','Beijing 1954 / Gauss-Kruger 13N',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16313','EPSG','1587',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','21474','Beijing 1954 / Gauss-Kruger 14N',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16314','EPSG','1588',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','21475','Beijing 1954 / Gauss-Kruger 15N',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16315','EPSG','1589',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','21476','Beijing 1954 / Gauss-Kruger 16N',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16316','EPSG','1590',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','21477','Beijing 1954 / Gauss-Kruger 17N',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16317','EPSG','1591',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','21478','Beijing 1954 / Gauss-Kruger 18N',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16318','EPSG','1592',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','21479','Beijing 1954 / Gauss-Kruger 19N',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16319','EPSG','1593',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','21480','Beijing 1954 / Gauss-Kruger 20N',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16320','EPSG','1594',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','21481','Beijing 1954 / Gauss-Kruger 21N',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16321','EPSG','1595',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','21482','Beijing 1954 / Gauss-Kruger 22N',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16322','EPSG','1596',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','21483','Beijing 1954 / Gauss-Kruger 23N',NULL,NULL,'EPSG','4530','EPSG','4214','EPSG','16323','EPSG','1597',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','21500','Belge 1950 (Brussels) / Belge Lambert 50',NULL,NULL,'EPSG','4499','EPSG','4809','EPSG','19901','EPSG','1347',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21780','Bern 1898 (Bern) / LV03C',NULL,NULL,'EPSG','4498','EPSG','4801','EPSG','19923','EPSG','1286',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21781','CH1903 / LV03',NULL,NULL,'EPSG','4498','EPSG','4149','EPSG','19922','EPSG','1286',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21782','CH1903 / LV03C-G',NULL,NULL,'EPSG','4498','EPSG','4149','EPSG','19841','EPSG','1144',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21817','Bogota 1975 / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4218','EPSG','16017','EPSG','1602',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','21818','Bogota 1975 / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4218','EPSG','16018','EPSG','1603',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21891','Bogota 1975 / Colombia West zone',NULL,NULL,'EPSG','4499','EPSG','4218','EPSG','18051','EPSG','1598',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','21892','Bogota 1975 / Colombia Bogota zone',NULL,NULL,'EPSG','4499','EPSG','4218','EPSG','18052','EPSG','1599',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','21893','Bogota 1975 / Colombia East Central zone',NULL,NULL,'EPSG','4499','EPSG','4218','EPSG','18053','EPSG','1600',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','21894','Bogota 1975 / Colombia East',NULL,NULL,'EPSG','4499','EPSG','4218','EPSG','18054','EPSG','1601',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','21896','Bogota 1975 / Colombia West zone',NULL,NULL,'EPSG','4530','EPSG','4218','EPSG','18051','EPSG','1598',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21897','Bogota 1975 / Colombia Bogota zone',NULL,NULL,'EPSG','4530','EPSG','4218','EPSG','18052','EPSG','1599',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21898','Bogota 1975 / Colombia East Central zone',NULL,NULL,'EPSG','4530','EPSG','4218','EPSG','18053','EPSG','1600',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','21899','Bogota 1975 / Colombia East zone',NULL,NULL,'EPSG','4530','EPSG','4218','EPSG','18054','EPSG','1601',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22032','Camacupa 1948 / UTM zone 32S',NULL,NULL,'EPSG','4400','EPSG','4220','EPSG','16132','EPSG','1606',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22033','Camacupa 1948 / UTM zone 33S',NULL,NULL,'EPSG','4400','EPSG','4220','EPSG','16133','EPSG','1607',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22091','Camacupa 1948 / TM 11.30 SE',NULL,NULL,'EPSG','4400','EPSG','4220','EPSG','16611','EPSG','1605',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22092','Camacupa 1948 / TM 12 SE',NULL,NULL,'EPSG','4400','EPSG','4220','EPSG','16612','EPSG','1604',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22171','POSGAR 98 / Argentina 1',NULL,NULL,'EPSG','4530','EPSG','4190','EPSG','18031','EPSG','1608',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22172','POSGAR 98 / Argentina 2',NULL,NULL,'EPSG','4530','EPSG','4190','EPSG','18032','EPSG','1609',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22173','POSGAR 98 / Argentina 3',NULL,NULL,'EPSG','4530','EPSG','4190','EPSG','18033','EPSG','1610',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22174','POSGAR 98 / Argentina 4',NULL,NULL,'EPSG','4530','EPSG','4190','EPSG','18034','EPSG','1611',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22175','POSGAR 98 / Argentina 5',NULL,NULL,'EPSG','4530','EPSG','4190','EPSG','18035','EPSG','1612',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22176','POSGAR 98 / Argentina 6',NULL,NULL,'EPSG','4530','EPSG','4190','EPSG','18036','EPSG','1613',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22177','POSGAR 98 / Argentina 7',NULL,NULL,'EPSG','4530','EPSG','4190','EPSG','18037','EPSG','1614',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22181','POSGAR 94 / Argentina 1',NULL,NULL,'EPSG','4530','EPSG','4694','EPSG','18031','EPSG','1608',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22182','POSGAR 94 / Argentina 2',NULL,NULL,'EPSG','4530','EPSG','4694','EPSG','18032','EPSG','1609',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22183','POSGAR 94 / Argentina 3',NULL,NULL,'EPSG','4530','EPSG','4694','EPSG','18033','EPSG','1610',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22184','POSGAR 94 / Argentina 4',NULL,NULL,'EPSG','4530','EPSG','4694','EPSG','18034','EPSG','1611',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22185','POSGAR 94 / Argentina 5',NULL,NULL,'EPSG','4530','EPSG','4694','EPSG','18035','EPSG','1612',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22186','POSGAR 94 / Argentina 6',NULL,NULL,'EPSG','4530','EPSG','4694','EPSG','18036','EPSG','1613',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22187','POSGAR 94 / Argentina 7',NULL,NULL,'EPSG','4530','EPSG','4694','EPSG','18037','EPSG','1614',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22191','Campo Inchauspe / Argentina 1',NULL,NULL,'EPSG','4530','EPSG','4221','EPSG','18031','EPSG','1608',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22192','Campo Inchauspe / Argentina 2',NULL,NULL,'EPSG','4530','EPSG','4221','EPSG','18032','EPSG','1609',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22193','Campo Inchauspe / Argentina 3',NULL,NULL,'EPSG','4530','EPSG','4221','EPSG','18033','EPSG','1610',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22194','Campo Inchauspe / Argentina 4',NULL,NULL,'EPSG','4530','EPSG','4221','EPSG','18034','EPSG','1611',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22195','Campo Inchauspe / Argentina 5',NULL,NULL,'EPSG','4530','EPSG','4221','EPSG','18035','EPSG','1612',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22196','Campo Inchauspe / Argentina 6',NULL,NULL,'EPSG','4530','EPSG','4221','EPSG','18036','EPSG','1613',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22197','Campo Inchauspe / Argentina 7',NULL,NULL,'EPSG','4530','EPSG','4221','EPSG','18037','EPSG','1614',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22234','Cape / UTM zone 34S',NULL,NULL,'EPSG','4400','EPSG','4222','EPSG','16134','EPSG','1615',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22235','Cape / UTM zone 35S',NULL,NULL,'EPSG','4400','EPSG','4222','EPSG','16135','EPSG','1617',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22236','Cape / UTM zone 36S',NULL,NULL,'EPSG','4400','EPSG','4222','EPSG','16136','EPSG','1616',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','22275','Cape / Lo15',NULL,NULL,'EPSG','6503','EPSG','4222','EPSG','17515','EPSG','1454',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22277','Cape / Lo17',NULL,NULL,'EPSG','6503','EPSG','4222','EPSG','17517','EPSG','1455',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22279','Cape / Lo19',NULL,NULL,'EPSG','6503','EPSG','4222','EPSG','17519','EPSG','1456',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22281','Cape / Lo21',NULL,NULL,'EPSG','6503','EPSG','4222','EPSG','17521','EPSG','1457',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22283','Cape / Lo23',NULL,NULL,'EPSG','6503','EPSG','4222','EPSG','17523','EPSG','1458',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22285','Cape / Lo25',NULL,NULL,'EPSG','6503','EPSG','4222','EPSG','17525','EPSG','1459',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22287','Cape / Lo27',NULL,NULL,'EPSG','6503','EPSG','4222','EPSG','17527','EPSG','1460',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22289','Cape / Lo29',NULL,NULL,'EPSG','6503','EPSG','4222','EPSG','17529','EPSG','1461',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22291','Cape / Lo31',NULL,NULL,'EPSG','6503','EPSG','4222','EPSG','17531','EPSG','1462',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22293','Cape / Lo33',NULL,NULL,'EPSG','6503','EPSG','4222','EPSG','17533','EPSG','1463',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22300','Carthage (Paris) / Tunisia Mining Grid',NULL,NULL,'EPSG','4406','EPSG','4816','EPSG','19937','EPSG','1618',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22332','Carthage / UTM zone 32N',NULL,NULL,'EPSG','4400','EPSG','4223','EPSG','16032','EPSG','1489',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22391','Carthage / Nord Tunisie',NULL,NULL,'EPSG','4499','EPSG','4223','EPSG','18181','EPSG','1619',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22392','Carthage / Sud Tunisie',NULL,NULL,'EPSG','4499','EPSG','4223','EPSG','18182','EPSG','1620',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22521','Corrego Alegre 1970-72 / UTM zone 21S',NULL,NULL,'EPSG','4400','EPSG','4225','EPSG','16121','EPSG','3355',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22522','Corrego Alegre 1970-72 / UTM zone 22S',NULL,NULL,'EPSG','4400','EPSG','4225','EPSG','16122','EPSG','3176',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22523','Corrego Alegre 1970-72 / UTM zone 23S',NULL,NULL,'EPSG','4400','EPSG','4225','EPSG','16123','EPSG','3177',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22524','Corrego Alegre 1970-72 / UTM zone 24S',NULL,NULL,'EPSG','4400','EPSG','4225','EPSG','16124','EPSG','1818',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22525','Corrego Alegre 1970-72 / UTM zone 25S',NULL,NULL,'EPSG','4400','EPSG','4225','EPSG','16125','EPSG','3178',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22700','Deir ez Zor / Levant Zone',NULL,NULL,'EPSG','4499','EPSG','4227','EPSG','19940','EPSG','1623',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22770','Deir ez Zor / Syria Lambert',NULL,NULL,'EPSG','4499','EPSG','4227','EPSG','19948','EPSG','1623',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22780','Deir ez Zor / Levant Stereographic',NULL,NULL,'EPSG','4499','EPSG','4227','EPSG','19949','EPSG','1623',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22832','Douala / UTM zone 32N',NULL,NULL,'EPSG','4400','EPSG','4228','EPSG','16032','EPSG','1060',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','22991','Egypt 1907 / Blue Belt',NULL,NULL,'EPSG','4400','EPSG','4229','EPSG','18071','EPSG','1642',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22992','Egypt 1907 / Red Belt',NULL,NULL,'EPSG','4400','EPSG','4229','EPSG','18072','EPSG','1643',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22993','Egypt 1907 / Purple Belt',NULL,NULL,'EPSG','4400','EPSG','4229','EPSG','18073','EPSG','1644',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','22994','Egypt 1907 / Extended Purple Belt',NULL,NULL,'EPSG','4400','EPSG','4229','EPSG','18074','EPSG','1645',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23028','ED50 / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4230','EPSG','16028','EPSG','1631',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23029','ED50 / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4230','EPSG','16029','EPSG','1632',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23030','ED50 / UTM zone 30N',NULL,NULL,'EPSG','4400','EPSG','4230','EPSG','16030','EPSG','1633',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23031','ED50 / UTM zone 31N',NULL,NULL,'EPSG','4400','EPSG','4230','EPSG','16031','EPSG','1634',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23032','ED50 / UTM zone 32N',NULL,NULL,'EPSG','4400','EPSG','4230','EPSG','16032','EPSG','1635',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23033','ED50 / UTM zone 33N',NULL,NULL,'EPSG','4400','EPSG','4230','EPSG','16033','EPSG','1636',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23034','ED50 / UTM zone 34N',NULL,NULL,'EPSG','4400','EPSG','4230','EPSG','16034','EPSG','1637',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23035','ED50 / UTM zone 35N',NULL,NULL,'EPSG','4400','EPSG','4230','EPSG','16035','EPSG','1638',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23036','ED50 / UTM zone 36N',NULL,NULL,'EPSG','4400','EPSG','4230','EPSG','16036','EPSG','1639',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23037','ED50 / UTM zone 37N',NULL,NULL,'EPSG','4400','EPSG','4230','EPSG','16037','EPSG','1640',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23038','ED50 / UTM zone 38N',NULL,NULL,'EPSG','4400','EPSG','4230','EPSG','16038','EPSG','1641',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23090','ED50 / TM 0 N',NULL,NULL,'EPSG','4400','EPSG','4230','EPSG','16400','EPSG','1629',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23095','ED50 / TM 5 NE',NULL,NULL,'EPSG','4400','EPSG','4230','EPSG','16405','EPSG','1630',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23239','Fahud / UTM zone 39N',NULL,NULL,'EPSG','4400','EPSG','4232','EPSG','16039','EPSG','1544',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23240','Fahud / UTM zone 40N',NULL,NULL,'EPSG','4400','EPSG','4232','EPSG','16040','EPSG','4008',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23433','Garoua / UTM zone 33N',NULL,NULL,'EPSG','4400','EPSG','4234','EPSG','16033','EPSG','1060',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','23700','HD72 / EOV',NULL,NULL,'EPSG','4498','EPSG','4237','EPSG','19931','EPSG','1119',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23830','DGN95 / Indonesia TM-3 zone 46.2',NULL,NULL,'EPSG','4499','EPSG','4755','EPSG','17432','EPSG','3976',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23831','DGN95 / Indonesia TM-3 zone 47.1',NULL,NULL,'EPSG','4499','EPSG','4755','EPSG','17433','EPSG','3510',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23832','DGN95 / Indonesia TM-3 zone 47.2',NULL,NULL,'EPSG','4499','EPSG','4755','EPSG','17434','EPSG','3511',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23833','DGN95 / Indonesia TM-3 zone 48.1',NULL,NULL,'EPSG','4499','EPSG','4755','EPSG','17435','EPSG','3512',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23834','DGN95 / Indonesia TM-3 zone 48.2',NULL,NULL,'EPSG','4499','EPSG','4755','EPSG','17436','EPSG','3513',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23835','DGN95 / Indonesia TM-3 zone 49.1',NULL,NULL,'EPSG','4499','EPSG','4755','EPSG','17437','EPSG','3514',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23836','DGN95 / Indonesia TM-3 zone 49.2',NULL,NULL,'EPSG','4499','EPSG','4755','EPSG','17438','EPSG','3515',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23837','DGN95 / Indonesia TM-3 zone 50.1',NULL,NULL,'EPSG','4499','EPSG','4755','EPSG','17439','EPSG','3516',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23838','DGN95 / Indonesia TM-3 zone 50.2',NULL,NULL,'EPSG','4499','EPSG','4755','EPSG','17440','EPSG','3517',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23839','DGN95 / Indonesia TM-3 zone 51.1',NULL,NULL,'EPSG','4499','EPSG','4755','EPSG','17441','EPSG','3518',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23840','DGN95 / Indonesia TM-3 zone 51.2',NULL,NULL,'EPSG','4499','EPSG','4755','EPSG','17442','EPSG','3519',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23841','DGN95 / Indonesia TM-3 zone 52.1',NULL,NULL,'EPSG','4499','EPSG','4755','EPSG','17443','EPSG','3520',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23842','DGN95 / Indonesia TM-3 zone 52.2',NULL,NULL,'EPSG','4499','EPSG','4755','EPSG','17444','EPSG','3521',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23843','DGN95 / Indonesia TM-3 zone 53.1',NULL,NULL,'EPSG','4499','EPSG','4755','EPSG','17445','EPSG','3522',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23844','DGN95 / Indonesia TM-3 zone 53.2',NULL,NULL,'EPSG','4499','EPSG','4755','EPSG','17446','EPSG','3523',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23845','DGN95 / Indonesia TM-3 zone 54.1',NULL,NULL,'EPSG','4499','EPSG','4755','EPSG','17447','EPSG','3975',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23846','ID74 / UTM zone 46N',NULL,NULL,'EPSG','4400','EPSG','4238','EPSG','16046','EPSG','3976',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23847','ID74 / UTM zone 47N',NULL,NULL,'EPSG','4400','EPSG','4238','EPSG','16047','EPSG','3978',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23848','ID74 / UTM zone 48N',NULL,NULL,'EPSG','4400','EPSG','4238','EPSG','16048','EPSG','3979',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23849','ID74 / UTM zone 49N',NULL,NULL,'EPSG','4400','EPSG','4238','EPSG','16049','EPSG','3980',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23850','ID74 / UTM zone 50N',NULL,NULL,'EPSG','4400','EPSG','4238','EPSG','16050','EPSG','3981',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23851','ID74 / UTM zone 51N',NULL,NULL,'EPSG','4400','EPSG','4238','EPSG','16051','EPSG','3983',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23852','ID74 / UTM zone 52N',NULL,NULL,'EPSG','4400','EPSG','4238','EPSG','16052','EPSG','3984',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23853','ID74 / UTM zone 53N',NULL,NULL,'EPSG','4400','EPSG','4238','EPSG','16053','EPSG','1661',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','23866','DGN95 / UTM zone 46N',NULL,NULL,'EPSG','4400','EPSG','4755','EPSG','16046','EPSG','1647',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23867','DGN95 / UTM zone 47N',NULL,NULL,'EPSG','4400','EPSG','4755','EPSG','16047','EPSG','1649',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23868','DGN95 / UTM zone 48N',NULL,NULL,'EPSG','4400','EPSG','4755','EPSG','16048','EPSG','1651',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23869','DGN95 / UTM zone 49N',NULL,NULL,'EPSG','4400','EPSG','4755','EPSG','16049','EPSG','1653',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23870','DGN95 / UTM zone 50N',NULL,NULL,'EPSG','4400','EPSG','4755','EPSG','16050','EPSG','1655',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23871','DGN95 / UTM zone 51N',NULL,NULL,'EPSG','4400','EPSG','4755','EPSG','16051','EPSG','1657',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23872','DGN95 / UTM zone 52N',NULL,NULL,'EPSG','4400','EPSG','4755','EPSG','16052','EPSG','1659',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23877','DGN95 / UTM zone 47S',NULL,NULL,'EPSG','4400','EPSG','4755','EPSG','16147','EPSG','1650',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23878','DGN95 / UTM zone 48S',NULL,NULL,'EPSG','4400','EPSG','4755','EPSG','16148','EPSG','1652',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23879','DGN95 / UTM zone 49S',NULL,NULL,'EPSG','4400','EPSG','4755','EPSG','16149','EPSG','1654',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23880','DGN95 / UTM zone 50S',NULL,NULL,'EPSG','4400','EPSG','4755','EPSG','16150','EPSG','1656',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23881','DGN95 / UTM zone 51S',NULL,NULL,'EPSG','4400','EPSG','4755','EPSG','16151','EPSG','1658',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23882','DGN95 / UTM zone 52S',NULL,NULL,'EPSG','4400','EPSG','4755','EPSG','16152','EPSG','1660',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23883','DGN95 / UTM zone 53S',NULL,NULL,'EPSG','4400','EPSG','4755','EPSG','16153','EPSG','1662',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23884','DGN95 / UTM zone 54S',NULL,NULL,'EPSG','4400','EPSG','4755','EPSG','16154','EPSG','1663',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23886','ID74 / UTM zone 46S',NULL,NULL,'EPSG','4400','EPSG','4238','EPSG','16146','EPSG','1648',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','23887','ID74 / UTM zone 47S',NULL,NULL,'EPSG','4400','EPSG','4238','EPSG','16147','EPSG','3985',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23888','ID74 / UTM zone 48S',NULL,NULL,'EPSG','4400','EPSG','4238','EPSG','16148','EPSG','3986',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23889','ID74 / UTM zone 49S',NULL,NULL,'EPSG','4400','EPSG','4238','EPSG','16149','EPSG','3987',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23890','ID74 / UTM zone 50S',NULL,NULL,'EPSG','4400','EPSG','4238','EPSG','16150','EPSG','3988',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23891','ID74 / UTM zone 51S',NULL,NULL,'EPSG','4400','EPSG','4238','EPSG','16151','EPSG','3989',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23892','ID74 / UTM zone 52S',NULL,NULL,'EPSG','4400','EPSG','4238','EPSG','16152','EPSG','3990',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23893','ID74 / UTM zone 53S',NULL,NULL,'EPSG','4400','EPSG','4238','EPSG','16153','EPSG','3991',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23894','ID74 / UTM zone 54S',NULL,NULL,'EPSG','4400','EPSG','4238','EPSG','16154','EPSG','3975',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23946','Indian 1954 / UTM zone 46N',NULL,NULL,'EPSG','4400','EPSG','4239','EPSG','16046','EPSG','1664',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23947','Indian 1954 / UTM zone 47N',NULL,NULL,'EPSG','4400','EPSG','4239','EPSG','16047','EPSG','1665',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','23948','Indian 1954 / UTM zone 48N',NULL,NULL,'EPSG','4400','EPSG','4239','EPSG','16048','EPSG','3735',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24047','Indian 1975 / UTM zone 47N',NULL,NULL,'EPSG','4400','EPSG','4240','EPSG','16047','EPSG','1667',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24048','Indian 1975 / UTM zone 48N',NULL,NULL,'EPSG','4400','EPSG','4240','EPSG','16048','EPSG','1666',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24100','Jamaica 1875 / Jamaica (Old Grid)',NULL,NULL,'EPSG','4403','EPSG','4241','EPSG','19909','EPSG','3342',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24200','JAD69 / Jamaica National Grid',NULL,NULL,'EPSG','4400','EPSG','4242','EPSG','19910','EPSG','3342',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24305','Kalianpur 1937 / UTM zone 45N',NULL,NULL,'EPSG','4400','EPSG','4144','EPSG','16045','EPSG','1674',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24306','Kalianpur 1937 / UTM zone 46N',NULL,NULL,'EPSG','4400','EPSG','4144','EPSG','16046','EPSG','1675',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24311','Kalianpur 1962 / UTM zone 41N',NULL,NULL,'EPSG','4400','EPSG','4145','EPSG','16041','EPSG','1687',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24312','Kalianpur 1962 / UTM zone 42N',NULL,NULL,'EPSG','4400','EPSG','4145','EPSG','16042','EPSG','1688',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24313','Kalianpur 1962 / UTM zone 43N',NULL,NULL,'EPSG','4400','EPSG','4145','EPSG','16043','EPSG','1689',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24342','Kalianpur 1975 / UTM zone 42N',NULL,NULL,'EPSG','4400','EPSG','4146','EPSG','16042','EPSG','1679',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24343','Kalianpur 1975 / UTM zone 43N',NULL,NULL,'EPSG','4400','EPSG','4146','EPSG','16043','EPSG','1680',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24344','Kalianpur 1975 / UTM zone 44N',NULL,NULL,'EPSG','4400','EPSG','4146','EPSG','16044','EPSG','1681',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24345','Kalianpur 1975 / UTM zone 45N',NULL,NULL,'EPSG','4400','EPSG','4146','EPSG','16045','EPSG','1682',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24346','Kalianpur 1975 / UTM zone 46N',NULL,NULL,'EPSG','4400','EPSG','4146','EPSG','16046','EPSG','1683',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24347','Kalianpur 1975 / UTM zone 47N',NULL,NULL,'EPSG','4400','EPSG','4146','EPSG','16047','EPSG','1684',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24370','Kalianpur 1880 / India zone 0',NULL,NULL,'EPSG','4408','EPSG','4243','EPSG','18110','EPSG','1668',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24371','Kalianpur 1880 / India zone I',NULL,NULL,'EPSG','4408','EPSG','4243','EPSG','18111','EPSG','1669',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24372','Kalianpur 1880 / India zone IIa',NULL,NULL,'EPSG','4408','EPSG','4243','EPSG','18112','EPSG','1670',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24373','Kalianpur 1880 / India zone IIIa',NULL,NULL,'EPSG','4408','EPSG','4243','EPSG','18114','EPSG','1672',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24374','Kalianpur 1880 / India zone IVa',NULL,NULL,'EPSG','4408','EPSG','4243','EPSG','18116','EPSG','1673',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24375','Kalianpur 1937 / India zone IIb',NULL,NULL,'EPSG','4400','EPSG','4144','EPSG','18238','EPSG','3217',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24376','Kalianpur 1962 / India zone I',NULL,NULL,'EPSG','4400','EPSG','4145','EPSG','18236','EPSG','1685',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24377','Kalianpur 1962 / India zone IIa',NULL,NULL,'EPSG','4400','EPSG','4145','EPSG','18237','EPSG','1686',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24378','Kalianpur 1975 / India zone I',NULL,NULL,'EPSG','4400','EPSG','4146','EPSG','18231','EPSG','1676',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24379','Kalianpur 1975 / India zone IIa',NULL,NULL,'EPSG','4400','EPSG','4146','EPSG','18232','EPSG','1677',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24380','Kalianpur 1975 / India zone IIb',NULL,NULL,'EPSG','4400','EPSG','4146','EPSG','18235','EPSG','1678',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24381','Kalianpur 1975 / India zone IIIa',NULL,NULL,'EPSG','4400','EPSG','4146','EPSG','18233','EPSG','1672',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24382','Kalianpur 1880 / India zone IIb',NULL,NULL,'EPSG','4408','EPSG','4243','EPSG','18113','EPSG','1671',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24383','Kalianpur 1975 / India zone IVa',NULL,NULL,'EPSG','4400','EPSG','4146','EPSG','18234','EPSG','1673',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24500','Kertau 1968 / Singapore Grid',NULL,NULL,'EPSG','4400','EPSG','4245','EPSG','19920','EPSG','1210',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24547','Kertau 1968 / UTM zone 47N',NULL,NULL,'EPSG','4400','EPSG','4245','EPSG','16047','EPSG','1691',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24548','Kertau 1968 / UTM zone 48N',NULL,NULL,'EPSG','4400','EPSG','4245','EPSG','16048','EPSG','1692',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24571','Kertau / R.S.O. Malaya (ch)',NULL,NULL,'EPSG','4401','EPSG','4245','EPSG','19935','EPSG','1690',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','24600','KOC Lambert',NULL,NULL,'EPSG','4400','EPSG','4246','EPSG','19906','EPSG','3267',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24718','La Canoa / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4247','EPSG','16018','EPSG','1693',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24719','La Canoa / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4247','EPSG','16019','EPSG','1694',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24720','La Canoa / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4247','EPSG','16020','EPSG','1695',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24817','PSAD56 / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4248','EPSG','16017','EPSG','3112',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24818','PSAD56 / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4248','EPSG','16018','EPSG','1756',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24819','PSAD56 / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4248','EPSG','16019','EPSG','1758',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24820','PSAD56 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4248','EPSG','16020','EPSG','1760',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24821','PSAD56 / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4248','EPSG','16021','EPSG','1762',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24877','PSAD56 / UTM zone 17S',NULL,NULL,'EPSG','4400','EPSG','4248','EPSG','16117','EPSG','1755',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24878','PSAD56 / UTM zone 18S',NULL,NULL,'EPSG','4400','EPSG','4248','EPSG','16118','EPSG','1757',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24879','PSAD56 / UTM zone 19S',NULL,NULL,'EPSG','4400','EPSG','4248','EPSG','16119','EPSG','1759',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24880','PSAD56 / UTM zone 20S',NULL,NULL,'EPSG','4400','EPSG','4248','EPSG','16120','EPSG','1761',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24881','PSAD56 / UTM zone 21S',NULL,NULL,'EPSG','4400','EPSG','4248','EPSG','16121','EPSG','3733',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24882','PSAD56 / UTM zone 22S',NULL,NULL,'EPSG','4400','EPSG','4248','EPSG','16122','EPSG','1754',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24891','PSAD56 / Peru west zone',NULL,NULL,'EPSG','4499','EPSG','4248','EPSG','18161','EPSG','1753',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24892','PSAD56 / Peru central zone',NULL,NULL,'EPSG','4499','EPSG','4248','EPSG','18162','EPSG','1752',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','24893','PSAD56 / Peru east zone',NULL,NULL,'EPSG','4499','EPSG','4248','EPSG','18163','EPSG','1751',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25000','Leigon / Ghana Metre Grid',NULL,NULL,'EPSG','4400','EPSG','4250','EPSG','19904','EPSG','1104',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25231','Lome / UTM zone 31N',NULL,NULL,'EPSG','4400','EPSG','4252','EPSG','16031','EPSG','1232',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25391','Luzon 1911 / Philippines zone I',NULL,NULL,'EPSG','4499','EPSG','4253','EPSG','18171','EPSG','3958',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25392','Luzon 1911 / Philippines zone II',NULL,NULL,'EPSG','4499','EPSG','4253','EPSG','18172','EPSG','3964',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25393','Luzon 1911 / Philippines zone III',NULL,NULL,'EPSG','4499','EPSG','4253','EPSG','18173','EPSG','3965',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25394','Luzon 1911 / Philippines zone IV',NULL,NULL,'EPSG','4499','EPSG','4253','EPSG','18174','EPSG','3966',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25395','Luzon 1911 / Philippines zone V',NULL,NULL,'EPSG','4499','EPSG','4253','EPSG','18175','EPSG','3967',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25700','Makassar (Jakarta) / NEIEZ',NULL,NULL,'EPSG','4499','EPSG','4804','EPSG','19905','EPSG','1316',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','25828','ETRS89 / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','16028','EPSG','2122',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25829','ETRS89 / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','16029','EPSG','2123',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25830','ETRS89 / UTM zone 30N',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','16030','EPSG','2124',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25831','ETRS89 / UTM zone 31N',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','16031','EPSG','2125',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25832','ETRS89 / UTM zone 32N',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','16032','EPSG','2126',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25833','ETRS89 / UTM zone 33N',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','16033','EPSG','2127',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25834','ETRS89 / UTM zone 34N',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','16034','EPSG','2128',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25835','ETRS89 / UTM zone 35N',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','16035','EPSG','2129',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25836','ETRS89 / UTM zone 36N',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','16036','EPSG','2130',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25837','ETRS89 / UTM zone 37N',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','16037','EPSG','2131',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25838','ETRS89 / UTM zone 38N',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','16038','EPSG','2132',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','25884','ETRS89 / TM Baltic93',NULL,NULL,'EPSG','4530','EPSG','4258','EPSG','19939','EPSG','1646',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','25932','Malongo 1987 / UTM zone 32S',NULL,NULL,'EPSG','4400','EPSG','4259','EPSG','16132','EPSG','3180',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26191','Merchich / Nord Maroc',NULL,NULL,'EPSG','4499','EPSG','4261','EPSG','18131','EPSG','1703',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26192','Merchich / Sud Maroc',NULL,NULL,'EPSG','4499','EPSG','4261','EPSG','18132','EPSG','2787',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26193','Merchich / Sahara',NULL,NULL,'EPSG','4499','EPSG','4261','EPSG','18133','EPSG','1705',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26194','Merchich / Sahara Nord',NULL,NULL,'EPSG','4499','EPSG','4261','EPSG','18134','EPSG','2788',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26195','Merchich / Sahara Sud',NULL,NULL,'EPSG','4499','EPSG','4261','EPSG','18135','EPSG','2789',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26237','Massawa / UTM zone 37N',NULL,NULL,'EPSG','4400','EPSG','4262','EPSG','16037','EPSG','1089',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26331','Minna / UTM zone 31N',NULL,NULL,'EPSG','4400','EPSG','4263','EPSG','16031','EPSG','1716',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26332','Minna / UTM zone 32N',NULL,NULL,'EPSG','4400','EPSG','4263','EPSG','16032','EPSG','3812',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26391','Minna / Nigeria West Belt',NULL,NULL,'EPSG','4400','EPSG','4263','EPSG','18151','EPSG','1715',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26392','Minna / Nigeria Mid Belt',NULL,NULL,'EPSG','4400','EPSG','4263','EPSG','18152','EPSG','1714',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26393','Minna / Nigeria East Belt',NULL,NULL,'EPSG','4400','EPSG','4263','EPSG','18153','EPSG','1713',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26432','Mhast / UTM zone 32S',NULL,NULL,'EPSG','4400','EPSG','4264','EPSG','16132','EPSG','1318',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26591','Monte Mario (Rome) / Italy zone 1',NULL,NULL,'EPSG','4499','EPSG','4806','EPSG','18121','EPSG','1718',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26592','Monte Mario (Rome) / Italy zone 2',NULL,NULL,'EPSG','4499','EPSG','4806','EPSG','18122','EPSG','1719',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26632','M''poraloko / UTM zone 32N',NULL,NULL,'EPSG','4400','EPSG','4266','EPSG','16032','EPSG','1696',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26692','M''poraloko / UTM zone 32S',NULL,NULL,'EPSG','4400','EPSG','4266','EPSG','16132','EPSG','1697',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26701','NAD27 / UTM zone 1N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16001','EPSG','3374',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26702','NAD27 / UTM zone 2N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16002','EPSG','3375',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26703','NAD27 / UTM zone 3N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16003','EPSG','2133',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26704','NAD27 / UTM zone 4N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16004','EPSG','2134',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26705','NAD27 / UTM zone 5N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16005','EPSG','2135',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26706','NAD27 / UTM zone 6N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16006','EPSG','2136',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26707','NAD27 / UTM zone 7N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16007','EPSG','2137',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26708','NAD27 / UTM zone 8N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16008','EPSG','2138',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26709','NAD27 / UTM zone 9N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16009','EPSG','2139',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26710','NAD27 / UTM zone 10N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16010','EPSG','2140',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26711','NAD27 / UTM zone 11N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16011','EPSG','2141',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26712','NAD27 / UTM zone 12N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16012','EPSG','2142',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26713','NAD27 / UTM zone 13N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16013','EPSG','2143',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26714','NAD27 / UTM zone 14N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16014','EPSG','2144',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26715','NAD27 / UTM zone 15N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16015','EPSG','2145',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26716','NAD27 / UTM zone 16N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16016','EPSG','2146',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26717','NAD27 / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16017','EPSG','2147',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26718','NAD27 / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16018','EPSG','2148',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26719','NAD27 / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16019','EPSG','2149',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26720','NAD27 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16020','EPSG','2150',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26721','NAD27 / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16021','EPSG','3891',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26722','NAD27 / UTM zone 22N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16022','EPSG','2152',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26729','NAD27 / Alabama East',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10101','EPSG','2154',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26730','NAD27 / Alabama West',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10102','EPSG','2155',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26731','NAD27 / Alaska zone 1',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15001','EPSG','2156',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26732','NAD27 / Alaska zone 2',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15002','EPSG','2158',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26733','NAD27 / Alaska zone 3',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15003','EPSG','2159',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26734','NAD27 / Alaska zone 4',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15004','EPSG','2160',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26735','NAD27 / Alaska zone 5',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15005','EPSG','2161',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26736','NAD27 / Alaska zone 6',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15006','EPSG','2162',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26737','NAD27 / Alaska zone 7',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15007','EPSG','2163',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26738','NAD27 / Alaska zone 8',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15008','EPSG','2164',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26739','NAD27 / Alaska zone 9',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15009','EPSG','2165',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26740','NAD27 / Alaska zone 10',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15010','EPSG','2157',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26741','NAD27 / California zone I',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10401','EPSG','2175',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26742','NAD27 / California zone II',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10402','EPSG','2176',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26743','NAD27 / California zone III',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10403','EPSG','2177',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26744','NAD27 / California zone IV',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10404','EPSG','2178',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26745','NAD27 / California zone V',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10405','EPSG','2179',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26746','NAD27 / California zone VI',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10406','EPSG','2180',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26747','NAD27 / California zone VII',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10407','EPSG','2181',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26748','NAD27 / Arizona East',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10201','EPSG','2167',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26749','NAD27 / Arizona Central',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10202','EPSG','2166',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26750','NAD27 / Arizona West',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10203','EPSG','2168',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26751','NAD27 / Arkansas North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10301','EPSG','2169',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26752','NAD27 / Arkansas South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10302','EPSG','2170',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26753','NAD27 / Colorado North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10501','EPSG','2184',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26754','NAD27 / Colorado Central',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10502','EPSG','2183',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26755','NAD27 / Colorado South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10503','EPSG','2185',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26756','NAD27 / Connecticut',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10600','EPSG','1377',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26757','NAD27 / Delaware',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10700','EPSG','1378',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26758','NAD27 / Florida East',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10901','EPSG','2186',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26759','NAD27 / Florida West',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10902','EPSG','2188',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26760','NAD27 / Florida North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10903','EPSG','2187',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26766','NAD27 / Georgia East',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11001','EPSG','2189',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26767','NAD27 / Georgia West',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11002','EPSG','2190',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26768','NAD27 / Idaho East',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11101','EPSG','2192',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26769','NAD27 / Idaho Central',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11102','EPSG','2191',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26770','NAD27 / Idaho West',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11103','EPSG','2193',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26771','NAD27 / Illinois East',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11201','EPSG','2194',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26772','NAD27 / Illinois West',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11202','EPSG','2195',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26773','NAD27 / Indiana East',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11301','EPSG','2196',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26774','NAD27 / Indiana West',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11302','EPSG','2197',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26775','NAD27 / Iowa North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11401','EPSG','2198',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26776','NAD27 / Iowa South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11402','EPSG','2199',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26777','NAD27 / Kansas North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11501','EPSG','2200',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26778','NAD27 / Kansas South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11502','EPSG','2201',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26779','NAD27 / Kentucky North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11601','EPSG','2202',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26780','NAD27 / Kentucky South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11602','EPSG','2203',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26781','NAD27 / Louisiana North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11701','EPSG','2204',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26782','NAD27 / Louisiana South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11702','EPSG','2205',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26783','NAD27 / Maine East',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11801','EPSG','2206',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26784','NAD27 / Maine West',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11802','EPSG','2207',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26785','NAD27 / Maryland',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11900','EPSG','1389',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26786','NAD27 / Massachusetts Mainland',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12001','EPSG','2209',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26787','NAD27 / Massachusetts Island',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12002','EPSG','2208',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26791','NAD27 / Minnesota North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12201','EPSG','2214',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26792','NAD27 / Minnesota Central',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12202','EPSG','2213',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26793','NAD27 / Minnesota South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12203','EPSG','2215',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26794','NAD27 / Mississippi East',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12301','EPSG','2216',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26795','NAD27 / Mississippi West',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12302','EPSG','2217',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26796','NAD27 / Missouri East',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12401','EPSG','2219',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26797','NAD27 / Missouri Central',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12402','EPSG','2218',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26798','NAD27 / Missouri West',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12403','EPSG','2220',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26799','NAD27 / California zone VII',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','10408','EPSG','2181',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26801','NAD Michigan / Michigan East',NULL,NULL,'EPSG','4497','EPSG','4268','EPSG','12101','EPSG','1720',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26802','NAD Michigan / Michigan Old Central',NULL,NULL,'EPSG','4497','EPSG','4268','EPSG','12102','EPSG','1721',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26803','NAD Michigan / Michigan West',NULL,NULL,'EPSG','4497','EPSG','4268','EPSG','12103','EPSG','3652',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26811','NAD Michigan / Michigan North',NULL,NULL,'EPSG','4497','EPSG','4268','EPSG','12111','EPSG','1723',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26812','NAD Michigan / Michigan Central',NULL,NULL,'EPSG','4497','EPSG','4268','EPSG','12112','EPSG','1724',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26813','NAD Michigan / Michigan South',NULL,NULL,'EPSG','4497','EPSG','4268','EPSG','12113','EPSG','1725',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26814','NAD83 / Maine East (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11833','EPSG','2206',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26815','NAD83 / Maine West (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11834','EPSG','2207',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26819','NAD83 / Minnesota North (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12234','EPSG','2214',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26820','NAD83 / Minnesota Central (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12235','EPSG','2213',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26821','NAD83 / Minnesota South (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12236','EPSG','2215',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26822','NAD83 / Nebraska (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15396','EPSG','1396',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26823','NAD83 / West Virginia North (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14733','EPSG','2264',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26824','NAD83 / West Virginia South (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14734','EPSG','2265',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26825','NAD83(HARN) / Maine East (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11833','EPSG','2206',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26826','NAD83(HARN) / Maine West (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','11834','EPSG','2207',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26830','NAD83(HARN) / Minnesota North (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12234','EPSG','2214',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26831','NAD83(HARN) / Minnesota Central (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12235','EPSG','2213',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26832','NAD83(HARN) / Minnesota South (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','12236','EPSG','2215',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26833','NAD83(HARN) / Nebraska (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','15396','EPSG','1396',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26834','NAD83(HARN) / West Virginia North (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14733','EPSG','2264',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26835','NAD83(HARN) / West Virginia South (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4152','EPSG','14734','EPSG','2265',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26836','NAD83(NSRS2007) / Maine East (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11833','EPSG','2206',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26837','NAD83(NSRS2007) / Maine West (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','11834','EPSG','2207',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26841','NAD83(NSRS2007) / Minnesota North (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12234','EPSG','2214',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26842','NAD83(NSRS2007) / Minnesota Central (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12235','EPSG','2213',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26843','NAD83(NSRS2007) / Minnesota South (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','12236','EPSG','2215',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26844','NAD83(NSRS2007) / Nebraska (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','15396','EPSG','1396',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26845','NAD83(NSRS2007) / West Virginia North (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14733','EPSG','2264',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26846','NAD83(NSRS2007) / West Virginia South (ftUS)',NULL,NULL,'EPSG','4499','EPSG','4759','EPSG','14734','EPSG','2265',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26847','NAD83 / Maine East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','11833','EPSG','2206',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26848','NAD83 / Maine West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','11834','EPSG','2207',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26849','NAD83 / Minnesota North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','12234','EPSG','2214',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26850','NAD83 / Minnesota Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','12235','EPSG','2213',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26851','NAD83 / Minnesota South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','12236','EPSG','2215',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26852','NAD83 / Nebraska (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15396','EPSG','1396',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26853','NAD83 / West Virginia North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','14735','EPSG','2264',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26854','NAD83 / West Virginia South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','14736','EPSG','2265',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26855','NAD83(HARN) / Maine East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','11833','EPSG','2206',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26856','NAD83(HARN) / Maine West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','11834','EPSG','2207',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26857','NAD83(HARN) / Minnesota North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','12234','EPSG','2214',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26858','NAD83(HARN) / Minnesota Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','12235','EPSG','2213',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26859','NAD83(HARN) / Minnesota South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','12236','EPSG','2215',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26860','NAD83(HARN) / Nebraska (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','15396','EPSG','1396',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26861','NAD83(HARN) / West Virginia North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','14735','EPSG','2264',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26862','NAD83(HARN) / West Virginia South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4152','EPSG','14736','EPSG','2265',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26863','NAD83(NSRS2007) / Maine East (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','11833','EPSG','2206',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26864','NAD83(NSRS2007) / Maine West (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','11834','EPSG','2207',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26865','NAD83(NSRS2007) / Minnesota North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','12234','EPSG','2214',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26866','NAD83(NSRS2007) / Minnesota Central (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','12235','EPSG','2213',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26867','NAD83(NSRS2007) / Minnesota South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','12236','EPSG','2215',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26868','NAD83(NSRS2007) / Nebraska (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','15396','EPSG','1396',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26869','NAD83(NSRS2007) / West Virginia North (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','14735','EPSG','2264',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26870','NAD83(NSRS2007) / West Virginia South (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4759','EPSG','14736','EPSG','2265',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26891','NAD83(CSRS) / MTM zone 11',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','17711','EPSG','1432',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26892','NAD83(CSRS) / MTM zone 12',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','17712','EPSG','1433',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26893','NAD83(CSRS) / MTM zone 13',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','17713','EPSG','1434',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26894','NAD83(CSRS) / MTM zone 14',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','17714','EPSG','1435',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26895','NAD83(CSRS) / MTM zone 15',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','17715','EPSG','1436',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26896','NAD83(CSRS) / MTM zone 16',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','17716','EPSG','1437',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26897','NAD83(CSRS) / MTM zone 17',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','17717','EPSG','1438',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26898','NAD83(CSRS) / MTM zone 1',NULL,NULL,'EPSG','4496','EPSG','4617','EPSG','17701','EPSG','2226',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26899','NAD83(CSRS) / MTM zone 2',NULL,NULL,'EPSG','4496','EPSG','4617','EPSG','17702','EPSG','2227',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26901','NAD83 / UTM zone 1N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16001','EPSG','3374',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26902','NAD83 / UTM zone 2N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16002','EPSG','3375',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26903','NAD83 / UTM zone 3N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16003','EPSG','2133',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26904','NAD83 / UTM zone 4N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16004','EPSG','3489',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26905','NAD83 / UTM zone 5N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16005','EPSG','3492',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26906','NAD83 / UTM zone 6N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16006','EPSG','2136',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26907','NAD83 / UTM zone 7N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16007','EPSG','3872',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26908','NAD83 / UTM zone 8N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16008','EPSG','3867',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26909','NAD83 / UTM zone 9N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16009','EPSG','3866',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26910','NAD83 / UTM zone 10N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16010','EPSG','3864',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26911','NAD83 / UTM zone 11N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16011','EPSG','3404',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26912','NAD83 / UTM zone 12N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16012','EPSG','3405',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26913','NAD83 / UTM zone 13N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16013','EPSG','3406',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26914','NAD83 / UTM zone 14N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16014','EPSG','3407',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26915','NAD83 / UTM zone 15N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16015','EPSG','3114',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26916','NAD83 / UTM zone 16N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16016','EPSG','3115',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26917','NAD83 / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16017','EPSG','3116',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26918','NAD83 / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16018','EPSG','3117',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26919','NAD83 / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16019','EPSG','3419',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26920','NAD83 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16020','EPSG','3420',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26921','NAD83 / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16021','EPSG','2151',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26922','NAD83 / UTM zone 22N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16022','EPSG','2152',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26923','NAD83 / UTM zone 23N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16023','EPSG','2153',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26929','NAD83 / Alabama East',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10131','EPSG','2154',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26930','NAD83 / Alabama West',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10132','EPSG','2155',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26931','NAD83 / Alaska zone 1',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15031','EPSG','2156',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26932','NAD83 / Alaska zone 2',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15032','EPSG','2158',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26933','NAD83 / Alaska zone 3',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15033','EPSG','2159',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26934','NAD83 / Alaska zone 4',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15034','EPSG','2160',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26935','NAD83 / Alaska zone 5',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15035','EPSG','2161',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26936','NAD83 / Alaska zone 6',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15036','EPSG','2162',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26937','NAD83 / Alaska zone 7',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15037','EPSG','2163',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26938','NAD83 / Alaska zone 8',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15038','EPSG','2164',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26939','NAD83 / Alaska zone 9',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15039','EPSG','2165',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26940','NAD83 / Alaska zone 10',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15040','EPSG','2157',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26941','NAD83 / California zone 1',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10431','EPSG','2175',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26942','NAD83 / California zone 2',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10432','EPSG','2176',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26943','NAD83 / California zone 3',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10433','EPSG','2177',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26944','NAD83 / California zone 4',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10434','EPSG','2178',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26945','NAD83 / California zone 5',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10435','EPSG','2182',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26946','NAD83 / California zone 6',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10436','EPSG','2180',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26948','NAD83 / Arizona East',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10231','EPSG','2167',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26949','NAD83 / Arizona Central',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10232','EPSG','2166',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26950','NAD83 / Arizona West',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10233','EPSG','2168',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26951','NAD83 / Arkansas North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10331','EPSG','2169',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26952','NAD83 / Arkansas South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10332','EPSG','2170',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26953','NAD83 / Colorado North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10531','EPSG','2184',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26954','NAD83 / Colorado Central',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10532','EPSG','2183',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26955','NAD83 / Colorado South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10533','EPSG','2185',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26956','NAD83 / Connecticut',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10630','EPSG','1377',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26957','NAD83 / Delaware',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10730','EPSG','1378',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26958','NAD83 / Florida East',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10931','EPSG','2186',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26959','NAD83 / Florida West',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10932','EPSG','2188',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26960','NAD83 / Florida North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','10933','EPSG','2187',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26961','NAD83 / Hawaii zone 1',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15131','EPSG','1546',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26962','NAD83 / Hawaii zone 2',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15132','EPSG','1547',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26963','NAD83 / Hawaii zone 3',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15133','EPSG','1548',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26964','NAD83 / Hawaii zone 4',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15134','EPSG','1549',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26965','NAD83 / Hawaii zone 5',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15135','EPSG','1550',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26966','NAD83 / Georgia East',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11031','EPSG','2189',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26967','NAD83 / Georgia West',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11032','EPSG','2190',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26968','NAD83 / Idaho East',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11131','EPSG','2192',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26969','NAD83 / Idaho Central',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11132','EPSG','2191',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26970','NAD83 / Idaho West',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11133','EPSG','2193',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26971','NAD83 / Illinois East',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11231','EPSG','2194',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26972','NAD83 / Illinois West',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11232','EPSG','2195',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26973','NAD83 / Indiana East',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11331','EPSG','2196',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26974','NAD83 / Indiana West',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11332','EPSG','2197',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26975','NAD83 / Iowa North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11431','EPSG','2198',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26976','NAD83 / Iowa South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11432','EPSG','2199',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26977','NAD83 / Kansas North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11531','EPSG','2200',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26978','NAD83 / Kansas South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11532','EPSG','2201',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26979','NAD83 / Kentucky North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11631','EPSG','2202',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','26980','NAD83 / Kentucky South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11632','EPSG','2203',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26981','NAD83 / Louisiana North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11731','EPSG','2204',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26982','NAD83 / Louisiana South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11732','EPSG','2529',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26983','NAD83 / Maine East',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11831','EPSG','2206',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26984','NAD83 / Maine West',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11832','EPSG','2207',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26985','NAD83 / Maryland',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11930','EPSG','1389',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26986','NAD83 / Massachusetts Mainland',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12031','EPSG','2209',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26987','NAD83 / Massachusetts Island',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12032','EPSG','2208',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26988','NAD83 / Michigan North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12141','EPSG','1723',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26989','NAD83 / Michigan Central',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12142','EPSG','1724',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26990','NAD83 / Michigan South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12143','EPSG','1725',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26991','NAD83 / Minnesota North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12231','EPSG','2214',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26992','NAD83 / Minnesota Central',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12232','EPSG','2213',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26993','NAD83 / Minnesota South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12233','EPSG','2215',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26994','NAD83 / Mississippi East',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12331','EPSG','2216',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26995','NAD83 / Mississippi West',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12332','EPSG','2217',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26996','NAD83 / Missouri East',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12431','EPSG','2219',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26997','NAD83 / Missouri Central',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12432','EPSG','2218',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','26998','NAD83 / Missouri West',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12433','EPSG','2220',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27037','Nahrwan 1967 / UTM zone 37N',NULL,NULL,'EPSG','4400','EPSG','4270','EPSG','16037','EPSG','3387',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','27038','Nahrwan 1967 / UTM zone 38N',NULL,NULL,'EPSG','4400','EPSG','4270','EPSG','16038','EPSG','3386',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','27039','Nahrwan 1967 / UTM zone 39N',NULL,NULL,'EPSG','4400','EPSG','4270','EPSG','16039','EPSG','1749',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27040','Nahrwan 1967 / UTM zone 40N',NULL,NULL,'EPSG','4400','EPSG','4270','EPSG','16040','EPSG','1750',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27120','Naparima 1972 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4271','EPSG','16020','EPSG','1322',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27200','NZGD49 / New Zealand Map Grid',NULL,NULL,'EPSG','4400','EPSG','4272','EPSG','19917','EPSG','3973',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27205','NZGD49 / Mount Eden Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17901','EPSG','3781',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27206','NZGD49 / Bay of Plenty Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17902','EPSG','3779',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27207','NZGD49 / Poverty Bay Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17903','EPSG','3780',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27208','NZGD49 / Hawkes Bay Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17904','EPSG','3772',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27209','NZGD49 / Taranaki Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17905','EPSG','3777',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27210','NZGD49 / Tuhirangi Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17906','EPSG','3778',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27211','NZGD49 / Wanganui Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17907','EPSG','3776',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27212','NZGD49 / Wairarapa Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17908','EPSG','3775',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27213','NZGD49 / Wellington Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17909','EPSG','3774',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27214','NZGD49 / Collingwood Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17910','EPSG','3782',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27215','NZGD49 / Nelson Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17911','EPSG','3784',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27216','NZGD49 / Karamea Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17912','EPSG','3783',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27217','NZGD49 / Buller Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17913','EPSG','3786',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27218','NZGD49 / Grey Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17914','EPSG','3787',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27219','NZGD49 / Amuri Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17915','EPSG','3788',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27220','NZGD49 / Marlborough Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17916','EPSG','3785',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27221','NZGD49 / Hokitika Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17917','EPSG','3789',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27222','NZGD49 / Okarito Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17918','EPSG','3791',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27223','NZGD49 / Jacksons Bay Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17919','EPSG','3794',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27224','NZGD49 / Mount Pleasant Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17920','EPSG','3790',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27225','NZGD49 / Gawler Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17921','EPSG','3792',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27226','NZGD49 / Timaru Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17922','EPSG','3793',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27227','NZGD49 / Lindis Peak Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17923','EPSG','3795',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27228','NZGD49 / Mount Nicholas Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17924','EPSG','3797',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27229','NZGD49 / Mount York Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17925','EPSG','3799',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27230','NZGD49 / Observation Point Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17926','EPSG','3796',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27231','NZGD49 / North Taieri Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17927','EPSG','3798',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27232','NZGD49 / Bluff Circuit',NULL,NULL,'EPSG','4500','EPSG','4272','EPSG','17928','EPSG','3800',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27258','NZGD49 / UTM zone 58S',NULL,NULL,'EPSG','4400','EPSG','4272','EPSG','16158','EPSG','3970',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27259','NZGD49 / UTM zone 59S',NULL,NULL,'EPSG','4400','EPSG','4272','EPSG','16159','EPSG','3971',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27260','NZGD49 / UTM zone 60S',NULL,NULL,'EPSG','4400','EPSG','4272','EPSG','16160','EPSG','3972',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27291','NZGD49 / North Island Grid',NULL,NULL,'EPSG','4409','EPSG','4272','EPSG','18141','EPSG','1500',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27292','NZGD49 / South Island Grid',NULL,NULL,'EPSG','4409','EPSG','4272','EPSG','18142','EPSG','3344',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27391','NGO 1948 (Oslo) / NGO zone I',NULL,NULL,'EPSG','4531','EPSG','4817','EPSG','18221','EPSG','1741',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27392','NGO 1948 (Oslo) / NGO zone II',NULL,NULL,'EPSG','4531','EPSG','4817','EPSG','18222','EPSG','1742',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27393','NGO 1948 (Oslo) / NGO zone III',NULL,NULL,'EPSG','4531','EPSG','4817','EPSG','18223','EPSG','1743',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27394','NGO 1948 (Oslo) / NGO zone IV',NULL,NULL,'EPSG','4531','EPSG','4817','EPSG','18224','EPSG','1744',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27395','NGO 1948 (Oslo) / NGO zone V',NULL,NULL,'EPSG','4531','EPSG','4817','EPSG','18225','EPSG','1745',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27396','NGO 1948 (Oslo) / NGO zone VI',NULL,NULL,'EPSG','4531','EPSG','4817','EPSG','18226','EPSG','1746',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27397','NGO 1948 (Oslo) / NGO zone VII',NULL,NULL,'EPSG','4531','EPSG','4817','EPSG','18227','EPSG','1747',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27398','NGO 1948 (Oslo) / NGO zone VIII',NULL,NULL,'EPSG','4531','EPSG','4817','EPSG','18228','EPSG','1748',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27429','Datum 73 / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4274','EPSG','16029','EPSG','1294',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27492','Datum 73 / Modified Portuguese Grid',NULL,NULL,'EPSG','4530','EPSG','4274','EPSG','19974','EPSG','1294',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','27493','Datum 73 / Modified Portuguese Grid',NULL,NULL,'EPSG','4499','EPSG','4274','EPSG','19974','EPSG','1294',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27500','ATF (Paris) / Nord de Guerre',NULL,NULL,'EPSG','4499','EPSG','4901','EPSG','19903','EPSG','1369',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27561','NTF (Paris) / Lambert Nord France',NULL,NULL,'EPSG','4499','EPSG','4807','EPSG','18091','EPSG','1731',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27562','NTF (Paris) / Lambert Centre France',NULL,NULL,'EPSG','4499','EPSG','4807','EPSG','18092','EPSG','1732',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27563','NTF (Paris) / Lambert Sud France',NULL,NULL,'EPSG','4499','EPSG','4807','EPSG','18093','EPSG','1733',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27564','NTF (Paris) / Lambert Corse',NULL,NULL,'EPSG','4499','EPSG','4807','EPSG','18094','EPSG','1327',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27571','NTF (Paris) / Lambert zone I',NULL,NULL,'EPSG','4499','EPSG','4807','EPSG','18081','EPSG','1731',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27572','NTF (Paris) / Lambert zone II',NULL,NULL,'EPSG','4499','EPSG','4807','EPSG','18082','EPSG','1734',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27573','NTF (Paris) / Lambert zone III',NULL,NULL,'EPSG','4499','EPSG','4807','EPSG','18083','EPSG','1733',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27574','NTF (Paris) / Lambert zone IV',NULL,NULL,'EPSG','4499','EPSG','4807','EPSG','18084','EPSG','1327',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','27581','NTF (Paris) / France I',NULL,NULL,'EPSG','4499','EPSG','4807','EPSG','18081','EPSG','1731',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','27582','NTF (Paris) / France II',NULL,NULL,'EPSG','4499','EPSG','4807','EPSG','18082','EPSG','1734',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','27583','NTF (Paris) / France III',NULL,NULL,'EPSG','4499','EPSG','4807','EPSG','18083','EPSG','1733',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','27584','NTF (Paris) / France IV',NULL,NULL,'EPSG','4499','EPSG','4807','EPSG','18084','EPSG','1327',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','27591','NTF (Paris) / Nord France',NULL,NULL,'EPSG','4499','EPSG','4807','EPSG','18091','EPSG','1731',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','27592','NTF (Paris) / Centre France',NULL,NULL,'EPSG','4499','EPSG','4807','EPSG','18092','EPSG','1732',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','27593','NTF (Paris) / Sud France',NULL,NULL,'EPSG','4499','EPSG','4807','EPSG','18093','EPSG','1733',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','27594','NTF (Paris) / Corse',NULL,NULL,'EPSG','4499','EPSG','4807','EPSG','18094','EPSG','1327',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','27700','OSGB 1936 / British National Grid',NULL,NULL,'EPSG','4400','EPSG','4277','EPSG','19916','EPSG','4390',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28191','Palestine 1923 / Palestine Grid',NULL,NULL,'EPSG','4400','EPSG','4281','EPSG','18201','EPSG','1356',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28192','Palestine 1923 / Palestine Belt',NULL,NULL,'EPSG','4400','EPSG','4281','EPSG','18202','EPSG','1356',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28193','Palestine 1923 / Israeli CS Grid',NULL,NULL,'EPSG','4400','EPSG','4281','EPSG','18203','EPSG','2603',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28232','Pointe Noire / UTM zone 32S',NULL,NULL,'EPSG','4400','EPSG','4282','EPSG','16132','EPSG','1072',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28348','GDA94 / MGA zone 48',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','17348','EPSG','4191',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28349','GDA94 / MGA zone 49',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','17349','EPSG','4176',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28350','GDA94 / MGA zone 50',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','17350','EPSG','4178',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28351','GDA94 / MGA zone 51',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','17351','EPSG','1559',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28352','GDA94 / MGA zone 52',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','17352','EPSG','1560',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28353','GDA94 / MGA zone 53',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','17353','EPSG','1561',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28354','GDA94 / MGA zone 54',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','17354','EPSG','1562',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28355','GDA94 / MGA zone 55',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','17355','EPSG','1563',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28356','GDA94 / MGA zone 56',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','17356','EPSG','1564',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28357','GDA94 / MGA zone 57',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','17357','EPSG','4196',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28358','GDA94 / MGA zone 58',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','17358','EPSG','4175',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28402','Pulkovo 1942 / Gauss-Kruger zone 2',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16202','EPSG','1805',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28403','Pulkovo 1942 / Gauss-Kruger zone 3',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16203','EPSG','1792',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28404','Pulkovo 1942 / Gauss-Kruger zone 4',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16204','EPSG','1793',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28405','Pulkovo 1942 / Gauss-Kruger zone 5',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16205','EPSG','1794',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28406','Pulkovo 1942 / Gauss-Kruger zone 6',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16206','EPSG','1795',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28407','Pulkovo 1942 / Gauss-Kruger zone 7',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16207','EPSG','1796',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28408','Pulkovo 1942 / Gauss-Kruger zone 8',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16208','EPSG','1797',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28409','Pulkovo 1942 / Gauss-Kruger zone 9',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16209','EPSG','1798',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28410','Pulkovo 1942 / Gauss-Kruger zone 10',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16210','EPSG','1799',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28411','Pulkovo 1942 / Gauss-Kruger zone 11',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16211','EPSG','1800',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28412','Pulkovo 1942 / Gauss-Kruger zone 12',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16212','EPSG','1801',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28413','Pulkovo 1942 / Gauss-Kruger zone 13',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16213','EPSG','1802',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28414','Pulkovo 1942 / Gauss-Kruger zone 14',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16214','EPSG','1803',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28415','Pulkovo 1942 / Gauss-Kruger zone 15',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16215','EPSG','1804',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28416','Pulkovo 1942 / Gauss-Kruger zone 16',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16216','EPSG','1775',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28417','Pulkovo 1942 / Gauss-Kruger zone 17',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16217','EPSG','1776',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28418','Pulkovo 1942 / Gauss-Kruger zone 18',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16218','EPSG','1777',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28419','Pulkovo 1942 / Gauss-Kruger zone 19',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16219','EPSG','1778',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28420','Pulkovo 1942 / Gauss-Kruger zone 20',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16220','EPSG','1779',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28421','Pulkovo 1942 / Gauss-Kruger zone 21',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16221','EPSG','1780',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28422','Pulkovo 1942 / Gauss-Kruger zone 22',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16222','EPSG','1781',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28423','Pulkovo 1942 / Gauss-Kruger zone 23',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16223','EPSG','1782',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28424','Pulkovo 1942 / Gauss-Kruger zone 24',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16224','EPSG','1783',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28425','Pulkovo 1942 / Gauss-Kruger zone 25',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16225','EPSG','1784',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28426','Pulkovo 1942 / Gauss-Kruger zone 26',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16226','EPSG','1785',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28427','Pulkovo 1942 / Gauss-Kruger zone 27',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16227','EPSG','1786',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28428','Pulkovo 1942 / Gauss-Kruger zone 28',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16228','EPSG','1787',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28429','Pulkovo 1942 / Gauss-Kruger zone 29',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16229','EPSG','1788',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28430','Pulkovo 1942 / Gauss-Kruger zone 30',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16230','EPSG','1789',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28431','Pulkovo 1942 / Gauss-Kruger zone 31',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16231','EPSG','1790',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28432','Pulkovo 1942 / Gauss-Kruger zone 32',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16232','EPSG','1791',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28462','Pulkovo 1942 / Gauss-Kruger 2N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16302','EPSG','1805',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28463','Pulkovo 1942 / Gauss-Kruger 3N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16303','EPSG','1792',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28464','Pulkovo 1942 / Gauss-Kruger 4N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16304','EPSG','1793',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28465','Pulkovo 1942 / Gauss-Kruger 5N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16305','EPSG','1794',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28466','Pulkovo 1942 / Gauss-Kruger 6N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16306','EPSG','1795',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28467','Pulkovo 1942 / Gauss-Kruger 7N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16307','EPSG','1796',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28468','Pulkovo 1942 / Gauss-Kruger 8N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16308','EPSG','1797',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28469','Pulkovo 1942 / Gauss-Kruger 9N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16309','EPSG','1798',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28470','Pulkovo 1942 / Gauss-Kruger 10N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16310','EPSG','1799',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28471','Pulkovo 1942 / Gauss-Kruger 11N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16311','EPSG','1800',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28472','Pulkovo 1942 / Gauss-Kruger 12N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16312','EPSG','1801',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28473','Pulkovo 1942 / Gauss-Kruger 13N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16313','EPSG','1802',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28474','Pulkovo 1942 / Gauss-Kruger 14N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16314','EPSG','1803',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28475','Pulkovo 1942 / Gauss-Kruger 15N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16315','EPSG','1804',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28476','Pulkovo 1942 / Gauss-Kruger 16N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16316','EPSG','1775',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28477','Pulkovo 1942 / Gauss-Kruger 17N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16317','EPSG','1776',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28478','Pulkovo 1942 / Gauss-Kruger 18N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16318','EPSG','1777',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28479','Pulkovo 1942 / Gauss-Kruger 19N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16319','EPSG','1778',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28480','Pulkovo 1942 / Gauss-Kruger 20N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16320','EPSG','1779',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28481','Pulkovo 1942 / Gauss-Kruger 21N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16321','EPSG','1780',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28482','Pulkovo 1942 / Gauss-Kruger 22N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16322','EPSG','1781',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28483','Pulkovo 1942 / Gauss-Kruger 23N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16323','EPSG','1782',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28484','Pulkovo 1942 / Gauss-Kruger 24N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16324','EPSG','1783',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28485','Pulkovo 1942 / Gauss-Kruger 25N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16325','EPSG','1784',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28486','Pulkovo 1942 / Gauss-Kruger 26N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16326','EPSG','1785',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28487','Pulkovo 1942 / Gauss-Kruger 27N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16327','EPSG','1786',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28488','Pulkovo 1942 / Gauss-Kruger 28N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16328','EPSG','1787',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28489','Pulkovo 1942 / Gauss-Kruger 29N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16329','EPSG','1788',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28490','Pulkovo 1942 / Gauss-Kruger 30N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16330','EPSG','1789',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28491','Pulkovo 1942 / Gauss-Kruger 31N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16331','EPSG','1790',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28492','Pulkovo 1942 / Gauss-Kruger 32N',NULL,NULL,'EPSG','4530','EPSG','4284','EPSG','16332','EPSG','1791',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','28600','Qatar 1974 / Qatar National Grid',NULL,NULL,'EPSG','4400','EPSG','4285','EPSG','19919','EPSG','1346',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28991','Amersfoort / RD Old',NULL,NULL,'EPSG','4499','EPSG','4289','EPSG','19913','EPSG','1275',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','28992','Amersfoort / RD New',NULL,NULL,'EPSG','4499','EPSG','4289','EPSG','19914','EPSG','1275',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29100','SAD69 / Brazil Polyconic',NULL,NULL,'EPSG','4499','EPSG','4291','EPSG','19941','EPSG','1053',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29101','SAD69 / Brazil Polyconic',NULL,NULL,'EPSG','4499','EPSG','4618','EPSG','19941','EPSG','1053',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29118','SAD69 / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4291','EPSG','16018','EPSG','1807',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29119','SAD69 / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4291','EPSG','16019','EPSG','1809',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29120','SAD69 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4291','EPSG','16020','EPSG','1811',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29121','SAD69 / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4291','EPSG','16021','EPSG','1813',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29122','SAD69 / UTM zone 22N',NULL,NULL,'EPSG','4400','EPSG','4291','EPSG','16022','EPSG','1815',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29168','SAD69 / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4618','EPSG','16018','EPSG','3832',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29169','SAD69 / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4618','EPSG','16019','EPSG','3834',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29170','SAD69 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4618','EPSG','16020','EPSG','3839',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29171','SAD69 / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4618','EPSG','16021','EPSG','3841',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29172','SAD69 / UTM zone 22N',NULL,NULL,'EPSG','4400','EPSG','4618','EPSG','16022','EPSG','1815',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29177','SAD69 / UTM zone 17S',NULL,NULL,'EPSG','4400','EPSG','4291','EPSG','16117','EPSG','1806',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29178','SAD69 / UTM zone 18S',NULL,NULL,'EPSG','4400','EPSG','4291','EPSG','16118','EPSG','1808',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29179','SAD69 / UTM zone 19S',NULL,NULL,'EPSG','4400','EPSG','4291','EPSG','16119','EPSG','1810',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29180','SAD69 / UTM zone 20S',NULL,NULL,'EPSG','4400','EPSG','4291','EPSG','16120','EPSG','1812',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29181','SAD69 / UTM zone 21S',NULL,NULL,'EPSG','4400','EPSG','4291','EPSG','16121','EPSG','1814',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29182','SAD69 / UTM zone 22S',NULL,NULL,'EPSG','4400','EPSG','4291','EPSG','16122','EPSG','1816',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29183','SAD69 / UTM zone 23S',NULL,NULL,'EPSG','4400','EPSG','4291','EPSG','16123','EPSG','1817',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29184','SAD69 / UTM zone 24S',NULL,NULL,'EPSG','4400','EPSG','4291','EPSG','16124','EPSG','1818',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29185','SAD69 / UTM zone 25S',NULL,NULL,'EPSG','4400','EPSG','4291','EPSG','16125','EPSG','1819',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29187','SAD69 / UTM zone 17S',NULL,NULL,'EPSG','4400','EPSG','4618','EPSG','16117','EPSG','3831',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29188','SAD69 / UTM zone 18S',NULL,NULL,'EPSG','4400','EPSG','4618','EPSG','16118','EPSG','3833',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29189','SAD69 / UTM zone 19S',NULL,NULL,'EPSG','4400','EPSG','4618','EPSG','16119','EPSG','3835',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29190','SAD69 / UTM zone 20S',NULL,NULL,'EPSG','4400','EPSG','4618','EPSG','16120','EPSG','3840',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29191','SAD69 / UTM zone 21S',NULL,NULL,'EPSG','4400','EPSG','4618','EPSG','16121','EPSG','1814',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29192','SAD69 / UTM zone 22S',NULL,NULL,'EPSG','4400','EPSG','4618','EPSG','16122','EPSG','1816',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29193','SAD69 / UTM zone 23S',NULL,NULL,'EPSG','4400','EPSG','4618','EPSG','16123','EPSG','3445',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29194','SAD69 / UTM zone 24S',NULL,NULL,'EPSG','4400','EPSG','4618','EPSG','16124','EPSG','3446',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29195','SAD69 / UTM zone 25S',NULL,NULL,'EPSG','4400','EPSG','4618','EPSG','16125','EPSG','3447',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29220','Sapper Hill 1943 / UTM zone 20S',NULL,NULL,'EPSG','4400','EPSG','4292','EPSG','16120','EPSG','1820',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29221','Sapper Hill 1943 / UTM zone 21S',NULL,NULL,'EPSG','4400','EPSG','4292','EPSG','16121','EPSG','1821',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29333','Schwarzeck / UTM zone 33S',NULL,NULL,'EPSG','4400','EPSG','4293','EPSG','16133','EPSG','1822',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29371','Schwarzeck / Lo22/11',NULL,NULL,'EPSG','6502','EPSG','4293','EPSG','17611','EPSG','1838',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29373','Schwarzeck / Lo22/13',NULL,NULL,'EPSG','6502','EPSG','4293','EPSG','17613','EPSG','1839',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29375','Schwarzeck / Lo22/15',NULL,NULL,'EPSG','6502','EPSG','4293','EPSG','17615','EPSG','1840',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29377','Schwarzeck / Lo22/17',NULL,NULL,'EPSG','6502','EPSG','4293','EPSG','17617','EPSG','1841',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29379','Schwarzeck / Lo22/19',NULL,NULL,'EPSG','6502','EPSG','4293','EPSG','17619','EPSG','1842',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29381','Schwarzeck / Lo22/21',NULL,NULL,'EPSG','6502','EPSG','4293','EPSG','17621','EPSG','1843',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29383','Schwarzeck / Lo22/23',NULL,NULL,'EPSG','6502','EPSG','4293','EPSG','17623','EPSG','1844',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29385','Schwarzeck / Lo22/25',NULL,NULL,'EPSG','6502','EPSG','4293','EPSG','17625','EPSG','1845',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29635','Sudan / UTM zone 35N',NULL,NULL,'EPSG','4400','EPSG','4296','EPSG','16035','EPSG','1846',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29636','Sudan / UTM zone 36N',NULL,NULL,'EPSG','4400','EPSG','4296','EPSG','16036','EPSG','1847',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29700','Tananarive (Paris) / Laborde Grid',NULL,NULL,'EPSG','4499','EPSG','4810','EPSG','19911','EPSG','3273',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29701','Tananarive (Paris) / Laborde Grid',NULL,NULL,'EPSG','4530','EPSG','4810','EPSG','19861','EPSG','3273',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29702','Tananarive (Paris) / Laborde Grid approximation',NULL,NULL,'EPSG','4530','EPSG','4810','EPSG','19911','EPSG','3273',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29738','Tananarive / UTM zone 38S',NULL,NULL,'EPSG','4400','EPSG','4297','EPSG','16138','EPSG','1848',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29739','Tananarive / UTM zone 39S',NULL,NULL,'EPSG','4400','EPSG','4297','EPSG','16139','EPSG','1849',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29849','Timbalai 1948 / UTM zone 49N',NULL,NULL,'EPSG','4400','EPSG','4298','EPSG','16049','EPSG','1852',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29850','Timbalai 1948 / UTM zone 50N',NULL,NULL,'EPSG','4400','EPSG','4298','EPSG','16050','EPSG','1853',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29871','Timbalai 1948 / RSO Borneo (ch)',NULL,NULL,'EPSG','4402','EPSG','4298','EPSG','19956','EPSG','1362',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29872','Timbalai 1948 / RSO Borneo (ftSe)',NULL,NULL,'EPSG','4405','EPSG','4298','EPSG','19957','EPSG','1851',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29873','Timbalai 1948 / RSO Borneo (m)',NULL,NULL,'EPSG','4400','EPSG','4298','EPSG','19958','EPSG','1362',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29900','TM65 / Irish National Grid',NULL,NULL,'EPSG','4400','EPSG','4299','EPSG','19908','EPSG','1305',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','29901','OSNI 1952 / Irish National Grid',NULL,NULL,'EPSG','4400','EPSG','4188','EPSG','19973','EPSG','2530',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29902','TM65 / Irish Grid',NULL,NULL,'EPSG','4400','EPSG','4299','EPSG','19972','EPSG','3767',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','29903','TM75 / Irish Grid',NULL,NULL,'EPSG','4400','EPSG','4300','EPSG','19972','EPSG','1305',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30161','Tokyo / Japan Plane Rectangular CS I',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17801','EPSG','1854',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30162','Tokyo / Japan Plane Rectangular CS II',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17802','EPSG','1855',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30163','Tokyo / Japan Plane Rectangular CS III',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17803','EPSG','1856',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30164','Tokyo / Japan Plane Rectangular CS IV',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17804','EPSG','1857',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30165','Tokyo / Japan Plane Rectangular CS V',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17805','EPSG','1858',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30166','Tokyo / Japan Plane Rectangular CS VI',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17806','EPSG','1859',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30167','Tokyo / Japan Plane Rectangular CS VII',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17807','EPSG','1860',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30168','Tokyo / Japan Plane Rectangular CS VIII',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17808','EPSG','1861',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30169','Tokyo / Japan Plane Rectangular CS IX',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17809','EPSG','1862',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30170','Tokyo / Japan Plane Rectangular CS X',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17810','EPSG','1863',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30171','Tokyo / Japan Plane Rectangular CS XI',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17811','EPSG','1864',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30172','Tokyo / Japan Plane Rectangular CS XII',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17812','EPSG','1865',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30173','Tokyo / Japan Plane Rectangular CS XIII',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17813','EPSG','1866',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30174','Tokyo / Japan Plane Rectangular CS XIV',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17814','EPSG','1867',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30175','Tokyo / Japan Plane Rectangular CS XV',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17815','EPSG','1868',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30176','Tokyo / Japan Plane Rectangular CS XVI',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17816','EPSG','1869',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30177','Tokyo / Japan Plane Rectangular CS XVII',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17817','EPSG','1870',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30178','Tokyo / Japan Plane Rectangular CS XVIII',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17818','EPSG','1871',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30179','Tokyo / Japan Plane Rectangular CS XIX',NULL,NULL,'EPSG','4530','EPSG','4301','EPSG','17819','EPSG','1872',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30200','Trinidad 1903 / Trinidad Grid',NULL,NULL,'EPSG','4407','EPSG','4302','EPSG','19925','EPSG','1339',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30339','TC(1948) / UTM zone 39N',NULL,NULL,'EPSG','4400','EPSG','4303','EPSG','16039','EPSG','1850',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30340','TC(1948) / UTM zone 40N',NULL,NULL,'EPSG','4400','EPSG','4303','EPSG','16040','EPSG','4022',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30491','Voirol 1875 / Nord Algerie (ancienne)',NULL,NULL,'EPSG','4499','EPSG','4304','EPSG','18011','EPSG','1728',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30492','Voirol 1875 / Sud Algerie (ancienne)',NULL,NULL,'EPSG','4499','EPSG','4304','EPSG','18012','EPSG','4519',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30493','Voirol 1879 / Nord Algerie (ancienne)',NULL,NULL,'EPSG','4499','EPSG','4671','EPSG','18011','EPSG','1728',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30494','Voirol 1879 / Sud Algerie (ancienne)',NULL,NULL,'EPSG','4499','EPSG','4671','EPSG','18012','EPSG','4519',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30729','Nord Sahara 1959 / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4307','EPSG','16029','EPSG','1735',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30730','Nord Sahara 1959 / UTM zone 30N',NULL,NULL,'EPSG','4400','EPSG','4307','EPSG','16030','EPSG','3952',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30731','Nord Sahara 1959 / UTM zone 31N',NULL,NULL,'EPSG','4400','EPSG','4307','EPSG','16031','EPSG','3953',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30732','Nord Sahara 1959 / UTM zone 32N',NULL,NULL,'EPSG','4400','EPSG','4307','EPSG','16032','EPSG','3954',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30791','Nord Sahara 1959 / Nord Algerie',NULL,NULL,'EPSG','4499','EPSG','4307','EPSG','18021','EPSG','1728',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30792','Nord Sahara 1959 / Sud Algerie',NULL,NULL,'EPSG','4499','EPSG','4307','EPSG','18022','EPSG','1729',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','30800','RT38 2.5 gon W',NULL,NULL,'EPSG','4530','EPSG','4308','EPSG','19929','EPSG','1225',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31028','Yoff / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4310','EPSG','16028','EPSG','1207',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31121','Zanderij / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4311','EPSG','16021','EPSG','1222',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31154','Zanderij / TM 54 NW',NULL,NULL,'EPSG','4400','EPSG','4311','EPSG','17054','EPSG','1727',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31170','Zanderij / Suriname Old TM',NULL,NULL,'EPSG','4400','EPSG','4311','EPSG','19954','EPSG','3312',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31171','Zanderij / Suriname TM',NULL,NULL,'EPSG','4400','EPSG','4311','EPSG','19955','EPSG','3312',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31251','MGI (Ferro) / Austria GK West Zone',NULL,NULL,'EPSG','4530','EPSG','4805','EPSG','18001','EPSG','1706',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31252','MGI (Ferro) / Austria GK Central Zone',NULL,NULL,'EPSG','4530','EPSG','4805','EPSG','18002','EPSG','1707',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31253','MGI (Ferro) / Austria GK East Zone',NULL,NULL,'EPSG','4530','EPSG','4805','EPSG','18003','EPSG','1708',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31254','MGI / Austria GK West',NULL,NULL,'EPSG','4530','EPSG','4312','EPSG','18004','EPSG','1706',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31255','MGI / Austria GK Central',NULL,NULL,'EPSG','4530','EPSG','4312','EPSG','18005','EPSG','1707',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31256','MGI / Austria GK East',NULL,NULL,'EPSG','4530','EPSG','4312','EPSG','18006','EPSG','1708',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31257','MGI / Austria GK M28',NULL,NULL,'EPSG','4530','EPSG','4312','EPSG','18007','EPSG','1706',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31258','MGI / Austria GK M31',NULL,NULL,'EPSG','4530','EPSG','4312','EPSG','18008','EPSG','1707',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31259','MGI / Austria GK M34',NULL,NULL,'EPSG','4530','EPSG','4312','EPSG','18009','EPSG','1708',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31265','MGI / 3-degree Gauss zone 5',NULL,NULL,'EPSG','4499','EPSG','4312','EPSG','16265','EPSG','1709',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31266','MGI / 3-degree Gauss zone 6',NULL,NULL,'EPSG','4499','EPSG','4312','EPSG','16266','EPSG','1710',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31267','MGI / 3-degree Gauss zone 7',NULL,NULL,'EPSG','4499','EPSG','4312','EPSG','16267','EPSG','1711',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31268','MGI / 3-degree Gauss zone 8',NULL,NULL,'EPSG','4499','EPSG','4312','EPSG','16268','EPSG','1712',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31275','MGI / Balkans zone 5',NULL,NULL,'EPSG','4530','EPSG','4312','EPSG','18275','EPSG','1709',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31276','MGI / Balkans zone 6',NULL,NULL,'EPSG','4530','EPSG','4312','EPSG','18276','EPSG','1710',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31277','MGI / Balkans zone 7',NULL,NULL,'EPSG','4530','EPSG','4312','EPSG','18277','EPSG','1711',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31278','MGI / Balkans zone 8',NULL,NULL,'EPSG','4530','EPSG','4312','EPSG','18277','EPSG','1712',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31279','MGI / Balkans zone 8',NULL,NULL,'EPSG','4530','EPSG','4312','EPSG','18278','EPSG','1712',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31281','MGI (Ferro) / Austria West Zone',NULL,NULL,'EPSG','4530','EPSG','4805','EPSG','18041','EPSG','1706',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31282','MGI (Ferro) / Austria Central Zone',NULL,NULL,'EPSG','4530','EPSG','4805','EPSG','18042','EPSG','1707',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31283','MGI (Ferro) / Austria East Zone',NULL,NULL,'EPSG','4530','EPSG','4805','EPSG','18043','EPSG','1708',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31284','MGI / Austria M28',NULL,NULL,'EPSG','4530','EPSG','4312','EPSG','18044','EPSG','1706',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31285','MGI / Austria M31',NULL,NULL,'EPSG','4530','EPSG','4312','EPSG','18045','EPSG','1707',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31286','MGI / Austria M34',NULL,NULL,'EPSG','4530','EPSG','4312','EPSG','18046','EPSG','1708',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31287','MGI / Austria Lambert',NULL,NULL,'EPSG','4530','EPSG','4312','EPSG','19947','EPSG','1037',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31288','MGI (Ferro) / M28',NULL,NULL,'EPSG','4530','EPSG','4805','EPSG','18047','EPSG','1706',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31289','MGI (Ferro) / M31',NULL,NULL,'EPSG','4530','EPSG','4805','EPSG','18048','EPSG','1707',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31290','MGI (Ferro) / M34',NULL,NULL,'EPSG','4530','EPSG','4805','EPSG','18049','EPSG','1708',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31291','MGI (Ferro) / Austria West Zone',NULL,NULL,'EPSG','4499','EPSG','4805','EPSG','18041','EPSG','1706',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31292','MGI (Ferro) / Austria Central Zone',NULL,NULL,'EPSG','4499','EPSG','4805','EPSG','18042','EPSG','1708',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31293','MGI (Ferro) / Austria East Zone',NULL,NULL,'EPSG','4499','EPSG','4805','EPSG','18043','EPSG','1707',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31294','MGI / M28',NULL,NULL,'EPSG','4499','EPSG','4312','EPSG','18044','EPSG','1706',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31295','MGI / M31',NULL,NULL,'EPSG','4499','EPSG','4312','EPSG','18045','EPSG','1707',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31296','MGI / M34',NULL,NULL,'EPSG','4499','EPSG','4312','EPSG','18046','EPSG','1708',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31297','MGI / Austria Lambert',NULL,NULL,'EPSG','4499','EPSG','4312','EPSG','19947','EPSG','1037',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31300','Belge 1972 / Belge Lambert 72',NULL,NULL,'EPSG','4499','EPSG','4313','EPSG','19902','EPSG','1347',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31370','Belge 1972 / Belgian Lambert 72',NULL,NULL,'EPSG','4499','EPSG','4313','EPSG','19961','EPSG','1347',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31461','DHDN / 3-degree Gauss zone 1',NULL,NULL,'EPSG','4499','EPSG','4314','EPSG','16261','EPSG','1628',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31462','DHDN / 3-degree Gauss zone 2',NULL,NULL,'EPSG','4499','EPSG','4314','EPSG','16262','EPSG','1624',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31463','DHDN / 3-degree Gauss zone 3',NULL,NULL,'EPSG','4499','EPSG','4314','EPSG','16263','EPSG','1625',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31464','DHDN / 3-degree Gauss zone 4',NULL,NULL,'EPSG','4499','EPSG','4314','EPSG','16264','EPSG','1626',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31465','DHDN / 3-degree Gauss zone 5',NULL,NULL,'EPSG','4499','EPSG','4314','EPSG','16265','EPSG','1627',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31466','DHDN / 3-degree Gauss-Kruger zone 2',NULL,NULL,'EPSG','4530','EPSG','4314','EPSG','16262','EPSG','1624',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31467','DHDN / 3-degree Gauss-Kruger zone 3',NULL,NULL,'EPSG','4530','EPSG','4314','EPSG','16263','EPSG','1625',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31468','DHDN / 3-degree Gauss-Kruger zone 4',NULL,NULL,'EPSG','4530','EPSG','4314','EPSG','16264','EPSG','1626',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31469','DHDN / 3-degree Gauss-Kruger zone 5',NULL,NULL,'EPSG','4530','EPSG','4314','EPSG','16265','EPSG','1627',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31528','Conakry 1905 / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4315','EPSG','16028','EPSG','1468',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31529','Conakry 1905 / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4315','EPSG','16029','EPSG','1469',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31600','Dealul Piscului 1930 / Stereo 33',NULL,NULL,'EPSG','4499','EPSG','4316','EPSG','19927','EPSG','3295',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31700','Dealul Piscului 1970/ Stereo 70',NULL,NULL,'EPSG','4530','EPSG','4317','EPSG','19926','EPSG','1197',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31838','NGN / UTM zone 38N',NULL,NULL,'EPSG','4400','EPSG','4318','EPSG','16038','EPSG','1739',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31839','NGN / UTM zone 39N',NULL,NULL,'EPSG','4400','EPSG','4318','EPSG','16039','EPSG','1740',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31900','KUDAMS / KTM',NULL,NULL,'EPSG','4400','EPSG','4319','EPSG','19928','EPSG','1310',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','31901','KUDAMS / KTM',NULL,NULL,'EPSG','4400','EPSG','4319','EPSG','19997','EPSG','1310',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31965','SIRGAS 2000 / UTM zone 11N',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16011','EPSG','3748',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31966','SIRGAS 2000 / UTM zone 12N',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16012','EPSG','3756',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31967','SIRGAS 2000 / UTM zone 13N',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16013','EPSG','3759',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31968','SIRGAS 2000 / UTM zone 14N',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16014','EPSG','3763',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31969','SIRGAS 2000 / UTM zone 15N',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16015','EPSG','3427',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31970','SIRGAS 2000 / UTM zone 16N',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16016','EPSG','3428',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31971','SIRGAS 2000 / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16017','EPSG','3421',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31972','SIRGAS 2000 / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16018','EPSG','3422',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31973','SIRGAS 2000 / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16019','EPSG','3436',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31974','SIRGAS 2000 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16020','EPSG','3437',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31975','SIRGAS 2000 / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16021','EPSG','3438',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31976','SIRGAS 2000 / UTM zone 22N',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16022','EPSG','3439',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31977','SIRGAS 2000 / UTM zone 17S',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16117','EPSG','1824',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31978','SIRGAS 2000 / UTM zone 18S',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16118','EPSG','3440',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31979','SIRGAS 2000 / UTM zone 19S',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16119','EPSG','3441',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31980','SIRGAS 2000 / UTM zone 20S',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16120','EPSG','3442',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31981','SIRGAS 2000 / UTM zone 21S',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16121','EPSG','3443',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31982','SIRGAS 2000 / UTM zone 22S',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16122','EPSG','3444',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31983','SIRGAS 2000 / UTM zone 23S',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16123','EPSG','3445',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31984','SIRGAS 2000 / UTM zone 24S',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16124','EPSG','3446',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31985','SIRGAS 2000 / UTM zone 25S',NULL,NULL,'EPSG','4400','EPSG','4674','EPSG','16125','EPSG','3447',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31986','SIRGAS 1995 / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16017','EPSG','1823',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31987','SIRGAS 1995 / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16018','EPSG','1825',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31988','SIRGAS 1995 / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16019','EPSG','1827',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31989','SIRGAS 1995 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16020','EPSG','1829',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31990','SIRGAS 1995 / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16021','EPSG','1831',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31991','SIRGAS 1995 / UTM zone 22N',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16022','EPSG','1833',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31992','SIRGAS 1995 / UTM zone 17S',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16117','EPSG','3638',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31993','SIRGAS 1995 / UTM zone 18S',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16118','EPSG','1826',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31994','SIRGAS 1995 / UTM zone 19S',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16119','EPSG','1828',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31995','SIRGAS 1995 / UTM zone 20S',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16120','EPSG','1830',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31996','SIRGAS 1995 / UTM zone 21S',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16121','EPSG','1832',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31997','SIRGAS 1995 / UTM zone 22S',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16122','EPSG','1834',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31998','SIRGAS 1995 / UTM zone 23S',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16123','EPSG','1835',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','31999','SIRGAS 1995 / UTM zone 24S',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16124','EPSG','1836',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32000','SIRGAS 1995 / UTM zone 25S',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16125','EPSG','1837',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32001','NAD27 / Montana North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12501','EPSG','2211',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32002','NAD27 / Montana Central',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12502','EPSG','2210',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32003','NAD27 / Montana South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12503','EPSG','2212',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32005','NAD27 / Nebraska North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12601','EPSG','2221',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32006','NAD27 / Nebraska South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12602','EPSG','2222',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32007','NAD27 / Nevada East',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12701','EPSG','2224',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32008','NAD27 / Nevada Central',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12702','EPSG','2223',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32009','NAD27 / Nevada West',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12703','EPSG','2225',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32010','NAD27 / New Hampshire',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12800','EPSG','1398',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32011','NAD27 / New Jersey',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','12900','EPSG','1399',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32012','NAD27 / New Mexico East',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13001','EPSG','2228',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32013','NAD27 / New Mexico Central',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13002','EPSG','2229',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32014','NAD27 / New Mexico West',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13003','EPSG','2230',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32015','NAD27 / New York East',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13101','EPSG','2234',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32016','NAD27 / New York Central',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13102','EPSG','2233',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32017','NAD27 / New York West',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13103','EPSG','2236',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32018','NAD27 / New York Long Island',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13104','EPSG','2235',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','32019','NAD27 / North Carolina',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13200','EPSG','1402',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32020','NAD27 / North Dakota North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13301','EPSG','2237',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32021','NAD27 / North Dakota South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13302','EPSG','2238',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32022','NAD27 / Ohio North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13401','EPSG','2239',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32023','NAD27 / Ohio South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13402','EPSG','2240',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32024','NAD27 / Oklahoma North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13501','EPSG','2241',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32025','NAD27 / Oklahoma South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13502','EPSG','2242',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32026','NAD27 / Oregon North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13601','EPSG','2243',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32027','NAD27 / Oregon South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13602','EPSG','2244',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32028','NAD27 / Pennsylvania North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13701','EPSG','2245',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32029','NAD27 / Pennsylvania South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13702','EPSG','2246',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','32030','NAD27 / Rhode Island',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13800','EPSG','1408',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32031','NAD27 / South Carolina North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13901','EPSG','2247',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32033','NAD27 / South Carolina South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','13902','EPSG','2248',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32034','NAD27 / South Dakota North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14001','EPSG','2249',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32035','NAD27 / South Dakota South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14002','EPSG','2250',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32036','NAD27 / Tennessee',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14100','EPSG','1411',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','32037','NAD27 / Texas North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14201','EPSG','2253',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32038','NAD27 / Texas North Central',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14202','EPSG','2254',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32039','NAD27 / Texas Central',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14203','EPSG','2252',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32040','NAD27 / Texas South Central',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14204','EPSG','2256',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32041','NAD27 / Texas South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14205','EPSG','2255',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32042','NAD27 / Utah North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14301','EPSG','2258',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32043','NAD27 / Utah Central',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14302','EPSG','2257',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32044','NAD27 / Utah South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14303','EPSG','2259',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32045','NAD27 / Vermont',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14400','EPSG','1414',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32046','NAD27 / Virginia North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14501','EPSG','2260',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32047','NAD27 / Virginia South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14502','EPSG','2261',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32048','NAD27 / Washington North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14601','EPSG','2262',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32049','NAD27 / Washington South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14602','EPSG','2263',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32050','NAD27 / West Virginia North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14701','EPSG','2264',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32051','NAD27 / West Virginia South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14702','EPSG','2265',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32052','NAD27 / Wisconsin North',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14801','EPSG','2267',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32053','NAD27 / Wisconsin Central',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14802','EPSG','2266',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32054','NAD27 / Wisconsin South',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14803','EPSG','2268',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32055','NAD27 / Wyoming East',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14901','EPSG','2269',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32056','NAD27 / Wyoming East Central',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14902','EPSG','2270',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32057','NAD27 / Wyoming West Central',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14903','EPSG','2272',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32058','NAD27 / Wyoming West',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','14904','EPSG','2271',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32061','NAD27 / Guatemala Norte',NULL,NULL,'EPSG','4499','EPSG','4267','EPSG','18211','EPSG','2120',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','32062','NAD27 / Guatemala Sur',NULL,NULL,'EPSG','4499','EPSG','4267','EPSG','18212','EPSG','2121',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','32064','NAD27 / BLM 14N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15914','EPSG','3637',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32065','NAD27 / BLM 15N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15915','EPSG','3640',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32066','NAD27 / BLM 16N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15916','EPSG','3641',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32067','NAD27 / BLM 17N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15917','EPSG','3642',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32074','NAD27 / BLM 14N (feet)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15914','EPSG','2171',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','32075','NAD27 / BLM 15N (feet)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15915','EPSG','2172',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','32076','NAD27 / BLM 16N (feet)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15916','EPSG','2173',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','32077','NAD27 / BLM 17N (feet)',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','15917','EPSG','2174',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','32081','NAD27 / MTM zone 1',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','17701','EPSG','2226',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32082','NAD27 / MTM zone 2',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','17702','EPSG','2227',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32083','NAD27 / MTM zone 3',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','17703','EPSG','2275',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32084','NAD27 / MTM zone 4',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','17704','EPSG','3875',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32085','NAD27 / MTM zone 5',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','17705','EPSG','3865',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32086','NAD27 / MTM zone 6',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','17706','EPSG','3880',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32098','NAD27 / Quebec Lambert',NULL,NULL,'EPSG','4499','EPSG','4267','EPSG','19944','EPSG','1368',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32099','NAD27 / Louisiana Offshore',NULL,NULL,'EPSG','4497','EPSG','4267','EPSG','11703','EPSG','1387',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32100','NAD83 / Montana',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12530','EPSG','1395',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32104','NAD83 / Nebraska',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12630','EPSG','1396',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32107','NAD83 / Nevada East',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12731','EPSG','2224',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32108','NAD83 / Nevada Central',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12732','EPSG','2223',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32109','NAD83 / Nevada West',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12733','EPSG','2225',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32110','NAD83 / New Hampshire',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12830','EPSG','1398',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32111','NAD83 / New Jersey',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','12930','EPSG','1399',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32112','NAD83 / New Mexico East',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13031','EPSG','2228',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32113','NAD83 / New Mexico Central',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13032','EPSG','2231',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32114','NAD83 / New Mexico West',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13033','EPSG','2232',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32115','NAD83 / New York East',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13131','EPSG','2234',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32116','NAD83 / New York Central',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13132','EPSG','2233',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32117','NAD83 / New York West',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13133','EPSG','2236',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32118','NAD83 / New York Long Island',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13134','EPSG','2235',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32119','NAD83 / North Carolina',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13230','EPSG','1402',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32120','NAD83 / North Dakota North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13331','EPSG','2237',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32121','NAD83 / North Dakota South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13332','EPSG','2238',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32122','NAD83 / Ohio North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13431','EPSG','2239',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32123','NAD83 / Ohio South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13432','EPSG','2240',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32124','NAD83 / Oklahoma North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13531','EPSG','2241',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32125','NAD83 / Oklahoma South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13532','EPSG','2242',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32126','NAD83 / Oregon North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13631','EPSG','2243',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32127','NAD83 / Oregon South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13632','EPSG','2244',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32128','NAD83 / Pennsylvania North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13731','EPSG','2245',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32129','NAD83 / Pennsylvania South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13732','EPSG','2246',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32130','NAD83 / Rhode Island',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13830','EPSG','1408',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32133','NAD83 / South Carolina',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','13930','EPSG','1409',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32134','NAD83 / South Dakota North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14031','EPSG','2249',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32135','NAD83 / South Dakota South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14032','EPSG','2250',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32136','NAD83 / Tennessee',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14130','EPSG','1411',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32137','NAD83 / Texas North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14231','EPSG','2253',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32138','NAD83 / Texas North Central',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14232','EPSG','2254',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32139','NAD83 / Texas Central',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14233','EPSG','2252',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32140','NAD83 / Texas South Central',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14234','EPSG','2527',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32141','NAD83 / Texas South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14235','EPSG','2528',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32142','NAD83 / Utah North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14331','EPSG','2258',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32143','NAD83 / Utah Central',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14332','EPSG','2257',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32144','NAD83 / Utah South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14333','EPSG','2259',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32145','NAD83 / Vermont',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14430','EPSG','1414',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32146','NAD83 / Virginia North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14531','EPSG','2260',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32147','NAD83 / Virginia South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14532','EPSG','2261',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32148','NAD83 / Washington North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14631','EPSG','2273',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32149','NAD83 / Washington South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14632','EPSG','2274',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32150','NAD83 / West Virginia North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14731','EPSG','2264',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32151','NAD83 / West Virginia South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14732','EPSG','2265',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32152','NAD83 / Wisconsin North',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14831','EPSG','2267',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32153','NAD83 / Wisconsin Central',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14832','EPSG','2266',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32154','NAD83 / Wisconsin South',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14833','EPSG','2268',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32155','NAD83 / Wyoming East',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14931','EPSG','2269',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32156','NAD83 / Wyoming East Central',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14932','EPSG','2270',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32157','NAD83 / Wyoming West Central',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14933','EPSG','2272',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32158','NAD83 / Wyoming West',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','14934','EPSG','2271',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32161','NAD83 / Puerto Rico & Virgin Is.',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','15230','EPSG','2251',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32164','NAD83 / BLM 14N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15914','EPSG','3637',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32165','NAD83 / BLM 15N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15915','EPSG','3640',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32166','NAD83 / BLM 16N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15916','EPSG','3641',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32167','NAD83 / BLM 17N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4269','EPSG','15917','EPSG','3642',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32180','NAD83 / SCoPQ zone 2',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','17700','EPSG','1420',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','32181','NAD83 / MTM zone 1',NULL,NULL,'EPSG','4496','EPSG','4269','EPSG','17701','EPSG','2226',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32182','NAD83 / MTM zone 2',NULL,NULL,'EPSG','4496','EPSG','4269','EPSG','17702','EPSG','2227',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32183','NAD83 / MTM zone 3',NULL,NULL,'EPSG','4496','EPSG','4269','EPSG','17703','EPSG','2290',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32184','NAD83 / MTM zone 4',NULL,NULL,'EPSG','4496','EPSG','4269','EPSG','17704','EPSG','2276',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32185','NAD83 / MTM zone 5',NULL,NULL,'EPSG','4496','EPSG','4269','EPSG','17705','EPSG','2277',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32186','NAD83 / MTM zone 6',NULL,NULL,'EPSG','4496','EPSG','4269','EPSG','17706','EPSG','2278',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32187','NAD83 / MTM zone 7',NULL,NULL,'EPSG','4496','EPSG','4269','EPSG','17707','EPSG','1425',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32188','NAD83 / MTM zone 8',NULL,NULL,'EPSG','4496','EPSG','4269','EPSG','17708','EPSG','2279',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32189','NAD83 / MTM zone 9',NULL,NULL,'EPSG','4496','EPSG','4269','EPSG','17709','EPSG','2280',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32190','NAD83 / MTM zone 10',NULL,NULL,'EPSG','4496','EPSG','4269','EPSG','17710','EPSG','2281',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32191','NAD83 / MTM zone 11',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','17711','EPSG','1432',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32192','NAD83 / MTM zone 12',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','17712','EPSG','1433',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32193','NAD83 / MTM zone 13',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','17713','EPSG','1434',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32194','NAD83 / MTM zone 14',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','17714','EPSG','1435',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32195','NAD83 / MTM zone 15',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','17715','EPSG','1436',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32196','NAD83 / MTM zone 16',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','17716','EPSG','1437',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32197','NAD83 / MTM zone 17',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','17717','EPSG','1438',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32198','NAD83 / Quebec Lambert',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','19944','EPSG','1368',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32199','NAD83 / Louisiana Offshore',NULL,NULL,'EPSG','4499','EPSG','4269','EPSG','11733','EPSG','1387',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32201','WGS 72 / UTM zone 1N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16001','EPSG','1873',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32202','WGS 72 / UTM zone 2N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16002','EPSG','1875',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32203','WGS 72 / UTM zone 3N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16003','EPSG','1877',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32204','WGS 72 / UTM zone 4N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16004','EPSG','1879',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32205','WGS 72 / UTM zone 5N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16005','EPSG','1881',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32206','WGS 72 / UTM zone 6N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16006','EPSG','1883',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32207','WGS 72 / UTM zone 7N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16007','EPSG','1885',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32208','WGS 72 / UTM zone 8N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16008','EPSG','1887',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32209','WGS 72 / UTM zone 9N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16009','EPSG','1889',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32210','WGS 72 / UTM zone 10N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16010','EPSG','1891',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32211','WGS 72 / UTM zone 11N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16011','EPSG','1893',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32212','WGS 72 / UTM zone 12N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16012','EPSG','1895',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32213','WGS 72 / UTM zone 13N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16013','EPSG','1897',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32214','WGS 72 / UTM zone 14N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16014','EPSG','1899',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32215','WGS 72 / UTM zone 15N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16015','EPSG','1901',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32216','WGS 72 / UTM zone 16N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16016','EPSG','1903',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32217','WGS 72 / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16017','EPSG','1905',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32218','WGS 72 / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16018','EPSG','1907',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32219','WGS 72 / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16019','EPSG','1909',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32220','WGS 72 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16020','EPSG','1911',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32221','WGS 72 / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16021','EPSG','1913',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32222','WGS 72 / UTM zone 22N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16022','EPSG','1915',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32223','WGS 72 / UTM zone 23N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16023','EPSG','1917',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32224','WGS 72 / UTM zone 24N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16024','EPSG','1919',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32225','WGS 72 / UTM zone 25N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16025','EPSG','1921',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32226','WGS 72 / UTM zone 26N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16026','EPSG','1923',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32227','WGS 72 / UTM zone 27N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16027','EPSG','1925',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32228','WGS 72 / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16028','EPSG','1927',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32229','WGS 72 / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16029','EPSG','1929',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32230','WGS 72 / UTM zone 30N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16030','EPSG','1931',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32231','WGS 72 / UTM zone 31N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16031','EPSG','1933',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32232','WGS 72 / UTM zone 32N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16032','EPSG','1935',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32233','WGS 72 / UTM zone 33N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16033','EPSG','1937',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32234','WGS 72 / UTM zone 34N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16034','EPSG','1939',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32235','WGS 72 / UTM zone 35N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16035','EPSG','1941',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32236','WGS 72 / UTM zone 36N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16036','EPSG','1943',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32237','WGS 72 / UTM zone 37N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16037','EPSG','1945',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32238','WGS 72 / UTM zone 38N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16038','EPSG','1947',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32239','WGS 72 / UTM zone 39N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16039','EPSG','1949',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32240','WGS 72 / UTM zone 40N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16040','EPSG','1951',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32241','WGS 72 / UTM zone 41N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16041','EPSG','1953',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32242','WGS 72 / UTM zone 42N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16042','EPSG','1955',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32243','WGS 72 / UTM zone 43N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16043','EPSG','1957',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32244','WGS 72 / UTM zone 44N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16044','EPSG','1959',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32245','WGS 72 / UTM zone 45N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16045','EPSG','1961',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32246','WGS 72 / UTM zone 46N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16046','EPSG','1963',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32247','WGS 72 / UTM zone 47N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16047','EPSG','1965',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32248','WGS 72 / UTM zone 48N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16048','EPSG','1967',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32249','WGS 72 / UTM zone 49N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16049','EPSG','1969',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32250','WGS 72 / UTM zone 50N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16050','EPSG','1971',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32251','WGS 72 / UTM zone 51N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16051','EPSG','1973',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32252','WGS 72 / UTM zone 52N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16052','EPSG','1975',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32253','WGS 72 / UTM zone 53N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16053','EPSG','1977',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32254','WGS 72 / UTM zone 54N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16054','EPSG','1979',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32255','WGS 72 / UTM zone 55N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16055','EPSG','1981',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32256','WGS 72 / UTM zone 56N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16056','EPSG','1983',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32257','WGS 72 / UTM zone 57N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16057','EPSG','1985',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32258','WGS 72 / UTM zone 58N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16058','EPSG','1987',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32259','WGS 72 / UTM zone 59N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16059','EPSG','1989',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32260','WGS 72 / UTM zone 60N',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16060','EPSG','1991',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32301','WGS 72 / UTM zone 1S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16101','EPSG','1874',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32302','WGS 72 / UTM zone 2S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16102','EPSG','1876',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32303','WGS 72 / UTM zone 3S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16103','EPSG','1878',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32304','WGS 72 / UTM zone 4S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16104','EPSG','1880',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32305','WGS 72 / UTM zone 5S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16105','EPSG','1882',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32306','WGS 72 / UTM zone 6S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16106','EPSG','1884',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32307','WGS 72 / UTM zone 7S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16107','EPSG','1886',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32308','WGS 72 / UTM zone 8S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16108','EPSG','1888',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32309','WGS 72 / UTM zone 9S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16109','EPSG','1890',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32310','WGS 72 / UTM zone 10S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16110','EPSG','1892',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32311','WGS 72 / UTM zone 11S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16111','EPSG','1894',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32312','WGS 72 / UTM zone 12S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16112','EPSG','1896',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32313','WGS 72 / UTM zone 13S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16113','EPSG','1898',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32314','WGS 72 / UTM zone 14S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16114','EPSG','1900',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32315','WGS 72 / UTM zone 15S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16115','EPSG','1902',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32316','WGS 72 / UTM zone 16S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16116','EPSG','1904',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32317','WGS 72 / UTM zone 17S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16117','EPSG','1906',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32318','WGS 72 / UTM zone 18S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16118','EPSG','1908',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32319','WGS 72 / UTM zone 19S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16119','EPSG','1910',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32320','WGS 72 / UTM zone 20S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16120','EPSG','1912',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32321','WGS 72 / UTM zone 21S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16121','EPSG','1914',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32322','WGS 72 / UTM zone 22S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16122','EPSG','1916',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32323','WGS 72 / UTM zone 23S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16123','EPSG','1918',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32324','WGS 72 / UTM zone 24S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16124','EPSG','1920',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32325','WGS 72 / UTM zone 25S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16125','EPSG','1922',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32326','WGS 72 / UTM zone 26S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16126','EPSG','1924',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32327','WGS 72 / UTM zone 27S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16127','EPSG','1926',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32328','WGS 72 / UTM zone 28S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16128','EPSG','1928',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32329','WGS 72 / UTM zone 29S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16129','EPSG','1930',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32330','WGS 72 / UTM zone 30S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16130','EPSG','1932',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32331','WGS 72 / UTM zone 31S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16131','EPSG','1934',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32332','WGS 72 / UTM zone 32S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16132','EPSG','1936',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32333','WGS 72 / UTM zone 33S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16133','EPSG','1938',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32334','WGS 72 / UTM zone 34S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16134','EPSG','1940',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32335','WGS 72 / UTM zone 35S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16135','EPSG','1942',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32336','WGS 72 / UTM zone 36S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16136','EPSG','1944',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32337','WGS 72 / UTM zone 37S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16137','EPSG','1946',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32338','WGS 72 / UTM zone 38S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16138','EPSG','1948',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32339','WGS 72 / UTM zone 39S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16139','EPSG','1950',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32340','WGS 72 / UTM zone 40S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16140','EPSG','1952',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32341','WGS 72 / UTM zone 41S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16141','EPSG','1954',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32342','WGS 72 / UTM zone 42S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16142','EPSG','1956',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32343','WGS 72 / UTM zone 43S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16143','EPSG','1958',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32344','WGS 72 / UTM zone 44S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16144','EPSG','1960',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32345','WGS 72 / UTM zone 45S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16145','EPSG','1962',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32346','WGS 72 / UTM zone 46S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16146','EPSG','1964',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32347','WGS 72 / UTM zone 47S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16147','EPSG','1966',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32348','WGS 72 / UTM zone 48S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16148','EPSG','1968',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32349','WGS 72 / UTM zone 49S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16149','EPSG','1970',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32350','WGS 72 / UTM zone 50S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16150','EPSG','1972',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32351','WGS 72 / UTM zone 51S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16151','EPSG','1974',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32352','WGS 72 / UTM zone 52S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16152','EPSG','1976',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32353','WGS 72 / UTM zone 53S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16153','EPSG','1978',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32354','WGS 72 / UTM zone 54S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16154','EPSG','1980',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32355','WGS 72 / UTM zone 55S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16155','EPSG','1982',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32356','WGS 72 / UTM zone 56S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16156','EPSG','1984',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32357','WGS 72 / UTM zone 57S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16157','EPSG','1986',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32358','WGS 72 / UTM zone 58S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16158','EPSG','1988',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32359','WGS 72 / UTM zone 59S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16159','EPSG','1990',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32360','WGS 72 / UTM zone 60S',NULL,NULL,'EPSG','4400','EPSG','4322','EPSG','16160','EPSG','1992',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32401','WGS 72BE / UTM zone 1N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16001','EPSG','1873',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32402','WGS 72BE / UTM zone 2N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16002','EPSG','1876',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32403','WGS 72BE / UTM zone 3N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16003','EPSG','1877',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32404','WGS 72BE / UTM zone 4N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16004','EPSG','1879',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32405','WGS 72BE / UTM zone 5N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16005','EPSG','1881',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32406','WGS 72BE / UTM zone 6N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16006','EPSG','1883',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32407','WGS 72BE / UTM zone 7N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16007','EPSG','1885',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32408','WGS 72BE / UTM zone 8N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16008','EPSG','1887',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32409','WGS 72BE / UTM zone 9N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16009','EPSG','1889',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32410','WGS 72BE / UTM zone 10N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16010','EPSG','1891',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32411','WGS 72BE / UTM zone 11N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16011','EPSG','1893',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32412','WGS 72BE / UTM zone 12N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16012','EPSG','1895',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32413','WGS 72BE / UTM zone 13N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16013','EPSG','1897',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32414','WGS 72BE / UTM zone 14N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16014','EPSG','1899',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32415','WGS 72BE / UTM zone 15N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16015','EPSG','1901',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32416','WGS 72BE / UTM zone 16N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16016','EPSG','1903',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32417','WGS 72BE / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16017','EPSG','1905',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32418','WGS 72BE / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16018','EPSG','1907',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32419','WGS 72BE / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16019','EPSG','1909',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32420','WGS 72BE / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16020','EPSG','1911',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32421','WGS 72BE / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16021','EPSG','1913',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32422','WGS 72BE / UTM zone 22N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16022','EPSG','1915',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32423','WGS 72BE / UTM zone 23N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16023','EPSG','1917',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32424','WGS 72BE / UTM zone 24N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16024','EPSG','1919',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32425','WGS 72BE / UTM zone 25N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16025','EPSG','1921',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32426','WGS 72BE / UTM zone 26N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16026','EPSG','1923',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32427','WGS 72BE / UTM zone 27N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16027','EPSG','1925',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32428','WGS 72BE / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16028','EPSG','1927',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32429','WGS 72BE / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16029','EPSG','1929',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32430','WGS 72BE / UTM zone 30N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16030','EPSG','1931',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32431','WGS 72BE / UTM zone 31N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16031','EPSG','1933',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32432','WGS 72BE / UTM zone 32N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16032','EPSG','1935',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32433','WGS 72BE / UTM zone 33N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16033','EPSG','3464',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32434','WGS 72BE / UTM zone 34N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16034','EPSG','3465',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32435','WGS 72BE / UTM zone 35N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16035','EPSG','1941',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32436','WGS 72BE / UTM zone 36N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16036','EPSG','1943',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32437','WGS 72BE / UTM zone 37N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16037','EPSG','1945',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32438','WGS 72BE / UTM zone 38N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16038','EPSG','1947',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32439','WGS 72BE / UTM zone 39N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16039','EPSG','1949',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32440','WGS 72BE / UTM zone 40N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16040','EPSG','1951',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32441','WGS 72BE / UTM zone 41N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16041','EPSG','1953',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32442','WGS 72BE / UTM zone 42N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16042','EPSG','1955',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32443','WGS 72BE / UTM zone 43N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16043','EPSG','1957',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32444','WGS 72BE / UTM zone 44N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16044','EPSG','1959',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32445','WGS 72BE / UTM zone 45N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16045','EPSG','1961',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32446','WGS 72BE / UTM zone 46N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16046','EPSG','1963',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32447','WGS 72BE / UTM zone 47N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16047','EPSG','1965',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32448','WGS 72BE / UTM zone 48N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16048','EPSG','1993',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32449','WGS 72BE / UTM zone 49N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16049','EPSG','1994',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32450','WGS 72BE / UTM zone 50N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16050','EPSG','1971',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32451','WGS 72BE / UTM zone 51N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16051','EPSG','1973',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32452','WGS 72BE / UTM zone 52N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16052','EPSG','1975',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32453','WGS 72BE / UTM zone 53N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16053','EPSG','1977',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32454','WGS 72BE / UTM zone 54N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16054','EPSG','1979',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32455','WGS 72BE / UTM zone 55N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16055','EPSG','1981',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32456','WGS 72BE / UTM zone 56N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16056','EPSG','1983',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32457','WGS 72BE / UTM zone 57N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16057','EPSG','1985',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32458','WGS 72BE / UTM zone 58N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16058','EPSG','1987',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32459','WGS 72BE / UTM zone 59N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16059','EPSG','1989',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32460','WGS 72BE / UTM zone 60N',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16060','EPSG','1991',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32501','WGS 72BE / UTM zone 1S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16101','EPSG','1874',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32502','WGS 72BE / UTM zone 2S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16102','EPSG','1876',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32503','WGS 72BE / UTM zone 3S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16103','EPSG','1878',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32504','WGS 72BE / UTM zone 4S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16104','EPSG','1880',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32505','WGS 72BE / UTM zone 5S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16105','EPSG','1882',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32506','WGS 72BE / UTM zone 6S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16106','EPSG','1884',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32507','WGS 72BE / UTM zone 7S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16107','EPSG','1886',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32508','WGS 72BE / UTM zone 8S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16108','EPSG','1888',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32509','WGS 72BE / UTM zone 9S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16109','EPSG','1890',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32510','WGS 72BE / UTM zone 10S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16110','EPSG','1892',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32511','WGS 72BE / UTM zone 11S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16111','EPSG','1894',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32512','WGS 72BE / UTM zone 12S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16112','EPSG','1896',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32513','WGS 72BE / UTM zone 13S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16113','EPSG','1898',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32514','WGS 72BE / UTM zone 14S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16114','EPSG','1900',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32515','WGS 72BE / UTM zone 15S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16115','EPSG','1902',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32516','WGS 72BE / UTM zone 16S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16116','EPSG','1904',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32517','WGS 72BE / UTM zone 17S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16117','EPSG','1906',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32518','WGS 72BE / UTM zone 18S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16118','EPSG','1908',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32519','WGS 72BE / UTM zone 19S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16119','EPSG','1910',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32520','WGS 72BE / UTM zone 20S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16120','EPSG','1912',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32521','WGS 72BE / UTM zone 21S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16121','EPSG','1914',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32522','WGS 72BE / UTM zone 22S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16122','EPSG','1916',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32523','WGS 72BE / UTM zone 23S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16123','EPSG','1918',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32524','WGS 72BE / UTM zone 24S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16124','EPSG','1920',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32525','WGS 72BE / UTM zone 25S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16125','EPSG','1922',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32526','WGS 72BE / UTM zone 26S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16126','EPSG','1924',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32527','WGS 72BE / UTM zone 27S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16127','EPSG','1926',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32528','WGS 72BE / UTM zone 28S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16128','EPSG','1928',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32529','WGS 72BE / UTM zone 29S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16129','EPSG','1930',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32530','WGS 72BE / UTM zone 30S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16130','EPSG','1932',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32531','WGS 72BE / UTM zone 31S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16131','EPSG','1934',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32532','WGS 72BE / UTM zone 32S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16132','EPSG','1936',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32533','WGS 72BE / UTM zone 33S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16133','EPSG','1938',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32534','WGS 72BE / UTM zone 34S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16134','EPSG','1940',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32535','WGS 72BE / UTM zone 35S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16135','EPSG','1942',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32536','WGS 72BE / UTM zone 36S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16136','EPSG','1944',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32537','WGS 72BE / UTM zone 37S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16137','EPSG','1946',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32538','WGS 72BE / UTM zone 38S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16138','EPSG','1948',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32539','WGS 72BE / UTM zone 39S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16139','EPSG','1950',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32540','WGS 72BE / UTM zone 40S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16140','EPSG','1952',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32541','WGS 72BE / UTM zone 41S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16141','EPSG','1954',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32542','WGS 72BE / UTM zone 42S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16142','EPSG','1956',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32543','WGS 72BE / UTM zone 43S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16143','EPSG','1958',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32544','WGS 72BE / UTM zone 44S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16144','EPSG','1960',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32545','WGS 72BE / UTM zone 45S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16145','EPSG','1962',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32546','WGS 72BE / UTM zone 46S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16146','EPSG','1964',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32547','WGS 72BE / UTM zone 47S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16147','EPSG','1966',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32548','WGS 72BE / UTM zone 48S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16148','EPSG','1968',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32549','WGS 72BE / UTM zone 49S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16149','EPSG','1995',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32550','WGS 72BE / UTM zone 50S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16150','EPSG','1972',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32551','WGS 72BE / UTM zone 51S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16151','EPSG','1974',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32552','WGS 72BE / UTM zone 52S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16152','EPSG','1976',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32553','WGS 72BE / UTM zone 53S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16153','EPSG','1978',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32554','WGS 72BE / UTM zone 54S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16154','EPSG','1980',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32555','WGS 72BE / UTM zone 55S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16155','EPSG','1982',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32556','WGS 72BE / UTM zone 56S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16156','EPSG','1984',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32557','WGS 72BE / UTM zone 57S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16157','EPSG','1986',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32558','WGS 72BE / UTM zone 58S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16158','EPSG','1988',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32559','WGS 72BE / UTM zone 59S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16159','EPSG','1990',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32560','WGS 72BE / UTM zone 60S',NULL,NULL,'EPSG','4400','EPSG','4324','EPSG','16160','EPSG','1992',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32600','WGS 84 / UTM grid system (northern hemisphere)',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16000','EPSG','1998',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32601','WGS 84 / UTM zone 1N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16001','EPSG','2000',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32602','WGS 84 / UTM zone 2N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16002','EPSG','2002',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32603','WGS 84 / UTM zone 3N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16003','EPSG','2004',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32604','WGS 84 / UTM zone 4N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16004','EPSG','2006',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32605','WGS 84 / UTM zone 5N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16005','EPSG','2008',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32606','WGS 84 / UTM zone 6N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16006','EPSG','2010',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32607','WGS 84 / UTM zone 7N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16007','EPSG','2012',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32608','WGS 84 / UTM zone 8N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16008','EPSG','2014',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32609','WGS 84 / UTM zone 9N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16009','EPSG','2016',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32610','WGS 84 / UTM zone 10N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16010','EPSG','2018',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32611','WGS 84 / UTM zone 11N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16011','EPSG','2020',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32612','WGS 84 / UTM zone 12N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16012','EPSG','2022',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32613','WGS 84 / UTM zone 13N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16013','EPSG','2024',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32614','WGS 84 / UTM zone 14N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16014','EPSG','2026',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32615','WGS 84 / UTM zone 15N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16015','EPSG','2028',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32616','WGS 84 / UTM zone 16N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16016','EPSG','2030',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32617','WGS 84 / UTM zone 17N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16017','EPSG','2032',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32618','WGS 84 / UTM zone 18N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16018','EPSG','2034',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32619','WGS 84 / UTM zone 19N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16019','EPSG','2036',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32620','WGS 84 / UTM zone 20N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16020','EPSG','2038',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32621','WGS 84 / UTM zone 21N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16021','EPSG','2040',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32622','WGS 84 / UTM zone 22N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16022','EPSG','2042',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32623','WGS 84 / UTM zone 23N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16023','EPSG','2044',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32624','WGS 84 / UTM zone 24N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16024','EPSG','2046',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32625','WGS 84 / UTM zone 25N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16025','EPSG','2048',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32626','WGS 84 / UTM zone 26N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16026','EPSG','2050',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32627','WGS 84 / UTM zone 27N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16027','EPSG','2052',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32628','WGS 84 / UTM zone 28N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16028','EPSG','2054',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32629','WGS 84 / UTM zone 29N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16029','EPSG','2056',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32630','WGS 84 / UTM zone 30N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16030','EPSG','2058',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32631','WGS 84 / UTM zone 31N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16031','EPSG','2060',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32632','WGS 84 / UTM zone 32N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16032','EPSG','2062',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32633','WGS 84 / UTM zone 33N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16033','EPSG','2064',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32634','WGS 84 / UTM zone 34N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16034','EPSG','2066',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32635','WGS 84 / UTM zone 35N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16035','EPSG','2068',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32636','WGS 84 / UTM zone 36N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16036','EPSG','2070',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32637','WGS 84 / UTM zone 37N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16037','EPSG','2072',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32638','WGS 84 / UTM zone 38N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16038','EPSG','2074',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32639','WGS 84 / UTM zone 39N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16039','EPSG','2076',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32640','WGS 84 / UTM zone 40N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16040','EPSG','2078',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32641','WGS 84 / UTM zone 41N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16041','EPSG','2080',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32642','WGS 84 / UTM zone 42N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16042','EPSG','2082',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32643','WGS 84 / UTM zone 43N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16043','EPSG','2084',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32644','WGS 84 / UTM zone 44N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16044','EPSG','2086',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32645','WGS 84 / UTM zone 45N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16045','EPSG','2088',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32646','WGS 84 / UTM zone 46N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16046','EPSG','2090',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32647','WGS 84 / UTM zone 47N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16047','EPSG','2092',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32648','WGS 84 / UTM zone 48N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16048','EPSG','2094',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32649','WGS 84 / UTM zone 49N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16049','EPSG','2096',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32650','WGS 84 / UTM zone 50N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16050','EPSG','2098',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32651','WGS 84 / UTM zone 51N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16051','EPSG','2100',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32652','WGS 84 / UTM zone 52N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16052','EPSG','2102',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32653','WGS 84 / UTM zone 53N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16053','EPSG','2104',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32654','WGS 84 / UTM zone 54N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16054','EPSG','2106',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32655','WGS 84 / UTM zone 55N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16055','EPSG','2108',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32656','WGS 84 / UTM zone 56N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16056','EPSG','2110',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32657','WGS 84 / UTM zone 57N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16057','EPSG','2112',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32658','WGS 84 / UTM zone 58N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16058','EPSG','2114',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32659','WGS 84 / UTM zone 59N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16059','EPSG','2116',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32660','WGS 84 / UTM zone 60N',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16060','EPSG','2118',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32661','WGS 84 / UPS North (N,E)',NULL,NULL,'EPSG','4493','EPSG','4326','EPSG','16061','EPSG','1996',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32662','WGS 84 / Plate Carree',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','19968','EPSG','1262',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','32663','WGS 84 / World Equidistant Cylindrical',NULL,NULL,'EPSG','4499','EPSG','4326','EPSG','19846','EPSG','1262',NULL,1);
INSERT INTO "projected_crs" VALUES('EPSG','32664','WGS 84 / BLM 14N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4326','EPSG','15914','EPSG','2171',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32665','WGS 84 / BLM 15N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4326','EPSG','15915','EPSG','2172',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32666','WGS 84 / BLM 16N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4326','EPSG','15916','EPSG','2173',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32667','WGS 84 / BLM 17N (ftUS)',NULL,NULL,'EPSG','4497','EPSG','4326','EPSG','15917','EPSG','2174',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32700','WGS 84 / UTM grid system (southern hemisphere)',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16100','EPSG','1999',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32701','WGS 84 / UTM zone 1S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16101','EPSG','2001',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32702','WGS 84 / UTM zone 2S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16102','EPSG','2003',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32703','WGS 84 / UTM zone 3S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16103','EPSG','2005',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32704','WGS 84 / UTM zone 4S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16104','EPSG','2007',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32705','WGS 84 / UTM zone 5S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16105','EPSG','2009',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32706','WGS 84 / UTM zone 6S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16106','EPSG','2011',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32707','WGS 84 / UTM zone 7S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16107','EPSG','2013',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32708','WGS 84 / UTM zone 8S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16108','EPSG','2015',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32709','WGS 84 / UTM zone 9S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16109','EPSG','2017',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32710','WGS 84 / UTM zone 10S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16110','EPSG','2019',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32711','WGS 84 / UTM zone 11S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16111','EPSG','2021',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32712','WGS 84 / UTM zone 12S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16112','EPSG','2023',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32713','WGS 84 / UTM zone 13S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16113','EPSG','2025',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32714','WGS 84 / UTM zone 14S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16114','EPSG','2027',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32715','WGS 84 / UTM zone 15S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16115','EPSG','2029',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32716','WGS 84 / UTM zone 16S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16116','EPSG','2031',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32717','WGS 84 / UTM zone 17S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16117','EPSG','2033',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32718','WGS 84 / UTM zone 18S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16118','EPSG','2035',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32719','WGS 84 / UTM zone 19S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16119','EPSG','2037',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32720','WGS 84 / UTM zone 20S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16120','EPSG','2039',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32721','WGS 84 / UTM zone 21S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16121','EPSG','2041',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32722','WGS 84 / UTM zone 22S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16122','EPSG','2043',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32723','WGS 84 / UTM zone 23S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16123','EPSG','2045',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32724','WGS 84 / UTM zone 24S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16124','EPSG','2047',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32725','WGS 84 / UTM zone 25S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16125','EPSG','2049',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32726','WGS 84 / UTM zone 26S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16126','EPSG','2051',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32727','WGS 84 / UTM zone 27S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16127','EPSG','2053',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32728','WGS 84 / UTM zone 28S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16128','EPSG','2055',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32729','WGS 84 / UTM zone 29S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16129','EPSG','2057',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32730','WGS 84 / UTM zone 30S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16130','EPSG','2059',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32731','WGS 84 / UTM zone 31S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16131','EPSG','2061',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32732','WGS 84 / UTM zone 32S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16132','EPSG','2063',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32733','WGS 84 / UTM zone 33S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16133','EPSG','2065',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32734','WGS 84 / UTM zone 34S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16134','EPSG','2067',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32735','WGS 84 / UTM zone 35S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16135','EPSG','2069',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32736','WGS 84 / UTM zone 36S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16136','EPSG','2071',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32737','WGS 84 / UTM zone 37S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16137','EPSG','2073',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32738','WGS 84 / UTM zone 38S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16138','EPSG','2075',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32739','WGS 84 / UTM zone 39S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16139','EPSG','2077',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32740','WGS 84 / UTM zone 40S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16140','EPSG','2079',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32741','WGS 84 / UTM zone 41S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16141','EPSG','2081',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32742','WGS 84 / UTM zone 42S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16142','EPSG','2083',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32743','WGS 84 / UTM zone 43S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16143','EPSG','2085',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32744','WGS 84 / UTM zone 44S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16144','EPSG','2087',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32745','WGS 84 / UTM zone 45S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16145','EPSG','2089',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32746','WGS 84 / UTM zone 46S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16146','EPSG','2091',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32747','WGS 84 / UTM zone 47S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16147','EPSG','2093',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32748','WGS 84 / UTM zone 48S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16148','EPSG','2095',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32749','WGS 84 / UTM zone 49S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16149','EPSG','2097',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32750','WGS 84 / UTM zone 50S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16150','EPSG','2099',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32751','WGS 84 / UTM zone 51S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16151','EPSG','2101',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32752','WGS 84 / UTM zone 52S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16152','EPSG','2103',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32753','WGS 84 / UTM zone 53S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16153','EPSG','2105',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32754','WGS 84 / UTM zone 54S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16154','EPSG','2107',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32755','WGS 84 / UTM zone 55S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16155','EPSG','2109',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32756','WGS 84 / UTM zone 56S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16156','EPSG','2111',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32757','WGS 84 / UTM zone 57S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16157','EPSG','2113',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32758','WGS 84 / UTM zone 58S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16158','EPSG','2115',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32759','WGS 84 / UTM zone 59S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16159','EPSG','2117',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32760','WGS 84 / UTM zone 60S',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16160','EPSG','2119',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32761','WGS 84 / UPS South (N,E)',NULL,NULL,'EPSG','4494','EPSG','4326','EPSG','16161','EPSG','1997',NULL,0);
INSERT INTO "projected_crs" VALUES('EPSG','32766','WGS 84 / TM 36 SE',NULL,NULL,'EPSG','4400','EPSG','4326','EPSG','16636','EPSG','1726',NULL,0);
