--- This file has been generated by scripts/build_db_from_esri.py. DO NOT EDIT !

INSERT INTO "metadata" VALUES('ESRI.VERSION', 'ArcMap 10.7.0');
INSERT INTO "metadata" VALUES('ESRI.DATE', '2019-03-25');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','1025','Millimeter','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','1033','Centimeter','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9001','Meter','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9002','Foot','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9003','Foot_US','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9005','Foot_Clarke','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9014','Fathom','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9030','Nautical_Mile','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9031','Meter_German','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9033','Chain_US','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9034','Link_US','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9035','Mile_US','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9036','Kilometer','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9037','Yard_Clarke','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9038','Chain_Clarke','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9039','Link_Clarke','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9040','Yard_Sears','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9041','Foot_Sears','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9042','Chain_Sears','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9043','Link_Sears','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9050','Yard_Benoit_1895_A','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9051','Foot_Benoit_1895_A','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9052','Chain_Benoit_1895_A','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9053','Link_Benoit_1895_A','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9060','Yard_Benoit_1895_B','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9061','Foot_Benoit_1895_B','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9062','Chain_Benoit_1895_B','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9063','Link_Benoit_1895_B','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9070','Foot_1865','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9080','Foot_Indian','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9081','Foot_Indian_1937','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9082','Foot_Indian_1962','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9083','Foot_Indian_1975','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9084','Yard_Indian','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9085','Yard_Indian_1937','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9086','Yard_Indian_1962','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9087','Yard_Indian_1975','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9093','Statute_Mile','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9094','Foot_Gold_Coast','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9095','Foot_British_1936','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9096','Yard','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9097','Chain','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9098','Link','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9099','Yard_Sears_1922_Truncated','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9300','Foot_Sears_1922_Truncated','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9301','Chain_Sears_1922_Truncated','ESRI');
INSERT INTO alias_name VALUES('unit_of_measure','EPSG','9302','Link_Sears_1922_Truncated','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','1026','Zach_1812','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7001','Airy_1830','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7002','Airy_Modified','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7003','Australian','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7004','Bessel_1841','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7005','Bessel_Modified','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7006','Bessel_Namibia','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7007','Clarke_1858','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7008','Clarke_1866','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7009','Clarke_1866_Michigan','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7010','Clarke_1880_Benoit','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7011','Clarke_1880_IGN','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7012','Clarke_1880_RGS','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7013','Clarke_1880_Arc','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7014','Clarke_1880_SGA','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7015','Everest_Adjustment_1937','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7016','Everest_Definition_1967','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7018','Everest_1830_Modified','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7019','GRS_1980','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7020','Helmert_1906','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7021','Indonesian','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7022','International_1924','ESRI');
INSERT INTO ellipsoid VALUES('ESRI','7023','International_1967','International 1967','PROJ','EARTH',6378160.0,'EPSG','9001',298.25,NULL,0);
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7024','Krasovsky_1940','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7025','NWL_9D','ESRI');
INSERT INTO ellipsoid VALUES('ESRI','7026','NWL_10D','NWL-10D == WGS 1972','PROJ','EARTH',6378135.0,'EPSG','9001',298.26,NULL,0);
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7027','Plessis_1817','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7028','Struve_1860','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7029','War_Office','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7030','WGS_1984','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7031','GEM_10C','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7032','OSU_86F','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7033','OSU_91A','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7034','Clarke_1880','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7036','GRS_1967','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7041','ATS_1977','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7042','Everest_1830','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7043','WGS_1972','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7044','Everest_Definition_1962','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7045','Everest_Definition_1975','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7048','Sphere_GRS_1980_Authalic','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7049','Xian_1980','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7050','GRS_1967_Truncated','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7051','Danish_1876','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7052','Sphere_Clarke_1866_Authalic','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7053','Hough_1960','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7054','PZ_1990','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7055','Clarke_1880_Intl_Ft','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7056','Everest_Modified_1969','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7057','Sphere_International_1924_Authalic','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7058','Hughes_1980','ESRI');
INSERT INTO alias_name VALUES('ellipsoid','EPSG','7059','WGS_1984_Major_Auxiliary_Sphere','ESRI');
INSERT INTO ellipsoid VALUES('ESRI','107001','WGS_1966','WGS 1966','PROJ','EARTH',6378145.0,'EPSG','9001',298.25,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107002','Fischer_1960','Fischer 1960','PROJ','EARTH',6378166.0,'EPSG','9001',298.3,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107003','Fischer_1968','Fischer 1968','PROJ','EARTH',6378150.0,'EPSG','9001',298.3,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107004','Fischer_Modified','Fischer modified','PROJ','EARTH',6378155.0,'EPSG','9001',298.3,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107005','Hough_1960','Hough 1960','PROJ','EARTH',6378270.0,'EPSG','9001',297.0,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107006','Everest_Modified_1969','Everest modified 1969 - 107006, called Everest 1830 (RSO 1969) in EPSG','PROJ','EARTH',6377295.664,'EPSG','9001',300.8017,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107007','Walbeck','Walbeck','PROJ','EARTH',6376896.0,'EPSG','9001',302.78,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107008','Sphere_ARC_INFO','Authalic sphere (ARC/INFO)','PROJ','EARTH',6370997.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107009','Sphere_EMEP','EMEP Sphere of 6370000 m','PROJ','EARTH',6370000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107036','GRS_1967_Truncated','GRS 1967 Truncated - was 107036, called GRS67 Modified in EPSG','PROJ','EARTH',6378160.0,'EPSG','9001',298.25,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107037','WGS_1984_Major_Auxiliary_Sphere','Major auxiliary sphere based on WGS 1984','PROJ','EARTH',6378137.0,'EPSG','9001',0.0,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107038','CGCS2000','China Geodetic Coordinate System 2000','PROJ','EARTH',6378137.0,'EPSG','9001',298.257222101,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107047','Sphere_GRS_1980_Mean_Radius','Sphere with mean radius based on GRS80','PROJ','EARTH',6371008.7714,'EPSG','9001',0.0,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107700','S_GRS_1980_Adj_MN_Anoka','GRS 1980 Adj. Minnesota Anoka','PROJ','EARTH',6378418.941,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107701','S_GRS_1980_Adj_MN_Becker','GRS 1980 Adj. Minnesota Becker','PROJ','EARTH',6378586.581,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107702','S_GRS_1980_Adj_MN_Beltrami_North','GRS 1980 Adj. Minnesota Beltrami North','PROJ','EARTH',6378505.809,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107703','S_GRS_1980_Adj_MN_Beltrami_South','GRS 1980 Adj. Minnesota Beltrami South','PROJ','EARTH',6378544.823,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107704','S_GRS_1980_Adj_MN_Benton','GRS 1980 Adj. Minnesota Benton','PROJ','EARTH',6378490.569,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107705','S_GRS_1980_Adj_MN_Big_Stone','GRS 1980 Adj. Minnesota Big Stone','PROJ','EARTH',6378470.757,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107706','S_GRS_1980_Adj_MN_Blue_Earth','GRS 1980 Adj. Minnesota Blue Earth','PROJ','EARTH',6378403.701,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107707','S_GRS_1980_Adj_MN_Brown','GRS 1980 Adj. Minnesota Brown','PROJ','EARTH',6378434.181,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107708','S_GRS_1980_Adj_MN_Carlton','GRS 1980 Adj. Minnesota Carlton','PROJ','EARTH',6378454.907,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107709','S_GRS_1980_Adj_MN_Carver','GRS 1980 Adj. Minnesota Carver','PROJ','EARTH',6378400.653,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107710','S_GRS_1980_Adj_MN_Cass_North','GRS 1980 Adj. Minnesota Cass North','PROJ','EARTH',6378567.378,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107711','S_GRS_1980_Adj_MN_Cass_South','GRS 1980 Adj. Minnesota Cass South','PROJ','EARTH',6378546.957,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107712','S_GRS_1980_Adj_MN_Chippewa','GRS 1980 Adj. Minnesota Chippewa','PROJ','EARTH',6378476.853,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107713','S_GRS_1980_Adj_MN_Chisago','GRS 1980 Adj. Minnesota Chisago','PROJ','EARTH',6378411.321,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107714','S_GRS_1980_Adj_MN_Cook_North','GRS 1980 Adj. Minnesota Cook North','PROJ','EARTH',6378647.541,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107715','S_GRS_1980_Adj_MN_Cook_South','GRS 1980 Adj. Minnesota Cook South','PROJ','EARTH',6378647.541,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107716','S_GRS_1980_Adj_MN_Cottonwood','GRS 1980 Adj. Minnesota Cottonwood','PROJ','EARTH',6378514.953,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107717','S_GRS_1980_Adj_MN_Crow_Wing','GRS 1980 Adj. Minnesota Crow Wing','PROJ','EARTH',6378546.957,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107718','S_GRS_1980_Adj_MN_Dakota','GRS 1980 Adj. Minnesota Dakota','PROJ','EARTH',6378421.989,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107719','S_GRS_1980_Adj_MN_Dodge','GRS 1980 Adj. Minnesota Dodge','PROJ','EARTH',6378481.425,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107720','S_GRS_1980_Adj_MN_Douglas','GRS 1980 Adj. Minnesota Douglas','PROJ','EARTH',6378518.001,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107721','S_GRS_1980_Adj_MN_Faribault','GRS 1980 Adj. Minnesota Faribault','PROJ','EARTH',6378521.049,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107722','S_GRS_1980_Adj_MN_Fillmore','GRS 1980 Adj. Minnesota Fillmore','PROJ','EARTH',6378464.661,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107723','S_GRS_1980_Adj_MN_Freeborn','GRS 1980 Adj. Minnesota Freeborn','PROJ','EARTH',6378521.049,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107724','S_GRS_1980_Adj_MN_Goodhue','GRS 1980 Adj. Minnesota Goodhue','PROJ','EARTH',6378434.181,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107725','S_GRS_1980_Adj_MN_Grant','GRS 1980 Adj. Minnesota Grant','PROJ','EARTH',6378518.001,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107726','S_GRS_1980_Adj_MN_Hennepin','GRS 1980 Adj. Minnesota Hennepin','PROJ','EARTH',6378418.941,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107727','S_GRS_1980_Adj_MN_Houston','GRS 1980 Adj. Minnesota Houston','PROJ','EARTH',6378436.619,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107728','S_GRS_1980_Adj_MN_Isanti','GRS 1980 Adj. Minnesota Isanti','PROJ','EARTH',6378411.321,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107729','S_GRS_1980_Adj_MN_Itasca_North','GRS 1980 Adj. Minnesota Itasca North','PROJ','EARTH',6378574.389,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107730','S_GRS_1980_Adj_MN_Itasca_South','GRS 1980 Adj. Minnesota Itasca South','PROJ','EARTH',6378574.389,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107731','S_GRS_1980_Adj_MN_Jackson','GRS 1980 Adj. Minnesota Jackson','PROJ','EARTH',6378521.049,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107732','S_GRS_1980_Adj_MN_Kanabec','GRS 1980 Adj. Minnesota Kanabec','PROJ','EARTH',6378472.281,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107733','S_GRS_1980_Adj_MN_Kandiyohi','GRS 1980 Adj. Minnesota Kandiyohi','PROJ','EARTH',6378498.189,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107734','S_GRS_1980_Adj_MN_Kittson','GRS 1980 Adj. Minnesota Kittson','PROJ','EARTH',6378449.421,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107735','S_GRS_1980_Adj_MN_Koochiching','GRS 1980 Adj. Minnesota Koochiching','PROJ','EARTH',6378525.621,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107736','S_GRS_1980_Adj_MN_Lac_Qui_Parle','GRS 1980 Adj. Minnesota Lac Qui Parle','PROJ','EARTH',6378476.853,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107737','S_GRS_1980_Adj_MN_Lake_of_the_Woods_North','GRS 1980 Adj. Minnesota Lake of the Woods North','PROJ','EARTH',6378466.185,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107738','S_GRS_1980_Adj_MN_Lake_of_the_Woods_South','GRS 1980 Adj. Minnesota Lake of the Woods South','PROJ','EARTH',6378496.665,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107739','S_GRS_1980_Adj_MN_Le_Sueur','GRS 1980 Adj. Minnesota Le Sueur','PROJ','EARTH',6378434.181,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107740','S_GRS_1980_Adj_MN_Lincoln','GRS 1980 Adj. Minnesota Lincoln','PROJ','EARTH',6378643.579,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107741','S_GRS_1980_Adj_MN_Lyon','GRS 1980 Adj. Minnesota Lyon','PROJ','EARTH',6378559.758,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107742','S_GRS_1980_Adj_MN_McLeod','GRS 1980 Adj. Minnesota McLeod','PROJ','EARTH',6378414.369,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107743','S_GRS_1980_Adj_MN_Mahnomen','GRS 1980 Adj. Minnesota Mahnomen','PROJ','EARTH',6378586.581,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107744','S_GRS_1980_Adj_MN_Marshall','GRS 1980 Adj. Minnesota Marshall','PROJ','EARTH',6378441.801,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107745','S_GRS_1980_Adj_MN_Martin','GRS 1980 Adj. Minnesota Martin','PROJ','EARTH',6378521.049,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107746','S_GRS_1980_Adj_MN_Meeker','GRS 1980 Adj. Minnesota Meeker','PROJ','EARTH',6378498.189,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107747','S_GRS_1980_Adj_MN_Morrison','GRS 1980 Adj. Minnesota Morrison','PROJ','EARTH',6378502.761,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107748','S_GRS_1980_Adj_MN_Mower','GRS 1980 Adj. Minnesota Mower','PROJ','EARTH',6378521.049,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107749','S_GRS_1980_Adj_MN_Murray','GRS 1980 Adj. Minnesota Murray','PROJ','EARTH',6378617.061,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107750','S_GRS_1980_Adj_MN_Nicollet','GRS 1980 Adj. Minnesota Nicollet','PROJ','EARTH',6378403.701,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107751','S_GRS_1980_Adj_MN_Nobles','GRS 1980 Adj. Minnesota Nobles','PROJ','EARTH',6378624.681,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107752','S_GRS_1980_Adj_MN_Norman','GRS 1980 Adj. Minnesota Norman','PROJ','EARTH',6378468.623,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107753','S_GRS_1980_Adj_MN_Olmsted','GRS 1980 Adj. Minnesota Olmsted','PROJ','EARTH',6378481.425,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107754','S_GRS_1980_Adj_MN_Ottertail','GRS 1980 Adj. Minnesota Ottertail','PROJ','EARTH',6378525.621,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107755','S_GRS_1980_Adj_MN_Pennington','GRS 1980 Adj. Minnesota Pennington','PROJ','EARTH',6378445.763,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107756','S_GRS_1980_Adj_MN_Pine','GRS 1980 Adj. Minnesota Pine','PROJ','EARTH',6378472.281,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107757','S_GRS_1980_Adj_MN_Pipestone','GRS 1980 Adj. Minnesota Pipestone','PROJ','EARTH',6378670.401,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107758','S_GRS_1980_Adj_MN_Polk','GRS 1980 Adj. Minnesota Polk','PROJ','EARTH',6378445.763,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107759','S_GRS_1980_Adj_MN_Pope','GRS 1980 Adj. Minnesota Pope','PROJ','EARTH',6378502.761,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107760','S_GRS_1980_Adj_MN_Ramsey','GRS 1980 Adj. Minnesota Ramsey','PROJ','EARTH',6378418.941,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107761','S_GRS_1980_Adj_MN_Red_Lake','GRS 1980 Adj. Minnesota Red Lake','PROJ','EARTH',6378445.763,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107762','S_GRS_1980_Adj_MN_Redwood','GRS 1980 Adj. Minnesota Redwood','PROJ','EARTH',6378438.753,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107763','S_GRS_1980_Adj_MN_Renville','GRS 1980 Adj. Minnesota Renville','PROJ','EARTH',6378414.369,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107764','S_GRS_1980_Adj_MN_Rice','GRS 1980 Adj. Minnesota Rice','PROJ','EARTH',6378434.181,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107765','S_GRS_1980_Adj_MN_Rock','GRS 1980 Adj. Minnesota Rock','PROJ','EARTH',6378624.681,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107766','S_GRS_1980_Adj_MN_Roseau','GRS 1980 Adj. Minnesota Roseau','PROJ','EARTH',6378449.421,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107767','S_GRS_1980_Adj_MN_St_Louis_North','GRS 1980 Adj. Minnesota St Louis North','PROJ','EARTH',6378543.909,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107768','S_GRS_1980_Adj_MN_St_Louis_Central','GRS 1980 Adj. Minnesota St Louis Central','PROJ','EARTH',6378605.783,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107769','S_GRS_1980_Adj_MN_St_Louis_South','GRS 1980 Adj. Minnesota St Louis South','PROJ','EARTH',6378540.861,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107770','S_GRS_1980_Adj_MN_Scott','GRS 1980 Adj. Minnesota Scott','PROJ','EARTH',6378421.989,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107771','S_GRS_1980_Adj_MN_Sherburne','GRS 1980 Adj. Minnesota Sherburne','PROJ','EARTH',6378443.325,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107772','S_GRS_1980_Adj_MN_Sibley','GRS 1980 Adj. Minnesota Sibley','PROJ','EARTH',6378414.369,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107773','S_GRS_1980_Adj_MN_Stearns','GRS 1980 Adj. Minnesota Stearns','PROJ','EARTH',6378502.761,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107774','S_GRS_1980_Adj_MN_Steele','GRS 1980 Adj. Minnesota Steele','PROJ','EARTH',6378481.425,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107775','S_GRS_1980_Adj_MN_Stevens','GRS 1980 Adj. Minnesota Stevens','PROJ','EARTH',6378502.761,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107776','S_GRS_1980_Adj_MN_Swift','GRS 1980 Adj. Minnesota Swift','PROJ','EARTH',6378470.757,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107777','S_GRS_1980_Adj_MN_Todd','GRS 1980 Adj. Minnesota Todd','PROJ','EARTH',6378548.481,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107778','S_GRS_1980_Adj_MN_Traverse','GRS 1980 Adj. Minnesota Traverse','PROJ','EARTH',6378463.746,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107779','S_GRS_1980_Adj_MN_Wabasha','GRS 1980 Adj. Minnesota Wabasha','PROJ','EARTH',6378426.561,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107780','S_GRS_1980_Adj_MN_Wadena','GRS 1980 Adj. Minnesota Wadena','PROJ','EARTH',6378546.957,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107781','S_GRS_1980_Adj_MN_Waseca','GRS 1980 Adj. Minnesota Waseca','PROJ','EARTH',6378481.425,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107782','S_GRS_1980_Adj_MN_Watonwan','GRS 1980 Adj. Minnesota Watonwan','PROJ','EARTH',6378514.953,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107783','S_GRS_1980_Adj_MN_Winona','GRS 1980 Adj. Minnesota Winona','PROJ','EARTH',6378453.688,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107784','S_GRS_1980_Adj_MN_Wright','GRS 1980 Adj. Minnesota Wright','PROJ','EARTH',6378443.325,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107785','S_GRS_1980_Adj_MN_Yellow_Medicine','GRS 1980 Adj. Minnesota Yellow Medicine','PROJ','EARTH',6378530.193,'EPSG','9001',298.2572221008827,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107786','S_GRS_1980_Adj_MN_St_Louis','GRS 1980 Adj. Minnesota St. Louis','PROJ','EARTH',6378523.0,'EPSG','9001',298.2752724,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107800','GRS_1980_Adj_WI_AL','GRS 1980 Adj. Wisconsin Ashland','PROJ','EARTH',6378471.92,'EPSG','9001',298.272883775229,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107801','GRS_1980_Adj_WI_BA','GRS 1980 Adj. Wisconsin Barron','PROJ','EARTH',6378472.931,'EPSG','9001',298.272931052052,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107802','GRS_1980_Adj_WI_BF','GRS 1980 Adj. Wisconsin Bayfield','PROJ','EARTH',6378411.351,'EPSG','9001',298.270051421254,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107803','GRS_1980_Adj_WI_BR','GRS 1980 Adj. Wisconsin Brown','PROJ','EARTH',6378137.0,'EPSG','9001',298.257222100225,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107804','GRS_1980_Adj_WI_BU','GRS 1980 Adj. Wisconsin Buffalo','PROJ','EARTH',6378380.991,'EPSG','9001',298.268631713702,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107805','GRS_1980_Adj_WI_BN','GRS 1980 Adj. Wisconsin Burnett','PROJ','EARTH',6378414.96,'EPSG','9001',298.270220186885,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107806','GRS_1980_Adj_WI_CP','GRS 1980 Adj. Wisconsin Chippewa','PROJ','EARTH',6378412.542,'EPSG','9001',298.270107115315,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107807','GRS_1980_Adj_WI_CK','GRS 1980 Adj. Wisconsin Clark','PROJ','EARTH',6378470.401,'EPSG','9001',298.272812743089,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107808','GRS_1980_Adj_WI_CO','GRS 1980 Adj. Wisconsin Columbia','PROJ','EARTH',6378376.331,'EPSG','9001',298.268413800752,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107809','GRS_1980_Adj_WI_CR','GRS 1980 Adj. Wisconsin Crawford','PROJ','EARTH',6378379.031,'EPSG','9001',298.268540059328,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107810','GRS_1980_Adj_WI_DN','GRS 1980 Adj. Wisconsin Dane','PROJ','EARTH',6378407.621,'EPSG','9001',298.269876997368,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107811','GRS_1980_Adj_WI_DR','GRS 1980 Adj. Wisconsin Door','PROJ','EARTH',6378313.92,'EPSG','9001',298.26549531037,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107812','GRS_1980_Adj_WI_DG','GRS 1980 Adj. Wisconsin Douglas','PROJ','EARTH',6378414.93,'EPSG','9001',298.270218784012,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107813','GRS_1980_Adj_WI_DU','GRS 1980 Adj. Wisconsin Dunn','PROJ','EARTH',6378413.021,'EPSG','9001',298.270129514522,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107814','GRS_1980_Adj_WI_EC','GRS 1980 Adj. Wisconsin EauClaire','PROJ','EARTH',6378380.381,'EPSG','9001',298.268603188617,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107815','GRS_1980_Adj_WI_FN','GRS 1980 Adj. Wisconsin Florence','PROJ','EARTH',6378530.851,'EPSG','9001',298.275639532334,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107816','GRS_1980_Adj_WI_FR','GRS 1980 Adj. Wisconsin Forest','PROJ','EARTH',6378591.521,'EPSG','9001',298.278476609315,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107817','GRS_1980_Adj_WI_GT','GRS 1980 Adj. Wisconsin Grant','PROJ','EARTH',6378378.881,'EPSG','9001',298.268533044963,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107818','GRS_1980_Adj_WI_IA','GRS 1980 Adj. Wisconsin Iowa','PROJ','EARTH',6378408.041,'EPSG','9001',298.269896637591,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107819','GRS_1980_Adj_WI_IR','GRS 1980 Adj. Wisconsin Iron','PROJ','EARTH',6378655.071,'EPSG','9001',298.281448362111,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107820','GRS_1980_Adj_WI_JA','GRS 1980 Adj. Wisconsin Jackson','PROJ','EARTH',6378409.151,'EPSG','9001',298.269948543895,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107821','GRS_1980_Adj_WI_LC','GRS 1980 Adj. Wisconsin LaCrosse','PROJ','EARTH',6378379.301,'EPSG','9001',298.268552685186,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107822','GRS_1980_Adj_WI_LG','GRS 1980 Adj. Wisconsin Langlade','PROJ','EARTH',6378560.121,'EPSG','9001',298.277008268831,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107823','GRS_1980_Adj_WI_LN','GRS 1980 Adj. Wisconsin Lincoln','PROJ','EARTH',6378531.821,'EPSG','9001',298.275684891897,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107824','GRS_1980_Adj_WI_MA','GRS 1980 Adj. Wisconsin Marathon','PROJ','EARTH',6378500.6,'EPSG','9001',298.274224921888,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107825','GRS_1980_Adj_WI_MN','GRS 1980 Adj. Wisconsin Marinette','PROJ','EARTH',6378376.041,'EPSG','9001',298.268400239645,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107826','GRS_1980_Adj_WI_ME','GRS 1980 Adj. Wisconsin Menominee','PROJ','EARTH',6378406.601,'EPSG','9001',298.269829299684,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107827','GRS_1980_Adj_WI_MR','GRS 1980 Adj. Wisconsin Monroe','PROJ','EARTH',6378438.991,'EPSG','9001',298.27134393498,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107828','GRS_1980_Adj_WI_OC','GRS 1980 Adj. Wisconsin Oconto','PROJ','EARTH',6378345.42,'EPSG','9001',298.266968327098,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107829','GRS_1980_Adj_WI_ON','GRS 1980 Adj. Wisconsin Oneida','PROJ','EARTH',6378593.86,'EPSG','9001',298.278585986653,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107830','GRS_1980_Adj_WI_PK','GRS 1980 Adj. Wisconsin Polk','PROJ','EARTH',6378413.671,'EPSG','9001',298.270159910105,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107831','GRS_1980_Adj_WI_PT','GRS 1980 Adj. Wisconsin Portage','PROJ','EARTH',6378344.377,'EPSG','9001',298.266919538913,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107832','GRS_1980_Adj_WI_PR','GRS 1980 Adj. Wisconsin Price','PROJ','EARTH',6378563.891,'EPSG','9001',298.277184563214,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107833','GRS_1980_Adj_WI_RC','GRS 1980 Adj. Wisconsin Richland','PROJ','EARTH',6378408.091,'EPSG','9001',298.269898975713,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107834','GRS_1980_Adj_WI_RK','GRS 1980 Adj. Wisconsin Rock','PROJ','EARTH',6378377.671,'EPSG','9001',298.268476462415,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107835','GRS_1980_Adj_WI_RS','GRS 1980 Adj. Wisconsin Rusk','PROJ','EARTH',6378472.751,'EPSG','9001',298.272922634813,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107836','GRS_1980_Adj_WI_SC','GRS 1980 Adj. Wisconsin StCroix','PROJ','EARTH',6378412.511,'EPSG','9001',298.270105665679,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107837','GRS_1980_Adj_WI_SK','GRS 1980 Adj. Wisconsin Sauk','PROJ','EARTH',6378407.281,'EPSG','9001',298.26986109814,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107838','GRS_1980_Adj_WI_SW','GRS 1980 Adj. Wisconsin Sawyer','PROJ','EARTH',6378534.451,'EPSG','9001',298.275807877103,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107839','GRS_1980_Adj_WI_SH','GRS 1980 Adj. Wisconsin Shawano','PROJ','EARTH',6378406.051,'EPSG','9001',298.269803580344,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107840','GRS_1980_Adj_WI_TA','GRS 1980 Adj. Wisconsin Taylor','PROJ','EARTH',6378532.921,'EPSG','9001',298.275736330576,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107841','GRS_1980_Adj_WI_TR','GRS 1980 Adj. Wisconsin Trempealeau','PROJ','EARTH',6378380.091,'EPSG','9001',298.26858962751,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107842','GRS_1980_Adj_WI_VR','GRS 1980 Adj. Wisconsin Vernon','PROJ','EARTH',6378408.941,'EPSG','9001',298.269938723784,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107843','GRS_1980_Adj_WI_VI','GRS 1980 Adj. Wisconsin Vilas','PROJ','EARTH',6378624.171,'EPSG','9001',298.280003402845,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107844','GRS_1980_Adj_WI_WW','GRS 1980 Adj. Wisconsin Walworth','PROJ','EARTH',6378377.411,'EPSG','9001',298.268464304182,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107845','GRS_1980_Adj_WI_WB','GRS 1980 Adj. Wisconsin Washburn','PROJ','EARTH',6378474.591,'EPSG','9001',298.273008677695,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107846','GRS_1980_Adj_WI_WA','GRS 1980 Adj. Wisconsin Washington','PROJ','EARTH',6378407.141,'EPSG','9001',298.269854551399,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107847','GRS_1980_Adj_WI_WK','GRS 1980 Adj. Wisconsin Waukesha','PROJ','EARTH',6378376.871,'EPSG','9001',298.268439052467,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107848','GRS_1980_Adj_WI_WP','GRS 1980 Adj. Wisconsin Waupaca','PROJ','EARTH',6378375.251,'EPSG','9001',298.268363297321,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107849','GRS_1980_Adj_WI_WS','GRS 1980 Adj. Wisconsin Waushara','PROJ','EARTH',6378405.971,'EPSG','9001',298.269799839349,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107850','GRS_1980_Adj_WI_WD','GRS 1980 Adj. Wisconsin Wood','PROJ','EARTH',6378437.651,'EPSG','9001',298.271281273316,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107851','GRS_1980_Adj_WI_AD_JN','GRS 1980 Adj. Wisconsin Adams and Juneau','PROJ','EARTH',6378376.271,'EPSG','9001',298.268410995005,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107852','GRS_1980_Adj_WI_GR_LF','GRS 1980 Adj. Wisconsin Green and Lafayette','PROJ','EARTH',6378408.481,'EPSG','9001',298.269917213063,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107853','GRS_1980_Adj_WI_GL_MQ','GRS 1980 Adj. Wisconsin Green Lake and Marquette','PROJ','EARTH',6378375.601,'EPSG','9001',298.268379664173,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107854','GRS_1980_Adj_WI_DD_JF','GRS 1980 Adj. Wisconsin Dodge and Jefferson','PROJ','EARTH',6378376.811,'EPSG','9001',298.268436246721,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107855','GRS_1980_Adj_WI_PP_PC','GRS 1980 Adj. Wisconsin Pepin and Pierce','PROJ','EARTH',6378381.271,'EPSG','9001',298.268644807185,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107856','GRS_1980_Adj_WI_CL_FL_OG_WN','GRS 1980 Adj. Wisconsin Calumet, Fond du Lac, Outagamie, and Winnebago','PROJ','EARTH',6378345.09,'EPSG','9001',298.266952895494,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107857','GRS_1980_Adj_WI_KN_MW_OZ_RA','GRS 1980 Adj. Wisconsin Kenosha, Milwaukee, Ozaukee, and Racine','PROJ','EARTH',6378315.7,'EPSG','9001',298.265578547505,NULL,1);
INSERT INTO ellipsoid VALUES('ESRI','107858','GRS_1980_Adj_WI_KW_MT_SG','GRS 1980 Adj. Wisconsin Kewaunee, Manitowoc, and Sheboygan','PROJ','EARTH',6378285.86,'EPSG','9001',298.264183156421,NULL,1);
INSERT INTO celestial_body VALUES('ESRI', 'Mercury', 'Mercury', 2439700.0);
INSERT INTO ellipsoid VALUES('ESRI','107900','Mercury_2000_IAU_IAG','Mercury','ESRI','Mercury',2439700.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Venus', 'Venus', 6051000.0);
INSERT INTO ellipsoid VALUES('ESRI','107901','Venus_1985_IAU_IAG_COSPAR','Venus 1985','ESRI','Venus',6051000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107902','Venus_2000_IAU_IAG','Venus 2000','ESRI','Venus',6051800.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Moon', 'Moon', 1737400.0);
INSERT INTO ellipsoid VALUES('ESRI','107903','Moon_2000_IAU_IAG','The Moon','ESRI','Moon',1737400.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Mars', 'Mars', 3393400.0);
INSERT INTO ellipsoid VALUES('ESRI','107904','Mars_1979_IAU_IAG','Mars 1979','ESRI','Mars',3393400.0,'EPSG','9001',192.0430107526882,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107905','Mars_2000_IAU_IAG','Mars 2000','ESRI','Mars',3396190.0,'EPSG','9001',169.8944472236118,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Deimos', 'Deimos', 6200.0);
INSERT INTO ellipsoid VALUES('ESRI','107906','Deimos_2000_IAU_IAG','Mars - Deimos','ESRI','Deimos',6200.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Phobos', 'Phobos', 11100.0);
INSERT INTO ellipsoid VALUES('ESRI','107907','Phobos_2000_IAU_IAG','Mars - Phobos','ESRI','Phobos',11100.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Jupiter', 'Jupiter', 71492000.0);
INSERT INTO ellipsoid VALUES('ESRI','107908','Jupiter_2000_IAU_IAG','Jupiter','ESRI','Jupiter',71492000.0,'EPSG','9001',15.41440275981026,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Adrastea', 'Adrastea', 8200.0);
INSERT INTO ellipsoid VALUES('ESRI','107909','Adrastea_2000_IAU_IAG','Jupiter - Adrastea','ESRI','Adrastea',8200.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Amalthea', 'Amalthea', 83500.0);
INSERT INTO ellipsoid VALUES('ESRI','107910','Amalthea_2000_IAU_IAG','Jupiter - Amalthea','ESRI','Amalthea',83500.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Ananke', 'Ananke', 10000.0);
INSERT INTO ellipsoid VALUES('ESRI','107911','Ananke_2000_IAU_IAG','Jupiter - Ananke','ESRI','Ananke',10000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Callisto', 'Callisto', 2409300.0);
INSERT INTO ellipsoid VALUES('ESRI','107912','Callisto_2000_IAU_IAG','Jupiter - Callisto','ESRI','Callisto',2409300.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Carme', 'Carme', 15000.0);
INSERT INTO ellipsoid VALUES('ESRI','107913','Carme_2000_IAU_IAG','Jupiter - Carme','ESRI','Carme',15000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Elara', 'Elara', 40000.0);
INSERT INTO ellipsoid VALUES('ESRI','107914','Elara_2000_IAU_IAG','Jupiter - Elara','ESRI','Elara',40000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Europa', 'Europa', 1562090.0);
INSERT INTO ellipsoid VALUES('ESRI','107915','Europa_2000_IAU_IAG','Jupiter - Europa','ESRI','Europa',1562090.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Ganymede', 'Ganymede', 2632345.0);
INSERT INTO ellipsoid VALUES('ESRI','107916','Ganymede_2000_IAU_IAG','Jupiter - Ganymede','ESRI','Ganymede',2632345.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Himalia', 'Himalia', 85000.0);
INSERT INTO ellipsoid VALUES('ESRI','107917','Himalia_2000_IAU_IAG','Jupiter - Himalia','ESRI','Himalia',85000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Io', 'Io', 1821460.0);
INSERT INTO ellipsoid VALUES('ESRI','107918','Io_2000_IAU_IAG','Jupiter - Io','ESRI','Io',1821460.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Leda', 'Leda', 5000.0);
INSERT INTO ellipsoid VALUES('ESRI','107919','Leda_2000_IAU_IAG','Jupiter - Leda','ESRI','Leda',5000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Lysithea', 'Lysithea', 12000.0);
INSERT INTO ellipsoid VALUES('ESRI','107920','Lysithea_2000_IAU_IAG','Jupiter - Lysithea','ESRI','Lysithea',12000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Metis', 'Metis', 30000.0);
INSERT INTO ellipsoid VALUES('ESRI','107921','Metis_2000_IAU_IAG','Jupiter - Metis','ESRI','Metis',30000.0,'EPSG','9001',3.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Pasiphae', 'Pasiphae', 18000.0);
INSERT INTO ellipsoid VALUES('ESRI','107922','Pasiphae_2000_IAU_IAG','Jupiter - Pasiphae','ESRI','Pasiphae',18000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Sinope', 'Sinope', 14000.0);
INSERT INTO ellipsoid VALUES('ESRI','107923','Sinope_2000_IAU_IAG','Jupiter - Sinope','ESRI','Sinope',14000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Thebe', 'Thebe', 49300.0);
INSERT INTO ellipsoid VALUES('ESRI','107924','Thebe_2000_IAU_IAG','Jupiter - Thebe','ESRI','Thebe',49300.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Saturn', 'Saturn', 60268000.0);
INSERT INTO ellipsoid VALUES('ESRI','107925','Saturn_2000_IAU_IAG','Saturn','ESRI','Saturn',60268000.0,'EPSG','9001',10.2079945799458,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Atlas', 'Atlas', 16000.0);
INSERT INTO ellipsoid VALUES('ESRI','107926','Atlas_2000_IAU_IAG','Saturn - Atlas','ESRI','Atlas',16000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Calypso', 'Calypso', 9500.0);
INSERT INTO ellipsoid VALUES('ESRI','107927','Calypso_2000_IAU_IAG','Saturn - Calypso','ESRI','Calypso',9500.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Dione', 'Dione', 560000.0);
INSERT INTO ellipsoid VALUES('ESRI','107928','Dione_2000_IAU_IAG','Saturn - Dione','ESRI','Dione',560000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Enceladus', 'Enceladus', 249400.0);
INSERT INTO ellipsoid VALUES('ESRI','107929','Enceladus_2000_IAU_IAG','Saturn - Enceladus','ESRI','Enceladus',249400.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Epimetheus', 'Epimetheus', 59500.0);
INSERT INTO ellipsoid VALUES('ESRI','107930','Epimetheus_2000_IAU_IAG','Saturn - Epimetheus','ESRI','Epimetheus',59500.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Helene', 'Helene', 16000.0);
INSERT INTO ellipsoid VALUES('ESRI','107931','Helene_2000_IAU_IAG','Saturn - Helene','ESRI','Helene',16000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Hyperion', 'Hyperion', 133000.0);
INSERT INTO ellipsoid VALUES('ESRI','107932','Hyperion_2000_IAU_IAG','Saturn - Hyperion','ESRI','Hyperion',133000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Iapetus', 'Iapetus', 718000.0);
INSERT INTO ellipsoid VALUES('ESRI','107933','Iapetus_2000_IAU_IAG','Saturn - Iapetus','ESRI','Iapetus',718000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Janus', 'Janus', 88800.0);
INSERT INTO ellipsoid VALUES('ESRI','107934','Janus_2000_IAU_IAG','Saturn - Janus','ESRI','Janus',88800.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Mimas', 'Mimas', 198630.0);
INSERT INTO ellipsoid VALUES('ESRI','107935','Mimas_2000_IAU_IAG','Saturn - Mimas','ESRI','Mimas',198630.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Pan', 'Pan', 10000.0);
INSERT INTO ellipsoid VALUES('ESRI','107936','Pan_2000_IAU_IAG','Saturn - Pan','ESRI','Pan',10000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Pandora', 'Pandora', 41900.0);
INSERT INTO ellipsoid VALUES('ESRI','107937','Pandora_2000_IAU_IAG','Saturn - Pandora','ESRI','Pandora',41900.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Phoebe', 'Phoebe', 110000.0);
INSERT INTO ellipsoid VALUES('ESRI','107938','Phoebe_2000_IAU_IAG','Saturn - Phoebe','ESRI','Phoebe',110000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Prometheus', 'Prometheus', 50100.0);
INSERT INTO ellipsoid VALUES('ESRI','107939','Prometheus_2000_IAU_IAG','Saturn - Prometheus','ESRI','Prometheus',50100.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Rhea', 'Rhea', 764000.0);
INSERT INTO ellipsoid VALUES('ESRI','107940','Rhea_2000_IAU_IAG','Saturn - Rhea','ESRI','Rhea',764000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Telesto', 'Telesto', 11000.0);
INSERT INTO ellipsoid VALUES('ESRI','107941','Telesto_2000_IAU_IAG','Saturn - Telesto','ESRI','Telesto',11000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Tethys', 'Tethys', 529800.0);
INSERT INTO ellipsoid VALUES('ESRI','107942','Tethys_2000_IAU_IAG','Saturn - Tethys','ESRI','Tethys',529800.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Titan', 'Titan', 2575000.0);
INSERT INTO ellipsoid VALUES('ESRI','107943','Titan_2000_IAU_IAG','Saturn - Titan','ESRI','Titan',2575000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Uranus', 'Uranus', 25559000.0);
INSERT INTO ellipsoid VALUES('ESRI','107944','Uranus_2000_IAU_IAG','Uranus','ESRI','Uranus',25559000.0,'EPSG','9001',43.61604095563141,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Ariel', 'Ariel', 578900.0);
INSERT INTO ellipsoid VALUES('ESRI','107945','Ariel_2000_IAU_IAG','Uranus - Ariel','ESRI','Ariel',578900.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Belinda', 'Belinda', 33000.0);
INSERT INTO ellipsoid VALUES('ESRI','107946','Belinda_2000_IAU_IAG','Uranus - Belinda','ESRI','Belinda',33000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Bianca', 'Bianca', 21000.0);
INSERT INTO ellipsoid VALUES('ESRI','107947','Bianca_2000_IAU_IAG','Uranus - Bianca','ESRI','Bianca',21000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Cordelia', 'Cordelia', 13000.0);
INSERT INTO ellipsoid VALUES('ESRI','107948','Cordelia_2000_IAU_IAG','Uranus - Cordelia','ESRI','Cordelia',13000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Cressida', 'Cressida', 31000.0);
INSERT INTO ellipsoid VALUES('ESRI','107949','Cressida_2000_IAU_IAG','Uranus - Cressida','ESRI','Cressida',31000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Desdemona', 'Desdemona', 27000.0);
INSERT INTO ellipsoid VALUES('ESRI','107950','Desdemona_2000_IAU_IAG','Uranus - Desdemona','ESRI','Desdemona',27000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Juliet', 'Juliet', 42000.0);
INSERT INTO ellipsoid VALUES('ESRI','107951','Juliet_2000_IAU_IAG','Uranus - Juliet','ESRI','Juliet',42000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Miranda', 'Miranda', 235800.0);
INSERT INTO ellipsoid VALUES('ESRI','107952','Miranda_2000_IAU_IAG','Uranus - Miranda','ESRI','Miranda',235800.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Oberon', 'Oberon', 761400.0);
INSERT INTO ellipsoid VALUES('ESRI','107953','Oberon_2000_IAU_IAG','Uranus - Oberon','ESRI','Oberon',761400.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Ophelia', 'Ophelia', 15000.0);
INSERT INTO ellipsoid VALUES('ESRI','107954','Ophelia_2000_IAU_IAG','Uranus - Ophelia','ESRI','Ophelia',15000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Portia', 'Portia', 54000.0);
INSERT INTO ellipsoid VALUES('ESRI','107955','Portia_2000_IAU_IAG','Uranus - Portia','ESRI','Portia',54000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Puck', 'Puck', 77000.0);
INSERT INTO ellipsoid VALUES('ESRI','107956','Puck_2000_IAU_IAG','Uranus - Puck','ESRI','Puck',77000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Rosalind', 'Rosalind', 27000.0);
INSERT INTO ellipsoid VALUES('ESRI','107957','Rosalind_2000_IAU_IAG','Uranus - Rosalind','ESRI','Rosalind',27000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Titania', 'Titania', 788900.0);
INSERT INTO ellipsoid VALUES('ESRI','107958','Titania_2000_IAU_IAG','Uranus - Titania','ESRI','Titania',788900.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Umbriel', 'Umbriel', 584700.0);
INSERT INTO ellipsoid VALUES('ESRI','107959','Umbriel_2000_IAU_IAG','Uranus - Umbriel','ESRI','Umbriel',584700.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Neptune', 'Neptune', 24764000.0);
INSERT INTO ellipsoid VALUES('ESRI','107960','Neptune_2000_IAU_IAG','Neptune','ESRI','Neptune',24764000.0,'EPSG','9001',58.54373522458629,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Despina', 'Despina', 74000.0);
INSERT INTO ellipsoid VALUES('ESRI','107961','Despina_2000_IAU_IAG','Neptune - Despina','ESRI','Despina',74000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Galatea', 'Galatea', 79000.0);
INSERT INTO ellipsoid VALUES('ESRI','107962','Galatea_2000_IAU_IAG','Neptune - Galatea','ESRI','Galatea',79000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Larissa', 'Larissa', 104000.0);
INSERT INTO ellipsoid VALUES('ESRI','107963','Larissa_2000_IAU_IAG','Neptune - Larissa','ESRI','Larissa',104000.0,'EPSG','9001',6.933333333333334,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Naiad', 'Naiad', 29000.0);
INSERT INTO ellipsoid VALUES('ESRI','107964','Naiad_2000_IAU_IAG','Neptune - Naiad','ESRI','Naiad',29000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Nereid', 'Nereid', 170000.0);
INSERT INTO ellipsoid VALUES('ESRI','107965','Nereid_2000_IAU_IAG','Neptune - Nereid','ESRI','Nereid',170000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Proteus', 'Proteus', 208000.0);
INSERT INTO ellipsoid VALUES('ESRI','107966','Proteus_2000_IAU_IAG','Neptune - Proteus','ESRI','Proteus',208000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Thalassa', 'Thalassa', 40000.0);
INSERT INTO ellipsoid VALUES('ESRI','107967','Thalassa_2000_IAU_IAG','Neptune - Thalassa','ESRI','Thalassa',40000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Triton', 'Triton', 1352600.0);
INSERT INTO ellipsoid VALUES('ESRI','107968','Triton_2000_IAU_IAG','Neptune - Triton','ESRI','Triton',1352600.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Pluto', 'Pluto', 1195000.0);
INSERT INTO ellipsoid VALUES('ESRI','107969','Pluto_2000_IAU_IAG','Pluto','ESRI','Pluto',1195000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Charon', 'Charon', 593000.0);
INSERT INTO ellipsoid VALUES('ESRI','107970','Charon_2000_IAU_IAG','Pluto - Charon','ESRI','Charon',593000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107971','Mars_2000_(Sphere)','Mars 2000 (Sphere)','ESRI','Mars',3396190.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', '1_Ceres', '1_Ceres', 470000.0);
INSERT INTO ellipsoid VALUES('ESRI','107972','1_Ceres_2015','1 Ceres 2015','ESRI','1_Ceres',470000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', '4_Vesta', '4_Vesta', 255000.0);
INSERT INTO ellipsoid VALUES('ESRI','107973','4_Vesta_2015','4 Vesta 2015','ESRI','4_Vesta',255000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO ellipsoid VALUES('ESRI','107974','Mercury_2015','Mercury 2015','ESRI','Mercury',2439400.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO celestial_body VALUES('ESRI', 'Sun', 'Sun', 695700000.0);
INSERT INTO ellipsoid VALUES('ESRI','107975','Sun_2015','Sun IAU 2015','ESRI','Sun',695700000.0,'EPSG','9001',0.0,NULL,0);
INSERT INTO alias_name VALUES('prime_meridian','EPSG','8914','Paris_RGS','ESRI');
INSERT INTO "prime_meridian" VALUES('ESRI','108900','Reference_Meridian',0.0,'EPSG','9110',0);
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1024','D_Hungarian_Datum_1909','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1025','D_TWD_1967','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1026','D_TWD_1997','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1029','D_Iraqi_Geospatial_Reference_System','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1031','D_MGI_1901','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1032','D_MOLDREF99','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1033','D_Reseau_Geodesique_de_la_RDC_2005','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1034','D_Serbian_Reference_Network_1998','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1035','D_Red_Geodesica_de_Canarias_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1036','D_Reseau_Geodesique_de_Mayotte_2004','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1037','D_Cadastre_1997','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1038','D_Reseau_Geodesique_de_St_Pierre_et_Miquelon_2006','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1041','D_PTRA08','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1042','D_Mexican_Datum_of_1993','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1043','D_China_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1044','D_Sao_Tome','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1045','D_New_Beijing','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1046','D_Principe','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1047','D_RRAF_1991','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1052','D_S_JTSK_05','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1053','D_Sri_Lanka_Datum_1999','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1055','D_S_JTSK_05_Ferro','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1056','D_GDBD2009','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1057','D_Turkish_National_Reference_Frame','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1058','D_Bhutan_National_Geodetic_Datum','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1060','D_Islands_Network_2004','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1061','D_ITRF_2008','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1062','D_POSGAR_2007','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1063','D_Marco_Geodesico_Nacional','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1064','D_SIRGAS-Chile','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1065','D_Costa_Rica_2005','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1066','D_SGNP_MARCARIO_SOLIS','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1067','D_Peru96','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1068','D_SIRGAS-ROU98','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1069','D_SIRGAS_ES2007.8','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1070','D_Ocotepeque_1935','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1071','D_Sibun_Gorge_1922','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1072','D_Panama-Colon-1911','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1073','Reseau_Geodesique_des_Antilles_Francaises_2009','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1074','D_Corrego_Alegre_1961','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1075','D_South_American_Datum_1969_96','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1076','D_Papua_New_Guinea_Geodetic_Datum_1994','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1077','D_Ukraine_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1078','D_Fehmarnbelt_Datum_2010','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1081','D_Deutsche_Bahn_Reference_System','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1095','D_Tonga_Geodetic_Datum_2005','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1100','D_Cayman_Islands_Geodetic_Datum_2011','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1111','D_Nepal_Nagarkot','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1112','D_Cyprus_Geodetic_Reference_System_1993','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1113','D_Reseau_Geodesique_des_Terres_Australes_et_Antarctiques_Francaises_2007','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1114','Israel_Geodetic_Datum_2005','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1115','Israeli_Geodetic_Datum_2005(2012)','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1116','D_NAD_1983_2011','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1117','D_NAD_1983_PA11','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1118','D_NAD_1983_MA11','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1120','D_Mexico_ITRF2008','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1128','D_JGD_2011','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1132','D_Rete_Dinamica_Nazionale_2008','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1133','D_NAD_1983_CORS96','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1135','D_Aden_1925','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1136','D_Bioko','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1137','D_Bekaa_Valley_1920','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1138','D_South_East_Island_1943','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1139','D_Gambia','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1142','IG05_Intermediate_Datum','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1143','Israel_Geodetic_Datum_2005','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1144','IG05(2012)_Intermediate_Datum','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1145','Israeli_Geodetic_Datum_2005(2012)','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1147','Oman_National_Geodetic_Datum_2014','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1152','World_Geodetic_System_1984_(G730)','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1153','World_Geodetic_System_1984_(G873)','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1154','World_Geodetic_System_1984_(G1150)','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1155','World_Geodetic_System_1984_(G1674)','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1156','World_Geodetic_System_1984_(G1762)','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1157','Parametry_Zemli_1990.02','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1158','Parametry_Zemli_1990.11','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1159','Geodezicheskaya_Sistema_Koordinat_2011','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1165','International_Terrestrial_Reference_Frame_2014','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1166','World_Geodetic_System_1984_(Transit)','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1167','Bulgaria_Geodetic_System_2005','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1168','GDA2020','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1173','St_Helena_Tritan','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1174','St_Helena_Geodetic_Datum_2015','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1178','D_ETRF_1989','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1179','European_Terrestrial_Reference_Frame_1990','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1180','European_Terrestrial_Reference_Frame_1991','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1181','European_Terrestrial_Reference_Frame_1992','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1182','European_Terrestrial_Reference_Frame_1993','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1183','European_Terrestrial_Reference_Frame_1994','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1184','European_Terrestrial_Reference_Frame_1996','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1185','European_Terrestrial_Reference_Frame_1997','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1186','European_Terrestrial_Reference_Frame_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1187','Islands_Net_2016','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1188','Gusterberg_(Ferro)','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1189','St._Stephen_(Ferro)','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1192','North_American_Datum_of_1983_(CSRS96)','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1193','North_American_Datum_of_1983_(CSRS)_version_2','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1194','North_American_Datum_of_1983_(CSRS)_version_3','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1195','North_American_Datum_of_1983_(CSRS)_version_4','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1196','North_American_Datum_of_1983_(CSRS)_version_5','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1197','North_American_Datum_of_1983_(CSRS)_version_6','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','1198','North_American_Datum_of_1983_(CSRS)_version_7','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6001','D_Airy_1830','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6002','D_Airy_Modified','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6003','D_Australian','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6004','D_Bessel_1841','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6005','D_Bessel_Modified','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6006','D_Bessel_Namibia','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6007','D_Clarke_1858','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6008','D_Clarke_1866','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6009','D_Clarke_1866_Michigan','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6010','D_Clarke_1880_Benoit','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6011','D_Clarke_1880_IGN','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6012','D_Clarke_1880_RGS','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6013','D_Clarke_1880_Arc','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6014','D_Clarke_1880_SGA','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6015','D_Everest_Adj_1937','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6016','D_Everest_Def_1967','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6018','D_Everest_Modified','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6019','D_GRS_1980','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6020','D_Helmert_1906','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6021','D_Indonesian','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6022','D_International_1924','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6024','D_Krasovsky_1940','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6025','D_NWL_9D','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6027','D_Plessis_1817','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6028','D_Struve_1860','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6029','D_War_Office','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6031','D_GEM_10C','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6032','D_OSU_86F','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6033','D_OSU_91A','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6034','D_Clarke_1880','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6035','D_Sphere','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6036','D_GRS_1967','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6042','D_Everest_1830','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6044','D_Everest_Def_1962','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6045','D_Everest_Def_1975','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6047','D_Sphere_GRS_1980_Authalic','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6052','D_Sphere_Clarke_1866_Authalic','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6053','D_Sphere_International_1924_Authalic','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6054','D_Hughes_1980','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6055','D_WGS_1984_Major_Auxiliary_Sphere','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6120','D_Greek','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6121','D_GGRS_1987','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6122','D_ATS_1977','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6123','D_KKJ','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6124','D_RT_1990','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6125','D_Samboja','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6126','D_Lithuania_1994','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6127','D_Tete','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6128','D_Madzansua','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6129','D_Observatario','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6130','D_Moznet','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6131','D_Indian_1960','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6132','D_FD_1958','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6133','D_Estonia_1992','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6134','D_PDO_1993','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6135','D_Old_Hawaiian','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6136','D_St_Lawrence_Island','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6137','D_St_Paul_Island','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6138','D_St_George_Island','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6139','D_Puerto_Rico','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6140','D_North_American_1983_CSRS','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6141','D_Israel','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6142','D_Locodjo_1965','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6143','D_Abidjan_1987','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6144','D_Kalianpur_1937','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6145','D_Kalianpur_1962','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6146','D_Kalianpur_1975','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6147','D_Hanoi_1972','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6148','D_Hartebeesthoek_1994','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6149','D_CH1903','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6150','D_CH1903+','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6151','D_Swiss_TRF_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6152','D_North_American_1983_HARN','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6153','D_Rassadiran','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6154','D_European_1950_ED77','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6155','D_Dabola_1981','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6156','D_S_JTSK','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6157','D_Mount_Dillon','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6158','D_Naparima_1955','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6159','D_European_Libyan_1979','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6160','D_Chos_Malal_1914','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6161','D_Pampa_del_Castillo','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6162','D_Korean_Datum_1985','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6163','D_Yemen_NGN_1996','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6164','D_South_Yemen','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6165','D_Bissau','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6166','D_Korean_Datum_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6167','D_NZGD_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6168','D_Accra','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6169','D_American_Samoa_1962','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6170','D_SIRGAS','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6171','D_RGF_1993','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6172','D_POSGAR','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6173','D_IRENET95','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6174','D_Sierra_Leone_1924','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6175','D_Sierra_Leone_1968','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6176','D_Australian_Antarctic_1998','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6178','D_Pulkovo_1942_Adj_1983','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6179','D_Pulkovo_1942_Adj_1958','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6180','D_Estonia_1997','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6181','D_Luxembourg_1930','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6182','D_Azores_Occidental_Islands_1939','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6183','D_Azores_Central_Islands_1948','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6184','D_Azores_Oriental_Islands_1940','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6185','D_Madeira_1936','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6188','D_OSNI_1952','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6189','D_REGVEN','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6190','D_POSGAR_1998','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6191','D_Albanian_1987','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6192','D_Douala_1948','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6193','D_Manoca_1962','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6194','D_Qornoq_1927','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6195','D_Scoresbysund_1952','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6196','D_Ammassalik_1958','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6197','D_Garoua','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6198','D_Kousseri','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6199','D_Egypt_1930','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6200','D_Pulkovo_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6201','D_Adindan','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6202','D_Australian_1966','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6203','D_Australian_1984','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6204','D_Ain_el_Abd_1970','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6205','D_Afgooye','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6206','D_Agadez','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6207','D_Lisbon','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6208','D_Aratu','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6209','D_Arc_1950','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6210','D_Arc_1960','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6211','D_Batavia','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6212','D_Barbados_1938','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6213','D_Beduaram','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6214','D_Beijing_1954','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6215','D_Belge_1950','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6216','D_Bermuda_1957','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6218','D_Bogota','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6219','D_Bukit_Rimpah','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6220','D_Camacupa','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6221','D_Campo_Inchauspe','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6222','D_Cape','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6223','D_Carthage','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6224','D_Chua','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6225','D_Corrego_Alegre','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6226','D_Cote_d_Ivoire','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6227','D_Deir_ez_Zor','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6228','D_Douala','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6229','D_Egypt_1907','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6230','D_European_1950','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6231','D_European_1987','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6232','D_Fahud','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6233','D_Gandajika_1970','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6234','D_Garoua','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6235','D_Guyane_Francaise','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6236','D_Hu_Tzu_Shan','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6237','D_Hungarian_1972','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6238','D_Indonesian_1974','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6239','D_Indian_1954','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6240','D_Indian_1975','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6241','D_Jamaica_1875','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6242','D_Jamaica_1969','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6243','D_Kalianpur_1880','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6244','D_Kandawala','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6245','D_Kertau','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6246','D_Kuwait_Oil_Company','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6247','D_La_Canoa','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6248','D_Provisional_S_American_1956','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6249','D_Lake','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6250','D_Leigon','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6251','D_Liberia_1964','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6252','D_Lome','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6253','D_Luzon_1911','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6254','D_Hito_XVIII_1963','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6255','D_Herat_North','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6256','D_Mahe_1971','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6257','D_Makassar','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6258','D_ETRS_1989','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6259','D_Malongo_1987','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6260','D_Manoca','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6261','D_Merchich','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6262','D_Massawa','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6263','D_Minna','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6264','D_Mhast','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6265','D_Monte_Mario','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6266','D_Mporaloko','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6267','D_North_American_1927','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6268','D_North_American_Michigan','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6269','D_North_American_1983','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6270','D_Nahrwan_1967','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6271','D_Naparima_1972','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6272','D_New_Zealand_1949','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6273','D_NGO_1948','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6274','D_Datum_73','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6275','D_NTF','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6276','D_NSWC_9Z_2','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6277','D_OSGB_1936','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6278','D_OSGB_1970_SN','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6279','D_OS_SN_1980','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6280','D_Padang_1884','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6281','D_Palestine_1923','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6282','D_Pointe_Noire','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6283','D_GDA_1994','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6284','D_Pulkovo_1942','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6285','D_Qatar','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6286','D_Qatar_1948','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6287','D_Qornoq','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6288','D_Loma_Quintana','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6289','D_Amersfoort','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6291','D_South_American_1969','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6292','D_Sapper_Hill_1943','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6293','D_Schwarzeck','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6294','D_Segora','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6295','D_Serindung','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6296','D_Sudan','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6297','D_Tananarive_1925','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6298','D_Timbalai_1948','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6299','D_TM65','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6300','D_TM75','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6301','D_Tokyo','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6302','D_Trinidad_1903','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6303','D_Trucial_Coast_1948','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6304','D_Voirol_1875','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6306','D_Bern_1938','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6307','D_Nord_Sahara_1959','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6308','D_Stockholm_1938','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6309','D_Yacare','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6310','D_Yoff','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6311','D_Zanderij','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6312','D_MGI','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6313','D_Belge_1972','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6314','D_Deutsches_Hauptdreiecksnetz','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6315','D_Conakry_1905','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6316','D_Dealul_Piscului_1933','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6317','D_Dealul_Piscului_1970','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6318','D_NGN','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6319','D_Kuwait_Utility','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6322','D_WGS_1972','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6324','D_WGS_1972_BE','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6326','D_WGS_1984','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6600','D_Anguilla_1957','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6601','D_Antigua_1943','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6602','D_Dominica_1945','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6603','D_Grenada_1953','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6604','D_Montserrat_1958','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6605','D_St_Kitts_1955','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6606','D_St_Lucia_1955','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6607','D_St_Vincent_1945','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6608','D_NAD_1927_Definition_1976','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6609','D_NAD_1927_CGQ77','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6610','D_Xian_1980','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6611','D_Hong_Kong_1980','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6612','D_JGD_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6613','D_Gunung_Segara','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6614','D_QND_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6615','D_Porto_Santo_1936','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6616','D_Selvagem_Grande_1938','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6618','D_South_American_1969','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6619','D_SWEREF99','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6620','D_Point_58','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6621','D_Fort_Marigot','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6622','D_Sainte_Anne','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6623','D_CSG_1967','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6624','D_RGFG_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6625','D_Fort_Desaix','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6626','D_Reunion_1947','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6627','D_RGR_1992','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6628','D_Tahiti_1952','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6629','D_Tahaa_1954','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6630','D_IGN72_Nuku_Hiva','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6631','D_Kerguelen_Island_1949','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6632','D_Combani_1950','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6633','D_IGN56_Lifou','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6634','D_IGN72_Grande_Terre','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6636','D_Petrels_1972','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6637','D_Pointe_Geologie_Perroud_1950','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6638','D_Saint_Pierre_et_Miquelon_1950','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6639','D_MOP78','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6641','D_IGN53_Mare','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6642','D_ST84_Ile_des_Pins','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6643','D_ST71_Belep','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6644','D_NEA74_Noumea','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6645','D_RGNC_1991','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6646','D_Grand_Comoros','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6647','D_ITRF_1988','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6648','D_ITRF_1989','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6649','D_ITRF_1990','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6650','D_ITRF_1991','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6651','D_ITRF_1992','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6652','D_ITRF_1993','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6653','D_ITRF_1994','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6654','D_ITRF_1996','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6655','D_ITRF_1997','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6656','D_ITRF_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6657','D_Reykjavik_1900','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6658','D_Hjorsey_1955','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6659','D_Islands_Network_1993','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6660','D_Helle_1954','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6661','D_Latvia_1992','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6663','D_Porto_Santo_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6664','D_Azores_Oriental_Islands_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6665','D_Azores_Central_Islands_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6666','D_Lisbon_1890','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6667','D_Iraq_Kuwait_Boundary_1992','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6668','D_European_1979','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6670','D_IGM_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6671','D_Voirol_1879','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6672','D_Chatham_Island_1971','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6673','D_Chatham_Islands_1979','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6674','D_SIRGAS_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6675','D_Guam_1963','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6676','D_Vientiane_1982','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6677','D_Lao_1993','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6678','D_Lao_National_Datum_1997','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6679','D_Jouik_1961','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6680','D_Nouakchott_1965','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6682','D_Gulshan_303','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6683','D_Philippine_Reference_System_1992','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6684','D_Gan_1970','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6686','D_MAGNA','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6687','D_Reseau_Geodesique_de_la_Polynesie_Francaise','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6688','D_Fatu_Iva_1972','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6689','D_IGN63_Hiva_Oa','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6690','D_Tahiti_1979','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6691','D_Moorea_1987','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6692','D_Maupiti_1983','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6693','D_Nakhl-e_Ghanem','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6694','D_POSGAR_1994','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6695','D_Katanga_1955','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6696','D_Kasai_1953','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6697','D_IGC_1962_Arc_of_the_6th_Parallel_South','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6698','D_Kerguelen_Island_1949','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6699','D_Le_Pouce_1934','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6700','D_IGN_Astro_1960','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6701','D_Institut_Geographique_du_Congo_Belge_1955','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6702','D_Mauritania_1999','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6703','D_Mhast_1951','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6704','D_Mhast_Onshore','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6705','D_Mhast_Offshore','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6706','D_Egypt_Gulf_of_Suez_S-650_TL','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6707','D_Tern_Island_1961','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6708','D_Anna_1_1965','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6709','D_Beacon_E_1945','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6710','D_DOS_71_4','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6711','D_Astro_1952','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6712','D_Ascension_Island_1958','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6713','D_Ayabelle','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6714','D_Bellevue_IGN','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6715','D_Camp_Area','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6716','D_Canton_1966','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6717','D_Cape_Canaveral','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6718','D_Solomon_1968','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6719','D_Easter_Island_1967','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6720','D_Fiji_1986','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6721','D_Fiji_1956','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6722','D_ISTS_061_1968','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6723','D_Grand_Cayman_1959','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6724','D_ISTS_073_1969','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6725','D_Johnston_Island_1961','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6726','D_Little_Cayman_1961','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6727','D_Midway_1961','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6728','D_Pico_de_Las_Nieves','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6729','D_Pitcairn_1967','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6730','D_Santo_DOS_1965','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6731','D_Viti_Levu_1916','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6732','D_Wake_Eniwetok_1960','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6733','D_Wake_Island_1952','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6734','D_Tristan_1968','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6735','D_Kusaie_1951','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6736','D_Deception_Island','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6737','D_Korea_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6738','D_Hong_Kong_1963','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6739','D_Hong_Kong_1963_67','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6740','D_Parametrop_Zemp_1990','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6741','D_Faroe_Datum_1954','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6742','D_GDM_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6743','D_Karbala_1979_Polservice','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6744','D_Nahrwan_1934','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6745','D_Rauenberg_1983','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6746','D_Potsdam_1983','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6747','D_Greenland_1996','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6748','D_Vanua_Levu_1915','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6749','D_Reseau_Geodesique_de_Nouvelle_Caledonie_1991-93','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6750','D_ST87_Ouvea','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6751','D_Kertau_RSO','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6752','D_Viti_Levu_1912','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6753','D_fk89','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6754','D_Libyan_Geodetic_Datum_2006','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6755','D_Datum_Geodesi_Nasional_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6756','D_Vietnam_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6757','D_SVY21','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6758','D_Jamaica_2001','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6759','D_NAD_1983_NSRS2007','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6760','D_WGS_1966','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6761','D_Croatian_Terrestrial_Reference_System','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6762','D_Bermuda_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6763','D_Pitcairn_2006','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6764','D_Ross_Sea_Region_Geodetic_Datum_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6765','D_Slovenia_Geodetic_Datum_1996','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6896','D_ITRF_2005','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6901','D_ATF','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6902','D_Nord_de_Guerre','ESRI');
INSERT INTO alias_name VALUES('geodetic_datum','EPSG','6903','D_Madrid_1870','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','3819','GCS_HD1909','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','3821','GCS_TWD_1967','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','3824','GCS_TWD_1997','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','3889','GCS_IGRS','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','3906','GCS_MGI_1901','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4001','GCS_Airy_1830','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4002','GCS_Airy_Modified','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4003','GCS_Australian','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4004','GCS_Bessel_1841','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4005','GCS_Bessel_Modified','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4006','GCS_Bessel_Namibia','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4007','GCS_Clarke_1858','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4008','GCS_Clarke_1866','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4009','GCS_Clarke_1866_Michigan','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4010','GCS_Clarke_1880_Benoit','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4011','GCS_Clarke_1880_IGN','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4012','GCS_Clarke_1880_RGS','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4013','GCS_Clarke_1880_Arc','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4014','GCS_Clarke_1880_SGA','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4015','GCS_Everest_Adj_1937','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4016','GCS_Everest_def_1967','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4018','GCS_Everest_Modified','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4019','GCS_GRS_1980','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4020','GCS_Helmert_1906','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4021','GCS_Indonesian','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4022','GCS_International_1924','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4023','GCS_MOLDREF99','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4024','GCS_Krasovsky_1940','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4025','GCS_NWL_9D','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4027','GCS_Plessis_1817','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4028','GCS_Struve_1860','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4029','GCS_War_Office','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4031','GCS_GEM_10C','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4032','GCS_OSU_86F','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4033','GCS_OSU_91A','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4034','GCS_Clarke_1880','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4035','GCS_Sphere','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4036','GCS_GRS_1967','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4042','GCS_Everest_1830','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4044','GCS_Everest_def_1962','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4045','GCS_Everest_def_1975','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4046','GCS_RGRDC_2005','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4047','GCS_Sphere_GRS_1980_Authalic','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4052','GCS_Sphere_Clarke_1866_Authalic','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4053','GCS_Sphere_International_1924_Authalic','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4054','GCS_Hughes_1980','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4055','GCS_WGS_1984_Major_Auxiliary_Sphere','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4075','GCS_SREF98','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4081','GCS_REGCAN95','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4120','GCS_Greek','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4121','GCS_GGRS_1987','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4122','GCS_ATS_1977','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4123','GCS_KKJ','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4124','GCS_RT_1990','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4125','GCS_Samboja','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4126','GCS_LKS_1994','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4127','GCS_Tete','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4128','GCS_Madzansua','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4129','GCS_Observatario','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4130','GCS_Moznet','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4131','GCS_Indian_1960','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4132','GCS_FD_1958','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4133','GCS_Estonia_1992','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4134','GCS_PDO_1993','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4135','GCS_Old_Hawaiian','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4136','GCS_St_Lawrence_Island','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4137','GCS_St_Paul_Island','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4138','GCS_St_George_Island','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4139','GCS_Puerto_Rico','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4140','GCS_North_American_1983_CSRS','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4141','GCS_Israel','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4142','GCS_Locodjo_1965','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4143','GCS_Abidjan_1987','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4144','GCS_Kalianpur_1937','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4145','GCS_Kalianpur_1962','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4146','GCS_Kalianpur_1975','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4147','GCS_Hanoi_1972','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4148','GCS_Hartebeesthoek_1994','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4149','GCS_CH1903','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4150','GCS_CH1903+','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4151','GCS_Swiss_TRF_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4152','GCS_North_American_1983_HARN','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4153','GCS_Rassadiran','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4154','GCS_European_1950_ED77','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4155','GCS_Dabola_1981','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4156','GCS_S_JTSK','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4157','GCS_Mount_Dillon','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4158','GCS_Naparima_1955','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4159','GCS_European_Libyan_Datum_1979','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4160','GCS_Chos_Malal_1914','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4161','GCS_Pampa_del_Castillo','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4162','GCS_Korean_Datum_1985','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4163','GCS_Yemen_NGN_1996','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4164','GCS_South_Yemen','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4165','GCS_Bissau','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4166','GCS_Korean_Datum_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4167','GCS_NZGD_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4168','GCS_Accra','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4169','GCS_American_Samoa_1962','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4170','GCS_SIRGAS','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4171','GCS_RGF_1993','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4172','GCS_POSGAR','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4173','GCS_IRENET95','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4174','GCS_Sierra_Leone_1924','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4175','GCS_Sierra_Leone_1968','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4176','GCS_Australian_Antarctic_1998','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4178','GCS_Pulkovo_1942_Adj_1983','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4179','GCS_Pulkovo_1942_Adj_1958','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4180','GCS_Estonia_1997','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4181','GCS_Luxembourg_1930','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4182','GCS_Azores_Occidental_1939','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4183','GCS_Azores_Central_1948','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4184','GCS_Azores_Oriental_1940','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4185','GCS_Madeira_1936','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4188','GCS_OSNI_1952','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4189','GCS_REGVEN','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4190','GCS_POSGAR_1998','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4191','GCS_Albanian_1987','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4192','GCS_Douala_1948','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4193','GCS_Manoca_1962','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4194','GCS_Qornoq_1927','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4195','GCS_Scoresbysund_1952','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4196','GCS_Ammassalik_1958','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4197','GCS_Garoua','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4198','GCS_Kousseri','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4199','GCS_Egypt_1930','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4200','GCS_Pulkovo_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4201','GCS_Adindan','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4202','GCS_Australian_1966','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4203','GCS_Australian_1984','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4204','GCS_Ain_el_Abd_1970','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4205','GCS_Afgooye','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4206','GCS_Agadez','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4207','GCS_Lisbon','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4208','GCS_Aratu','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4209','GCS_Arc_1950','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4210','GCS_Arc_1960','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4211','GCS_Batavia','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4212','GCS_Barbados_1938','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4213','GCS_Beduaram','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4214','GCS_Beijing_1954','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4215','GCS_Belge_1950','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4216','GCS_Bermuda_1957','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4218','GCS_Bogota','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4219','GCS_Bukit_Rimpah','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4220','GCS_Camacupa','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4221','GCS_Campo_Inchauspe','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4222','GCS_Cape','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4223','GCS_Carthage','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4224','GCS_Chua','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4225','GCS_Corrego_Alegre','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4226','GCS_Cote_d_Ivoire','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4227','GCS_Deir_ez_Zor','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4228','GCS_Douala','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4229','GCS_Egypt_1907','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4230','GCS_European_1950','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4231','GCS_European_1987','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4232','GCS_Fahud','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4233','GCS_Gandajika_1970','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4234','GCS_Garoua','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4235','GCS_Guyane_Francaise','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4236','GCS_Hu_Tzu_Shan','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4237','GCS_Hungarian_1972','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4238','GCS_Indonesian_1974','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4239','GCS_Indian_1954','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4240','GCS_Indian_1975','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4241','GCS_Jamaica_1875','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4242','GCS_Jamaica_1969','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4243','GCS_Kalianpur_1880','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4244','GCS_Kandawala','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4245','GCS_Kertau','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4246','GCS_Kuwait_Oil_Company','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4247','GCS_La_Canoa','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4248','GCS_Provisional_S_American_1956','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4249','GCS_Lake','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4250','GCS_Leigon','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4251','GCS_Liberia_1964','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4252','GCS_Lome','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4253','GCS_Luzon_1911','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4254','GCS_Hito_XVIII_1963','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4255','GCS_Herat_North','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4256','GCS_Mahe_1971','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4257','GCS_Makassar','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4258','GCS_ETRS_1989','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4259','GCS_Malongo_1987','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4260','GCS_Manoca','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4261','GCS_Merchich','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4262','GCS_Massawa','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4263','GCS_Minna','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4264','GCS_Mhast','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4265','GCS_Monte_Mario','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4266','GCS_Mporaloko','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4267','GCS_North_American_1927','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4268','GCS_North_American_Michigan','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4269','GCS_North_American_1983','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4270','GCS_Nahrwan_1967','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4271','GCS_Naparima_1972','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4272','GCS_New_Zealand_1949','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4273','GCS_NGO_1948','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4274','GCS_Datum_73','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4275','GCS_NTF','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4276','GCS_NSWC_9Z_2','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4277','GCS_OSGB_1936','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4278','GCS_OSGB_1970_SN','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4279','GCS_OS_SN_1980','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4280','GCS_Padang_1884','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4281','GCS_Palestine_1923','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4282','GCS_Pointe_Noire','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4283','GCS_GDA_1994','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4284','GCS_Pulkovo_1942','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4285','GCS_Qatar_1974','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4286','GCS_Qatar_1948','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4287','GCS_Qornoq','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4288','GCS_Loma_Quintana','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4289','GCS_Amersfoort','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4291','GCS_South_American_1969','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4292','GCS_Sapper_Hill_1943','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4293','GCS_Schwarzeck','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4294','GCS_Segora','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4295','GCS_Serindung','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4296','GCS_Sudan','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4297','GCS_Tananarive_1925','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4298','GCS_Timbalai_1948','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4299','GCS_TM65','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4300','GCS_TM75','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4301','GCS_Tokyo','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4302','GCS_Trinidad_1903','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4303','GCS_Trucial_Coast_1948','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4304','GCS_Voirol_1875','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106011','D_Voirol_Unifie_1960','Voirol Unifie 1960',NULL,'EPSG','7012','EPSG','8901','EPSG','1365',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','4305','GCS_Voirol_Unifie_1960',NULL,NULL,'geographic 2D','EPSG','6403','ESRI','106011','EPSG','1365',NULL,1);
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4306','GCS_Bern_1938','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4307','GCS_Nord_Sahara_1959','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4308','GCS_RT38','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4309','GCS_Yacare','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4310','GCS_Yoff','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4311','GCS_Zanderij','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4312','GCS_MGI','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4313','GCS_Belge_1972','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4314','GCS_Deutsches_Hauptdreiecksnetz','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4315','GCS_Conakry_1905','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4316','GCS_Dealul_Piscului_1933','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4317','GCS_Dealul_Piscului_1970','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4318','GCS_NGN','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4319','GCS_KUDAMS','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4322','GCS_WGS_1972','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4324','GCS_WGS_1972_BE','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4326','GCS_WGS_1984','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4463','GCS_RGSPM_2006','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106997','D_Reseau_Geodesique_de_St_Pierre_et_Miquelon_2006','Reseau Geodesique de St Pierre et Miquelon 2006',NULL,'EPSG','7019','EPSG','8901','EPSG','1220',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','4466','GCS_RGSPM_2006',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106997','EPSG','1220',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','4466','geodetic_crs','EPSG','4463','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106998','D_Reseau_Geodesique_de_Mayotte_2004','Reseau Geodesique de Mayotte 2004',NULL,'EPSG','7019','EPSG','8901','EPSG','1159',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','4469','GCS_RGM_2004',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106998','EPSG','1159',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','4469','geodetic_crs','EPSG','4470','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4470','GCS_RGM_2004','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4475','GCS_Cadastre_1997','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4483','GCS_Mexican_Datum_of_1993','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4490','GCS_China_Geodetic_Coordinate_System_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4555','GCS_New_Beijing','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4558','GCS_RRAF_1991','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4600','GCS_Anguilla_1957','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4601','GCS_Antigua_1943','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4602','GCS_Dominica_1945','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4603','GCS_Grenada_1953','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4604','GCS_Montserrat_1958','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4605','GCS_St_Kitts_1955','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4606','GCS_St_Lucia_1955','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4607','GCS_St_Vincent_1945','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4608','GCS_NAD_1927_Definition_1976','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4609','GCS_NAD_1927_CGQ77','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4610','GCS_Xian_1980','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4611','GCS_Hong_Kong_1980','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4612','GCS_JGD_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4613','GCS_Gunung_Segara','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4614','GCS_QND_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4615','GCS_Porto_Santo_1936','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4616','GCS_Selvagem_Grande_1938','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4617','GCS_North_American_1983_CSRS','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4618','GCS_South_American_1969','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4619','GCS_SWEREF99','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4620','GCS_Point_58','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4621','GCS_Fort_Marigot','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4622','GCS_Sainte_Anne','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4623','GCS_CSG_1967','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4624','GCS_RGFG_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4625','GCS_Fort_Desaix','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4626','GCS_Reunion_1947','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4627','GCS_RGR_1992','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4628','GCS_Tahiti_1952','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4629','GCS_Tahaa_1954','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4630','GCS_IGN72_Nuku_Hiva','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4631','GCS_Kerguelen_Island_1949','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4632','GCS_Combani_1950','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4633','GCS_IGN56_Lifou','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4636','GCS_Petrels_1972','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4637','GCS_Pointe_Geologie_Perroud_1950','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4638','GCS_Saint_Pierre_et_Miquelon_1950','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4639','GCS_MOP78','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4641','GCS_IGN53_Mare','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4642','GCS_ST84_Ile_des_Pins','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4643','GCS_ST71_Belep','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4644','GCS_NEA74_Noumea','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4645','GCS_RGNC_1991','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4646','GCS_Grand_Comoros','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4657','GCS_Reykjavik_1900','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4658','GCS_Hjorsey_1955','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4659','GCS_ISN_1993','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4660','GCS_Helle_1954','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4661','GCS_LKS_1992','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4662','GCS_IGN72_Grande_Terre','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4663','GCS_Porto_Santo_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4664','GCS_Azores_Oriental_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4665','GCS_Azores_Central_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4666','GCS_Lisbon_1890','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4667','GCS_IKBD_1992','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4668','GCS_European_1979','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4669','GCS_LKS_1994','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4670','GCS_IGM_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4671','GCS_Voirol_1879','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4672','GCS_Chatham_Island_1971','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4673','GCS_Chatham_Islands_1979','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4674','GCS_SIRGAS_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4675','GCS_Guam_1963','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4676','GCS_Vientiane_1982','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4677','GCS_Lao_1993','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4678','GCS_Lao_1997','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4679','GCS_Jouik_1961','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4680','GCS_Nouakchott_1965','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4682','GCS_Gulshan_303','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4683','GCS_PRS_1992','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4684','GCS_Gan_1970','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4686','GCS_MAGNA','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4687','GCS_RGPF','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4688','GCS_Fatu_Iva_1972','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4689','GCS_IGN63_Hiva_Oa','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4690','GCS_Tahiti_1979','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4691','GCS_Moorea_1987','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4692','GCS_Maupiti_1983','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4693','GCS_Nakhl-e_Ghanem','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4694','GCS_POSGAR_1994','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4695','GCS_Katanga_1955','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4696','GCS_Kasai_1953','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4697','GCS_IGC_1962_6th_Parallel_South','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4698','GCS_Kerguelen_Island_1949','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4699','GCS_Le_Pouce_1934','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4700','GCS_IGN_Astro_1960','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4701','GCS_IGCB_1955','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4702','GCS_Mauritania_1999','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4703','GCS_Mhast_1951','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4704','GCS_Mhast_Onshore','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4705','GCS_Mhast_Offshore','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4706','GCS_Egypt_Gulf_of_Suez_S-650_TL','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4707','GCS_Tern_Island_1961','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4708','GCS_Anna_1_1965','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4709','GCS_Beacon_E_1945','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4710','GCS_DOS_71_4','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4711','GCS_Astro_1952','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4712','GCS_Ascension_Island_1958','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4713','GCS_Ayabelle','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4714','GCS_Bellevue_IGN','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4715','GCS_Camp_Area','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4716','GCS_Canton_1966','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4717','GCS_Cape_Canaveral','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4718','GCS_Solomon_1968','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4719','GCS_Easter_Island_1967','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4720','GCS_Fiji_1986','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4721','GCS_Fiji_1956','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4722','GCS_ISTS_061_1968','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4723','GCS_Grand_Cayman_1959','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4724','GCS_ISTS_073_1969','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4725','GCS_Johnston_Island_1961','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4726','GCS_Little_Cayman_1961','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4727','GCS_Midway_1961','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4728','GCS_Pico_de_Las_Nieves','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4729','GCS_Pitcairn_1967','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4730','GCS_Santo_DOS_1965','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4731','GCS_Viti_Levu_1916','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4732','GCS_Wake_Eniwetok_1960','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4733','GCS_Wake_Island_1952','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4734','GCS_Tristan_1968','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4735','GCS_Kusaie_1951','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4736','GCS_Deception_Island','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4737','GCS_Korea_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4738','GCS_Hong_Kong_1963','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4739','GCS_Hong_Kong_1963_67','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4740','GCS_PZ_1990','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4741','GCS_FD_1954','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4742','GCS_GDM_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4743','GCS_Karbala_1979_Polservice','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4744','GCS_Nahrwan_1934','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4745','GCS_RD/83','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4746','GCS_PD/83','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4747','GCS_Greenland_1996','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4748','GCS_Vanua_Levu_1915','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4749','GCS_RGNC_1991-93','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4750','GCS_ST87_Ouvea','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4751','GCS_Kertau_RSO','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4752','GCS_Viti_Levu_1912','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4753','GCS_fk89','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4754','GCS_LGD2006','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4755','GCS_DGN_1995','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4756','GCS_VN_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4757','GCS_SVY21','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4758','GCS_JAD_2001','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4759','GCS_NAD_1983_NSRS2007','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4760','GCS_WGS_1966','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4761','GCS_HTRS96','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4762','GCS_Bermuda_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4763','GCS_Pitcairn_2006','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4764','GCS_RSRGD2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4765','GCS_Slovenia_1996','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4801','GCS_Bern_1898_Bern','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4802','GCS_Bogota_Bogota','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4803','GCS_Lisbon_Lisbon','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4804','GCS_Makassar_Jakarta','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4805','GCS_MGI_Ferro','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4806','GCS_Monte_Mario_Rome','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4807','GCS_NTF_Paris','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4808','GCS_Padang_1884_Jakarta','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4809','GCS_Belge_1950_Brussels','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4810','GCS_Tananarive_1925_Paris','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4811','GCS_Voirol_1875_Paris','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106011_Paris','D_Voirol_Unifie_1960',NULL,'Voirol Unifie 1960','EPSG','7012','EPSG','8903','EPSG','1365',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','4812','GCS_Voirol_Unifie_1960_Paris',NULL,NULL,'geographic 2D','EPSG','6403','ESRI','106011_Paris','EPSG','1365',NULL,1);
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4813','GCS_Batavia_Jakarta','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4814','GCS_RT38_Stockholm','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4815','GCS_Greek_Athens','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4816','GCS_Carthage_Paris','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4817','GCS_NGO_1948_Oslo','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4818','GCS_S_JTSK_Ferro','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4819','GCS_Nord_Sahara_1959_Paris','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4820','GCS_Gunung_Segara_Jakarta','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4821','GCS_Voirol_1879_Paris','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4823','GCS_Sao_Tome','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4824','GCS_Principe','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4901','GCS_ATF_Paris','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4902','GCS_Nord_de_Guerre_Paris','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4903','GCS_Madrid_1870_Madrid','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','4904','GCS_Lisbon_1890_Lisbon','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5013','GCS_PTRA08','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5228','GCS_S_JTSK/05','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5229','GCS_S_JTSK/05_Ferro','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5233','GCS_SLD99','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5246','GCS_GDBD2009','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5252','GCS_TUREF','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5264','GCS_DRUKREF_03','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5324','GCS_ISN_2004','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5340','GCS_POSGAR_2007','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5354','GCS_MARGEN','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5360','GCS_SIRGAS-Chile','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5365','GCS_CR05','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5371','GCS_MARCARIO_SOLIS','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5373','GCS_Peru96','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5381','GCS_SIRGAS-ROU98','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5393','GCS_SIRGAS_ES2007.8','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5451','GCS_Ocotepeque_1935','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5464','GCS_Sibun_Gorge_1922','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5467','GCS_Panama-Colon_1911','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5489','GCS_RGAF09','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5524','GCS_Corrego_Alegre_1961','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5527','GCS_SAD_1969_96','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5546','GCS_PNG94','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5561','GCS_Ukraine_2000','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5593','GCS_FEH2010','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5681','GCS_DB_REF','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','5886','GCS_TGD2005','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','6135','GCS_CIGD11','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','6207','GCS_Nepal_Nagarkot','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','6311','GCS_CGRS_1993','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','6318','GCS_NAD_1983_2011','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','6322','GCS_NAD_1983_PA11','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','6325','GCS_NAD_1983_MA11','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','6365','GCS_Mexico_ITRF2008','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','6668','GCS_JGD_2011','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','6706','GCS_RDN2008','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','6783','GCS_NAD_1983_CORS96','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','6881','GCS_Aden_1925','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','6882','GCS_Bekaa_Valley_1920','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','6883','GCS_Bioko','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','6892','GCS_South_East_Island_1943','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','6894','GCS_Gambia','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','6983','IG05_Intermediate_CRS','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','6987','IGD05(2012)','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','6990','IG05(2012)_Intermediate_CRS','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','7035','RGSPM06_(lon-lat)','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','7037','RGR92_(lon-lat)','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','7039','RGM04_(lon-lat)','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','7041','RGFG95_(lon-lat)','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','7073','GCS_RGTAAF07','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','7084','RGF93_(lon-lat)','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','7086','RGAF09_(lon-lat)','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','7133','RGTAAF07_(lon-lat)','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','7139','IGD05(2012)','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','7881','St_Helena_Tritan','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','8042','Gusterberg(Ferro)','ESRI');
INSERT INTO alias_name VALUES('geodetic_crs','EPSG','8043','St._Stephen(Ferro)','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','1209','Hong_Kong_Geodetic','Hong Kong Geodetic',NULL,'EPSG','7019','EPSG','8901','EPSG','1118',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','8427','Hong_Kong_Geodetic_CS',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','1209','EPSG','1118',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','1211','NAD_1983_(Federal_Base_Network)','NAD83 (Federal Base Network)',NULL,'EPSG','7019','EPSG','8901','EPSG','4515',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','8449','NAD_1983_(FBN)',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','1211','EPSG','4515',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','1212','NAD_1983_(High_Accuracy_Reference_Network-Corrected)','NAD83 (High Accuracy Reference Network - Corrected)',NULL,'EPSG','7019','EPSG','8901','EPSG','3634',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','8545','NAD_1983_(HARN_Corrected)',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','1212','EPSG','3634',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','1214','Serbian_Spatial_Reference_System_2000','Serbian Spatial Reference System 2000',NULL,'EPSG','7019','EPSG','8901','EPSG','3534',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','8685','SRB_ETRS89',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','1214','EPSG','3534',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','1218','MOMRA_Terrestrial_Reference_Frame_2000','MOMRA Terrestrial Reference Frame 2000',NULL,'EPSG','7019','EPSG','8901','EPSG','1206',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','8818','MTRF-2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','1218','EPSG','1206',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106001','D_WGS_1966','WGS 1966',NULL,'ESRI','107001','EPSG','8901','EPSG','1262',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37001','GCS_WGS_1966',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106001','EPSG','1262',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37001','geodetic_crs','EPSG','4760','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106002','D_Fischer_1960','Fischer 1960',NULL,'ESRI','107002','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37002','GCS_Fischer_1960',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106002','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106003','D_Fischer_1968','Fischer 1968',NULL,'ESRI','107003','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37003','GCS_Fischer_1968',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106003','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106004','D_Fischer_Modified','Fischer modified',NULL,'ESRI','107004','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37004','GCS_Fischer_Modified',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106004','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106005','D_Hough_1960','Hough 1960',NULL,'EPSG','7053','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37005','GCS_Hough_1960',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106005','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106006','D_Everest_Modified_1969','Everest modified 1969',NULL,'EPSG','7056','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37006','GCS_Everest_Modified_1969',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106006','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106007','D_Walbeck','Walbeck',NULL,'ESRI','107007','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37007','GCS_Walbeck',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106007','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106008','D_Sphere_ARC_INFO','Authalic sphere (ARC/INFO)',NULL,'ESRI','107008','EPSG','8901','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37008','GCS_Sphere_ARC_INFO',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106008','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106201','D_European_1979','European 1979',NULL,'EPSG','7022','EPSG','8901','EPSG','1297',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37201','GCS_European_1979',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106201','EPSG','1297',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37201','geodetic_crs','EPSG','4668','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106202','D_Everest_Bangladesh','Everest - Bangladesh',NULL,'EPSG','7015','EPSG','8901','EPSG','1041',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37202','GCS_Everest_Bangladesh',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106202','EPSG','1041',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106203','D_Everest_India_Nepal','Everest - India and Nepal',NULL,'EPSG','7044','EPSG','8901','EPSG','1121',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37203','GCS_Everest_India_Nepal',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106203','EPSG','1121',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106204','D_Hjorsey_1955','Hjorsey 1955',NULL,'EPSG','7022','EPSG','8901','EPSG','3262',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37204','GCS_Hjorsey_1955',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106204','EPSG','3262',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37204','geodetic_crs','EPSG','4658','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106205','D_Hong_Kong_1963_67','Hong Kong 1963(67)',NULL,'EPSG','7022','EPSG','8901','EPSG','1118',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37205','GCS_Hong_Kong_1963_67',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106205','EPSG','1118',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37205','geodetic_crs','EPSG','4739','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106206','D_Oman','Oman',NULL,'EPSG','7012','EPSG','8901','EPSG','1183',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37206','GCS_Oman',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106206','EPSG','1183',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106207','D_South_Asia_Singapore','South Asia Singapore',NULL,'ESRI','107004','EPSG','8901','EPSG','1210',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37207','GCS_South_Asia_Singapore',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106207','EPSG','1210',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106208','D_Ayabelle','Ayabelle Lighthouse',NULL,'EPSG','7012','EPSG','8901','EPSG','1081',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37208','GCS_Ayabelle',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106208','EPSG','1081',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37208','geodetic_crs','EPSG','4713','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106211','D_Point_58','Point 58',NULL,'EPSG','7012','EPSG','8901','EPSG','2790',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37211','GCS_Point_58',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106211','EPSG','2790',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37211','geodetic_crs','EPSG','4620','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106212','D_Beacon_E_1945','Astro Beacon E 1945 (Iwo Jima 1945)',NULL,'EPSG','7022','EPSG','8901','EPSG','3200',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37212','GCS_Beacon_E_1945',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106212','EPSG','3200',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37212','geodetic_crs','EPSG','4709','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106213','D_Tern_Island_1961','Tern Island Astro 1961',NULL,'EPSG','7022','EPSG','8901','EPSG','3181',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37213','GCS_Tern_Island_1961',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106213','EPSG','3181',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37213','geodetic_crs','EPSG','4707','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106214','D_Astro_1952','Astronomical Station 1952 (Marcus Island 1952 )',NULL,'EPSG','7022','EPSG','8901','EPSG','1872',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37214','GCS_Astro_1952',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106214','EPSG','1872',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37214','geodetic_crs','EPSG','4711','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106215','D_Bellevue_IGN','Bellevue IGN',NULL,'EPSG','7022','EPSG','8901','EPSG','3193',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37215','GCS_Bellevue_IGN',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106215','EPSG','3193',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37215','geodetic_crs','EPSG','4714','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106216','D_Canton_1966','Canton Astro 1966 (Phoenix Islands 1966)',NULL,'EPSG','7022','EPSG','8901','EPSG','3196',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37216','GCS_Canton_1966',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106216','EPSG','3196',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37216','geodetic_crs','EPSG','4716','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106217','D_Chatham_Island_1971','Chatham Island Astro 1971',NULL,'EPSG','7022','EPSG','8901','EPSG','2889',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37217','GCS_Chatham_Island_1971',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106217','EPSG','2889',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37217','geodetic_crs','EPSG','4672','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106218','D_DOS_1968','DOS 1968',NULL,'EPSG','7022','EPSG','8901','EPSG','3198',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37218','GCS_DOS_1968',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106218','EPSG','3198',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106219','D_Easter_Island_1967','Easter Island 1967',NULL,'EPSG','7022','EPSG','8901','EPSG','3188',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37219','GCS_Easter_Island_1967',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106219','EPSG','3188',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37219','geodetic_crs','EPSG','4719','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106220','D_Guam_1963','Guam 1963',NULL,'EPSG','7008','EPSG','8901','EPSG','4167',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37220','GCS_Guam_1963',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106220','EPSG','4167',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37220','geodetic_crs','EPSG','4675','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106221','D_GUX_1','GUX 1 Astro',NULL,'EPSG','7022','EPSG','8901','EPSG','3197',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37221','GCS_GUX_1',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106221','EPSG','3197',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106222','D_Johnston_Island_1961','Johnston Island 1961',NULL,'EPSG','7022','EPSG','8901','EPSG','3201',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37222','GCS_Johnston_Island_1961',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106222','EPSG','3201',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37222','geodetic_crs','EPSG','4725','ESRI');
INSERT INTO "geodetic_crs" VALUES('ESRI','37223','GCS_Carthage',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6223','EPSG','1236',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37223','geodetic_crs','EPSG','4223','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106224','D_Midway_1961','Midway Astro 1961',NULL,'EPSG','7022','EPSG','8901','EPSG','3202',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37224','GCS_Midway_1961',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106224','EPSG','3202',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37224','geodetic_crs','EPSG','4727','ESRI');
INSERT INTO "geodetic_crs" VALUES('ESRI','37225','GCS_Carthage_Grad',NULL,NULL,'geographic 2D','EPSG','6403','EPSG','6223','EPSG','1236',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106226','D_Pitcairn_1967','Pitcairn Astro 1967',NULL,'EPSG','7022','EPSG','8901','EPSG','3208',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37226','GCS_Pitcairn_1967',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106226','EPSG','3208',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37226','geodetic_crs','EPSG','4729','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106227','D_Santo_DOS_1965','Santo DOS 1965',NULL,'EPSG','7022','EPSG','8901','EPSG','3194',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37227','GCS_Santo_DOS_1965',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106227','EPSG','3194',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37227','geodetic_crs','EPSG','4730','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106228','D_Viti_Levu_1916','Viti Levu 1916',NULL,'EPSG','7012','EPSG','8901','EPSG','3195',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37228','GCS_Viti_Levu_1916',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106228','EPSG','3195',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37228','geodetic_crs','EPSG','4731','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106229','D_Wake_Eniwetok_1960','Wake-Eniwetok 1960 (Marshall Islands 1960)',NULL,'EPSG','7053','EPSG','8901','EPSG','3191',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37229','GCS_Wake_Eniwetok_1960',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106229','EPSG','3191',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37229','geodetic_crs','EPSG','4732','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106230','D_Wake_Island_1952','Wake Island Astro 1952',NULL,'EPSG','7022','EPSG','8901','EPSG','3190',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37230','GCS_Wake_Island_1952',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106230','EPSG','3190',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37230','geodetic_crs','EPSG','4733','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106231','D_Anna_1_1965','Anna 1 Astro 1965 (Cocos Islands 1965)',NULL,'EPSG','7003','EPSG','8901','EPSG','1069',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37231','GCS_Anna_1_1965',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106231','EPSG','1069',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37231','geodetic_crs','EPSG','4708','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106232','D_Gan_1970','Gan 1970',NULL,'EPSG','7022','EPSG','8901','EPSG','3274',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37232','GCS_Gan_1970',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106232','EPSG','3274',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37232','geodetic_crs','EPSG','4684','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106233','D_ISTS_073_1969','ISTS 073 Astro 1969 (Diego Garcia 1969)',NULL,'EPSG','7022','EPSG','8901','EPSG','3189',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37233','GCS_ISTS_073_1969',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106233','EPSG','3189',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37233','geodetic_crs','EPSG','4724','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106234','D_Kerguelen_Island_1949','Kerguelen Island 1949',NULL,'EPSG','7022','EPSG','8901','EPSG','2816',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37234','GCS_Kerguelen_Island_1949',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106234','EPSG','2816',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37234','geodetic_crs','EPSG','4698','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106235','D_Reunion_1947','Reunion 1947',NULL,'EPSG','7022','EPSG','8901','EPSG','3337',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37235','GCS_Reunion_1947',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106235','EPSG','3337',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37235','geodetic_crs','EPSG','4626','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106237','D_Ascension_Island_1958','Ascension Island 1958',NULL,'EPSG','7022','EPSG','8901','EPSG','3182',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37237','GCS_Ascension_Island_1958',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106237','EPSG','3182',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37237','geodetic_crs','EPSG','4712','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106238','D_DOS_71_4','Astro DOS 71/4 (St. Helena 1971)',NULL,'EPSG','7022','EPSG','8901','EPSG','3183',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37238','GCS_DOS_71_4',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106238','EPSG','3183',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37238','geodetic_crs','EPSG','4710','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106239','D_Cape_Canaveral','Cape Canaveral',NULL,'EPSG','7008','EPSG','8901','EPSG','3206',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37239','GCS_Cape_Canaveral',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106239','EPSG','3206',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37239','geodetic_crs','EPSG','4717','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106240','D_Fort_Thomas_1955','Fort Thomas 1955',NULL,'EPSG','7012','EPSG','8901','EPSG','1200',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37240','GCS_Fort_Thomas_1955',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106240','EPSG','1200',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106241','D_Graciosa_Base_SW_1948','Graciosa Base SW 1948',NULL,'EPSG','7022','EPSG','8901','EPSG','1301',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37241','GCS_Graciosa_Base_SW_1948',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106241','EPSG','1301',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106242','D_ISTS_061_1968','ISTS 061 Astro 1968 (South Georgia 1968)',NULL,'EPSG','7022','EPSG','8901','EPSG','3529',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37242','GCS_ISTS_061_1968',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106242','EPSG','3529',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37242','geodetic_crs','EPSG','4722','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106243','D_LC5_1961','L.C. 5 Astro 1961',NULL,'EPSG','7008','EPSG','8901','EPSG','3186',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37243','GCS_LC5_1961',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106243','EPSG','3186',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106245','D_Observatorio_Meteorologico_1939','Observ. Meteorologico 1939',NULL,'EPSG','7022','EPSG','8901','EPSG','1344',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37245','GCS_Observatorio_Meteorologico_1939',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106245','EPSG','1344',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106246','D_Pico_de_Las_Nieves','Pico de Las Nieves',NULL,'EPSG','7022','EPSG','8901','EPSG','3873',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37246','GCS_Pico_de_Las_Nieves',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106246','EPSG','3873',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37246','geodetic_crs','EPSG','4728','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106247','D_Porto_Santo_1936','Porto Santo 1936',NULL,'EPSG','7022','EPSG','8901','EPSG','1314',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37247','GCS_Porto_Santo_1936',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106247','EPSG','1314',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37247','geodetic_crs','EPSG','4615','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106249','D_Sao_Braz','Sao Braz',NULL,'EPSG','7022','EPSG','8901','EPSG','1345',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37249','GCS_Sao_Braz',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106249','EPSG','1345',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106250','D_Selvagem_Grande_1938','Selvagem Grande 1938',NULL,'EPSG','7022','EPSG','8901','EPSG','2779',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37250','GCS_Selvagem_Grande_1938',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106250','EPSG','2779',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37250','geodetic_crs','EPSG','4616','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106251','D_Tristan_1968','Tristan Astro 1968',NULL,'EPSG','7022','EPSG','8901','EPSG','3184',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37251','GCS_Tristan_1968',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106251','EPSG','3184',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37251','geodetic_crs','EPSG','4734','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106252','D_American_Samoa_1962','American Samoa 1962',NULL,'EPSG','7008','EPSG','8901','EPSG','3109',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37252','GCS_American_Samoa_1962',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106252','EPSG','3109',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37252','geodetic_crs','EPSG','4169','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106253','D_Camp_Area','Camp Area Astro',NULL,'EPSG','7022','EPSG','8901','EPSG','3205',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37253','GCS_Camp_Area',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106253','EPSG','3205',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37253','geodetic_crs','EPSG','4715','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106254','D_Deception_Island','Deception Island',NULL,'EPSG','7012','EPSG','8901','EPSG','3204',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37254','GCS_Deception_Island',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106254','EPSG','3204',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37254','geodetic_crs','EPSG','4736','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106255','D_Gunung_Segara','Gunung Segara',NULL,'EPSG','7004','EPSG','8901','EPSG','1360',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37255','GCS_Gunung_Segara',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106255','EPSG','1360',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37255','geodetic_crs','EPSG','4613','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106257','D_S42_Hungary','S-42 Hungary',NULL,'EPSG','7024','EPSG','8901','EPSG','1119',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37257','GCS_S42_Hungary',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106257','EPSG','1119',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106259','D_Kusaie_1951','Kusaie Astro 1951',NULL,'EPSG','7022','EPSG','8901','EPSG','3192',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','37259','GCS_Kusaie_1951',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106259','EPSG','3192',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','37259','geodetic_crs','EPSG','4735','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106260','D_Alaskan_Islands','Alaskan Islands',NULL,'EPSG','7008','EPSG','8901','EPSG','1330',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','37260','GCS_Alaskan_Islands',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106260','EPSG','1330',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104000','GCS_Assumed_Geographic_1',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6267','EPSG','1263',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106009','D_Kyrgyz_Republic_2006','Kyrgyz Republic 2006',NULL,'EPSG','7019','EPSG','8901','EPSG','1137',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104009','GCS_Kyrg-06',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106009','EPSG','1137',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104010','GCS_IGS08',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1141','EPSG','2830',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104011','WGS_1984_(G730)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1152','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104012','WGS_1984_(G873)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1153','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104013','WGS_1984_(G1150)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1154','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104014','WGS_1984_(G1674)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1155','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104015','WGS_1984_(G1762)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1156','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104016','WGS_1984_(Transit)',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1166','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104017','PZ-90.02',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1157','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104018','PZ-90.11',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1158','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104019','ITRF2014',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1165','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106020','D_JGD_2011','Japan Geodetic Datum 2011',NULL,'EPSG','7019','EPSG','8901','EPSG','1129',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104020','GCS_JGD_2011',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106020','EPSG','1129',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104020','geodetic_crs','EPSG','6668','ESRI');
INSERT INTO "geodetic_crs" VALUES('ESRI','104021','IGS14',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1191','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106010','Georgia_Geodetic_Datum','Georgia Geodetic Datum - ITRF2008/IGS08',NULL,'EPSG','7019','EPSG','8901','EPSG','3251',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104022','GGD',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106010','EPSG','3251',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','6023','D_International_1967','International 1967',NULL,'ESRI','7023','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104023','GCS_International_1967',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','6023','EPSG','1263',NULL,1);
INSERT INTO "area" VALUES('ESRI','1','USA - California and borders of NV, AZ, OR and MX','USA - California and borders of NV, AZ, OR and MX',32.25,42.53,-124.44,-113.6,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106012','California_SRS_Epoch_2017.50_(NAD83)','California SRS Epoch 2017.5 (NAD83)',NULL,'EPSG','7019','EPSG','8901','ESRI','1',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104024','California_SRS_Epoch_2017.50_(NAD83)',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106012','ESRI','1',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104025','GCS_Voirol_Unifie_1960_Paris',NULL,NULL,'geographic 2D','EPSG','6403','ESRI','106011','EPSG','1365',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106011_Greenwich','D_Voirol_Unifie_1960',NULL,'Voirol Unifie 1960','EPSG','7012','EPSG','8901','EPSG','1365',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104026','GCS_Voirol_Unifie_1960',NULL,NULL,'geographic 2D','EPSG','6403','ESRI','106011_Greenwich','EPSG','1365',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106047','D_Sphere_GRS_1980_Mean_Radius','GRS 1980 Mean Radius Sphere',NULL,'ESRI','107047','EPSG','8901','EPSG','1263',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104047','GCS_Sphere_GRS_1980_Mean_Radius',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106047','EPSG','1263',NULL,0);
INSERT INTO "area" VALUES('ESRI','2','UK - London','UK - London',51.2,51.8,-0.7,0.6,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106050','D_Xrail84','Xrail84',NULL,'EPSG','7030','EPSG','8901','ESRI','2',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104050','GCS_Xrail84',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106050','ESRI','2',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106100','D_GDBD2009','GDBD2009',NULL,'EPSG','7019','EPSG','8901','EPSG','1055',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104100','GCS_GDBD2009',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106100','EPSG','1055',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104100','geodetic_crs','EPSG','5246','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106101','D_Estonia_1937','Estonia 1937',NULL,'EPSG','7004','EPSG','8901','EPSG','1090',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104101','GCS_Estonia_1937',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106101','EPSG','1090',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106102','D_Hermannskogel','Hermannskogel',NULL,'EPSG','7004','EPSG','8901','EPSG','1321',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104102','GCS_Hermannskogel',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106102','EPSG','1321',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106103','D_Sierra_Leone_1960','Sierra Leone 1960',NULL,'EPSG','7012','EPSG','8901','EPSG','1209',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104103','GCS_Sierra_Leone_1960',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106103','EPSG','1209',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106261','D_Hong_Kong_1980','Hong Kong 1980',NULL,'EPSG','7022','EPSG','8901','EPSG','1118',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104104','GCS_Hong_Kong_1980',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106261','EPSG','1118',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104104','geodetic_crs','EPSG','4611','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106262','D_Datum_Lisboa_Bessel','Datum Lisboa Bessel',NULL,'EPSG','7004','EPSG','8901','EPSG','1193',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104105','GCS_Datum_Lisboa_Bessel',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106262','EPSG','1193',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106263','D_Datum_Lisboa_Hayford','Datum Lisboa Hayford',NULL,'EPSG','7022','EPSG','8901','EPSG','1193',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104106','GCS_Datum_Lisboa_Hayford',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106263','EPSG','1193',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106264','D_RGF_1993','Reseau Geodesique Francais 1993',NULL,'EPSG','7019','EPSG','8901','EPSG','1096',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104107','GCS_RGF_1993',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106264','EPSG','1096',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104107','geodetic_crs','EPSG','4171','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106265','D_NZGD_2000','New Zealand Geodetic Datum 2000',NULL,'EPSG','7019','EPSG','8901','EPSG','1175',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104108','GCS_NZGD_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106265','EPSG','1175',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104108','geodetic_crs','EPSG','4167','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106266','D_Pohnpei','Pohnpei - Fed. States Micronesia',NULL,'EPSG','7008','EPSG','8901','EPSG','1161',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104109','GCS_Pohnpei',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106266','EPSG','1161',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106267','D_REGVEN','REGVEN',NULL,'EPSG','7019','EPSG','8901','EPSG','1251',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104110','GCS_REGVEN',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106267','EPSG','1251',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104110','geodetic_crs','EPSG','4189','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106268','D_JGD_2000','Japan Geodetic Datum 2000',NULL,'EPSG','7019','EPSG','8901','EPSG','1129',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104111','GCS_JGD_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106268','EPSG','1129',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104111','geodetic_crs','EPSG','4612','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106269','D_Bab_South','Bab South Astro - Bablethuap Is - Republic of Palau',NULL,'EPSG','7008','EPSG','8901','EPSG','1185',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104112','GCS_Bab_South',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106269','EPSG','1185',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106270','D_Majuro','Majuro - Republic of Marshall Is.',NULL,'EPSG','7008','EPSG','8901','EPSG','1155',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104113','GCS_Majuro',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106270','EPSG','1155',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106271','D_Bermuda_2000','Bermuda 2000',NULL,'EPSG','7030','EPSG','8901','EPSG','1047',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104114','GCS_Bermuda_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106271','EPSG','1047',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104114','geodetic_crs','EPSG','4762','ESRI');
INSERT INTO "geodetic_crs" VALUES('ESRI','104115','GCS_ITRF_1988',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6647','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104116','GCS_ITRF_1989',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6648','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104117','GCS_ITRF_1990',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6649','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104118','GCS_ITRF_1991',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6650','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104119','GCS_ITRF_1992',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6651','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104120','GCS_ITRF_1993',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6652','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104121','GCS_ITRF_1994',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6653','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104122','GCS_ITRF_1996',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6654','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104123','GCS_ITRF_1997',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6655','EPSG','1262',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104124','GCS_ITRF_2000',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6656','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106273','D_Chatham_Islands_1979','Chatham Islands 1979',NULL,'EPSG','7022','EPSG','8901','EPSG','2889',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104125','GCS_Chatham_Islands_1979',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106273','EPSG','2889',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104125','geodetic_crs','EPSG','4673','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106274','D_Observatorio_Meteorologico_1965','Observatorio Meteorologico 1965',NULL,'EPSG','7022','EPSG','8901','EPSG','1147',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104126','GCS_Observatorio_Meteorologico_1965',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106274','EPSG','1147',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106275','D_Roma_1940','Roma 1940',NULL,'EPSG','7022','EPSG','8901','EPSG','3343',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104127','GCS_Roma_1940',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106275','EPSG','3343',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106276','D_Sphere_EMEP','EMEP',NULL,'ESRI','107009','EPSG','8901','EPSG','2881',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104128','GCS_Sphere_EMEP',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106276','EPSG','2881',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104129','GCS_EUREF_FIN',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6258','EPSG','1095',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106277','D_Jordan','Jordan',NULL,'EPSG','7022','EPSG','8901','EPSG','1130',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104130','GCS_Jordan',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106277','EPSG','1130',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106278','D_D48','D48 - Slovenia',NULL,'EPSG','7004','EPSG','8901','EPSG','1212',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104131','GCS_D48',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106278','EPSG','1212',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106279','D_Ocotepeque_1935','Ocotepeque 1935',NULL,'EPSG','7008','EPSG','8901','EPSG','3876',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104132','GCS_Ocotepeque_1935',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106279','EPSG','3876',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104132','geodetic_crs','EPSG','5451','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106280','D_Jamaica_2001','Jamaica 2001',NULL,'EPSG','7030','EPSG','8901','EPSG','1128',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104133','GCS_JAD_2001',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106280','EPSG','1128',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104133','geodetic_crs','EPSG','4758','ESRI');
INSERT INTO "geodetic_crs" VALUES('ESRI','104134','GCS_MONREF_1997',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6656','EPSG','1164',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104135','GCS_MSK_1942',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6284','EPSG','1164',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106281','D_TWD_1967','Taiwan 1967',NULL,'EPSG','7050','EPSG','8901','EPSG','3315',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104136','GCS_TWD_1967',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106281','EPSG','3315',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104136','geodetic_crs','EPSG','3821','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106282','D_TWD_1997','Taiwan 1997',NULL,'EPSG','7019','EPSG','8901','EPSG','1228',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104137','GCS_TWD_1997',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106282','EPSG','1228',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104137','geodetic_crs','EPSG','3824','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106284','D_Old_Hawaiian_Intl_1924','Old Hawaiian on Intl_1924 spheroid (NGS)',NULL,'EPSG','7022','EPSG','8901','EPSG','1334',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104138','GCS_Old_Hawaiian_Intl_1924',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106284','EPSG','1334',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104139','GCS_Voirol_1875_Grad',NULL,NULL,'geographic 2D','EPSG','6403','EPSG','6304','EPSG','1365',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104140','GCS_Voirol_1879_Grad',NULL,NULL,'geographic 2D','EPSG','6403','EPSG','6671','EPSG','1365',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106225','D_Cyprus_Geodetic_Reference_System_1993','Cyprus GRS 1993',NULL,'EPSG','7030','EPSG','8901','EPSG','3236',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104141','GCS_CGRS_1993',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106225','EPSG','3236',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104141','geodetic_crs','EPSG','6311','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106236','D_PTRA08','Portugal - Autonomous Regions (Madeira and Azores Archipelagos)',NULL,'EPSG','7019','EPSG','8901','EPSG','3670',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104142','GCS_PTRA08',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106236','EPSG','3670',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104142','geodetic_crs','EPSG','5013','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106244','D_Costa_Rica_2005','Costa Rica 2005',NULL,'EPSG','7030','EPSG','8901','EPSG','1074',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104143','GCS_CR05',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106244','EPSG','1074',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104143','geodetic_crs','EPSG','5365','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106144','D_Islands_Network_2004','Islands Network 2004',NULL,'EPSG','7019','EPSG','8901','EPSG','1120',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104144','GCS_ISN_2004',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106144','EPSG','1120',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104144','geodetic_crs','EPSG','5324','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106285','D_NAD_1983_2011','NAD 1983 (2011)',NULL,'EPSG','7019','EPSG','8901','EPSG','1511',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104145','GCS_NAD_1983_2011',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106285','EPSG','1511',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104145','geodetic_crs','EPSG','6318','ESRI');
INSERT INTO "geodetic_crs" VALUES('ESRI','104179','ETRF90',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1179','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104180','ETRF91',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1180','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104181','ETRF92',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1181','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104182','ETRF93',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1182','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104183','ETRF94',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1183','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104184','ETRF96',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1184','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104185','ETRF97',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1185','EPSG','1298',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104186','ETRF2000',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1186','EPSG','1298',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106283','D_WGS_1984_Major_Auxiliary_Sphere','Major auxiliary sphere based on WGS 1984',NULL,'EPSG','7059','EPSG','8901','EPSG','1262',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104199','GCS_WGS_1984_Major_Auxiliary_Sphere',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106283','EPSG','1262',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104199','geodetic_crs','EPSG','4055','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106223','D_NAD_1983_CORS96','NAD 1983 (CORS96)',NULL,'EPSG','7019','EPSG','8901','EPSG','1511',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104223','GCS_NAD_1983_CORS96',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106223','EPSG','1511',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104223','geodetic_crs','EPSG','6783','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106248','D_MACAO_2008','Macao 2008 (ITRF 2005)',NULL,'EPSG','7022','EPSG','8901','EPSG','1147',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104248','GCS_MACAO_2008',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106248','EPSG','1147',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106256','D_Nepal_Nagarkot','Nepal Nagarkot',NULL,'EPSG','7015','EPSG','8901','EPSG','1171',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104256','GCS_Nepal_Nagarkot',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106256','EPSG','1171',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104256','geodetic_crs','EPSG','6207','ESRI');
INSERT INTO "geodetic_crs" VALUES('ESRI','104257','GCS_ITRF_2008',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','1061','EPSG','2830',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106258','D_ETRF_1989','European Terrestrial Ref. Frame 1989',NULL,'EPSG','7030','EPSG','8901','EPSG','1298',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104258','GCS_ETRF_1989',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106258','EPSG','1298',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106209','D_NAD_1983_PACP00','NAD 1983 PACP00',NULL,'EPSG','7019','EPSG','8901','EPSG','4162',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104259','GCS_NAD_1983_PACP00',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106209','EPSG','4162',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106210','D_NAD_1983_MARP00','NAD 1983 MARP00',NULL,'EPSG','7019','EPSG','8901','EPSG','4167',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104260','GCS_NAD_1983_MARP00',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106210','EPSG','4167',NULL,0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104261','GCS_Merchich_Degree',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6261','EPSG','3280',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106286','D_NAD_1983_MA11','NAD 1983 (MA11) - Marianas Plate 2011',NULL,'EPSG','7019','EPSG','8901','EPSG','4167',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104286','GCS_NAD_1983_MA11',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106286','EPSG','4167',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104286','geodetic_crs','EPSG','6325','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106287','D_NAD_1983_PA11','NAD 1983 (PA11) - Pacific Plate 2011',NULL,'EPSG','7019','EPSG','8901','EPSG','4162',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104287','GCS_NAD_1983_PA11',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106287','EPSG','4162',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104287','geodetic_crs','EPSG','6322','ESRI');
INSERT INTO "geodetic_crs" VALUES('ESRI','104304','GCS_Voirol_1875',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6304','EPSG','1365',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104304','geodetic_crs','EPSG','4304','ESRI');
INSERT INTO "geodetic_crs" VALUES('ESRI','104305','GCS_Voirol_Unifie_1960_Degree',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106011','EPSG','1365',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106700','D_NAD_1983_HARN_Adj_MN_Anoka','NAD 1983 HARN Adj. Minnesota Anoka',NULL,'ESRI','107700','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104700','GCS_NAD_1983_HARN_Adj_MN_Anoka',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106700','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106701','D_NAD_1983_HARN_Adj_MN_Becker','NAD 1983 HARN Adj. Minnesota Becker',NULL,'ESRI','107701','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104701','GCS_NAD_1983_HARN_Adj_MN_Becker',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106701','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106702','D_NAD_1983_HARN_Adj_MN_Beltrami_North','NAD 1983 HARN Adj. Minnesota Beltrami North',NULL,'ESRI','107702','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104702','GCS_NAD_1983_HARN_Adj_MN_Beltrami_North',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106702','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106703','D_NAD_1983_HARN_Adj_MN_Beltrami_South','NAD 1983 HARN Adj. Minnesota Beltrami South',NULL,'ESRI','107703','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104703','GCS_NAD_1983_HARN_Adj_MN_Beltrami_South',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106703','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106704','D_NAD_1983_HARN_Adj_MN_Benton','NAD 1983 HARN Adj. Minnesota Benton',NULL,'ESRI','107704','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104704','GCS_NAD_1983_HARN_Adj_MN_Benton',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106704','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106705','D_NAD_1983_HARN_Adj_MN_Big_Stone','NAD 1983 HARN Adj. Minnesota Big Stone',NULL,'ESRI','107705','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104705','GCS_NAD_1983_HARN_Adj_MN_Big_Stone',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106705','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106706','D_NAD_1983_HARN_Adj_MN_Blue_Earth','NAD 1983 HARN Adj. Minnesota Blue Earth',NULL,'ESRI','107706','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104706','GCS_NAD_1983_HARN_Adj_MN_Blue_Earth',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106706','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106707','D_NAD_1983_HARN_Adj_MN_Brown','NAD 1983 HARN Adj. Minnesota Brown',NULL,'ESRI','107707','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104707','GCS_NAD_1983_HARN_Adj_MN_Brown',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106707','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106708','D_NAD_1983_HARN_Adj_MN_Carlton','NAD 1983 HARN Adj. Minnesota Carlton',NULL,'ESRI','107708','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104708','GCS_NAD_1983_HARN_Adj_MN_Carlton',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106708','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106709','D_NAD_1983_HARN_Adj_MN_Carver','NAD 1983 HARN Adj. Minnesota Carver',NULL,'ESRI','107709','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104709','GCS_NAD_1983_HARN_Adj_MN_Carver',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106709','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106710','D_NAD_1983_HARN_Adj_MN_Cass_North','NAD 1983 HARN Adj. Minnesota Cass North',NULL,'ESRI','107710','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104710','GCS_NAD_1983_HARN_Adj_MN_Cass_North',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106710','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106711','D_NAD_1983_HARN_Adj_MN_Cass_South','NAD 1983 HARN Adj. Minnesota Cass South',NULL,'ESRI','107711','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104711','GCS_NAD_1983_HARN_Adj_MN_Cass_South',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106711','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106712','D_NAD_1983_HARN_Adj_MN_Chippewa','NAD 1983 HARN Adj. Minnesota Chippewa',NULL,'ESRI','107712','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104712','GCS_NAD_1983_HARN_Adj_MN_Chippewa',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106712','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106713','D_NAD_1983_HARN_Adj_MN_Chisago','NAD 1983 HARN Adj. Minnesota Chisago',NULL,'ESRI','107713','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104713','GCS_NAD_1983_HARN_Adj_MN_Chisago',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106713','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106714','D_NAD_1983_HARN_Adj_MN_Cook_North','NAD 1983 HARN Adj. Minnesota Cook North',NULL,'ESRI','107714','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104714','GCS_NAD_1983_HARN_Adj_MN_Cook_North',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106714','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106715','D_NAD_1983_HARN_Adj_MN_Cook_South','NAD 1983 HARN Adj. Minnesota Cook South',NULL,'ESRI','107715','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104715','GCS_NAD_1983_HARN_Adj_MN_Cook_South',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106715','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106716','D_NAD_1983_HARN_Adj_MN_Cottonwood','NAD 1983 HARN Adj. Minnesota Cottonwood',NULL,'ESRI','107716','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104716','GCS_NAD_1983_HARN_Adj_MN_Cottonwood',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106716','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106717','D_NAD_1983_HARN_Adj_MN_Crow_Wing','NAD 1983 HARN Adj. Minnesota Crow Wing',NULL,'ESRI','107717','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104717','GCS_NAD_1983_HARN_Adj_MN_Crow_Wing',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106717','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106718','D_NAD_1983_HARN_Adj_MN_Dakota','NAD 1983 HARN Adj. Minnesota Dakota',NULL,'ESRI','107718','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104718','GCS_NAD_1983_HARN_Adj_MN_Dakota',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106718','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106719','D_NAD_1983_HARN_Adj_MN_Dodge','NAD 1983 HARN Adj. Minnesota Dodge',NULL,'ESRI','107719','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104719','GCS_NAD_1983_HARN_Adj_MN_Dodge',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106719','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106720','D_NAD_1983_HARN_Adj_MN_Douglas','NAD 1983 HARN Adj. Minnesota Douglas',NULL,'ESRI','107720','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104720','GCS_NAD_1983_HARN_Adj_MN_Douglas',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106720','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106721','D_NAD_1983_HARN_Adj_MN_Faribault','NAD 1983 HARN Adj. Minnesota Faribault',NULL,'ESRI','107721','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104721','GCS_NAD_1983_HARN_Adj_MN_Faribault',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106721','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106722','D_NAD_1983_HARN_Adj_MN_Fillmore','NAD 1983 HARN Adj. Minnesota Fillmore',NULL,'ESRI','107722','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104722','GCS_NAD_1983_HARN_Adj_MN_Fillmore',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106722','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106723','D_NAD_1983_HARN_Adj_MN_Freeborn','NAD 1983 HARN Adj. Minnesota Freeborn',NULL,'ESRI','107723','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104723','GCS_NAD_1983_HARN_Adj_MN_Freeborn',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106723','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106724','D_NAD_1983_HARN_Adj_MN_Goodhue','NAD 1983 HARN Adj. Minnesota Goodhue',NULL,'ESRI','107724','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104724','GCS_NAD_1983_HARN_Adj_MN_Goodhue',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106724','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106725','D_NAD_1983_HARN_Adj_MN_Grant','NAD 1983 HARN Adj. Minnesota Grant',NULL,'ESRI','107725','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104725','GCS_NAD_1983_HARN_Adj_MN_Grant',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106725','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106726','D_NAD_1983_HARN_Adj_MN_Hennepin','NAD 1983 HARN Adj. Minnesota Hennepin',NULL,'ESRI','107726','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104726','GCS_NAD_1983_HARN_Adj_MN_Hennepin',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106726','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106727','D_NAD_1983_HARN_Adj_MN_Houston','NAD 1983 HARN Adj. Minnesota Houston',NULL,'ESRI','107727','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104727','GCS_NAD_1983_HARN_Adj_MN_Houston',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106727','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106728','D_NAD_1983_HARN_Adj_MN_Isanti','NAD 1983 HARN Adj. Minnesota Isanti',NULL,'ESRI','107728','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104728','GCS_NAD_1983_HARN_Adj_MN_Isanti',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106728','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106729','D_NAD_1983_HARN_Adj_MN_Itasca_North','NAD 1983 HARN Adj. Minnesota Itasca North',NULL,'ESRI','107729','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104729','GCS_NAD_1983_HARN_Adj_MN_Itasca_North',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106729','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106730','D_NAD_1983_HARN_Adj_MN_Itasca_South','NAD 1983 HARN Adj. Minnesota Itasca South',NULL,'ESRI','107730','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104730','GCS_NAD_1983_HARN_Adj_MN_Itasca_South',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106730','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106731','D_NAD_1983_HARN_Adj_MN_Jackson','NAD 1983 HARN Adj. Minnesota Jackson',NULL,'ESRI','107731','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104731','GCS_NAD_1983_HARN_Adj_MN_Jackson',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106731','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106732','D_NAD_1983_HARN_Adj_MN_Kanabec','NAD 1983 HARN Adj. Minnesota Kanabec',NULL,'ESRI','107732','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104732','GCS_NAD_1983_HARN_Adj_MN_Kanabec',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106732','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106733','D_NAD_1983_HARN_Adj_MN_Kandiyohi','NAD 1983 HARN Adj. Minnesota Kandiyohi',NULL,'ESRI','107733','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104733','GCS_NAD_1983_HARN_Adj_MN_Kandiyohi',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106733','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106734','D_NAD_1983_HARN_Adj_MN_Kittson','NAD 1983 HARN Adj. Minnesota Kittson',NULL,'ESRI','107734','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104734','GCS_NAD_1983_HARN_Adj_MN_Kittson',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106734','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106735','D_NAD_1983_HARN_Adj_MN_Koochiching','NAD 1983 HARN Adj. Minnesota Koochiching',NULL,'ESRI','107735','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104735','GCS_NAD_1983_HARN_Adj_MN_Koochiching',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106735','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106736','D_NAD_1983_HARN_Adj_MN_Lac_Qui_Parle','NAD 1983 HARN Adj. Minnesota Lac Qui Parle',NULL,'ESRI','107736','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104736','GCS_NAD_1983_HARN_Adj_MN_Lac_Qui_Parle',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106736','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106737','D_NAD_1983_HARN_Adj_MN_Lake_of_the_Woods_North','NAD 1983 HARN Adj. Minnesota Lake of the Woods North',NULL,'ESRI','107737','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104737','GCS_NAD_1983_HARN_Adj_MN_Lake_of_the_Woods_North',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106737','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106738','D_NAD_1983_HARN_Adj_MN_Lake_of_the_Woods_South','NAD 1983 HARN Adj. Minnesota Lake of the Woods South',NULL,'ESRI','107738','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104738','GCS_NAD_1983_HARN_Adj_MN_Lake_of_the_Woods_South',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106738','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106739','D_NAD_1983_HARN_Adj_MN_Le_Sueur','NAD 1983 HARN Adj. Minnesota Le Sueur',NULL,'ESRI','107739','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104739','GCS_NAD_1983_HARN_Adj_MN_Le_Sueur',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106739','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106740','D_NAD_1983_HARN_Adj_MN_Lincoln','NAD 1983 HARN Adj. Minnesota Lincoln',NULL,'ESRI','107740','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104740','GCS_NAD_1983_HARN_Adj_MN_Lincoln',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106740','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106741','D_NAD_1983_HARN_Adj_MN_Lyon','NAD 1983 HARN Adj. Minnesota Lyon',NULL,'ESRI','107741','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104741','GCS_NAD_1983_HARN_Adj_MN_Lyon',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106741','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106742','D_NAD_1983_HARN_Adj_MN_McLeod','NAD 1983 HARN Adj. Minnesota McLeod',NULL,'ESRI','107742','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104742','GCS_NAD_1983_HARN_Adj_MN_McLeod',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106742','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106743','D_NAD_1983_HARN_Adj_MN_Mahnomen','NAD 1983 HARN Adj. Minnesota Mahnomen',NULL,'ESRI','107743','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104743','GCS_NAD_1983_HARN_Adj_MN_Mahnomen',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106743','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106744','D_NAD_1983_HARN_Adj_MN_Marshall','NAD 1983 HARN Adj. Minnesota Marshall',NULL,'ESRI','107744','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104744','GCS_NAD_1983_HARN_Adj_MN_Marshall',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106744','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106745','D_NAD_1983_HARN_Adj_MN_Martin','NAD 1983 HARN Adj. Minnesota Martin',NULL,'ESRI','107745','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104745','GCS_NAD_1983_HARN_Adj_MN_Martin',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106745','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106746','D_NAD_1983_HARN_Adj_MN_Meeker','NAD 1983 HARN Adj. Minnesota Meeker',NULL,'ESRI','107746','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104746','GCS_NAD_1983_HARN_Adj_MN_Meeker',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106746','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106747','D_NAD_1983_HARN_Adj_MN_Morrison','NAD 1983 HARN Adj. Minnesota Morrison',NULL,'ESRI','107747','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104747','GCS_NAD_1983_HARN_Adj_MN_Morrison',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106747','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106748','D_NAD_1983_HARN_Adj_MN_Mower','NAD 1983 HARN Adj. Minnesota Mower',NULL,'ESRI','107748','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104748','GCS_NAD_1983_HARN_Adj_MN_Mower',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106748','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106749','D_NAD_1983_HARN_Adj_MN_Murray','NAD 1983 HARN Adj. Minnesota Murray',NULL,'ESRI','107749','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104749','GCS_NAD_1983_HARN_Adj_MN_Murray',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106749','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106750','D_NAD_1983_HARN_Adj_MN_Nicollet','NAD 1983 HARN Adj. Minnesota Nicollet',NULL,'ESRI','107750','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104750','GCS_NAD_1983_HARN_Adj_MN_Nicollet',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106750','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106751','D_NAD_1983_HARN_Adj_MN_Nobles','NAD 1983 HARN Adj. Minnesota Nobles',NULL,'ESRI','107751','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104751','GCS_NAD_1983_HARN_Adj_MN_Nobles',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106751','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106752','D_NAD_1983_HARN_Adj_MN_Norman','NAD 1983 HARN Adj. Minnesota Norman',NULL,'ESRI','107752','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104752','GCS_NAD_1983_HARN_Adj_MN_Norman',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106752','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106753','D_NAD_1983_HARN_Adj_MN_Olmsted','NAD 1983 HARN Adj. Minnesota Olmsted',NULL,'ESRI','107753','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104753','GCS_NAD_1983_HARN_Adj_MN_Olmsted',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106753','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106754','D_NAD_1983_HARN_Adj_MN_Ottertail','NAD 1983 HARN Adj. Minnesota Ottertail',NULL,'ESRI','107754','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104754','GCS_NAD_1983_HARN_Adj_MN_Ottertail',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106754','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106755','D_NAD_1983_HARN_Adj_MN_Pennington','NAD 1983 HARN Adj. Minnesota Pennington',NULL,'ESRI','107755','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104755','GCS_NAD_1983_HARN_Adj_MN_Pennington',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106755','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106756','D_NAD_1983_HARN_Adj_MN_Pine','NAD 1983 HARN Adj. Minnesota Pine',NULL,'ESRI','107756','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104756','GCS_NAD_1983_HARN_Adj_MN_Pine',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106756','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106757','D_NAD_1983_HARN_Adj_MN_Pipestone','NAD 1983 HARN Adj. Minnesota Pipestone',NULL,'ESRI','107757','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104757','GCS_NAD_1983_HARN_Adj_MN_Pipestone',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106757','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106758','D_NAD_1983_HARN_Adj_MN_Polk','NAD 1983 HARN Adj. Minnesota Polk',NULL,'ESRI','107758','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104758','GCS_NAD_1983_HARN_Adj_MN_Polk',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106758','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106759','D_NAD_1983_HARN_Adj_MN_Pope','NAD 1983 HARN Adj. Minnesota Pope',NULL,'ESRI','107759','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104759','GCS_NAD_1983_HARN_Adj_MN_Pope',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106759','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106760','D_NAD_1983_HARN_Adj_MN_Ramsey','NAD 1983 HARN Adj. Minnesota Ramsey',NULL,'ESRI','107760','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104760','GCS_NAD_1983_HARN_Adj_MN_Ramsey',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106760','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106761','D_NAD_1983_HARN_Adj_MN_Red_Lake','NAD 1983 HARN Adj. Minnesota Red Lake',NULL,'ESRI','107761','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104761','GCS_NAD_1983_HARN_Adj_MN_Red_Lake',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106761','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106762','D_NAD_1983_HARN_Adj_MN_Redwood','NAD 1983 HARN Adj. Minnesota Redwood',NULL,'ESRI','107762','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104762','GCS_NAD_1983_HARN_Adj_MN_Redwood',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106762','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106763','D_NAD_1983_HARN_Adj_MN_Renville','NAD 1983 HARN Adj. Minnesota Renville',NULL,'ESRI','107763','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104763','GCS_NAD_1983_HARN_Adj_MN_Renville',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106763','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106764','D_NAD_1983_HARN_Adj_MN_Rice','NAD 1983 HARN Adj. Minnesota Rice',NULL,'ESRI','107764','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104764','GCS_NAD_1983_HARN_Adj_MN_Rice',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106764','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106765','D_NAD_1983_HARN_Adj_MN_Rock','NAD 1983 HARN Adj. Minnesota Rock',NULL,'ESRI','107765','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104765','GCS_NAD_1983_HARN_Adj_MN_Rock',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106765','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106766','D_NAD_1983_HARN_Adj_MN_Roseau','NAD 1983 HARN Adj. Minnesota Roseau',NULL,'ESRI','107766','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104766','GCS_NAD_1983_HARN_Adj_MN_Roseau',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106766','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106767','D_NAD_1983_HARN_Adj_MN_St_Louis_North','NAD 1983 HARN Adj. Minnesota St Louis North',NULL,'ESRI','107767','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104767','GCS_NAD_1983_HARN_Adj_MN_St_Louis_North',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106767','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106768','D_NAD_1983_HARN_Adj_MN_St_Louis_Central','NAD 1983 HARN Adj. Minnesota St Louis Central',NULL,'ESRI','107768','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104768','GCS_NAD_1983_HARN_Adj_MN_St_Louis_Central',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106768','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106769','D_NAD_1983_HARN_Adj_MN_St_Louis_South','NAD 1983 HARN Adj. Minnesota St Louis South',NULL,'ESRI','107769','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104769','GCS_NAD_1983_HARN_Adj_MN_St_Louis_South',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106769','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106770','D_NAD_1983_HARN_Adj_MN_Scott','NAD 1983 HARN Adj. Minnesota Scott',NULL,'ESRI','107770','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104770','GCS_NAD_1983_HARN_Adj_MN_Scott',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106770','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106771','D_NAD_1983_HARN_Adj_MN_Sherburne','NAD 1983 HARN Adj. Minnesota Sherburne',NULL,'ESRI','107771','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104771','GCS_NAD_1983_HARN_Adj_MN_Sherburne',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106771','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106772','D_NAD_1983_HARN_Adj_MN_Sibley','NAD 1983 HARN Adj. Minnesota Sibley',NULL,'ESRI','107772','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104772','GCS_NAD_1983_HARN_Adj_MN_Sibley',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106772','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106773','D_NAD_1983_HARN_Adj_MN_Stearns','NAD 1983 HARN Adj. Minnesota Stearns',NULL,'ESRI','107773','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104773','GCS_NAD_1983_HARN_Adj_MN_Stearns',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106773','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106774','D_NAD_1983_HARN_Adj_MN_Steele','NAD 1983 HARN Adj. Minnesota Steele',NULL,'ESRI','107774','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104774','GCS_NAD_1983_HARN_Adj_MN_Steele',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106774','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106775','D_NAD_1983_HARN_Adj_MN_Stevens','NAD 1983 HARN Adj. Minnesota Stevens',NULL,'ESRI','107775','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104775','GCS_NAD_1983_HARN_Adj_MN_Stevens',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106775','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106776','D_NAD_1983_HARN_Adj_MN_Swift','NAD 1983 HARN Adj. Minnesota Swift',NULL,'ESRI','107776','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104776','GCS_NAD_1983_HARN_Adj_MN_Swift',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106776','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106777','D_NAD_1983_HARN_Adj_MN_Todd','NAD 1983 HARN Adj. Minnesota Todd',NULL,'ESRI','107777','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104777','GCS_NAD_1983_HARN_Adj_MN_Todd',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106777','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106778','D_NAD_1983_HARN_Adj_MN_Traverse','NAD 1983 HARN Adj. Minnesota Traverse',NULL,'ESRI','107778','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104778','GCS_NAD_1983_HARN_Adj_MN_Traverse',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106778','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106779','D_NAD_1983_HARN_Adj_MN_Wabasha','NAD 1983 HARN Adj. Minnesota Wabasha',NULL,'ESRI','107779','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104779','GCS_NAD_1983_HARN_Adj_MN_Wabasha',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106779','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106780','D_NAD_1983_HARN_Adj_MN_Wadena','NAD 1983 HARN Adj. Minnesota Wadena',NULL,'ESRI','107780','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104780','GCS_NAD_1983_HARN_Adj_MN_Wadena',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106780','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106781','D_NAD_1983_HARN_Adj_MN_Waseca','NAD 1983 HARN Adj. Minnesota Waseca',NULL,'ESRI','107781','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104781','GCS_NAD_1983_HARN_Adj_MN_Waseca',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106781','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106782','D_NAD_1983_HARN_Adj_MN_Watonwan','NAD 1983 HARN Adj. Minnesota Watonwan',NULL,'ESRI','107782','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104782','GCS_NAD_1983_HARN_Adj_MN_Watonwan',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106782','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106783','D_NAD_1983_HARN_Adj_MN_Winona','NAD 1983 HARN Adj. Minnesota Winona',NULL,'ESRI','107783','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104783','GCS_NAD_1983_HARN_Adj_MN_Winona',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106783','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106784','D_NAD_1983_HARN_Adj_MN_Wright','NAD 1983 HARN Adj. Minnesota Wright',NULL,'ESRI','107784','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104784','GCS_NAD_1983_HARN_Adj_MN_Wright',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106784','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106785','D_NAD_1983_HARN_Adj_MN_Yellow_Medicine','NAD 1983 HARN Adj. Minnesota Yellow Medicine',NULL,'ESRI','107785','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104785','GCS_NAD_1983_HARN_Adj_MN_Yellow_Medicine',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106785','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106786','D_NAD_1983_HARN_Adj_MN_St_Louis','NAD 1983 HARN Adj. Minnesota St Louis',NULL,'ESRI','107786','EPSG','8901','EPSG','1392',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104786','GCS_NAD_1983_HARN_Adj_MN_St_Louis',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106786','EPSG','1392',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106851','D_NAD_1983_HARN_Adj_WI_AD_JN','NAD 1983 HARN Adj. Wisconsin Adams and Juneau',NULL,'ESRI','107851','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104800','GCS_NAD_1983_HARN_Adj_WI_Adams',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106851','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106800','D_NAD_1983_HARN_Adj_WI_AL','NAD 1983 HARN Adj. Wisconsin Ashland',NULL,'ESRI','107800','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104801','GCS_NAD_1983_HARN_Adj_WI_Ashland',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106800','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106801','D_NAD_1983_HARN_Adj_WI_BA','NAD 1983 HARN Adj. Wisconsin Barron',NULL,'ESRI','107801','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104802','GCS_NAD_1983_HARN_Adj_WI_Barron',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106801','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106802','D_NAD_1983_HARN_Adj_WI_BF','NAD 1983 HARN Adj. Wisconsin Bayfield',NULL,'ESRI','107802','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104803','GCS_NAD_1983_HARN_Adj_WI_Bayfield',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106802','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106803','D_NAD_1983_HARN_Adj_WI_BR','NAD 1983 HARN Adj. Wisconsin Brown',NULL,'ESRI','107803','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104804','GCS_NAD_1983_HARN_Adj_WI_Brown',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106803','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106804','D_NAD_1983_HARN_Adj_WI_BU','NAD 1983 HARN Adj. Wisconsin Buffalo',NULL,'ESRI','107804','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104805','GCS_NAD_1983_HARN_Adj_WI_Buffalo',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106804','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106805','D_NAD_1983_HARN_Adj_WI_BN','NAD 1983 HARN Adj. Wisconsin Burnett',NULL,'ESRI','107805','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104806','GCS_NAD_1983_HARN_Adj_WI_Burnett',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106805','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106856','D_NAD_1983_HARN_Adj_WI_CL_FL_OG_WN','NAD 1983 HARN Adj. Wisconsin Calumet, Fond du Lac, Outagamie, and Winnebago',NULL,'ESRI','107856','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104807','GCS_NAD_1983_HARN_Adj_WI_Calumet',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106856','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106806','D_NAD_1983_HARN_Adj_WI_CP','NAD 1983 HARN Adj. Wisconsin Chippewa',NULL,'ESRI','107806','EPSG','8901','EPSG','1418',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104808','GCS_NAD_1983_HARN_Adj_WI_Chippewa',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106806','EPSG','1418',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106807','D_NAD_1983_HARN_Adj_WI_CK','NAD 1983 HARN Adj. Wisconsin Clark',NULL,'ESRI','107807','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104809','GCS_NAD_1983_HARN_Adj_WI_Clark',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106807','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106808','D_NAD_1983_HARN_Adj_WI_CO','NAD 1983 HARN Adj. Wisconsin Columbia',NULL,'ESRI','107808','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104810','GCS_NAD_1983_HARN_Adj_WI_Columbia',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106808','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106809','D_NAD_1983_HARN_Adj_WI_CR','NAD 1983 HARN Adj. Wisconsin Crawford',NULL,'ESRI','107809','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104811','GCS_NAD_1983_HARN_Adj_WI_Crawford',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106809','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106810','D_NAD_1983_HARN_Adj_WI_DN','NAD 1983 HARN Adj. Wisconsin Dane',NULL,'ESRI','107810','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104812','GCS_NAD_1983_HARN_Adj_WI_Dane',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106810','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106854','D_NAD_1983_HARN_Adj_WI_DD_JF','NAD 1983 HARN Adj. Wisconsin Dodge and Jefferson',NULL,'ESRI','107854','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104813','GCS_NAD_1983_HARN_Adj_WI_Dodge',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106854','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106811','D_NAD_1983_HARN_Adj_WI_DR','NAD 1983 HARN Adj. Wisconsin Door',NULL,'ESRI','107811','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104814','GCS_NAD_1983_HARN_Adj_WI_Door',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106811','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106812','D_NAD_1983_HARN_Adj_WI_DG','NAD 1983 HARN Adj. Wisconsin Douglas',NULL,'ESRI','107812','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104815','GCS_NAD_1983_HARN_Adj_WI_Douglas',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106812','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106813','D_NAD_1983_HARN_Adj_WI_DU','NAD 1983 HARN Adj. Wisconsin Dunn',NULL,'ESRI','107813','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104816','GCS_NAD_1983_HARN_Adj_WI_Dunn',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106813','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106814','D_NAD_1983_HARN_Adj_WI_EC','NAD 1983 HARN Adj. Wisconsin EauClaire',NULL,'ESRI','107814','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104817','GCS_NAD_1983_HARN_Adj_WI_EauClaire',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106814','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106815','D_NAD_1983_HARN_Adj_WI_FN','NAD 1983 HARN Adj. Wisconsin Florence',NULL,'ESRI','107815','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104818','GCS_NAD_1983_HARN_Adj_WI_Florence',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106815','EPSG','1418',NULL,1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104819','GCS_NAD_1983_HARN_Adj_WI_FondduLac',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106856','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106816','D_NAD_1983_HARN_Adj_WI_FR','NAD 1983 HARN Adj. Wisconsin Forest',NULL,'ESRI','107816','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104820','GCS_NAD_1983_HARN_Adj_WI_Forest',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106816','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106817','D_NAD_1983_HARN_Adj_WI_GT','NAD 1983 HARN Adj. Wisconsin Grant',NULL,'ESRI','107817','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104821','GCS_NAD_1983_HARN_Adj_WI_Grant',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106817','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106852','D_NAD_1983_HARN_Adj_WI_GR_LF','NAD 1983 HARN Adj. Wisconsin Green and Lafayette',NULL,'ESRI','107852','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104822','GCS_NAD_1983_HARN_Adj_WI_Green',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106852','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106853','D_NAD_1983_HARN_Adj_WI_GL_MQ','NAD 1983 HARN Adj. Wisconsin Green Lake and Marquette',NULL,'ESRI','107853','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104823','GCS_NAD_1983_HARN_Adj_WI_GreenLake',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106853','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106818','D_NAD_1983_HARN_Adj_WI_IA','NAD 1983 HARN Adj. Wisconsin Iowa',NULL,'ESRI','107818','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104824','GCS_NAD_1983_HARN_Adj_WI_Iowa',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106818','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106819','D_NAD_1983_HARN_Adj_WI_IR','NAD 1983 HARN Adj. Wisconsin Iron',NULL,'ESRI','107819','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104825','GCS_NAD_1983_HARN_Adj_WI_Iron',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106819','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106820','D_NAD_1983_HARN_Adj_WI_JA','NAD 1983 HARN Adj. Wisconsin Jackson',NULL,'ESRI','107820','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104826','GCS_NAD_1983_HARN_Adj_WI_Jackson',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106820','EPSG','1418',NULL,1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104827','GCS_NAD_1983_HARN_Adj_WI_Jefferson',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106854','EPSG','1418',NULL,1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104828','GCS_NAD_1983_HARN_Adj_WI_Juneau',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106851','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106857','D_NAD_1983_HARN_Adj_WI_KN_MW_OZ_RA','NAD 1983 HARN Adj. Wisconsin Kenosha, Milwaukee, Ozaukee, and Racine',NULL,'ESRI','107857','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104829','GCS_NAD_1983_HARN_Adj_WI_Kenosha',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106857','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106858','D_NAD_1983_HARN_Adj_WI_KW_MT_SG','NAD 1983 HARN Adj. Wisconsin Kewaunee, Manitowoc, and Sheboygan',NULL,'ESRI','107858','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104830','GCS_NAD_1983_HARN_Adj_WI_Kewaunee',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106858','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106821','D_NAD_1983_HARN_Adj_WI_LC','NAD 1983 HARN Adj. Wisconsin LaCrosse',NULL,'ESRI','107821','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104831','GCS_NAD_1983_HARN_Adj_WI_LaCrosse',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106821','EPSG','1418',NULL,1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104832','GCS_NAD_1983_HARN_Adj_WI_Lafayette',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106852','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106822','D_NAD_1983_HARN_Adj_WI_LG','NAD 1983 HARN Adj. Wisconsin Langlade',NULL,'ESRI','107822','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104833','GCS_NAD_1983_HARN_Adj_WI_Langlade',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106822','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106823','D_NAD_1983_HARN_Adj_WI_LN','NAD 1983 HARN Adj. Wisconsin Lincoln',NULL,'ESRI','107823','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104834','GCS_NAD_1983_HARN_Adj_WI_Lincoln',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106823','EPSG','1418',NULL,1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104835','GCS_NAD_1983_HARN_Adj_WI_Manitowoc',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106858','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106824','D_NAD_1983_HARN_Adj_WI_MA','NAD 1983 HARN Adj. Wisconsin Marathon',NULL,'ESRI','107824','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104836','GCS_NAD_1983_HARN_Adj_WI_Marathon',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106824','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106825','D_NAD_1983_HARN_Adj_WI_MN','NAD 1983 HARN Adj. Wisconsin Marinette',NULL,'ESRI','107825','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104837','GCS_NAD_1983_HARN_Adj_WI_Marinette',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106825','EPSG','1418',NULL,1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104838','GCS_NAD_1983_HARN_Adj_WI_Marquette',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106853','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106826','D_NAD_1983_HARN_Adj_WI_ME','NAD 1983 HARN Adj. Wisconsin Menominee',NULL,'ESRI','107826','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104839','GCS_NAD_1983_HARN_Adj_WI_Menominee',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106826','EPSG','1418',NULL,1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104840','GCS_NAD_1983_HARN_Adj_WI_Milwaukee',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106857','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106827','D_NAD_1983_HARN_Adj_WI_MR','NAD 1983 HARN Adj. Wisconsin Monroe',NULL,'ESRI','107827','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104841','GCS_NAD_1983_HARN_Adj_WI_Monroe',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106827','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106828','D_NAD_1983_HARN_Adj_WI_OC','NAD 1983 HARN Adj. Wisconsin Oconto',NULL,'ESRI','107828','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104842','GCS_NAD_1983_HARN_Adj_WI_Oconto',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106828','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106829','D_NAD_1983_HARN_Adj_WI_ON','NAD 1983 HARN Adj. Wisconsin Oneida',NULL,'ESRI','107829','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104843','GCS_NAD_1983_HARN_Adj_WI_Oneida',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106829','EPSG','1418',NULL,1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104844','GCS_NAD_1983_HARN_Adj_WI_Outagamie',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106856','EPSG','1418',NULL,1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104845','GCS_NAD_1983_HARN_Adj_WI_Ozaukee',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106857','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106855','D_NAD_1983_HARN_Adj_WI_PP_PC','NAD 1983 HARN Adj. Wisconsin Pepin and Pierce',NULL,'ESRI','107855','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104846','GCS_NAD_1983_HARN_Adj_WI_Pepin',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106855','EPSG','1418',NULL,1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104847','GCS_NAD_1983_HARN_Adj_WI_Pierce',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106855','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106830','D_NAD_1983_HARN_Adj_WI_PK','NAD 1983 HARN Adj. Wisconsin Polk',NULL,'ESRI','107830','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104848','GCS_NAD_1983_HARN_Adj_WI_Polk',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106830','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106831','D_NAD_1983_HARN_Adj_WI_PT','NAD 1983 HARN Adj. Wisconsin Portage',NULL,'ESRI','107831','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104849','GCS_NAD_1983_HARN_Adj_WI_Portage',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106831','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106832','D_NAD_1983_HARN_Adj_WI_PR','NAD 1983 HARN Adj. Wisconsin Price',NULL,'ESRI','107832','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104850','GCS_NAD_1983_HARN_Adj_WI_Price',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106832','EPSG','1418',NULL,1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104851','GCS_NAD_1983_HARN_Adj_WI_Racine',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106857','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106833','D_NAD_1983_HARN_Adj_WI_RC','NAD 1983 HARN Adj. Wisconsin Richland',NULL,'ESRI','107833','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104852','GCS_NAD_1983_HARN_Adj_WI_Richland',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106833','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106834','D_NAD_1983_HARN_Adj_WI_RK','NAD 1983 HARN Adj. Wisconsin Rock',NULL,'ESRI','107834','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104853','GCS_NAD_1983_HARN_Adj_WI_Rock',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106834','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106835','D_NAD_1983_HARN_Adj_WI_RS','NAD 1983 HARN Adj. Wisconsin Rusk',NULL,'ESRI','107835','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104854','GCS_NAD_1983_HARN_Adj_WI_Rusk',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106835','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106836','D_NAD_1983_HARN_Adj_WI_SC','NAD 1983 HARN Adj. Wisconsin StCroix',NULL,'ESRI','107836','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104855','GCS_NAD_1983_HARN_Adj_WI_StCroix',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106836','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106837','D_NAD_1983_HARN_Adj_WI_SK','NAD 1983 HARN Adj. Wisconsin Sauk',NULL,'ESRI','107837','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104856','GCS_NAD_1983_HARN_Adj_WI_Sauk',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106837','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106838','D_NAD_1983_HARN_Adj_WI_SW','NAD 1983 HARN Adj. Wisconsin Sawyer',NULL,'ESRI','107838','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104857','GCS_NAD_1983_HARN_Adj_WI_Sawyer',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106838','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106839','D_NAD_1983_HARN_Adj_WI_SH','NAD 1983 HARN Adj. Wisconsin Shawano',NULL,'ESRI','107839','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104858','GCS_NAD_1983_HARN_Adj_WI_Shawano',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106839','EPSG','1418',NULL,1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104859','GCS_NAD_1983_HARN_Adj_WI_Sheboygan',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106858','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106840','D_NAD_1983_HARN_Adj_WI_TA','NAD 1983 HARN Adj. Wisconsin Taylor',NULL,'ESRI','107840','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104860','GCS_NAD_1983_HARN_Adj_WI_Taylor',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106840','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106841','D_NAD_1983_HARN_Adj_WI_TR','NAD 1983 HARN Adj. Wisconsin Trempealeau',NULL,'ESRI','107841','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104861','GCS_NAD_1983_HARN_Adj_WI_Trempealeau',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106841','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106842','D_NAD_1983_HARN_Adj_WI_VR','NAD 1983 HARN Adj. Wisconsin Vernon',NULL,'ESRI','107842','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104862','GCS_NAD_1983_HARN_Adj_WI_Vernon',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106842','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106843','D_NAD_1983_HARN_Adj_WI_VI','NAD 1983 HARN Adj. Wisconsin Vilas',NULL,'ESRI','107843','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104863','GCS_NAD_1983_HARN_Adj_WI_Vilas',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106843','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106844','D_NAD_1983_HARN_Adj_WI_WW','NAD 1983 HARN Adj. Wisconsin Walworth',NULL,'ESRI','107844','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104864','GCS_NAD_1983_HARN_Adj_WI_Walworth',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106844','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106845','D_NAD_1983_HARN_Adj_WI_WB','NAD 1983 HARN Adj. Wisconsin Washburn',NULL,'ESRI','107845','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104865','GCS_NAD_1983_HARN_Adj_WI_Washburn',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106845','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106846','D_NAD_1983_HARN_Adj_WI_WA','NAD 1983 HARN Adj. Wisconsin Washington',NULL,'ESRI','107846','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104866','GCS_NAD_1983_HARN_Adj_WI_Washington',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106846','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106847','D_NAD_1983_HARN_Adj_WI_WK','NAD 1983 HARN Adj. Wisconsin Waukesha',NULL,'ESRI','107847','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104867','GCS_NAD_1983_HARN_Adj_WI_Waukesha',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106847','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106848','D_NAD_1983_HARN_Adj_WI_WP','NAD 1983 HARN Adj. Wisconsin Waupaca',NULL,'ESRI','107848','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104868','GCS_NAD_1983_HARN_Adj_WI_Waupaca',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106848','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106849','D_NAD_1983_HARN_Adj_WI_WS','NAD 1983 HARN Adj. Wisconsin Waushara',NULL,'ESRI','107849','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104869','GCS_NAD_1983_HARN_Adj_WI_Waushara',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106849','EPSG','1418',NULL,1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104870','GCS_NAD_1983_HARN_Adj_WI_Winnebago',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106856','EPSG','1418',NULL,1);
INSERT INTO "geodetic_datum" VALUES('ESRI','106850','D_NAD_1983_HARN_Adj_WI_WD','NAD 1983 HARN Adj. Wisconsin Wood',NULL,'ESRI','107850','EPSG','8901','EPSG','1418',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104871','GCS_NAD_1983_HARN_Adj_WI_Wood',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106850','EPSG','1418',NULL,1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104896','GCS_ITRF_2005',NULL,NULL,'geographic 2D','EPSG','6422','EPSG','6896','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106900','D_Mercury_2000','Mercury',NULL,'ESRI','107900','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104900','GCS_Mercury_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106900','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106901','D_Venus_1985','Venus 1985',NULL,'ESRI','107901','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104901','GCS_Venus_1985',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106901','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106902','D_Venus_2000','Venus 2000',NULL,'ESRI','107902','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104902','GCS_Venus_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106902','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106903','D_Moon_2000','The Moon',NULL,'ESRI','107903','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104903','GCS_Moon_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106903','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106904','D_Mars_1979','Mars 1979',NULL,'ESRI','107904','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104904','GCS_Mars_1979',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106904','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106905','D_Mars_2000','Mars 2000',NULL,'ESRI','107905','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104905','GCS_Mars_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106905','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106906','D_Deimos_2000','Mars - Deimos',NULL,'ESRI','107906','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104906','GCS_Deimos_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106906','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106907','D_Phobos_2000','Mars - Phobos',NULL,'ESRI','107907','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104907','GCS_Phobos_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106907','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106908','D_Jupiter_2000','Jupiter',NULL,'ESRI','107908','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104908','GCS_Jupiter_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106908','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106909','D_Adrastea_2000','Jupiter - Adrastea',NULL,'ESRI','107909','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104909','GCS_Adrastea_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106909','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106910','D_Amalthea_2000','Jupiter - Amalthea',NULL,'ESRI','107910','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104910','GCS_Amalthea_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106910','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106911','D_Ananke_2000','Jupiter - Ananke',NULL,'ESRI','107911','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104911','GCS_Ananke_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106911','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106912','D_Callisto_2000','Jupiter - Callisto',NULL,'ESRI','107912','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104912','GCS_Callisto_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106912','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106913','D_Carme_2000','Jupiter - Carme',NULL,'ESRI','107913','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104913','GCS_Carme_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106913','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106914','D_Elara_2000','Jupiter - Elara',NULL,'ESRI','107914','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104914','GCS_Elara_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106914','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106915','D_Europa_2000','Jupiter - Europa',NULL,'ESRI','107915','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104915','GCS_Europa_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106915','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106916','D_Ganymede_2000','Jupiter - Ganymede',NULL,'ESRI','107916','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104916','GCS_Ganymede_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106916','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106917','D_Himalia_2000','Jupiter - Himalia',NULL,'ESRI','107917','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104917','GCS_Himalia_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106917','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106918','D_Io_2000','Jupiter - Io',NULL,'ESRI','107918','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104918','GCS_Io_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106918','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106919','D_Leda_2000','Jupiter - Leda',NULL,'ESRI','107919','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104919','GCS_Leda_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106919','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106920','D_Lysithea_2000','Jupiter - Lysithea',NULL,'ESRI','107920','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104920','GCS_Lysithea_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106920','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106921','D_Metis_2000','Jupiter - Metis',NULL,'ESRI','107921','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104921','GCS_Metis_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106921','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106922','D_Pasiphae_2000','Jupiter - Pasiphae',NULL,'ESRI','107922','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104922','GCS_Pasiphae_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106922','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106923','D_Sinope_2000','Jupiter - Sinope',NULL,'ESRI','107923','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104923','GCS_Sinope_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106923','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106924','D_Thebe_2000','Jupiter - Thebe',NULL,'ESRI','107924','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104924','GCS_Thebe_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106924','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106925','D_Saturn_2000','Saturn',NULL,'ESRI','107925','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104925','GCS_Saturn_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106925','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106926','D_Atlas_2000','Saturn - Atlas',NULL,'ESRI','107926','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104926','GCS_Atlas_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106926','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106927','D_Calypso_2000','Saturn - Calypso',NULL,'ESRI','107927','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104927','GCS_Calypso_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106927','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106928','D_Dione_2000','Saturn - Dione',NULL,'ESRI','107928','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104928','GCS_Dione_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106928','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106929','D_Enceladus_2000','Saturn - Enceladus',NULL,'ESRI','107929','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104929','GCS_Enceladus_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106929','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106930','D_Epimetheus_2000','Saturn - Epimetheus',NULL,'ESRI','107930','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104930','GCS_Epimetheus_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106930','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106931','D_Helene_2000','Saturn - Helene',NULL,'ESRI','107931','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104931','GCS_Helene_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106931','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106932','D_Hyperion_2000','Saturn - Hyperion',NULL,'ESRI','107932','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104932','GCS_Hyperion_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106932','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106933','D_Iapetus_2000','Saturn - Iapetus',NULL,'ESRI','107933','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104933','GCS_Iapetus_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106933','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106934','D_Janus_2000','Saturn - Janus',NULL,'ESRI','107934','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104934','GCS_Janus_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106934','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106935','D_Mimas_2000','Saturn - Mimas',NULL,'ESRI','107935','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104935','GCS_Mimas_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106935','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106936','D_Pan_2000','Saturn - Pan',NULL,'ESRI','107936','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104936','GCS_Pan_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106936','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106937','D_Pandora_2000','Saturn - Pandora',NULL,'ESRI','107937','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104937','GCS_Pandora_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106937','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106938','D_Phoebe_2000','Saturn - Phoebe',NULL,'ESRI','107938','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104938','GCS_Phoebe_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106938','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106939','D_Prometheus_2000','Saturn - Prometheus',NULL,'ESRI','107939','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104939','GCS_Prometheus_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106939','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106940','D_Rhea_2000','Saturn - Rhea',NULL,'ESRI','107940','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104940','GCS_Rhea_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106940','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106941','D_Telesto_2000','Saturn - Telesto',NULL,'ESRI','107941','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104941','GCS_Telesto_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106941','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106942','D_Tethys_2000','Saturn - Tethys',NULL,'ESRI','107942','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104942','GCS_Tethys_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106942','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106943','D_Titan_2000','Saturn - Titan',NULL,'ESRI','107943','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104943','GCS_Titan_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106943','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106944','D_Uranus_2000','Uranus',NULL,'ESRI','107944','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104944','GCS_Uranus_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106944','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106945','D_Ariel_2000','Uranus - Ariel',NULL,'ESRI','107945','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104945','GCS_Ariel_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106945','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106946','D_Belinda_2000','Uranus - Belinda',NULL,'ESRI','107946','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104946','GCS_Belinda_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106946','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106947','D_Bianca_2000','Uranus - Bianca',NULL,'ESRI','107947','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104947','GCS_Bianca_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106947','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106948','D_Cordelia_2000','Uranus - Cordelia',NULL,'ESRI','107948','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104948','GCS_Cordelia_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106948','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106949','D_Cressida_2000','Uranus - Cressida',NULL,'ESRI','107949','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104949','GCS_Cressida_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106949','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106950','D_Desdemona_2000','Uranus - Desdemona',NULL,'ESRI','107950','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104950','GCS_Desdemona_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106950','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106951','D_Juliet_2000','Uranus - Juliet',NULL,'ESRI','107951','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104951','GCS_Juliet_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106951','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106952','D_Miranda_2000','Uranus - Miranda',NULL,'ESRI','107952','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104952','GCS_Miranda_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106952','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106953','D_Oberon_2000','Uranus - Oberon',NULL,'ESRI','107953','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104953','GCS_Oberon_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106953','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106954','D_Ophelia_2000','Uranus - Ophelia',NULL,'ESRI','107954','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104954','GCS_Ophelia_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106954','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106955','D_Portia_2000','Uranus - Portia',NULL,'ESRI','107955','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104955','GCS_Portia_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106955','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106956','D_Puck_2000','Uranus - Puck',NULL,'ESRI','107956','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104956','GCS_Puck_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106956','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106957','D_Rosalind_2000','Uranus - Rosalind',NULL,'ESRI','107957','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104957','GCS_Rosalind_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106957','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106958','D_Titania_2000','Uranus - Titania',NULL,'ESRI','107958','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104958','GCS_Titania_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106958','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106959','D_Umbriel_2000','Uranus - Umbriel',NULL,'ESRI','107959','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104959','GCS_Umbriel_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106959','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106960','D_Neptune_2000','Neptune',NULL,'ESRI','107960','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104960','GCS_Neptune_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106960','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106961','D_Despina_2000','Neptune - Despina',NULL,'ESRI','107961','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104961','GCS_Despina_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106961','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106962','D_Galatea_2000','Neptune - Galatea',NULL,'ESRI','107962','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104962','GCS_Galatea_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106962','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106963','D_Larissa_2000','Neptune - Larissa',NULL,'ESRI','107963','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104963','GCS_Larissa_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106963','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106964','D_Naiad_2000','Neptune - Naiad',NULL,'ESRI','107964','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104964','GCS_Naiad_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106964','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106965','D_Nereid_2000','Neptune - Nereid',NULL,'ESRI','107965','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104965','GCS_Nereid_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106965','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106966','D_Proteus_2000','Neptune - Proteus',NULL,'ESRI','107966','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104966','GCS_Proteus_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106966','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106967','D_Thalassa_2000','Neptune - Thalassa',NULL,'ESRI','107967','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104967','GCS_Thalassa_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106967','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106968','D_Triton_2000','Neptune - Triton',NULL,'ESRI','107968','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104968','GCS_Triton_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106968','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106969','D_Pluto_2000','Pluto',NULL,'ESRI','107969','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104969','GCS_Pluto_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106969','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106970','D_Charon_2000','Pluto - Charon',NULL,'ESRI','107970','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104970','GCS_Charon_2000',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106970','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106971','Mars_2000_(Sphere)','Mars 2000 (Sphere)',NULL,'ESRI','107971','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104971','Mars_2000_(Sphere)',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106971','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106972','1_Ceres_2015','1 Ceres 2015',NULL,'ESRI','107972','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104972','1_Ceres_2015',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106972','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106973','4_Vesta_2015','4 Vesta 2015',NULL,'ESRI','107973','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104973','4_Vesta_2015',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106973','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106974','Mercury_2015','Mercury 2015',NULL,'ESRI','107974','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104974','Mercury_2015',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106974','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106975','Sun_2015','Sun IAU 2015',NULL,'ESRI','107975','ESRI','108900','EPSG','1262',0);
INSERT INTO "geodetic_crs" VALUES('ESRI','104975','Sun_2015',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106975','EPSG','1262',NULL,0);
INSERT INTO "geodetic_datum" VALUES('ESRI','106990','D_Hungarian_Datum_1909','Hungarian Datum 1909',NULL,'EPSG','7004','EPSG','8901','EPSG','1119',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104990','GCS_HD1909',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106990','EPSG','1119',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104990','geodetic_crs','EPSG','3819','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106991','D_Iraqi_Geospatial_Reference_System','Iraqi Geospatial Reference System',NULL,'EPSG','7019','EPSG','8901','EPSG','1124',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104991','GCS_IGRS',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106991','EPSG','1124',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104991','geodetic_crs','EPSG','3889','ESRI');
INSERT INTO "geodetic_datum" VALUES('ESRI','106992','D_MGI_1901','MGI 1901',NULL,'EPSG','7004','EPSG','8901','EPSG','2370',1);
INSERT INTO "geodetic_crs" VALUES('ESRI','104992','GCS_MGI_1901',NULL,NULL,'geographic 2D','EPSG','6422','ESRI','106992','EPSG','2370',NULL,1);
INSERT INTO "supersession" VALUES('geodetic_crs','ESRI','104992','geodetic_crs','EPSG','3906','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2000','Anguilla_1957_British_West_Indies_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2001','Antigua_1943_British_West_Indies_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2002','Dominica_1945_British_West_Indies_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2003','Grenada_1953_British_West_Indies_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2004','Montserrat_1958_British_West_Indies_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2005','St_Kitts_1955_British_West_Indies_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2006','St_Lucia_1955_British_West_Indies_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2007','St_Vincent_1945_British_West_Indies_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2008','NAD_1927_CGQ77_MTM_2_SCoPQ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2009','NAD_1927_CGQ77_MTM_3_SCoPQ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2010','NAD_1927_CGQ77_MTM_4_SCoPQ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2011','NAD_1927_CGQ77_MTM_5_SCoPQ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2012','NAD_1927_CGQ77_MTM_6_SCoPQ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2013','NAD_1927_CGQ77_MTM_7_SCoPQ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2014','NAD_1927_CGQ77_MTM_8_SCoPQ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2015','NAD_1927_CGQ77_MTM_9_SCoPQ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2016','NAD_1927_CGQ77_MTM_10_SCoPQ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2017','NAD_1927_DEF_1976_MTM_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2018','NAD_1927_DEF_1976_MTM_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2019','NAD_1927_DEF_1976_MTM_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2020','NAD_1927_DEF_1976_MTM_11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2021','NAD_1927_DEF_1976_MTM_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2022','NAD_1927_DEF_1976_MTM_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2023','NAD_1927_DEF_1976_MTM_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2024','NAD_1927_DEF_1976_MTM_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2025','NAD_1927_DEF_1976_MTM_16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2026','NAD_1927_DEF_1976_MTM_17','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2027','NAD_1927_DEF_1976_UTM_Zone_15N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2028','NAD_1927_DEF_1976_UTM_Zone_16N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2029','NAD_1927_DEF_1976_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2030','NAD_1927_DEF_1976_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2031','NAD_1927_CGQ77_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2032','NAD_1927_CGQ77_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2033','NAD_1927_CGQ77_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2034','NAD_1927_CGQ77_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2035','NAD_1927_CGQ77_UTM_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2036','NAD_1983_CSRS_New_Brunswick_Stereographic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2037','NAD_1983_CSRS_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2038','NAD_1983_CSRS_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2039','Israel_TM_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2040','Locodjo_1965_UTM_Zone_30N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2041','Abidjan_1987_UTM_Zone_30N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2042','Locodjo_1965_UTM_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2043','Abidjan_1987_UTM_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2044','Hanoi_1972_GK_Zone_18','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2045','Hanoi_1972_GK_Zone_19','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2056','CH1903+_LV95','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2057','Rassadiran_Nakhl_e_Taqi','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2058','ED_1950_ED77_UTM_Zone_38N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2059','ED_1950_ED77_UTM_Zone_39N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2060','ED_1950_ED77_UTM_Zone_40N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2061','ED_1950_ED77_UTM_Zone_41N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2062','Madrid_1870_Madrid_Spain','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2063','Dabola_1981_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2064','Dabola_1981_UTM_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2065','S-JTSK_Ferro_Krovak','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2066','Mount_Dillon_Tobago_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2067','Naparima_1955_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2068','ELD_1979_Libya_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2069','ELD_1979_Libya_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2070','ELD_1979_Libya_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2071','ELD_1979_Libya_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2072','ELD_1979_Libya_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2073','ELD_1979_Libya_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2074','ELD_1979_Libya_11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2075','ELD_1979_Libya_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2076','ELD_1979_Libya_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2077','ELD_1979_UTM_Zone_32N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2078','ELD_1979_UTM_Zone_33N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2079','ELD_1979_UTM_Zone_34N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2080','ELD_1979_UTM_Zone_35N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2081','Chos_Malal_1914_Argentina_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2082','Pampa_del_Castillo_Argentina_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2083','Hito_XVIII_1963_Argentina_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2084','Hito_XVIII_1963_UTM_19S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2085','NAD_1927_Cuba_Norte','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2086','NAD_1927_Cuba_Sur','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2087','ELD_1979_TM_12_NE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2088','Carthage_TM_11_NE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2089','Yemen_NGN_1996_UTM_Zone_38N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2090','Yemen_NGN_1996_UTM_Zone_39N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2091','South_Yemen_GK_Zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2092','South_Yemen_GK_Zone_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2093','Hanoi_1972_GK_106_NE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2094','WGS_1972_BE_TM_106_NE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2095','Bissau_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2096','Korean_1985_Korea_East_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2097','Korean_1985_Korea_Central_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2098','Korean_1985_Korea_West_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2099','Qatar_1948_Qatar_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2100','Greek_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2101','Lake_Maracaibo_Grid_M1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2102','Lake_Maracaibo_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2103','Lake_Maracaibo_Grid_M3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2104','Lake_Maracaibo_La_Rosa_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2105','NZGD_2000_Mount_Eden_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2106','NZGD_2000_Bay_of_Plenty_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2107','NZGD_2000_Poverty_Bay_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2108','NZGD_2000_Hawkes_Bay_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2109','NZGD_2000_Taranaki_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2110','NZGD_2000_Tuhirangi_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2111','NZGD_2000_Wanganui_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2112','NZGD_2000_Wairarapa_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2113','NZGD_2000_Wellington_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2114','NZGD_2000_Collingwood_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2115','NZGD_2000_Nelson_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2116','NZGD_2000_Karamea_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2117','NZGD_2000_Buller_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2118','NZGD_2000_Grey_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2119','NZGD_2000_Amuri_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2120','NZGD_2000_Marlborough_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2121','NZGD_2000_Hokitika_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2122','NZGD_2000_Okarito_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2123','NZGD_2000_Jacksons_Bay_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2124','NZGD_2000_Mount_Pleasant_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2125','NZGD_2000_Gawler_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2126','NZGD_2000_Timaru_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2127','NZGD_2000_Lindis_Peak_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2128','NZGD_2000_Mount_Nicholas_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2129','NZGD_2000_Mount_York_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2130','NZGD_2000_Observation_Point_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2131','NZGD_2000_North_Taieri_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2132','NZGD_2000_Bluff_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2133','NZGD_2000_UTM_Zone_58S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2134','NZGD_2000_UTM_Zone_59S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2135','NZGD_2000_UTM_Zone_60S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2136','Accra_Ghana_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2137','Accra_TM_1_NW','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2138','NAD_1927_CGQ77_Quebec_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2139','NAD_1983_CSRS_MTM_2_SCoPQ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2140','NAD_1983_CSRS_MTM_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2141','NAD_1983_CSRS_MTM_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2142','NAD_1983_CSRS_MTM_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2143','NAD_1983_CSRS_MTM_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2144','NAD_1983_CSRS_MTM_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2145','NAD_1983_CSRS_MTM_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2146','NAD_1983_CSRS_MTM_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2147','NAD_1983_CSRS_MTM_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2148','NAD_1983_CSRS_UTM_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2149','NAD_1983_CSRS_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2150','NAD_1983_CSRS_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2151','NAD_1983_CSRS_UTM_Zone_13N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2152','NAD_1983_CSRS_UTM_Zone_12N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2153','NAD_1983_CSRS_UTM_Zone_11N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2154','RGF_1993_Lambert_93','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2155','Samoa_1962_Samoa_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2157','IRENET95_Irish_Transverse_Mercator','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2158','IRENET95_UTM_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2159','Sierra_Leone_1924_New_Colony_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2160','Sierra_Leone_1924_New_War_Office_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2161','Sierra_Leone_1968_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2162','Sierra_Leone_1968_UTM_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2163','US_National_Atlas_Equal_Area','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2164','Locodjo_1965_TM_5_NW','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2165','Abidjan_1987_TM_5_NW','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2166','Pulkovo_1942_Adj_1983_3_Degree_GK_Zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2167','Pulkovo_1942_Adj_1983_3_Degree_GK_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2168','Pulkovo_1942_Adj_1983_3_Degree_GK_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2169','Luxembourg_1930_Gauss','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2170','MGI_Slovenia_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2172','Pulkovo_1942_Adj_1958_Poland_Zone_II','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2173','Pulkovo_1942_Adj_1958_Poland_Zone_III','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2174','Pulkovo_1942_Adj_1958_Poland_Zone_IV','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2175','Pulkovo_1942_Adj_1958_Poland_Zone_V','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2176','ETRS_1989_Poland_CS2000_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2177','ETRS_1989_Poland_CS2000_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2178','ETRS_1989_Poland_CS2000_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2179','ETRS_1989_Poland_CS2000_Zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2180','ETRS_1989_Poland_CS92','ESRI');
INSERT INTO "conversion" VALUES('ESRI','2181','unnamed',NULL,NULL,'EPSG','1524','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',9500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','2181','ED_1950_Turkey_9',NULL,NULL,'EPSG','4400','EPSG','4230','ESRI','2181','EPSG','1524',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','2182','unnamed',NULL,NULL,'EPSG','1525','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',30.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',10500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','2182','ED_1950_Turkey_10',NULL,NULL,'EPSG','4400','EPSG','4230','ESRI','2182','EPSG','1525',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','2183','unnamed',NULL,NULL,'EPSG','1526','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',11500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','2183','ED_1950_Turkey_11',NULL,NULL,'EPSG','4400','EPSG','4230','ESRI','2183','EPSG','1526',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','2184','unnamed',NULL,NULL,'EPSG','1527','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',36.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',12500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','2184','ED_1950_Turkey_12',NULL,NULL,'EPSG','4400','EPSG','4230','ESRI','2184','EPSG','1527',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','2185','unnamed',NULL,NULL,'EPSG','1528','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',39.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',13500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','2185','ED_1950_Turkey_13',NULL,NULL,'EPSG','4400','EPSG','4230','ESRI','2185','EPSG','1528',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','2186','unnamed',NULL,NULL,'EPSG','1529','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',42.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',14500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','2186','ED_1950_Turkey_14',NULL,NULL,'EPSG','4400','EPSG','4230','ESRI','2186','EPSG','1529',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','2187','unnamed',NULL,NULL,'EPSG','1530','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',15500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','2187','ED_1950_Turkey_15',NULL,NULL,'EPSG','4400','EPSG','4230','ESRI','2187','EPSG','1530',NULL,1);
INSERT INTO alias_name VALUES('projected_crs','EPSG','2188','Azores_Occidental_1939_UTM_Zone_25N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2189','Azores_Central_1948_UTM_Zone_26N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2190','Azores_Oriental_1940_UTM_Zone_26N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2191','Madeira_1936_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2192','ED_1950_France_EuroLambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2193','NZGD_2000_New_Zealand_Transverse_Mercator','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2195','NAD_1983_HARN_UTM_Zone_2S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2196','ETRS_1989_Kp2000_Jutland','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2197','ETRS_1989_Kp2000_Zealand','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2198','ETRS_1989_Kp2000_Bornholm','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2200','ATS_1977_New_Brunswick_Stereographic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2201','REGVEN_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2202','REGVEN_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2203','REGVEN_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2204','NAD_1927_StatePlane_Tennessee_FIPS_4100','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2205','NAD_1983_StatePlane_Kentucky_North_FIPS_1601','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2206','ED_1950_3_Degree_GK_Zone_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2207','ED_1950_3_Degree_GK_Zone_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2208','ED_1950_3_Degree_GK_Zone_11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2209','ED_1950_3_Degree_GK_Zone_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2210','ED_1950_3_Degree_GK_Zone_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2211','ED_1950_3_Degree_GK_Zone_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2212','ED_1950_3_Degree_GK_Zone_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2213','ETRS_1989_TM_30_NE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2214','Douala_1948_AEF_West','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2215','Manoca_1962_UTM_Zone_32N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2216','Qornoq_1927_UTM_Zone_22N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2217','Qornoq_1927_UTM_Zone_23N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2219','ATS_1977_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2220','ATS_1977_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2222','NAD_1983_StatePlane_Arizona_East_FIPS_0201_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2223','NAD_1983_StatePlane_Arizona_Central_FIPS_0202_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2224','NAD_1983_StatePlane_Arizona_West_FIPS_0203_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2225','NAD_1983_StatePlane_California_I_FIPS_0401_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2226','NAD_1983_StatePlane_California_II_FIPS_0402_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2227','NAD_1983_StatePlane_California_III_FIPS_0403_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2228','NAD_1983_StatePlane_California_IV_FIPS_0404_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2229','NAD_1983_StatePlane_California_V_FIPS_0405_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2230','NAD_1983_StatePlane_California_VI_FIPS_0406_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2231','NAD_1983_StatePlane_Colorado_North_FIPS_0501_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2232','NAD_1983_StatePlane_Colorado_Central_FIPS_0502_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2233','NAD_1983_StatePlane_Colorado_South_FIPS_0503_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2234','NAD_1983_StatePlane_Connecticut_FIPS_0600_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2235','NAD_1983_StatePlane_Delaware_FIPS_0700_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2236','NAD_1983_StatePlane_Florida_East_FIPS_0901_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2237','NAD_1983_StatePlane_Florida_West_FIPS_0902_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2238','NAD_1983_StatePlane_Florida_North_FIPS_0903_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2239','NAD_1983_StatePlane_Georgia_East_FIPS_1001_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2240','NAD_1983_StatePlane_Georgia_West_FIPS_1002_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2241','NAD_1983_StatePlane_Idaho_East_FIPS_1101_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2242','NAD_1983_StatePlane_Idaho_Central_FIPS_1102_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2243','NAD_1983_StatePlane_Idaho_West_FIPS_1103_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2244','NAD_1983_StatePlane_Indiana_East_FIPS_1301_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2245','NAD_1983_StatePlane_Indiana_West_FIPS_1302_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2246','NAD_1983_StatePlane_Kentucky_North_FIPS_1601_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2247','NAD_1983_StatePlane_Kentucky_South_FIPS_1602_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2248','NAD_1983_StatePlane_Maryland_FIPS_1900_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2249','NAD_1983_StatePlane_Massachusetts_Mainland_FIPS_2001_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2250','NAD_1983_StatePlane_Massachusetts_Island_FIPS_2002_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2251','NAD_1983_StatePlane_Michigan_North_FIPS_2111_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2252','NAD_1983_StatePlane_Michigan_Central_FIPS_2112_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2253','NAD_1983_StatePlane_Michigan_South_FIPS_2113_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2254','NAD_1983_StatePlane_Mississippi_East_FIPS_2301_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2255','NAD_1983_StatePlane_Mississippi_West_FIPS_2302_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2256','NAD_1983_StatePlane_Montana_FIPS_2500_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2257','NAD_1983_StatePlane_New_Mexico_East_FIPS_3001_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2258','NAD_1983_StatePlane_New_Mexico_Central_FIPS_3002_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2259','NAD_1983_StatePlane_New_Mexico_West_FIPS_3003_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2260','NAD_1983_StatePlane_New_York_East_FIPS_3101_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2261','NAD_1983_StatePlane_New_York_Central_FIPS_3102_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2262','NAD_1983_StatePlane_New_York_West_FIPS_3103_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2263','NAD_1983_StatePlane_New_York_Long_Island_FIPS_3104_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2264','NAD_1983_StatePlane_North_Carolina_FIPS_3200_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2265','NAD_1983_StatePlane_North_Dakota_North_FIPS_3301_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2266','NAD_1983_StatePlane_North_Dakota_South_FIPS_3302_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2267','NAD_1983_StatePlane_Oklahoma_North_FIPS_3501_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2268','NAD_1983_StatePlane_Oklahoma_South_FIPS_3502_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2269','NAD_1983_StatePlane_Oregon_North_FIPS_3601_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2270','NAD_1983_StatePlane_Oregon_South_FIPS_3602_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2271','NAD_1983_StatePlane_Pennsylvania_North_FIPS_3701_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2272','NAD_1983_StatePlane_Pennsylvania_South_FIPS_3702_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2273','NAD_1983_StatePlane_South_Carolina_FIPS_3900_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2274','NAD_1983_StatePlane_Tennessee_FIPS_4100_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2275','NAD_1983_StatePlane_Texas_North_FIPS_4201_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2276','NAD_1983_StatePlane_Texas_North_Central_FIPS_4202_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2277','NAD_1983_StatePlane_Texas_Central_FIPS_4203_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2278','NAD_1983_StatePlane_Texas_South_Central_FIPS_4204_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2279','NAD_1983_StatePlane_Texas_South_FIPS_4205_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2280','NAD_1983_StatePlane_Utah_North_FIPS_4301_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2281','NAD_1983_StatePlane_Utah_Central_FIPS_4302_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2282','NAD_1983_StatePlane_Utah_South_FIPS_4303_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2283','NAD_1983_StatePlane_Virginia_North_FIPS_4501_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2284','NAD_1983_StatePlane_Virginia_South_FIPS_4502_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2285','NAD_1983_StatePlane_Washington_North_FIPS_4601_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2286','NAD_1983_StatePlane_Washington_South_FIPS_4602_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2287','NAD_1983_StatePlane_Wisconsin_North_FIPS_4801_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2288','NAD_1983_StatePlane_Wisconsin_Central_FIPS_4802_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2289','NAD_1983_StatePlane_Wisconsin_South_FIPS_4803_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2290','Prince_Edward_Island_Stereographic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2291','NAD_1983_CSRS_Prince_Edward_Island','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2292','NAD_1983_CSRS_Prince_Edward_Island','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2294','ATS_1977_MTM_4_Nova_Scotia','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2295','ATS_1977_MTM_5_Nova_Scotia','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2308','Batavia_TM_109_SE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2309','WGS_1984_TM_116_SE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2310','WGS_1984_TM_132_SE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2311','WGS_1984_TM_6_NE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2312','Garoua_UTM_Zone_33N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2313','Kousseri_UTM_Zone_33N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2314','Trinidad_1903_Trinidad_Grid_Feet_Clarke','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2315','Campo_Inchauspe_UTM_19S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2316','Campo_Inchauspe_UTM_20S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2317','PSAD_1956_ICN_Regional','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2318','Ain_el_Abd_Aramco_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2319','ED_1950_TM27','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2320','ED_1950_TM30','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2321','ED_1950_TM33','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2322','ED_1950_TM36','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2323','ED_1950_TM39','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2324','ED_1950_TM42','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2325','ED_1950_TM45','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2326','Hong_Kong_1980_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2327','Xian_1980_GK_Zone_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2328','Xian_1980_GK_Zone_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2329','Xian_1980_GK_Zone_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2330','Xian_1980_GK_Zone_16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2331','Xian_1980_GK_Zone_17','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2332','Xian_1980_GK_Zone_18','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2333','Xian_1980_GK_Zone_19','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2334','Xian_1980_GK_Zone_20','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2335','Xian_1980_GK_Zone_21','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2336','Xian_1980_GK_Zone_22','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2337','Xian_1980_GK_Zone_23','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2338','Xian_1980_GK_CM_75E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2339','Xian_1980_GK_CM_81E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2340','Xian_1980_GK_CM_87E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2341','Xian_1980_GK_CM_93E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2342','Xian_1980_GK_CM_99E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2343','Xian_1980_GK_CM_105E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2344','Xian_1980_GK_CM_111E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2345','Xian_1980_GK_CM_117E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2346','Xian_1980_GK_CM_123E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2347','Xian_1980_GK_CM_129E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2348','Xian_1980_GK_CM_135E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2349','Xian_1980_3_Degree_GK_Zone_25','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2350','Xian_1980_3_Degree_GK_Zone_26','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2351','Xian_1980_3_Degree_GK_Zone_27','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2352','Xian_1980_3_Degree_GK_Zone_28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2353','Xian_1980_3_Degree_GK_Zone_29','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2354','Xian_1980_3_Degree_GK_Zone_30','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2355','Xian_1980_3_Degree_GK_Zone_31','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2356','Xian_1980_3_Degree_GK_Zone_32','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2357','Xian_1980_3_Degree_GK_Zone_33','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2358','Xian_1980_3_Degree_GK_Zone_34','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2359','Xian_1980_3_Degree_GK_Zone_35','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2360','Xian_1980_3_Degree_GK_Zone_36','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2361','Xian_1980_3_Degree_GK_Zone_37','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2362','Xian_1980_3_Degree_GK_Zone_38','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2363','Xian_1980_3_Degree_GK_Zone_39','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2364','Xian_1980_3_Degree_GK_Zone_40','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2365','Xian_1980_3_Degree_GK_Zone_41','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2366','Xian_1980_3_Degree_GK_Zone_42','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2367','Xian_1980_3_Degree_GK_Zone_43','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2368','Xian_1980_3_Degree_GK_Zone_44','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2369','Xian_1980_3_Degree_GK_Zone_45','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2370','Xian_1980_3_Degree_GK_CM_75E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2371','Xian_1980_3_Degree_GK_CM_78E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2372','Xian_1980_3_Degree_GK_CM_81E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2373','Xian_1980_3_Degree_GK_CM_84E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2374','Xian_1980_3_Degree_GK_CM_87E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2375','Xian_1980_3_Degree_GK_CM_90E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2376','Xian_1980_3_Degree_GK_CM_93E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2377','Xian_1980_3_Degree_GK_CM_96E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2378','Xian_1980_3_Degree_GK_CM_99E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2379','Xian_1980_3_Degree_GK_CM_102E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2380','Xian_1980_3_Degree_GK_CM_105E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2381','Xian_1980_3_Degree_GK_CM_108E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2382','Xian_1980_3_Degree_GK_CM_111E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2383','Xian_1980_3_Degree_GK_CM_114E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2384','Xian_1980_3_Degree_GK_CM_117E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2385','Xian_1980_3_Degree_GK_CM_120E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2386','Xian_1980_3_Degree_GK_CM_123E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2387','Xian_1980_3_Degree_GK_CM_126E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2388','Xian_1980_3_Degree_GK_CM_129E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2389','Xian_1980_3_Degree_GK_CM_132E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2390','Xian_1980_3_Degree_GK_CM_135E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2391','Finland_Zone_1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2392','Finland_Zone_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2393','Finland_Zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2394','Finland_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2395','South_Yemen_GK_Zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2396','South_Yemen_GK_Zone_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2397','Pulkovo_1942_Adj_1983_3_Degree_GK_Zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2398','Pulkovo_1942_Adj_1983_3_Degree_GK_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2399','Pulkovo_1942_Adj_1983_3_Degree_GK_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2400','RT90_25_gon_W','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2401','Beijing_1954_3_Degree_GK_Zone_25','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2402','Beijing_1954_3_Degree_GK_Zone_26','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2403','Beijing_1954_3_Degree_GK_Zone_27','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2404','Beijing_1954_3_Degree_GK_Zone_28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2405','Beijing_1954_3_Degree_GK_Zone_29','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2406','Beijing_1954_3_Degree_GK_Zone_30','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2407','Beijing_1954_3_Degree_GK_Zone_31','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2408','Beijing_1954_3_Degree_GK_Zone_32','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2409','Beijing_1954_3_Degree_GK_Zone_33','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2410','Beijing_1954_3_Degree_GK_Zone_34','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2411','Beijing_1954_3_Degree_GK_Zone_35','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2412','Beijing_1954_3_Degree_GK_Zone_36','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2413','Beijing_1954_3_Degree_GK_Zone_37','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2414','Beijing_1954_3_Degree_GK_Zone_38','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2415','Beijing_1954_3_Degree_GK_Zone_39','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2416','Beijing_1954_3_Degree_GK_Zone_40','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2417','Beijing_1954_3_Degree_GK_Zone_41','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2418','Beijing_1954_3_Degree_GK_Zone_42','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2419','Beijing_1954_3_Degree_GK_Zone_43','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2420','Beijing_1954_3_Degree_GK_Zone_44','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2421','Beijing_1954_3_Degree_GK_Zone_45','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2422','Beijing_1954_3_Degree_GK_CM_75E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2423','Beijing_1954_3_Degree_GK_CM_78E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2424','Beijing_1954_3_Degree_GK_CM_81E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2425','Beijing_1954_3_Degree_GK_CM_84E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2426','Beijing_1954_3_Degree_GK_CM_87E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2427','Beijing_1954_3_Degree_GK_CM_90E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2428','Beijing_1954_3_Degree_GK_CM_93E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2429','Beijing_1954_3_Degree_GK_CM_96E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2430','Beijing_1954_3_Degree_GK_CM_99E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2431','Beijing_1954_3_Degree_GK_CM_102E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2432','Beijing_1954_3_Degree_GK_CM_105E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2433','Beijing_1954_3_Degree_GK_CM_108E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2434','Beijing_1954_3_Degree_GK_CM_111E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2435','Beijing_1954_3_Degree_GK_CM_114E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2436','Beijing_1954_3_Degree_GK_CM_117E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2437','Beijing_1954_3_Degree_GK_CM_120E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2438','Beijing_1954_3_Degree_GK_CM_123E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2439','Beijing_1954_3_Degree_GK_CM_126E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2440','Beijing_1954_3_Degree_GK_CM_129E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2441','Beijing_1954_3_Degree_GK_CM_132E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2442','Beijing_1954_3_Degree_GK_CM_135E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2443','JGD_2000_Japan_Zone_1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2444','JGD_2000_Japan_Zone_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2445','JGD_2000_Japan_Zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2446','JGD_2000_Japan_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2447','JGD_2000_Japan_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2448','JGD_2000_Japan_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2449','JGD_2000_Japan_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2450','JGD_2000_Japan_Zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2451','JGD_2000_Japan_Zone_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2452','JGD_2000_Japan_Zone_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2453','JGD_2000_Japan_Zone_11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2454','JGD_2000_Japan_Zone_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2455','JGD_2000_Japan_Zone_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2456','JGD_2000_Japan_Zone_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2457','JGD_2000_Japan_Zone_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2458','JGD_2000_Japan_Zone_16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2459','JGD_2000_Japan_Zone_17','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2460','JGD_2000_Japan_Zone_18','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2461','JGD_2000_Japan_Zone_19','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2462','Albanian_1987_GK_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2463','Pulkovo_1995_Gauss-Kruger_CM_21E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2464','Pulkovo_1995_Gauss-Kruger_CM_27E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2465','Pulkovo_1995_Gauss-Kruger_CM_33E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2466','Pulkovo_1995_Gauss-Kruger_CM_39E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2467','Pulkovo_1995_Gauss-Kruger_CM_45E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2468','Pulkovo_1995_Gauss-Kruger_CM_51E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2469','Pulkovo_1995_Gauss-Kruger_CM_57E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2470','Pulkovo_1995_Gauss-Kruger_CM_63E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2471','Pulkovo_1995_Gauss-Kruger_CM_69E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2472','Pulkovo_1995_Gauss-Kruger_CM_75E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2473','Pulkovo_1995_Gauss-Kruger_CM_81E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2474','Pulkovo_1995_Gauss-Kruger_CM_87E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2475','Pulkovo_1995_Gauss-Kruger_CM_93E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2476','Pulkovo_1995_Gauss-Kruger_CM_99E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2477','Pulkovo_1995_Gauss-Kruger_CM_105E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2478','Pulkovo_1995_Gauss-Kruger_CM_111E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2479','Pulkovo_1995_Gauss-Kruger_CM_117E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2480','Pulkovo_1995_Gauss-Kruger_CM_123E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2481','Pulkovo_1995_Gauss-Kruger_CM_129E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2482','Pulkovo_1995_Gauss-Kruger_CM_135E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2483','Pulkovo_1995_Gauss-Kruger_CM_141E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2484','Pulkovo_1995_Gauss-Kruger_CM_147E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2485','Pulkovo_1995_Gauss-Kruger_CM_153E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2486','Pulkovo_1995_Gauss-Kruger_CM_159E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2487','Pulkovo_1995_Gauss-Kruger_CM_165E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2488','Pulkovo_1995_Gauss-Kruger_CM_171E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2489','Pulkovo_1995_Gauss-Kruger_CM_177E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2490','Pulkovo_1995_Gauss-Kruger_CM_177W','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2491','Pulkovo_1995_Gauss-Kruger_CM_171W','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2494','Pulkovo_1942_Gauss-Kruger_CM_21E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2495','Pulkovo_1942_Gauss-Kruger_CM_27E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2496','Pulkovo_1942_Gauss-Kruger_CM_33E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2497','Pulkovo_1942_Gauss-Kruger_CM_39E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2498','Pulkovo_1942_Gauss-Kruger_CM_45E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2499','Pulkovo_1942_Gauss-Kruger_CM_51E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2500','Pulkovo_1942_Gauss-Kruger_CM_57E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2501','Pulkovo_1942_Gauss-Kruger_CM_63E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2502','Pulkovo_1942_Gauss-Kruger_CM_69E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2503','Pulkovo_1942_Gauss-Kruger_CM_75E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2504','Pulkovo_1942_Gauss-Kruger_CM_81E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2505','Pulkovo_1942_Gauss-Kruger_CM_87E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2506','Pulkovo_1942_Gauss-Kruger_CM_93E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2507','Pulkovo_1942_Gauss-Kruger_CM_99E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2508','Pulkovo_1942_Gauss-Kruger_CM_105E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2509','Pulkovo_1942_Gauss-Kruger_CM_111E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2510','Pulkovo_1942_Gauss-Kruger_CM_117E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2511','Pulkovo_1942_Gauss-Kruger_CM_123E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2512','Pulkovo_1942_Gauss-Kruger_CM_129E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2513','Pulkovo_1942_Gauss-Kruger_CM_135E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2514','Pulkovo_1942_Gauss-Kruger_CM_141E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2515','Pulkovo_1942_Gauss-Kruger_CM_147E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2516','Pulkovo_1942_Gauss-Kruger_CM_153E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2517','Pulkovo_1942_Gauss-Kruger_CM_159E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2518','Pulkovo_1942_Gauss-Kruger_CM_165E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2519','Pulkovo_1942_Gauss-Kruger_CM_171E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2520','Pulkovo_1942_Gauss-Kruger_CM_177E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2521','Pulkovo_1942_Gauss-Kruger_CM_177W','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2522','Pulkovo_1942_Gauss-Kruger_CM_171W','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2523','Pulkovo_1942_3_Degree_GK_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2524','Pulkovo_1942_3_Degree_GK_Zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2525','Pulkovo_1942_3_Degree_GK_Zone_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2526','Pulkovo_1942_3_Degree_GK_Zone_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2527','Pulkovo_1942_3_Degree_GK_Zone_11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2528','Pulkovo_1942_3_Degree_GK_Zone_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2529','Pulkovo_1942_3_Degree_GK_Zone_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2530','Pulkovo_1942_3_Degree_GK_Zone_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2531','Pulkovo_1942_3_Degree_GK_Zone_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2532','Pulkovo_1942_3_Degree_GK_Zone_16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2533','Pulkovo_1942_3_Degree_GK_Zone_17','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2534','Pulkovo_1942_3_Degree_GK_Zone_18','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2535','Pulkovo_1942_3_Degree_GK_Zone_19','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2536','Pulkovo_1942_3_Degree_GK_Zone_20','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2537','Pulkovo_1942_3_Degree_GK_Zone_21','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2538','Pulkovo_1942_3_Degree_GK_Zone_22','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2539','Pulkovo_1942_3_Degree_GK_Zone_23','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2540','Pulkovo_1942_3_Degree_GK_Zone_24','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2541','Pulkovo_1942_3_Degree_GK_Zone_25','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2542','Pulkovo_1942_3_Degree_GK_Zone_26','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2543','Pulkovo_1942_3_Degree_GK_Zone_27','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2544','Pulkovo_1942_3_Degree_GK_Zone_28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2545','Pulkovo_1942_3_Degree_GK_Zone_29','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2546','Pulkovo_1942_3_Degree_GK_Zone_30','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2547','Pulkovo_1942_3_Degree_GK_Zone_31','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2548','Pulkovo_1942_3_Degree_GK_Zone_32','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2549','Pulkovo_1942_3_Degree_GK_Zone_33','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2550','Samboja_UTM_Zone_50S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2551','Pulkovo_1942_3_Degree_GK_Zone_34','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2552','Pulkovo_1942_3_Degree_GK_Zone_35','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2553','Pulkovo_1942_3_Degree_GK_Zone_36','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2554','Pulkovo_1942_3_Degree_GK_Zone_37','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2555','Pulkovo_1942_3_Degree_GK_Zone_38','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2556','Pulkovo_1942_3_Degree_GK_Zone_39','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2557','Pulkovo_1942_3_Degree_GK_Zone_40','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2558','Pulkovo_1942_3_Degree_GK_Zone_41','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2559','Pulkovo_1942_3_Degree_GK_Zone_42','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2560','Pulkovo_1942_3_Degree_GK_Zone_43','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2561','Pulkovo_1942_3_Degree_GK_Zone_44','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2562','Pulkovo_1942_3_Degree_GK_Zone_45','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2563','Pulkovo_1942_3_Degree_GK_Zone_46','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2564','Pulkovo_1942_3_Degree_GK_Zone_47','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2565','Pulkovo_1942_3_Degree_GK_Zone_48','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2566','Pulkovo_1942_3_Degree_GK_Zone_49','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2567','Pulkovo_1942_3_Degree_GK_Zone_50','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2568','Pulkovo_1942_3_Degree_GK_Zone_51','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2569','Pulkovo_1942_3_Degree_GK_Zone_52','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2570','Pulkovo_1942_3_Degree_GK_Zone_53','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2571','Pulkovo_1942_3_Degree_GK_Zone_54','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2572','Pulkovo_1942_3_Degree_GK_Zone_55','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2573','Pulkovo_1942_3_Degree_GK_Zone_56','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2574','Pulkovo_1942_3_Degree_GK_Zone_57','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2575','Pulkovo_1942_3_Degree_GK_Zone_58','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2576','Pulkovo_1942_3_Degree_GK_Zone_59','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2577','Pulkovo_1942_3_Degree_GK_Zone_60','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2578','Pulkovo_1942_3_Degree_GK_Zone_61','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2579','Pulkovo_1942_3_Degree_GK_Zone_62','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2580','Pulkovo_1942_3_Degree_GK_Zone_63','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2581','Pulkovo_1942_3_Degree_GK_Zone_64','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2582','Pulkovo_1942_3_Degree_GK_CM_21E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2583','Pulkovo_1942_3_Degree_GK_CM_24E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2584','Pulkovo_1942_3_Degree_GK_CM_27E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2585','Pulkovo_1942_3_Degree_GK_CM_30E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2586','Pulkovo_1942_3_Degree_GK_CM_33E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2587','Pulkovo_1942_3_Degree_GK_CM_36E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2588','Pulkovo_1942_3_Degree_GK_CM_39E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2589','Pulkovo_1942_3_Degree_GK_CM_42E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2590','Pulkovo_1942_3_Degree_GK_CM_45E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2591','Pulkovo_1942_3_Degree_GK_CM_48E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2592','Pulkovo_1942_3_Degree_GK_CM_51E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2593','Pulkovo_1942_3_Degree_GK_CM_54E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2594','Pulkovo_1942_3_Degree_GK_CM_57E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2595','Pulkovo_1942_3_Degree_GK_CM_60E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2596','Pulkovo_1942_3_Degree_GK_CM_63E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2597','Pulkovo_1942_3_Degree_GK_CM_66E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2598','Pulkovo_1942_3_Degree_GK_CM_69E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2599','Pulkovo_1942_3_Degree_GK_CM_72E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2600','LKS_1994_Lithuania_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2601','Pulkovo_1942_3_Degree_GK_CM_75E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2602','Pulkovo_1942_3_Degree_GK_CM_78E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2603','Pulkovo_1942_3_Degree_GK_CM_81E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2604','Pulkovo_1942_3_Degree_GK_CM_84E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2605','Pulkovo_1942_3_Degree_GK_CM_87E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2606','Pulkovo_1942_3_Degree_GK_CM_90E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2607','Pulkovo_1942_3_Degree_GK_CM_93E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2608','Pulkovo_1942_3_Degree_GK_CM_96E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2609','Pulkovo_1942_3_Degree_GK_CM_99E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2610','Pulkovo_1942_3_Degree_GK_CM_102E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2611','Pulkovo_1942_3_Degree_GK_CM_105E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2612','Pulkovo_1942_3_Degree_GK_CM_108E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2613','Pulkovo_1942_3_Degree_GK_CM_111E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2614','Pulkovo_1942_3_Degree_GK_CM_114E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2615','Pulkovo_1942_3_Degree_GK_CM_117E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2616','Pulkovo_1942_3_Degree_GK_CM_120E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2617','Pulkovo_1942_3_Degree_GK_CM_123E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2618','Pulkovo_1942_3_Degree_GK_CM_126E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2619','Pulkovo_1942_3_Degree_GK_CM_129E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2620','Pulkovo_1942_3_Degree_GK_CM_132E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2621','Pulkovo_1942_3_Degree_GK_CM_135E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2622','Pulkovo_1942_3_Degree_GK_CM_138E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2623','Pulkovo_1942_3_Degree_GK_CM_141E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2624','Pulkovo_1942_3_Degree_GK_CM_144E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2625','Pulkovo_1942_3_Degree_GK_CM_147E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2626','Pulkovo_1942_3_Degree_GK_CM_150E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2627','Pulkovo_1942_3_Degree_GK_CM_153E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2628','Pulkovo_1942_3_Degree_GK_CM_156E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2629','Pulkovo_1942_3_Degree_GK_CM_159E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2630','Pulkovo_1942_3_Degree_GK_CM_162E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2631','Pulkovo_1942_3_Degree_GK_CM_165E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2632','Pulkovo_1942_3_Degree_GK_CM_168E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2633','Pulkovo_1942_3_Degree_GK_CM_171E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2634','Pulkovo_1942_3_Degree_GK_CM_174E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2635','Pulkovo_1942_3_Degree_GK_CM_177E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2636','Pulkovo_1942_3_Degree_GK_CM_180E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2637','Pulkovo_1942_3_Degree_GK_CM_177W','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2638','Pulkovo_1942_3_Degree_GK_CM_174W','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2639','Pulkovo_1942_3_Degree_GK_CM_171W','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2640','Pulkovo_1942_3_Degree_GK_CM_168W','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2641','Pulkovo_1995_3_Degree_GK_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2642','Pulkovo_1995_3_Degree_GK_Zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2643','Pulkovo_1995_3_Degree_GK_Zone_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2644','Pulkovo_1995_3_Degree_GK_Zone_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2645','Pulkovo_1995_3_Degree_GK_Zone_11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2646','Pulkovo_1995_3_Degree_GK_Zone_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2647','Pulkovo_1995_3_Degree_GK_Zone_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2648','Pulkovo_1995_3_Degree_GK_Zone_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2649','Pulkovo_1995_3_Degree_GK_Zone_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2650','Pulkovo_1995_3_Degree_GK_Zone_16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2651','Pulkovo_1995_3_Degree_GK_Zone_17','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2652','Pulkovo_1995_3_Degree_GK_Zone_18','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2653','Pulkovo_1995_3_Degree_GK_Zone_19','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2654','Pulkovo_1995_3_Degree_GK_Zone_20','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2655','Pulkovo_1995_3_Degree_GK_Zone_21','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2656','Pulkovo_1995_3_Degree_GK_Zone_22','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2657','Pulkovo_1995_3_Degree_GK_Zone_23','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2658','Pulkovo_1995_3_Degree_GK_Zone_24','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2659','Pulkovo_1995_3_Degree_GK_Zone_25','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2660','Pulkovo_1995_3_Degree_GK_Zone_26','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2661','Pulkovo_1995_3_Degree_GK_Zone_27','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2662','Pulkovo_1995_3_Degree_GK_Zone_28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2663','Pulkovo_1995_3_Degree_GK_Zone_29','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2664','Pulkovo_1995_3_Degree_GK_Zone_30','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2665','Pulkovo_1995_3_Degree_GK_Zone_31','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2666','Pulkovo_1995_3_Degree_GK_Zone_32','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2667','Pulkovo_1995_3_Degree_GK_Zone_33','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2668','Pulkovo_1995_3_Degree_GK_Zone_34','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2669','Pulkovo_1995_3_Degree_GK_Zone_35','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2670','Pulkovo_1995_3_Degree_GK_Zone_36','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2671','Pulkovo_1995_3_Degree_GK_Zone_37','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2672','Pulkovo_1995_3_Degree_GK_Zone_38','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2673','Pulkovo_1995_3_Degree_GK_Zone_39','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2674','Pulkovo_1995_3_Degree_GK_Zone_40','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2675','Pulkovo_1995_3_Degree_GK_Zone_41','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2676','Pulkovo_1995_3_Degree_GK_Zone_42','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2677','Pulkovo_1995_3_Degree_GK_Zone_43','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2678','Pulkovo_1995_3_Degree_GK_Zone_44','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2679','Pulkovo_1995_3_Degree_GK_Zone_45','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2680','Pulkovo_1995_3_Degree_GK_Zone_46','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2681','Pulkovo_1995_3_Degree_GK_Zone_47','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2682','Pulkovo_1995_3_Degree_GK_Zone_48','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2683','Pulkovo_1995_3_Degree_GK_Zone_49','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2684','Pulkovo_1995_3_Degree_GK_Zone_50','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2685','Pulkovo_1995_3_Degree_GK_Zone_51','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2686','Pulkovo_1995_3_Degree_GK_Zone_52','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2687','Pulkovo_1995_3_Degree_GK_Zone_53','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2688','Pulkovo_1995_3_Degree_GK_Zone_54','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2689','Pulkovo_1995_3_Degree_GK_Zone_55','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2690','Pulkovo_1995_3_Degree_GK_Zone_56','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2691','Pulkovo_1995_3_Degree_GK_Zone_57','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2692','Pulkovo_1995_3_Degree_GK_Zone_58','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2693','Pulkovo_1995_3_Degree_GK_Zone_59','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2694','Pulkovo_1995_3_Degree_GK_Zone_60','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2695','Pulkovo_1995_3_Degree_GK_Zone_61','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2696','Pulkovo_1995_3_Degree_GK_Zone_62','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2697','Pulkovo_1995_3_Degree_GK_Zone_63','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2698','Pulkovo_1995_3_Degree_GK_Zone_64','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2699','Pulkovo_1995_3_Degree_GK_CM_21E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2700','Pulkovo_1995_3_Degree_GK_CM_24E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2701','Pulkovo_1995_3_Degree_GK_CM_27E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2702','Pulkovo_1995_3_Degree_GK_CM_30E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2703','Pulkovo_1995_3_Degree_GK_CM_33E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2704','Pulkovo_1995_3_Degree_GK_CM_36E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2705','Pulkovo_1995_3_Degree_GK_CM_39E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2706','Pulkovo_1995_3_Degree_GK_CM_42E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2707','Pulkovo_1995_3_Degree_GK_CM_45E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2708','Pulkovo_1995_3_Degree_GK_CM_48E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2709','Pulkovo_1995_3_Degree_GK_CM_51E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2710','Pulkovo_1995_3_Degree_GK_CM_54E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2711','Pulkovo_1995_3_Degree_GK_CM_57E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2712','Pulkovo_1995_3_Degree_GK_CM_60E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2713','Pulkovo_1995_3_Degree_GK_CM_63E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2714','Pulkovo_1995_3_Degree_GK_CM_66E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2715','Pulkovo_1995_3_Degree_GK_CM_69E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2716','Pulkovo_1995_3_Degree_GK_CM_72E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2717','Pulkovo_1995_3_Degree_GK_CM_75E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2718','Pulkovo_1995_3_Degree_GK_CM_78E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2719','Pulkovo_1995_3_Degree_GK_CM_81E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2720','Pulkovo_1995_3_Degree_GK_CM_84E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2721','Pulkovo_1995_3_Degree_GK_CM_87E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2722','Pulkovo_1995_3_Degree_GK_CM_90E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2723','Pulkovo_1995_3_Degree_GK_CM_93E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2724','Pulkovo_1995_3_Degree_GK_CM_96E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2725','Pulkovo_1995_3_Degree_GK_CM_99E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2726','Pulkovo_1995_3_Degree_GK_CM_102E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2727','Pulkovo_1995_3_Degree_GK_CM_105E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2728','Pulkovo_1995_3_Degree_GK_CM_108E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2729','Pulkovo_1995_3_Degree_GK_CM_111E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2730','Pulkovo_1995_3_Degree_GK_CM_114E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2731','Pulkovo_1995_3_Degree_GK_CM_117E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2732','Pulkovo_1995_3_Degree_GK_CM_120E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2733','Pulkovo_1995_3_Degree_GK_CM_123E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2734','Pulkovo_1995_3_Degree_GK_CM_126E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2735','Pulkovo_1995_3_Degree_GK_CM_129E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2736','Tete_UTM_Zone_36S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2737','Tete_UTM_Zone_37S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2738','Pulkovo_1995_3_Degree_GK_CM_132E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2739','Pulkovo_1995_3_Degree_GK_CM_135E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2740','Pulkovo_1995_3_Degree_GK_CM_138E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2741','Pulkovo_1995_3_Degree_GK_CM_141E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2742','Pulkovo_1995_3_Degree_GK_CM_144E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2743','Pulkovo_1995_3_Degree_GK_CM_147E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2744','Pulkovo_1995_3_Degree_GK_CM_150E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2745','Pulkovo_1995_3_Degree_GK_CM_153E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2746','Pulkovo_1995_3_Degree_GK_CM_156E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2747','Pulkovo_1995_3_Degree_GK_CM_159E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2748','Pulkovo_1995_3_Degree_GK_CM_162E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2749','Pulkovo_1995_3_Degree_GK_CM_165E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2750','Pulkovo_1995_3_Degree_GK_CM_168E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2751','Pulkovo_1995_3_Degree_GK_CM_171E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2752','Pulkovo_1995_3_Degree_GK_CM_174E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2753','Pulkovo_1995_3_Degree_GK_CM_177E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2754','Pulkovo_1995_3_Degree_GK_CM_180E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2755','Pulkovo_1995_3_Degree_GK_CM_177W','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2756','Pulkovo_1995_3_Degree_GK_CM_174W','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2757','Pulkovo_1995_3_Degree_GK_CM_171W','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2758','Pulkovo_1995_3_Degree_GK_CM_168W','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2759','NAD_1983_HARN_StatePlane_Alabama_East_FIPS_0101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2760','NAD_1983_HARN_StatePlane_Alabama_West_FIPS_0102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2761','NAD_1983_HARN_StatePlane_Arizona_East_FIPS_0201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2762','NAD_1983_HARN_StatePlane_Arizona_Central_FIPS_0202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2763','NAD_1983_HARN_StatePlane_Arizona_West_FIPS_0203','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2764','NAD_1983_HARN_StatePlane_Arkansas_North_FIPS_0301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2765','NAD_1983_HARN_StatePlane_Arkansas_South_FIPS_0302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2766','NAD_1983_HARN_StatePlane_California_I_FIPS_0401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2767','NAD_1983_HARN_StatePlane_California_II_FIPS_0402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2768','NAD_1983_HARN_StatePlane_California_III_FIPS_0403','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2769','NAD_1983_HARN_StatePlane_California_IV_FIPS_0404','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2770','NAD_1983_HARN_StatePlane_California_V_FIPS_0405','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2771','NAD_1983_HARN_StatePlane_California_VI_FIPS_0406','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2772','NAD_1983_HARN_StatePlane_Colorado_North_FIPS_0501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2773','NAD_1983_HARN_StatePlane_Colorado_Central_FIPS_0502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2774','NAD_1983_HARN_StatePlane_Colorado_South_FIPS_0503','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2775','NAD_1983_HARN_StatePlane_Connecticut_FIPS_0600','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2776','NAD_1983_HARN_StatePlane_Delaware_FIPS_0700','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2777','NAD_1983_HARN_StatePlane_Florida_East_FIPS_0901','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2778','NAD_1983_HARN_StatePlane_Florida_West_FIPS_0902','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2779','NAD_1983_HARN_StatePlane_Florida_North_FIPS_0903','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2780','NAD_1983_HARN_StatePlane_Georgia_East_FIPS_1001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2781','NAD_1983_HARN_StatePlane_Georgia_West_FIPS_1002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2782','NAD_1983_HARN_StatePlane_Hawaii_1_FIPS_5101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2783','NAD_1983_HARN_StatePlane_Hawaii_2_FIPS_5102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2784','NAD_1983_HARN_StatePlane_Hawaii_3_FIPS_5103','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2785','NAD_1983_HARN_StatePlane_Hawaii_4_FIPS_5104','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2786','NAD_1983_HARN_StatePlane_Hawaii_5_FIPS_5105','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2787','NAD_1983_HARN_StatePlane_Idaho_East_FIPS_1101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2788','NAD_1983_HARN_StatePlane_Idaho_Central_FIPS_1102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2789','NAD_1983_HARN_StatePlane_Idaho_West_FIPS_1103','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2790','NAD_1983_HARN_StatePlane_Illinois_East_FIPS_1201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2791','NAD_1983_HARN_StatePlane_Illinois_West_FIPS_1202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2792','NAD_1983_HARN_StatePlane_Indiana_East_FIPS_1301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2793','NAD_1983_HARN_StatePlane_Indiana_West_FIPS_1302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2794','NAD_1983_HARN_StatePlane_Iowa_North_FIPS_1401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2795','NAD_1983_HARN_StatePlane_Iowa_South_FIPS_1402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2796','NAD_1983_HARN_StatePlane_Kansas_North_FIPS_1501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2797','NAD_1983_HARN_StatePlane_Kansas_South_FIPS_1502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2798','NAD_1983_HARN_StatePlane_Kentucky_North_FIPS_1601','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2799','NAD_1983_HARN_StatePlane_Kentucky_South_FIPS_1602','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2800','NAD_1983_HARN_StatePlane_Louisiana_North_FIPS_1701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2801','NAD_1983_HARN_StatePlane_Louisiana_South_FIPS_1702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2802','NAD_1983_HARN_StatePlane_Maine_East_FIPS_1801','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2803','NAD_1983_HARN_StatePlane_Maine_West_FIPS_1802','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2804','NAD_1983_HARN_StatePlane_Maryland_FIPS_1900','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2805','NAD_1983_HARN_StatePlane_Massachusetts_Mainland_FIPS_2001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2806','NAD_1983_HARN_StatePlane_Massachusetts_Island_FIPS_2002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2807','NAD_1983_HARN_StatePlane_Michigan_North_FIPS_2111','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2808','NAD_1983_HARN_StatePlane_Michigan_Central_FIPS_2112','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2809','NAD_1983_HARN_StatePlane_Michigan_South_FIPS_2113','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2810','NAD_1983_HARN_StatePlane_Minnesota_North_FIPS_2201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2811','NAD_1983_HARN_StatePlane_Minnesota_Central_FIPS_2202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2812','NAD_1983_HARN_StatePlane_Minnesota_South_FIPS_2203','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2813','NAD_1983_HARN_StatePlane_Mississippi_East_FIPS_2301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2814','NAD_1983_HARN_StatePlane_Mississippi_West_FIPS_2302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2815','NAD_1983_HARN_StatePlane_Missouri_East_FIPS_2401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2816','NAD_1983_HARN_StatePlane_Missouri_Central_FIPS_2402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2817','NAD_1983_HARN_StatePlane_Missouri_West_FIPS_2403','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2818','NAD_1983_HARN_StatePlane_Montana_FIPS_2500','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2819','NAD_1983_HARN_StatePlane_Nebraska_FIPS_2600','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2820','NAD_1983_HARN_StatePlane_Nevada_East_FIPS_2701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2821','NAD_1983_HARN_StatePlane_Nevada_Central_FIPS_2702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2822','NAD_1983_HARN_StatePlane_Nevada_West_FIPS_2703','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2823','NAD_1983_HARN_StatePlane_New_Hampshire_FIPS_2800','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2824','NAD_1983_HARN_StatePlane_New_Jersey_FIPS_2900','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2825','NAD_1983_HARN_StatePlane_New_Mexico_East_FIPS_3001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2826','NAD_1983_HARN_StatePlane_New_Mexico_Central_FIPS_3002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2827','NAD_1983_HARN_StatePlane_New_Mexico_West_FIPS_3003','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2828','NAD_1983_HARN_StatePlane_New_York_East_FIPS_3101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2829','NAD_1983_HARN_StatePlane_New_York_Central_FIPS_3102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2830','NAD_1983_HARN_StatePlane_New_York_West_FIPS_3103','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2831','NAD_1983_HARN_StatePlane_New_York_Long_Island_FIPS_3104','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2832','NAD_1983_HARN_StatePlane_North_Dakota_North_FIPS_3301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2833','NAD_1983_HARN_StatePlane_North_Dakota_South_FIPS_3302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2834','NAD_1983_HARN_StatePlane_Ohio_North_FIPS_3401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2835','NAD_1983_HARN_StatePlane_Ohio_South_FIPS_3402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2836','NAD_1983_HARN_StatePlane_Oklahoma_North_FIPS_3501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2837','NAD_1983_HARN_StatePlane_Oklahoma_South_FIPS_3502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2838','NAD_1983_HARN_StatePlane_Oregon_North_FIPS_3601','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2839','NAD_1983_HARN_StatePlane_Oregon_South_FIPS_3602','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2840','NAD_1983_HARN_StatePlane_Rhode_Island_FIPS_3800','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2841','NAD_1983_HARN_StatePlane_South_Dakota_North_FIPS_4001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2842','NAD_1983_HARN_StatePlane_South_Dakota_South_FIPS_4002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2843','NAD_1983_HARN_StatePlane_Tennessee_FIPS_4100','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2844','NAD_1983_HARN_StatePlane_Texas_North_FIPS_4201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2845','NAD_1983_HARN_StatePlane_Texas_North_Central_FIPS_4202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2846','NAD_1983_HARN_StatePlane_Texas_Central_FIPS_4203','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2847','NAD_1983_HARN_StatePlane_Texas_South_Central_FIPS_4204','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2848','NAD_1983_HARN_StatePlane_Texas_South_FIPS_4205','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2849','NAD_1983_HARN_StatePlane_Utah_North_FIPS_4301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2850','NAD_1983_HARN_StatePlane_Utah_Central_FIPS_4302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2851','NAD_1983_HARN_StatePlane_Utah_South_FIPS_4303','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2852','NAD_1983_HARN_StatePlane_Vermont_FIPS_4400','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2853','NAD_1983_HARN_StatePlane_Virginia_North_FIPS_4501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2854','NAD_1983_HARN_StatePlane_Virginia_South_FIPS_4502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2855','NAD_1983_HARN_StatePlane_Washington_North_FIPS_4601','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2856','NAD_1983_HARN_StatePlane_Washington_South_FIPS_4602','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2857','NAD_1983_HARN_StatePlane_West_Virginia_North_FIPS_4701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2858','NAD_1983_HARN_StatePlane_West_Virginia_South_FIPS_4702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2859','NAD_1983_HARN_StatePlane_Wisconsin_North_FIPS_4801','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2860','NAD_1983_HARN_StatePlane_Wisconsin_Central_FIPS_4802','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2861','NAD_1983_HARN_StatePlane_Wisconsin_South_FIPS_4803','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2862','NAD_1983_HARN_StatePlane_Wyoming_East_FIPS_4901','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2863','NAD_1983_HARN_StatePlane_Wyoming_East_Central_FIPS_4902','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2864','NAD_1983_HARN_StatePlane_Wyoming_West_Central_FIPS_4903','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2865','NAD_1983_HARN_StatePlane_Wyoming_West_FIPS_4904','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2866','NAD_1983_HARN_StatePlane_Puerto_Rico_Virgin_Islands_FIPS_5200','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2867','NAD_1983_HARN_StatePlane_Arizona_East_FIPS_0201_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2868','NAD_1983_HARN_StatePlane_Arizona_Central_FIPS_0202_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2869','NAD_1983_HARN_StatePlane_Arizona_West_FIPS_0203_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2870','NAD_1983_HARN_StatePlane_California_I_FIPS_0401_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2871','NAD_1983_HARN_StatePlane_California_II_FIPS_0402_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2872','NAD_1983_HARN_StatePlane_California_III_FIPS_0403_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2873','NAD_1983_HARN_StatePlane_California_IV_FIPS_0404_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2874','NAD_1983_HARN_StatePlane_California_V_FIPS_0405_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2875','NAD_1983_HARN_StatePlane_California_VI_FIPS_0406_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2876','NAD_1983_HARN_StatePlane_Colorado_North_FIPS_0501_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2877','NAD_1983_HARN_StatePlane_Colorado_Central_FIPS_0502_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2878','NAD_1983_HARN_StatePlane_Colorado_South_FIPS_0503_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2879','NAD_1983_HARN_StatePlane_Connecticut_FIPS_0600_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2880','NAD_1983_HARN_StatePlane_Delaware_FIPS_0700_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2881','NAD_1983_HARN_StatePlane_Florida_East_FIPS_0901_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2882','NAD_1983_HARN_StatePlane_Florida_West_FIPS_0902_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2883','NAD_1983_HARN_StatePlane_Florida_North_FIPS_0903_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2884','NAD_1983_HARN_StatePlane_Georgia_East_FIPS_1001_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2885','NAD_1983_HARN_StatePlane_Georgia_West_FIPS_1002_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2886','NAD_1983_HARN_StatePlane_Idaho_East_FIPS_1101_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2887','NAD_1983_HARN_StatePlane_Idaho_Central_FIPS_1102_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2888','NAD_1983_HARN_StatePlane_Idaho_West_FIPS_1103_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2891','NAD_1983_HARN_StatePlane_Kentucky_North_FIPS_1601_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2892','NAD_1983_HARN_StatePlane_Kentucky_South_FIPS_1602_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2893','NAD_1983_HARN_StatePlane_Maryland_FIPS_1900_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2894','NAD_1983_HARN_StatePlane_Massachusetts_Mainland_FIPS_2001_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2895','NAD_1983_HARN_StatePlane_Massachusetts_Island_FIPS_2002_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2896','NAD_1983_HARN_StatePlane_Michigan_North_FIPS_2111_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2897','NAD_1983_HARN_StatePlane_Michigan_Central_FIPS_2112_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2898','NAD_1983_HARN_StatePlane_Michigan_South_FIPS_2113_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2899','NAD_1983_HARN_StatePlane_Mississippi_East_FIPS_2301_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2900','NAD_1983_HARN_StatePlane_Mississippi_West_FIPS_2302_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2901','NAD_1983_HARN_StatePlane_Montana_FIPS_2500_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2902','NAD_1983_HARN_StatePlane_New_Mexico_East_FIPS_3001_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2903','NAD_1983_HARN_StatePlane_New_Mexico_Central_FIPS_3002_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2904','NAD_1983_HARN_StatePlane_New_Mexico_West_FIPS_3003_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2905','NAD_1983_HARN_StatePlane_New_York_East_FIPS_3101_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2906','NAD_1983_HARN_StatePlane_New_York_Central_FIPS_3102_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2907','NAD_1983_HARN_StatePlane_New_York_West_FIPS_3103_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2908','NAD_1983_HARN_StatePlane_New_York_Long_Island_FIPS_3104_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2909','NAD_1983_HARN_StatePlane_North_Dakota_North_FIPS_3301_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2910','NAD_1983_HARN_StatePlane_North_Dakota_South_FIPS_3302_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2911','NAD_1983_HARN_StatePlane_Oklahoma_North_FIPS_3501_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2912','NAD_1983_HARN_StatePlane_Oklahoma_South_FIPS_3502_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2913','NAD_1983_HARN_StatePlane_Oregon_North_FIPS_3601_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2914','NAD_1983_HARN_StatePlane_Oregon_South_FIPS_3602_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2915','NAD_1983_HARN_StatePlane_Tennessee_FIPS_4100_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2916','NAD_1983_HARN_StatePlane_Texas_North_FIPS_4201_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2917','NAD_1983_HARN_StatePlane_Texas_North_Central_FIPS_4202_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2918','NAD_1983_HARN_StatePlane_Texas_Central_FIPS_4203_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2919','NAD_1983_HARN_StatePlane_Texas_South_Central_FIPS_4204_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2920','NAD_1983_HARN_StatePlane_Texas_South_FIPS_4205_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2921','NAD_1983_HARN_StatePlane_Utah_North_FIPS_4301_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2922','NAD_1983_HARN_StatePlane_Utah_Central_FIPS_4302_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2923','NAD_1983_HARN_StatePlane_Utah_South_FIPS_4303_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2924','NAD_1983_HARN_StatePlane_Virginia_North_FIPS_4501_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2925','NAD_1983_HARN_StatePlane_Virginia_South_FIPS_4502_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2926','NAD_1983_HARN_StatePlane_Washington_North_FIPS_4601_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2927','NAD_1983_HARN_StatePlane_Washington_South_FIPS_4602_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2928','NAD_1983_HARN_StatePlane_Wisconsin_North_FIPS_4801_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2929','NAD_1983_HARN_StatePlane_Wisconsin_Central_FIPS_4802_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2930','NAD_1983_HARN_StatePlane_Wisconsin_South_FIPS_4803_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2931','Beduaram_TM_13_NE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2932','QND_1995_Qatar_National_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2933','Gunung_Segara_UTM_Zone_50S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2934','Gunung_Segara_Jakarta_NEIEZ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2935','Pulkovo_1942_CS63_Zone_A1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2936','Pulkovo_1942_CS63_Zone_A2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2937','Pulkovo_1942_CS63_Zone_A3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2938','Pulkovo_1942_CS63_Zone_A4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2939','Pulkovo_1942_CS63_Zone_K2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2940','Pulkovo_1942_CS63_Zone_K3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2941','Pulkovo_1942_CS63_Zone_K4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2942','Porto_Santo_1936_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2943','Selvagem_Grande_1938_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2944','NAD_1983_CSRS_MTM_2_SCoPQ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2945','NAD_1983_CSRS_MTM_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2946','NAD_1983_CSRS_MTM_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2947','NAD_1983_CSRS_MTM_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2948','NAD_1983_CSRS_MTM_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2949','NAD_1983_CSRS_MTM_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2950','NAD_1983_CSRS_MTM_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2951','NAD_1983_CSRS_MTM_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2952','NAD_1983_CSRS_MTM_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2953','NAD_1983_CSRS_New_Brunswick_Stereographic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2954','NAD_1983_CSRS_Prince_Edward_Island','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2955','NAD_1983_CSRS_UTM_Zone_11N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2956','NAD_1983_CSRS_UTM_Zone_12N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2957','NAD_1983_CSRS_UTM_Zone_13N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2958','NAD_1983_CSRS_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2959','NAD_1983_CSRS_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2960','NAD_1983_CSRS_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2961','NAD_1983_CSRS_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2962','NAD_1983_CSRS_UTM_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2964','NAD_1927_Alaska_Albers_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2965','NAD_1983_StatePlane_Indiana_East_FIPS_1301_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2966','NAD_1983_StatePlane_Indiana_West_FIPS_1302_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2967','NAD_1983_HARN_StatePlane_Indiana_East_FIPS_1301_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2968','NAD_1983_HARN_StatePlane_Indiana_West_FIPS_1302_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2969','Fort_Marigot_UTM_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2970','Sainte_Anne_UTM_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2971','CSG_1967_UTM_22N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2972','RGFG_1995_UTM_22N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2973','Fort_Desaix_UTM_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2975','RGR_1992_UTM_40S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2976','Tahiti_1952_UTM_6S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2977','Tahaa_1954_UTM_5S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2978','IGN72_Nuku_Hiva_UTM_7S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2979','Kerguelen_Island_1949_UTM_42S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2980','Combani_1950_UTM_38S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2981','IGN56_Lifou_UTM_58S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2982','IGN72_Grande_Terre_UTM_58S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2984','RGNC_1991_Lambert_New_Caledonia','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2985','Petrels_1972_Terre_Adelie_Polar_Stereographic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2986','Perroud_1950_Terre_Adelie_Polar_Stereographic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2987','Saint_Pierre_et_Miquelon_1950_UTM_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2988','MOP78_UTM_1S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2991','NAD_1983_Oregon_Statewide_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2992','NAD_1983_Oregon_Statewide_Lambert_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2993','NAD_1983_HARN_Oregon_Statewide_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2994','NAD_1983_HARN_Oregon_Statewide_Lambert_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2995','IGN53_Mare_UTM_58S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2996','ST84_Ile_des_Pins_UTM_58S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2997','ST71_Belep_UTM_58S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2998','NEA74_Noumea_UTM_58S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','2999','Grand_Comoros_UTM_38S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3000','Gunung_Segara_NEIEZ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3001','Batavia_NEIEZ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3002','Makassar_NEIEZ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3003','Monte_Mario_Italy_1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3004','Monte_Mario_Italy_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3005','NAD_1983_BC_Environment_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3006','SWEREF99_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3007','SWEREF99_12_00','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3008','SWEREF99_13_30','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3009','SWEREF99_15_00','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3010','SWEREF99_16_30','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3011','SWEREF99_18_00','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3012','SWEREF99_14_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3013','SWEREF99_15_45','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3014','SWEREF99_17_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3015','SWEREF99_18_45','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3016','SWEREF99_20_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3017','SWEREF99_21_45','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3018','SWEREF99_23_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3019','RT90_75_gon_V','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3020','RT90_5_gon_V','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3021','RT90_25_gon_V','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3022','RT90_0_gon','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3023','RT90_25_gon_O','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3024','RT90_5_gon_O','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3025','RT38_75_gon_V','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3026','RT38_5_gon_V','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3027','RT38_25_gon_V','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3028','RT38_0_gon','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3029','RT38_25_gon_O','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3030','RT38_5_gon_O','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3031','WGS_1984_Antarctic_Polar_Stereographic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3032','WGS_1984_Australian_Antarctic_Polar_Stereographic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3033','WGS_1984_Australian_Antarctic_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3034','ETRS_1989_LCC','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3035','ETRS_1989_LAEA','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3036','Moznet_UTM_Zone_36S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3037','Moznet_UTM_Zone_37S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3038','ETRS_1989_ETRS-TM26','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3039','ETRS_1989_ETRS-TM27','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3040','ETRS_1989_ETRS-TM28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3041','ETRS_1989_ETRS-TM29','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3042','ETRS_1989_ETRS-TM30','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3043','ETRS_1989_ETRS-TM31','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3044','ETRS_1989_ETRS-TM32','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3045','ETRS_1989_ETRS-TM33','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3046','ETRS_1989_ETRS-TM34','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3047','ETRS_1989_ETRS-TM35','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3048','ETRS_1989_ETRS-TM36','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3049','ETRS_1989_ETRS-TM37','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3050','ETRS_1989_ETRS-TM38','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3051','ETRS_1989_ETRS-TM39','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3054','Hjorsey_1955_UTM_Zone_26N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3055','Hjorsey_1955_UTM_Zone_27N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3056','Hjorsey_1955_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3057','ISN_1993_Lambert_1993','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3058','Helle_1954_Jan_Mayen_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3059','LKS_1992_Latvia_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3060','IGN72_Grande_Terre_UTM_58S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3061','Porto_Santo_1995_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3062','Azores_Oriental_1995_UTM_Zone_26N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3063','Azores_Central_1995_UTM_Zone_26N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3064','IGM_1995_UTM_Zone_32N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3065','IGM_1995_UTM_Zone_33N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3066','ED_1950_Jordan_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3067','EUREF_FIN_TM35FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3068','DHDN_Soldner_Berlin','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3069','NAD_1927_Wisconsin_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3070','NAD_1983_Wisconsin_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3071','NAD_1983_HARN_Wisconsin_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3072','NAD_1983_Maine_2000_East_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3073','NAD_1983_Maine_2000_Central_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3074','NAD_1983_Maine_2000_West_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3075','NAD_1983_HARN_Maine_2000_East_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3076','NAD_1983_HARN_Maine_2000_Central_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3077','NAD_1983_HARN_Maine_2000_West_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3078','NAD_1983_Michigan_GeoRef_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3079','NAD_1983_HARN_Michigan_GeoRef_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3080','NAD_1927_Texas_Statewide_Mapping_System','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3081','NAD_1983_Texas_Statewide_Mapping_System','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3082','NAD_1983_Texas_Centric_Mapping_System_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3083','NAD_1983_Texas_Centric_Mapping_System_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3084','NAD_1983_HARN_Texas_Centric_Mapping_System_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3085','NAD_1983_HARN_Texas_Centric_Mapping_System_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3086','NAD_1983_Florida_GDL_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3087','NAD_1983_HARN_Florida_GDL_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3088','NAD_1983_StatePlane_Kentucky_FIPS_1600','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3089','NAD_1983_StatePlane_Kentucky_FIPS_1600_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3090','NAD_1983_HARN_StatePlane_Kentucky_FIPS_1600','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3091','NAD_1983_HARN_StatePlane_Kentucky_FIPS_1600_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3092','Tokyo_UTM_Zone_51N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3093','Tokyo_UTM_Zone_52N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3094','Tokyo_UTM_Zone_53N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3095','Tokyo_UTM_Zone_54N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3096','Tokyo_UTM_Zone_55N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3097','JGD_2000_UTM_Zone_51N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3098','JGD_2000_UTM_Zone_52N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3099','JGD_2000_UTM_Zone_53N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3100','JGD_2000_UTM_Zone_54N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3101','JGD_2000_UTM_Zone_55N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3102','Samoa_1962_Samoa_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3106','Gulshan_303_Bangladesh_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3107','GDA_1994_South_Australia_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3108','ETRS_1989_Guernsey_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3109','ETRS_1989_Jersey_Transverse_Mercator','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3110','AGD_1966_VICGRID','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3111','GDA_1994_VICGRID94','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3112','GDA_1994_Geoscience_Australia_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3113','GDA_1994_BCSG02','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3114','MAGNA_Colombia_Oeste_Oeste','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3115','MAGNA_Colombia_Oeste','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3116','MAGNA_Colombia_Bogota','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3117','MAGNA_Colombia_Este','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3118','MAGNA_Colombia_Este_Este','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3119','Douala_1948_AEF_West','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3120','Pulkovo_1942_Adj_1958_Poland_Zone_I','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3121','PRS_1992_Philippines_Zone_I','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3122','PRS_1992_Philippines_Zone_II','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3123','PRS_1992_Philippines_Zone_III','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3124','PRS_1992_Philippines_Zone_IV','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3125','PRS_1992_Philippines_Zone_V','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3126','ETRS_1989_ETRS-GK19FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3127','ETRS_1989_ETRS-GK20FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3128','ETRS_1989_ETRS-GK21FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3129','ETRS_1989_ETRS-GK22FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3130','ETRS_1989_ETRS-GK23FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3131','ETRS_1989_ETRS-GK24FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3132','ETRS_1989_ETRS-GK25FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3133','ETRS_1989_ETRS-GK26FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3134','ETRS_1989_ETRS-GK27FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3135','ETRS_1989_ETRS-GK28FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3136','ETRS_1989_ETRS-GK29FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3137','ETRS_1989_ETRS-GK30FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3138','ETRS_1989_ETRS-GK31FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3141','Fiji_1956_UTM_Zone_60S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3142','Fiji_1956_UTM_Zone_1S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3146','Pulkovo_1942_3_Degree_GK_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3147','Pulkovo_1942_3_Degree_GK_CM_18E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3148','Indian_1960_UTM_Zone_48N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3149','Indian_1960_UTM_Zone_49N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3150','Pulkovo_1995_3_Degree_GK_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3151','Pulkovo_1995_3_Degree_GK_CM_18E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3153','NAD_1983_CSRS_BC_Environment_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3154','NAD_1983_CSRS_UTM_Zone_7N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3155','NAD_1983_CSRS_UTM_Zone_8N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3156','NAD_1983_CSRS_UTM_Zone_9N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3157','NAD_1983_CSRS_UTM_Zone_10N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3158','NAD_1983_CSRS_UTM_Zone_14N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3159','NAD_1983_CSRS_UTM_Zone_15N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3160','NAD_1983_CSRS_UTM_Zone_16N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3161','NAD_1983_Ontario_MNR_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3162','NAD_1983_CSRS_Ontario_MNR_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3163','RGNC_1991_93_Lambert_New_Caledonia','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3164','ST87_Ouvea_UTM_58S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3165','NEA74_Noumea_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3166','NEA74_Noumea_Lambert_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3167','Kertau_RSO_RSO_Malaya_ChSears1922trunc','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3168','Kertau_RSO_RSO_Malaya','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3169','RGNC_1991-93_UTM_Zone_57S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3170','RGNC_1991-93_UTM_Zone_58S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3171','RGNC_1991-93_UTM_Zone_59S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3172','IGN53_Mare_UTM_Zone_59S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3174','NAD_1983_Great_Lakes_Basin_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3175','NAD_1983_Great_Lakes_and_St_Lawrence_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3176','Indian_1960_TM_106NE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3177','LGD2006_Libya_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3178','Greenland_1996_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3179','Greenland_1996_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3180','Greenland_1996_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3181','Greenland_1996_UTM_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3182','Greenland_1996_UTM_Zone_22N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3183','Greenland_1996_UTM_Zone_23N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3184','Greenland_1996_UTM_Zone_24N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3185','Greenland_1996_UTM_Zone_25N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3186','Greenland_1996_UTM_Zone_26N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3187','Greenland_1996_UTM_Zone_27N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3188','Greenland_1996_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3189','Greenland_1996_UTM_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3190','LGD2006_Libya_TM_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3191','LGD2006_Libya_TM_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3192','LGD2006_Libya_TM_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3193','LGD2006_Libya_TM_Zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3194','LGD2006_Libya_TM_Zone_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3195','LGD2006_Libya_TM_Zone_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3196','LGD2006_Libya_TM_Zone_11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3197','LGD2006_Libya_TM_Zone_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3198','LGD2006_Libya_TM_Zone_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3199','LGD2006_UTM_Zone_32N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3200','FD_1958_Iraq','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3201','LGD2006_UTM_Zone_33N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3202','LGD2006_UTM_Zone_34N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3203','LGD2006_UTM_Zone_35N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3294','WGS_1984_USGS_Transantarctic_Mountains','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3295','Guam_1963_Yap_Islands','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3296','RGPF_UTM_Zone_5S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3297','RGPF_UTM_Zone_6S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3298','RGPF_UTM_Zone_7S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3299','RGPF_UTM_Zone_8S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3300','Estonian_Coordinate_System_of_1992','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3301','Estonia_1997_Estonia_National_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3302','IGN63_Hiva_Oa_UTM_Zone_7S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3303','Fatu_Iva_1972_UTM_Zone_7S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3304','Tahiti_1979_UTM_Zone_6S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3305','Moorea_1987_UTM_Zone_6S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3306','Maupiti_1983_UTM_Zone_5S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3307','Nakhl-e_Ghanem_UTM_Zone_39N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3308','GDA_1994_NSW_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3309','NAD_1927_California_Teale_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3310','NAD_1983_California_Teale_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3311','NAD_1983_HARN_California_Teale_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3312','CSG_1967_UTM_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3313','RGFG_1995_UTM_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3315','Katanga_1955_Katanga_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3316','Kasai_1953_Congo_TM_Zone_22','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3317','Kasai_1953_Congo_TM_Zone_24','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3318','IGC_1962_Congo_TM_Zone_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3319','IGC_1962_Congo_TM_Zone_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3320','IGC_1962_Congo_TM_Zone_16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3321','IGC_1962_Congo_TM_Zone_18','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3322','IGC_1962_Congo_TM_Zone_20','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3323','IGC_1962_Congo_TM_Zone_22','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3324','IGC_1962_Congo_TM_Zone_24','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3325','IGC_1962_Congo_TM_Zone_26','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3326','IGC_1962_Congo_TM_Zone_28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3327','IGC_1962_Congo_TM_Zone_30','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3328','Pulkovo_1942_Adj_1958_GUGiK-80','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3329','Pulkovo_1942_Adj_1958_3_Degree_GK_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3330','Pulkovo_1942_Adj_1958_3_Degree_GK_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3331','Pulkovo_1942_Adj_1958_3_Degree_GK_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3332','Pulkovo_1942_Adj_1958_3_Degree_GK_Zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3333','Pulkovo_1942_Adj_1958_GK_Zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3334','Pulkovo_1942_Adj_1958_GK_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3335','Pulkovo_1942_Adj_1958_GK_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3336','Kerguelen_Island_1949_UTM_42S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3337','Le_Pouce_1934_Mauritius_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3338','NAD_1983_Alaska_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3339','IGCB_1955_Congo_TM_Zone_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3340','IGCB_1955_Congo_TM_Zone_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3341','IGCB_1955_Congo_TM_Zone_16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3342','IGCB_1955_UTM_Zone_33S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3343','Mauritania_1999_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3344','Mauritania_1999_UTM_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3345','Mauritania_1999_UTM_Zone_30N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3346','LKS_1994_Lithuania_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3347','NAD_1983_Statistics_Canada_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3348','NAD_1983_CSRS_Statistics_Canada_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3350','Pulkovo_1942_CS63_Zone_C0','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3351','Pulkovo_1942_CS63_Zone_C1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3352','Pulkovo_1942_CS63_Zone_C2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3353','Mhast_Onshore_UTM_Zone_32S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3354','Mhast_Offshore_UTM_Zone_32S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3355','Egypt_Gulf_of_Suez_S-650_TL_Red_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3356','Grand_Cayman_1959_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3357','Little_Cayman_1961_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3358','NAD_1983_HARN_StatePlane_North_Carolina_FIPS_3200','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3359','NAD_1983_HARN_StatePlane_North_Carolina_FIPS_3200_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3360','NAD_1983_HARN_StatePlane_South_Carolina_FIPS_3900','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3361','NAD_1983_HARN_StatePlane_South_Carolina_FIPS_3900_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3362','NAD_1983_HARN_StatePlane_Pennsylvania_North_FIPS_3701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3363','NAD_1983_HARN_StatePlane_Pennsylvania_North_FIPS_3701_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3364','NAD_1983_HARN_StatePlane_Pennsylvania_South_FIPS_3702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3365','NAD_1983_HARN_StatePlane_Pennsylvania_South_FIPS_3702_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3366','Hong_Kong_1963_Grid_System','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3367','IGN_Astro_1960_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3368','IGN_Astro_1960_UTM_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3369','IGN_Astro_1960_UTM_Zone_30N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3370','NAD_1927_UTM_Zone_59N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3371','NAD_1927_UTM_Zone_60N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3372','NAD_1983_UTM_Zone_59N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3373','NAD_1983_UTM_Zone_60N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3374','FD_1954_UTM_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3375','GDM_2000_MRSO_Peninsular_Malaysia','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3376','GDM_2000_BRSO_East_Malaysia','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3377','GDM_2000_State_Cassini_Johor','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3378','GDM_2000_State_Cassini_Negeri_Sembilan_and_Melaka','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3379','GDM_2000_State_Cassini_Pahang','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3380','GDM_2000_State_Cassini_Selangor','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3381','GDM_2000_State_Cassini_Terengganu','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3382','GDM_2000_State_Cassini_Pulau_Pinang_and_Seberang_Perai','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3383','GDM_2000_State_Cassini_Perlis','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3384','GDM_2000_State_Cassini_Perak','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3385','GDM_2000_State_Cassini_Kelantan','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3386','KKJ_Finland_Zone_0','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3387','KKJ_Finland_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3388','Pulkovo_1942_Caspian_Sea_Mercator','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3389','Pulkovo_1942_3_Degree_GK_Zone_60','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3390','Pulkovo_1995_3_Degree_GK_Zone_60','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3391','Karbala_1979_Polservice_UTM_Zone_37N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3392','Karbala_1979_Polservice_UTM_Zone_38N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3393','Karbala_1979_Polservice_UTM_Zone_39N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3394','Nahrwan_1934_Iraq_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3395','WGS_1984_World_Mercator','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3396','PD/83_GK_Zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3397','PD/83_GK_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3398','RD/83_GK_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3399','RD/83_GK_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3400','NAD_1983_10TM_AEP_Forest','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3401','NAD_1983_10TM_AEP_Resource','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3402','NAD_1983_CSRS_10TM_AEP_Forest','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3403','NAD_1983_CSRS_10TM_AEP_Resource','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3404','NAD_1983_HARN_StatePlane_North_Carolina_FIPS_3200_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3405','VN_2000_UTM_Zone_48N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3406','VN_2000_UTM_Zone_49N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3407','Hong_Kong_1963_Grid_System','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3408','NSIDC_EASE_Grid_North','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3409','NSIDC_EASE_Grid_South','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3410','NSIDC_EASE_Grid_Global','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3411','NSIDC_Sea_Ice_Polar_Stereographic_North','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3412','NSIDC_Sea_Ice_Polar_Stereographic_South','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3413','WGS_1984_NSIDC_Sea_Ice_Polar_Stereographic_North','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3414','SVY21_Singapore_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3415','WGS_1972_BE_South_China_Sea_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3416','ETRS_1989_Austria_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3417','NAD_1983_StatePlane_Iowa_North_FIPS_1401_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3418','NAD_1983_StatePlane_Iowa_South_FIPS_1402_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3419','NAD_1983_StatePlane_Kansas_North_FIPS_1501_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3420','NAD_1983_StatePlane_Kansas_South_FIPS_1502_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3421','NAD_1983_StatePlane_Nevada_East_FIPS_2701_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3422','NAD_1983_StatePlane_Nevada_Central_FIPS_2702_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3423','NAD_1983_StatePlane_Nevada_West_FIPS_2703_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3424','NAD_1983_StatePlane_New_Jersey_FIPS_2900_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3425','NAD_1983_HARN_StatePlane_Iowa_North_FIPS_1401_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3426','NAD_1983_HARN_StatePlane_Iowa_South_FIPS_1402_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3427','NAD_1983_HARN_StatePlane_Kansas_North_FIPS_1501_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3428','NAD_1983_HARN_StatePlane_Kansas_South_FIPS_1502_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3429','NAD_1983_HARN_StatePlane_Nevada_East_FIPS_2701_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3430','NAD_1983_HARN_StatePlane_Nevada_Central_FIPS_2702_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3431','NAD_1983_HARN_StatePlane_Nevada_West_FIPS_2703_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3432','NAD_1983_HARN_StatePlane_New_Jersey_FIPS_2900_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3433','NAD_1983_StatePlane_Arkansas_North_FIPS_0301_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3434','NAD_1983_StatePlane_Arkansas_South_FIPS_0302_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3435','NAD_1983_StatePlane_Illinois_East_FIPS_1201_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3436','NAD_1983_StatePlane_Illinois_West_FIPS_1202_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3437','NAD_1983_StatePlane_New_Hampshire_FIPS_2800_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3438','NAD_1983_StatePlane_Rhode_Island_FIPS_3800_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3439','PDO_1993_UTM_Zone_39N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3440','PDO_1993_UTM_Zone_40N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3441','NAD_1983_HARN_StatePlane_Arkansas_North_FIPS_0301_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3442','NAD_1983_HARN_StatePlane_Arkansas_South_FIPS_0302_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3443','NAD_1983_HARN_StatePlane_Illinois_East_FIPS_1201_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3444','NAD_1983_HARN_StatePlane_Illinois_West_FIPS_1202_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3445','NAD_1983_HARN_StatePlane_New_Hampshire_FIPS_2800_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3446','NAD_1983_HARN_StatePlane_Rhode_Island_FIPS_3800_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3447','Belge_Lambert_2005','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3448','JAD_2001_Jamaica_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3449','JAD_2001_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3450','JAD_2001_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3451','NAD_1983_StatePlane_Louisiana_North_FIPS_1701_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3452','NAD_1983_StatePlane_Louisiana_South_FIPS_1702_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3453','NAD_1983_StatePlane_Louisiana_Offshore_FIPS_1703_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3454','NAD_1983_StatePlane_South_Dakota_North_FIPS_4001_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3455','NAD_1983_StatePlane_South_Dakota_South_FIPS_4002_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3456','NAD_1983_HARN_StatePlane_Louisiana_North_FIPS_1701_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3457','NAD_1983_HARN_StatePlane_Louisiana_South_FIPS_1702_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3458','NAD_1983_HARN_StatePlane_South_Dakota_North_FIPS_4001_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3459','NAD_1983_HARN_StatePlane_South_Dakota_South_FIPS_4002_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3460','Fiji_1986_Fiji_Map_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3461','Dabola_1981_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3462','Dabola_1981_UTM_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3463','NAD_1983_Maine_2000_Central_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3464','NAD_1983_HARN_Maine_2000_Central_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3465','NAD_1983_NSRS2007_StatePlane_Alabama_East_FIPS_0101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3466','NAD_1983_NSRS2007_StatePlane_Alabama_West_FIPS_0102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3467','NAD_1983_NSRS2007_Alaska_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3468','NAD_1983_NSRS2007_StatePlane_Alaska_1_FIPS_5001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3469','NAD_1983_NSRS2007_StatePlane_Alaska_2_FIPS_5002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3470','NAD_1983_NSRS2007_StatePlane_Alaska_3_FIPS_5003','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3471','NAD_1983_NSRS2007_StatePlane_Alaska_4_FIPS_5004','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3472','NAD_1983_NSRS2007_StatePlane_Alaska_5_FIPS_5005','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3473','NAD_1983_NSRS2007_StatePlane_Alaska_6_FIPS_5006','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3474','NAD_1983_NSRS2007_StatePlane_Alaska_7_FIPS_5007','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3475','NAD_1983_NSRS2007_StatePlane_Alaska_8_FIPS_5008','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3476','NAD_1983_NSRS2007_StatePlane_Alaska_9_FIPS_5009','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3477','NAD_1983_NSRS2007_StatePlane_Alaska_10_FIPS_5010','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3478','NAD_1983_NSRS2007_StatePlane_Arizona_Central_FIPS_0202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3479','NAD_1983_NSRS2007_StatePlane_Arizona_Central_FIPS_0202_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3480','NAD_1983_NSRS2007_StatePlane_Arizona_East_FIPS_0201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3481','NAD_1983_NSRS2007_StatePlane_Arizona_East_FIPS_0201_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3482','NAD_1983_NSRS2007_StatePlane_Arizona_West_FIPS_0203','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3483','NAD_1983_NSRS2007_StatePlane_Arizona_West_FIPS_0203_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3484','NAD_1983_NSRS2007_StatePlane_Arkansas_North_FIPS_0301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3485','NAD_1983_NSRS2007_StatePlane_Arkansas_North_FIPS_0301_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3486','NAD_1983_NSRS2007_StatePlane_Arkansas_South_FIPS_0302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3487','NAD_1983_NSRS2007_StatePlane_Arkansas_South_FIPS_0302_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3488','NAD_1983_NSRS2007_California_Teale_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3489','NAD_1983_NSRS2007_StatePlane_California_I_FIPS_0401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3490','NAD_1983_NSRS2007_StatePlane_California_I_FIPS_0401_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3491','NAD_1983_NSRS2007_StatePlane_California_II_FIPS_0402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3492','NAD_1983_NSRS2007_StatePlane_California_II_FIPS_0402_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3493','NAD_1983_NSRS2007_StatePlane_California_III_FIPS_0403','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3494','NAD_1983_NSRS2007_StatePlane_California_III_FIPS_0403_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3495','NAD_1983_NSRS2007_StatePlane_California_IV_FIPS_0404','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3496','NAD_1983_NSRS2007_StatePlane_California_IV_FIPS_0404_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3497','NAD_1983_NSRS2007_StatePlane_California_V_FIPS_0405','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3498','NAD_1983_NSRS2007_StatePlane_California_V_FIPS_0405_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3499','NAD_1983_NSRS2007_StatePlane_California_VI_FIPS_0406','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3500','NAD_1983_NSRS2007_StatePlane_California_VI_FIPS_0406_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3501','NAD_1983_NSRS2007_StatePlane_Colorado_Central_FIPS_0502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3502','NAD_1983_NSRS2007_StatePlane_Colorado_Central_FIPS_0502_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3503','NAD_1983_NSRS2007_StatePlane_Colorado_North_FIPS_0501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3504','NAD_1983_NSRS2007_StatePlane_Colorado_North_FIPS_0501_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3505','NAD_1983_NSRS2007_StatePlane_Colorado_South_FIPS_0503','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3506','NAD_1983_NSRS2007_StatePlane_Colorado_South_FIPS_0503_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3507','NAD_1983_NSRS2007_StatePlane_Connecticut_FIPS_0600','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3508','NAD_1983_NSRS2007_StatePlane_Connecticut_FIPS_0600_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3509','NAD_1983_NSRS2007_StatePlane_Delaware_FIPS_0700','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3510','NAD_1983_NSRS2007_StatePlane_Delaware_FIPS_0700_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3511','NAD_1983_NSRS2007_StatePlane_Florida_East_FIPS_0901','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3512','NAD_1983_NSRS2007_StatePlane_Florida_East_FIPS_0901_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3513','NAD_1983_NSRS2007_Florida_GDL_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3514','NAD_1983_NSRS2007_StatePlane_Florida_North_FIPS_0903','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3515','NAD_1983_NSRS2007_StatePlane_Florida_North_FIPS_0903_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3516','NAD_1983_NSRS2007_StatePlane_Florida_West_FIPS_0902','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3517','NAD_1983_NSRS2007_StatePlane_Florida_West_FIPS_0902_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3518','NAD_1983_NSRS2007_StatePlane_Georgia_East_FIPS_1001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3519','NAD_1983_NSRS2007_StatePlane_Georgia_East_FIPS_1001_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3520','NAD_1983_NSRS2007_StatePlane_Georgia_West_FIPS_1002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3521','NAD_1983_NSRS2007_StatePlane_Georgia_West_FIPS_1002_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3522','NAD_1983_NSRS2007_StatePlane_Idaho_Central_FIPS_1102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3523','NAD_1983_NSRS2007_StatePlane_Idaho_Central_FIPS_1102_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3524','NAD_1983_NSRS2007_StatePlane_Idaho_East_FIPS_1101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3525','NAD_1983_NSRS2007_StatePlane_Idaho_East_FIPS_1101_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3526','NAD_1983_NSRS2007_StatePlane_Idaho_West_FIPS_1103','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3527','NAD_1983_NSRS2007_StatePlane_Idaho_West_FIPS_1103_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3528','NAD_1983_NSRS2007_StatePlane_Illinois_East_FIPS_1201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3529','NAD_1983_NSRS2007_StatePlane_Illinois_East_FIPS_1201_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3530','NAD_1983_NSRS2007_StatePlane_Illinois_West_FIPS_1202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3531','NAD_1983_NSRS2007_StatePlane_Illinois_West_FIPS_1202_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3532','NAD_1983_NSRS2007_StatePlane_Indiana_East_FIPS_1301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3533','NAD_1983_NSRS2007_StatePlane_Indiana_East_FIPS_1301_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3534','NAD_1983_NSRS2007_StatePlane_Indiana_West_FIPS_1302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3535','NAD_1983_NSRS2007_StatePlane_Indiana_West_FIPS_1302_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3536','NAD_1983_NSRS2007_StatePlane_Iowa_North_FIPS_1401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3537','NAD_1983_NSRS2007_StatePlane_Iowa_North_FIPS_1401_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3538','NAD_1983_NSRS2007_StatePlane_Iowa_South_FIPS_1402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3539','NAD_1983_NSRS2007_StatePlane_Iowa_South_FIPS_1402_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3540','NAD_1983_NSRS2007_StatePlane_Kansas_North_FIPS_1501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3541','NAD_1983_NSRS2007_StatePlane_Kansas_North_FIPS_1501_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3542','NAD_1983_NSRS2007_StatePlane_Kansas_South_FIPS_1502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3543','NAD_1983_NSRS2007_StatePlane_Kansas_South_FIPS_1502_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3544','NAD_1983_NSRS2007_StatePlane_Kentucky_North_FIPS_1601','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3545','NAD_1983_NSRS2007_StatePlane_Kentucky_North_FIPS_1601_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3546','NAD_1983_NSRS2007_StatePlane_Kentucky_FIPS_1600','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3547','NAD_1983_NSRS2007_StatePlane_Kentucky_FIPS_1600_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3548','NAD_1983_NSRS2007_StatePlane_Kentucky_South_FIPS_1602','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3549','NAD_1983_NSRS2007_StatePlane_Kentucky_South_FIPS_1602_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3550','NAD_1983_NSRS2007_StatePlane_Louisiana_North_FIPS_1701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3551','NAD_1983_NSRS2007_StatePlane_Louisiana_North_FIPS_1701_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3552','NAD_1983_NSRS2007_StatePlane_Louisiana_South_FIPS_1702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3553','NAD_1983_NSRS2007_StatePlane_Louisiana_South_FIPS_1702_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3554','NAD_1983_NSRS2007_Maine_2000_Central_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3555','NAD_1983_NSRS2007_Maine_2000_East_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3556','NAD_1983_NSRS2007_Maine_2000_West_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3557','NAD_1983_NSRS2007_StatePlane_Maine_East_FIPS_1801','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3558','NAD_1983_NSRS2007_StatePlane_Maine_West_FIPS_1802','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3559','NAD_1983_NSRS2007_StatePlane_Maryland_FIPS_1900','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3560','NAD_1983_StatePlane_Utah_North_FIPS_4301_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3561','Old_Hawaiian_StatePlane_Hawaii_1_FIPS_5101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3562','Old_Hawaiian_StatePlane_Hawaii_2_FIPS_5102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3563','Old_Hawaiian_StatePlane_Hawaii_3_FIPS_5103','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3564','Old_Hawaiian_StatePlane_Hawaii_4_FIPS_5104','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3565','Old_Hawaiian_StatePlane_Hawaii_5_FIPS_5105','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3566','NAD_1983_StatePlane_Utah_Central_FIPS_4302_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3567','NAD_1983_StatePlane_Utah_South_FIPS_4303_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3568','NAD_1983_HARN_StatePlane_Utah_North_FIPS_4301_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3569','NAD_1983_HARN_StatePlane_Utah_Central_FIPS_4302_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3570','NAD_1983_HARN_StatePlane_Utah_South_FIPS_4303_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3571','WGS_1984_North_Pole_LAEA_Bering_Sea','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3572','WGS_1984_North_Pole_LAEA_Alaska','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3573','WGS_1984_North_Pole_LAEA_Canada','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3574','WGS_1984_North_Pole_LAEA_Atlantic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3575','WGS_1984_North_Pole_LAEA_Europe','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3576','WGS_1984_North_Pole_LAEA_Russia','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3577','GDA_1994_Australia_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3578','NAD_1983_Yukon_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3579','NAD_1983_CSRS_Yukon_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3580','NAD_1983_Northwest_Territories_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3581','NAD_1983_CSRS_Northwest_Territories_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3582','NAD_1983_NSRS2007_StatePlane_Maryland_FIPS_1900_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3583','NAD_1983_NSRS2007_StatePlane_Massachusetts_Island_FIPS_2002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3584','NAD_1983_NSRS2007_StatePlane_Massachusetts_Isl_FIPS_2002_FtUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3585','NAD_1983_NSRS2007_StatePlane_Massachusetts_Mainland_FIPS_2001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3586','NAD_1983_NSRS2007_StatePlane_Massachusetts_Mnld_FIPS_2001_FtUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3587','NAD_1983_NSRS2007_StatePlane_Michigan_Central_FIPS_2112','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3588','NAD_1983_NSRS2007_StatePlane_Michigan_Central_FIPS_2112_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3589','NAD_1983_NSRS2007_StatePlane_Michigan_North_FIPS_2111','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3590','NAD_1983_NSRS2007_StatePlane_Michigan_North_FIPS_2111_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3591','NAD_1983_NSRS2007_Michigan_GeoRef_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3592','NAD_1983_NSRS2007_StatePlane_Michigan_South_FIPS_2113','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3593','NAD_1983_NSRS2007_StatePlane_Michigan_South_FIPS_2113_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3594','NAD_1983_NSRS2007_StatePlane_Minnesota_Central_FIPS_2202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3595','NAD_1983_NSRS2007_StatePlane_Minnesota_North_FIPS_2201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3596','NAD_1983_NSRS2007_StatePlane_Minnesota_South_FIPS_2203','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3597','NAD_1983_NSRS2007_StatePlane_Mississippi_East_FIPS_2301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3598','NAD_1983_NSRS2007_StatePlane_Mississippi_East_FIPS_2301_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3599','NAD_1983_NSRS2007_StatePlane_Mississippi_West_FIPS_2302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3600','NAD_1983_NSRS2007_StatePlane_Mississippi_West_FIPS_2302_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3601','NAD_1983_NSRS2007_StatePlane_Missouri_Central_FIPS_2402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3602','NAD_1983_NSRS2007_StatePlane_Missouri_East_FIPS_2401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3603','NAD_1983_NSRS2007_StatePlane_Missouri_West_FIPS_2403','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3604','NAD_1983_NSRS2007_StatePlane_Montana_FIPS_2500','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3605','NAD_1983_NSRS2007_StatePlane_Montana_FIPS_2500_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3606','NAD_1983_NSRS2007_StatePlane_Nebraska_FIPS_2600','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3607','NAD_1983_NSRS2007_StatePlane_Nevada_Central_FIPS_2702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3608','NAD_1983_NSRS2007_StatePlane_Nevada_Central_FIPS_2702_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3609','NAD_1983_NSRS2007_StatePlane_Nevada_East_FIPS_2701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3610','NAD_1983_NSRS2007_StatePlane_Nevada_East_FIPS_2701_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3611','NAD_1983_NSRS2007_StatePlane_Nevada_West_FIPS_2703','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3612','NAD_1983_NSRS2007_StatePlane_Nevada_West_FIPS_2703_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3613','NAD_1983_NSRS2007_StatePlane_New_Hampshire_FIPS_2800','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3614','NAD_1983_NSRS2007_StatePlane_New_Hampshire_FIPS_2800_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3615','NAD_1983_NSRS2007_StatePlane_New_Jersey_FIPS_2900','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3616','NAD_1983_NSRS2007_StatePlane_New_Jersey_FIPS_2900_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3617','NAD_1983_NSRS2007_StatePlane_New_Mexico_Central_FIPS_3002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3618','NAD_1983_NSRS2007_StatePlane_New_Mexico_Central_FIPS_3002_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3619','NAD_1983_NSRS2007_StatePlane_New_Mexico_East_FIPS_3001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3620','NAD_1983_NSRS2007_StatePlane_New_Mexico_East_FIPS_3001_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3621','NAD_1983_NSRS2007_StatePlane_New_Mexico_West_FIPS_3003','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3622','NAD_1983_NSRS2007_StatePlane_New_Mexico_West_FIPS_3003_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3623','NAD_1983_NSRS2007_StatePlane_New_York_Central_FIPS_3102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3624','NAD_1983_NSRS2007_StatePlane_New_York_Central_FIPS_3102_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3625','NAD_1983_NSRS2007_StatePlane_New_York_East_FIPS_3101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3626','NAD_1983_NSRS2007_StatePlane_New_York_East_FIPS_3101_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3627','NAD_1983_NSRS2007_StatePlane_New_York_Long_Island_FIPS_3104','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3628','NAD_1983_NSRS2007_StatePlane_New_York_Long_Isl_FIPS_3104_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3629','NAD_1983_NSRS2007_StatePlane_New_York_West_FIPS_3103','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3630','NAD_1983_NSRS2007_StatePlane_New_York_West_FIPS_3103_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3631','NAD_1983_NSRS2007_StatePlane_North_Carolina_FIPS_3200','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3632','NAD_1983_NSRS2007_StatePlane_North_Carolina_FIPS_3200_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3633','NAD_1983_NSRS2007_StatePlane_North_Dakota_North_FIPS_3301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3634','NAD_1983_NSRS2007_StatePlane_North_Dakota_North_FIPS_3301_FtI','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3635','NAD_1983_NSRS2007_StatePlane_North_Dakota_South_FIPS_3302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3636','NAD_1983_NSRS2007_StatePlane_North_Dakota_South_FIPS_3302_FtI','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3637','NAD_1983_NSRS2007_StatePlane_Ohio_North_FIPS_3401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3638','NAD_1983_NSRS2007_StatePlane_Ohio_South_FIPS_3402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3639','NAD_1983_NSRS2007_StatePlane_Oklahoma_North_FIPS_3501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3640','NAD_1983_NSRS2007_StatePlane_Oklahoma_North_FIPS_3501_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3641','NAD_1983_NSRS2007_StatePlane_Oklahoma_South_FIPS_3502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3642','NAD_1983_NSRS2007_StatePlane_Oklahoma_South_FIPS_3502_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3643','NAD_1983_NSRS2007_Oregon_Statewide_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3644','NAD_1983_NSRS2007_Oregon_Statewide_Lambert_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3645','NAD_1983_NSRS2007_StatePlane_Oregon_North_FIPS_3601','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3646','NAD_1983_NSRS2007_StatePlane_Oregon_North_FIPS_3601_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3647','NAD_1983_NSRS2007_StatePlane_Oregon_South_FIPS_3602','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3648','NAD_1983_NSRS2007_StatePlane_Oregon_South_FIPS_3602_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3649','NAD_1983_NSRS2007_StatePlane_Pennsylvania_North_FIPS_3701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3650','NAD_1983_NSRS2007_StatePlane_Pennsylvania_North_FIPS_3701_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3651','NAD_1983_NSRS2007_StatePlane_Pennsylvania_South_FIPS_3702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3652','NAD_1983_NSRS2007_StatePlane_Pennsylvania_South_FIPS_3702_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3653','NAD_1983_NSRS2007_StatePlane_Rhode_Island_FIPS_3800','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3654','NAD_1983_NSRS2007_StatePlane_Rhode_Island_FIPS_3800_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3655','NAD_1983_NSRS2007_StatePlane_South_Carolina_FIPS_3900','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3656','NAD_1983_NSRS2007_StatePlane_South_Carolina_FIPS_3900_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3657','NAD_1983_NSRS2007_StatePlane_South_Dakota_North_FIPS_4001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3658','NAD_1983_NSRS2007_StatePlane_South_Dakota_North_FIPS_4001_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3659','NAD_1983_NSRS2007_StatePlane_South_Dakota_South_FIPS_4002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3660','NAD_1983_NSRS2007_StatePlane_South_Dakota_South_FIPS_4002_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3661','NAD_1983_NSRS2007_StatePlane_Tennessee_FIPS_4100','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3662','NAD_1983_NSRS2007_StatePlane_Tennessee_FIPS_4100_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3663','NAD_1983_NSRS2007_StatePlane_Texas_Central_FIPS_4203','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3664','NAD_1983_NSRS2007_StatePlane_Texas_Central_FIPS_4203_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3665','NAD_1983_NSRS2007_Texas_Centric_Mapping_System_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3666','NAD_1983_NSRS2007_Texas_Centric_Mapping_System_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3667','NAD_1983_NSRS2007_StatePlane_Texas_North_FIPS_4201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3668','NAD_1983_NSRS2007_StatePlane_Texas_North_FIPS_4201_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3669','NAD_1983_NSRS2007_StatePlane_Texas_North_Central_FIPS_4202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3670','NAD_1983_NSRS2007_StatePlane_Texas_North_Central_FIPS_4202_FtUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3671','NAD_1983_NSRS2007_StatePlane_Texas_South_FIPS_4205','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3672','NAD_1983_NSRS2007_StatePlane_Texas_South_FIPS_4205_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3673','NAD_1983_NSRS2007_StatePlane_Texas_South_Central_FIPS_4204','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3674','NAD_1983_NSRS2007_StatePlane_Texas_South_Central_FIPS_4204_FtUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3675','NAD_1983_NSRS2007_StatePlane_Utah_Central_FIPS_4302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3676','NAD_1983_NSRS2007_StatePlane_Utah_Central_FIPS_4302_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3677','NAD_1983_NSRS2007_StatePlane_Utah_Central_FIPS_4302_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3678','NAD_1983_NSRS2007_StatePlane_Utah_North_FIPS_4301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3679','NAD_1983_NSRS2007_StatePlane_Utah_North_FIPS_4301_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3680','NAD_1983_NSRS2007_StatePlane_Utah_North_FIPS_4301_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3681','NAD_1983_NSRS2007_StatePlane_Utah_South_FIPS_4303','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3682','NAD_1983_NSRS2007_StatePlane_Utah_South_FIPS_4303_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3683','NAD_1983_NSRS2007_StatePlane_Utah_South_FIPS_4303_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3684','NAD_1983_NSRS2007_StatePlane_Vermont_FIPS_4400','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3685','NAD_1983_NSRS2007_StatePlane_Virginia_North_FIPS_4501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3686','NAD_1983_NSRS2007_StatePlane_Virginia_North_FIPS_4501_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3687','NAD_1983_NSRS2007_StatePlane_Virginia_South_FIPS_4502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3688','NAD_1983_NSRS2007_StatePlane_Virginia_South_FIPS_4502_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3689','NAD_1983_NSRS2007_StatePlane_Washington_North_FIPS_4601','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3690','NAD_1983_NSRS2007_StatePlane_Washington_North_FIPS_4601_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3691','NAD_1983_NSRS2007_StatePlane_Washington_South_FIPS_4602','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3692','NAD_1983_NSRS2007_StatePlane_Washington_South_FIPS_4602_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3693','NAD_1983_NSRS2007_StatePlane_West_Virginia_North_FIPS_4701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3694','NAD_1983_NSRS2007_StatePlane_West_Virginia_South_FIPS_4702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3695','NAD_1983_NSRS2007_StatePlane_Wisconsin_Central_FIPS_4802','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3696','NAD_1983_NSRS2007_StatePlane_Wisconsin_Central_FIPS_4802_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3697','NAD_1983_NSRS2007_StatePlane_Wisconsin_North_FIPS_4801','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3698','NAD_1983_NSRS2007_StatePlane_Wisconsin_North_FIPS_4801_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3699','NAD_1983_NSRS2007_StatePlane_Wisconsin_South_FIPS_4803','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3700','NAD_1983_NSRS2007_StatePlane_Wisconsin_South_FIPS_4803_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3701','NAD_1983_NSRS2007_Wisconsin_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3702','NAD_1983_NSRS2007_StatePlane_Wyoming_East_FIPS_4901','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3703','NAD_1983_NSRS2007_StatePlane_Wyoming_East_Central_FIPS_4902','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3704','NAD_1983_NSRS2007_StatePlane_Wyoming_West_Central_FIPS_4903','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3705','NAD_1983_NSRS2007_StatePlane_Wyoming_West_FIPS_4904','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3706','NAD_1983_NSRS2007_UTM_Zone_59N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3707','NAD_1983_NSRS2007_UTM_Zone_60N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3708','NAD_1983_NSRS2007_UTM_Zone_1N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3709','NAD_1983_NSRS2007_UTM_Zone_2N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3710','NAD_1983_NSRS2007_UTM_Zone_3N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3711','NAD_1983_NSRS2007_UTM_Zone_4N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3712','NAD_1983_NSRS2007_UTM_Zone_5N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3713','NAD_1983_NSRS2007_UTM_Zone_6N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3714','NAD_1983_NSRS2007_UTM_Zone_7N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3715','NAD_1983_NSRS2007_UTM_Zone_8N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3716','NAD_1983_NSRS2007_UTM_Zone_9N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3717','NAD_1983_NSRS2007_UTM_Zone_10N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3718','NAD_1983_NSRS2007_UTM_Zone_11N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3719','NAD_1983_NSRS2007_UTM_Zone_12N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3720','NAD_1983_NSRS2007_UTM_Zone_13N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3721','NAD_1983_NSRS2007_UTM_Zone_14N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3722','NAD_1983_NSRS2007_UTM_Zone_15N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3723','NAD_1983_NSRS2007_UTM_Zone_16N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3724','NAD_1983_NSRS2007_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3725','NAD_1983_NSRS2007_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3726','NAD_1983_NSRS2007_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3727','Reunion_1947_TM_Reunion','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3728','NAD_1983_NSRS2007_StatePlane_Ohio_North_FIPS_3401_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3729','NAD_1983_NSRS2007_StatePlane_Ohio_South_FIPS_3402_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3730','NAD_1983_NSRS2007_StatePlane_Wyoming_East_FIPS_4901_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3731','NAD_1983_NSRS2007_StatePlane_Wyoming_E_Central_FIPS_4902_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3732','NAD_1983_NSRS2007_StatePlane_Wyoming_W_Central_FIPS_4903_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3733','NAD_1983_NSRS2007_StatePlane_Wyoming_West_FIPS_4904_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3734','NAD_1983_StatePlane_Ohio_North_FIPS_3401_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3735','NAD_1983_StatePlane_Ohio_South_FIPS_3402_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3736','NAD_1983_StatePlane_Wyoming_East_FIPS_4901_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3737','NAD_1983_StatePlane_Wyoming_East_Central_FIPS_4902_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3738','NAD_1983_StatePlane_Wyoming_West_Central_FIPS_4903_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3739','NAD_1983_StatePlane_Wyoming_West_FIPS_4904_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3740','NAD_1983_HARN_UTM_Zone_10N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3741','NAD_1983_HARN_UTM_Zone_11N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3742','NAD_1983_HARN_UTM_Zone_12N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3743','NAD_1983_HARN_UTM_Zone_13N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3744','NAD_1983_HARN_UTM_Zone_14N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3745','NAD_1983_HARN_UTM_Zone_15N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3746','NAD_1983_HARN_UTM_Zone_16N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3747','NAD_1983_HARN_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3748','NAD_1983_HARN_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3749','NAD_1983_HARN_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3750','NAD_1983_HARN_UTM_Zone_4N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3751','NAD_1983_HARN_UTM_Zone_5N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3753','NAD_1983_HARN_StatePlane_Ohio_North_FIPS_3401_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3754','NAD_1983_HARN_StatePlane_Ohio_South_FIPS_3402_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3755','NAD_1983_HARN_StatePlane_Wyoming_East_FIPS_4901_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3756','NAD_1983_HARN_StatePlane_Wyoming_East_Central_FIPS_4902_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3757','NAD_1983_HARN_StatePlane_Wyoming_West_Central_FIPS_4903_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3758','NAD_1983_HARN_StatePlane_Wyoming_West_FIPS_4904_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3759','NAD_1983_StatePlane_Hawaii_3_FIPS_5103_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3760','NAD_1983_HARN_StatePlane_Hawaii_3_FIPS_5103_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3761','NAD_1983_CSRS_UTM_Zone_22N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3762','WGS_1984_South_Georgia_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3763','ETRS_1989_Portugal_TM06','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3764','NZGD_2000_Chatham_Island_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3765','HTRS96_Croatia_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3766','HTRS96_Croatia_LCC','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3767','HTRS96_UTM_Zone_33N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3768','HTRS96_UTM_Zone_34N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3769','Bermuda_1957_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3770','Bermuda_2000_National_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3771','NAD_1927_3TM_111','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3772','NAD_1927_3TM_114','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3773','NAD_1927_3TM_117','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3775','NAD_1983_3TM_111','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3776','NAD_1983_3TM_114','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3777','NAD_1983_3TM_117','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3779','NAD_1983_CSRS_3TM_111','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3780','NAD_1983_CSRS_3TM_114','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3781','NAD_1983_CSRS_3TM_117','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3783','Pitcairn_2006_Pitcairn_TM_2006','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3784','Pitcairn_1967_UTM_Zone_9S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3785','WGS_1984_Web_Mercator','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3788','NZGD_2000_Auckland_Islands_TM_2000','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3789','NZGD_2000_Campbell_Island_TM_2000','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3790','NZGD_2000_Antipodes_Islands_TM_2000','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3791','NZGD_2000_Raoul_Island_TM_2000','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3793','NZGD_2000_Chatham_Islands_TM_2000','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3794','Slovenia_1996_Slovene_National_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3797','NAD_1927_MTQ_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3798','NAD_1983_MTQ_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3799','NAD_1983_CSRS_MTQ_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3800','NAD_1927_3TM_120','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3801','NAD_1983_3TM_120','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3802','NAD_1983_CSRS_3TM_120','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3812','Belge_Lambert_2008','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3814','NAD_1983_Mississippi_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3815','NAD_1983_HARN_Mississippi_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3816','NAD_1983_NSRS2007_Mississippi_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3825','TWD_1997_TM_Penghu','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3826','TWD_1997_TM_Taiwan','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3827','TWD_1967_TM_Penghu','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3828','TWD_1967_TM_Taiwan','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3829','Hu_Tzu_Shan_UTM_Zone_51N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3832','WGS_1984_PDC_Mercator','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3833','Pulkovo_1942_Adj_1958_GK_Zone_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3834','Pulkovo_1942_Adj_1983_GK_Zone_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3835','Pulkovo_1942_Adj_1983_GK_Zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3836','Pulkovo_1942_Adj_1983_GK_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3837','Pulkovo_1942_Adj_1958_3_Degree_GK_Zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3838','Pulkovo_1942_Adj_1958_3_Degree_GK_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3839','Pulkovo_1942_Adj_1958_3_Degree_GK_Zone_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3840','Pulkovo_1942_Adj_1958_3_Degree_GK_Zone_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3841','Pulkovo_1942_Adj_1983_3_Degree_GK_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3844','Pulkovo_1942_Adj_58_Stereo_70','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3845','SWEREF99_RT90_7.5_gon_V_emulation','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3846','SWEREF99_RT90_5_gon_V_emulation','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3847','SWEREF99_RT90_2.5_gon_V_emulation','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3848','SWEREF99_RT90_0_gon_emulation','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3849','SWEREF99_RT90_2.5_gon_O_emulation','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3850','SWEREF99_RT90_5_gon_O_emulation','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3851','NZGD_2000_NZ_Continental_Shelf_2000','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3852','RSRGD2000_DGLC2000','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3854','SWEREF99_County_ST74','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3857','WGS_1984_Web_Mercator_Auxiliary_Sphere','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3873','ETRS_1989_GK19FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3874','ETRS_1989_GK20FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3875','ETRS_1989_GK21FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3876','ETRS_1989_GK22FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3877','ETRS_1989_GK23FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3878','ETRS_1989_GK24FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3879','ETRS_1989_GK25FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3880','ETRS_1989_GK26FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3881','ETRS_1989_GK27FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3882','ETRS_1989_GK28FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3883','ETRS_1989_GK29FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3884','ETRS_1989_GK30FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3885','ETRS_1989_GK31FIN','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3890','IGRS_UTM_Zone_37N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3891','IGRS_UTM_Zone_38N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3892','IGRS_UTM_Zone_39N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3893','ED_1950_Iraq_National_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3907','MGI_1901_Balkans_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3908','MGI_1901_Balkans_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3909','MGI_1901_Balkans_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3910','MGI_1901_Balkans_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3911','MGI_1901_Slovenia_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3912','MGI_1901_Slovene_National_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3920','Puerto_Rico_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3942','RGF_1993_CC42','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3943','RGF_1993_CC43','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3944','RGF_1993_CC44','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3945','RGF_1993_CC45','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3946','RGF_1993_CC46','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3947','RGF_1993_CC47','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3948','RGF_1993_CC48','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3949','RGF_1993_CC49','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3950','RGF_1993_CC50','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3968','NAD_1983_Virginia_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3969','NAD_1983_HARN_Virginia_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3970','NAD_1983_NSRS2007_Virginia_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3973','WGS_1984_EASE_Grid_North','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3974','WGS_1984_EASE_Grid_South','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3975','WGS_1984_EASE_Grid_Global','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3976','WGS_1984_NSIDC_Sea_Ice_Polar_Stereographic_South','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3978','NAD_1983_Canada_Atlas_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3979','NAD_1983_CSRS_Canada_Atlas_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3986','Katanga_1955_Katanga_Gauss_Zone_A','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3987','Katanga_1955_Katanga_Gauss_Zone_B','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3988','Katanga_1955_Katanga_Gauss_Zone_C','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3989','Katanga_1955_Katanga_Gauss_Zone_D','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3991','Puerto_Rico_StatePlane_Puerto_Rico_FIPS_5201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3992','Puerto_Rico_StatePlane_Virgin_Islands_St_Croix_FIPS_5202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3994','WGS_1984_Mercator_41','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3995','WGS_1984_Arctic_Polar_Stereographic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3996','WGS_1984_IBCAO_Polar_Stereographic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','3997','WGS_1984_Dubai_Local_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4026','MOLDREF99_Moldova_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4037','WGS_1984_TMzn35N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4038','WGS_1984_TMzn36N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4048','RGRDC_2005_Congo_TM_Zone_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4049','RGRDC_2005_Congo_TM_Zone_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4050','RGRDC_2005_Congo_TM_Zone_16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4051','RGRDC_2005_Congo_TM_Zone_18','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4056','RGRDC_2005_Congo_TM_Zone_20','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4057','RGRDC_2005_Congo_TM_Zone_22','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4058','RGRDC_2005_Congo_TM_Zone_24','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4059','RGRDC_2005_Congo_TM_Zone_26','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4060','RGRDC_2005_Congo_TM_Zone_28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4061','RGRDC_2005_UTM_Zone_33S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4062','RGRDC_2005_UTM_Zone_34S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4063','RGRDC_2005_UTM_Zone_35S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4071','Chua_UTM_Zone_23S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4082','REGCAN95_UTM_Zone_27N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4083','REGCAN95_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4087','WGS_1984_World_Equidistant_Cylindrical','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4088','World_Equidistant_Cylindrical_(Sphere)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4093','ETRS_1989_DKTM1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4094','ETRS_1989_DKTM2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4095','ETRS_1989_DKTM3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4096','ETRS_1989_DKTM4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4217','NAD_1983_BLM_Zone_59N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4390','Kertau_1968_Johor_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4391','Kertau_1968_Sembilan_and_Melaka_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4392','Kertau_1968_Pahang_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4393','Kertau_1968_Selangor_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4394','Kertau_1968_Terengganu_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4395','Kertau_1968_Pinang_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4396','Kertau_1968_Kedah_and_Perlis_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4397','Kertau_1968_Perak_Revised_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4398','Kertau_1968_Kelantan_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4399','NAD_1927_BLM_Zone_59N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4400','NAD_1927_BLM_Zone_60N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4401','NAD_1927_BLM_Zone_1N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4402','NAD_1927_BLM_Zone_2N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4403','NAD_1927_BLM_Zone_3N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4404','NAD_1927_BLM_Zone_4N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4405','NAD_1927_BLM_Zone_5N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4406','NAD_1927_BLM_Zone_6N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4407','NAD_1927_BLM_Zone_7N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4408','NAD_1927_BLM_Zone_8N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4409','NAD_1927_BLM_Zone_9N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4410','NAD_1927_BLM_Zone_10N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4411','NAD_1927_BLM_Zone_11N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4412','NAD_1927_BLM_Zone_12N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4413','NAD_1927_BLM_Zone_13N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4414','NAD_1983_HARN_Guam_Map_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4415','Katanga_1955_Katanga_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4417','Pulkovo_1942_Adj_1983_3_Degree_GK_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4418','NAD_1927_BLM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4419','NAD_1927_BLM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4420','NAD_1983_BLM_Zone_60N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4421','NAD_1983_BLM_Zone_1N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4422','NAD_1983_BLM_Zone_2N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4423','NAD_1983_BLM_Zone_3N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4424','NAD_1983_BLM_Zone_4N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4425','NAD_1983_BLM_Zone_5N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4426','NAD_1983_BLM_Zone_6N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4427','NAD_1983_BLM_Zone_7N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4428','NAD_1983_BLM_Zone_8N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4429','NAD_1983_BLM_Zone_9N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4430','NAD_1983_BLM_Zone_10N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4431','NAD_1983_BLM_Zone_11N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4432','NAD_1983_BLM_Zone_12N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4433','NAD_1983_BLM_Zone_13N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4434','Pulkovo_1942_Adj_1983_3_Degree_GK_Zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4437','NAD_1983_NSRS2007_StatePlane_Puerto_Rico_Virgin_Isls_FIPS_5200','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4438','NAD_1983_BLM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4439','NAD_1983_BLM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4455','NAD_1927_StatePlane_Pennsylvania_South_FIPS_3702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4456','NAD_1927_StatePlane_New_York_Long_Island_FIPS_3104','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4457','NAD_1983_StatePlane_South_Dakota_North_FIPS_4001_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4462','WGS_1984_Australian_Centre_for_Remote_Sensing_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4467','RGSPM_2006_UTM_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4471','RGM_2004_UTM_Zone_38S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4474','Cadastre_1997_UTM_Zone_38S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4484','Mexican_Datum_1993_UTM_Zone_11N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4485','Mexican_Datum_1993_UTM_Zone_12N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4486','Mexican_Datum_1993_UTM_Zone_13N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4487','Mexican_Datum_1993_UTM_Zone_14N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4488','Mexican_Datum_1993_UTM_Zone_15N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4489','Mexican_Datum_1993_UTM_Zone_16N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4491','CGCS2000_GK_Zone_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4492','CGCS2000_GK_Zone_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4493','CGCS2000_GK_Zone_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4494','CGCS2000_GK_Zone_16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4495','CGCS2000_GK_Zone_17','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4496','CGCS2000_GK_Zone_18','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4497','CGCS2000_GK_Zone_19','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4498','CGCS2000_GK_Zone_20','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4499','CGCS2000_GK_Zone_21','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4500','CGCS2000_GK_Zone_22','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4501','CGCS2000_GK_Zone_23','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4502','CGCS2000_GK_CM_75E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4503','CGCS2000_GK_CM_81E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4504','CGCS2000_GK_CM_87E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4505','CGCS2000_GK_CM_93E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4506','CGCS2000_GK_CM_99E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4507','CGCS2000_GK_CM_105E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4508','CGCS2000_GK_CM_111E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4509','CGCS2000_GK_CM_117E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4510','CGCS2000_GK_CM_123E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4511','CGCS2000_GK_CM_129E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4512','CGCS2000_GK_CM_135E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4513','CGCS2000_3_Degree_GK_Zone_25','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4514','CGCS2000_3_Degree_GK_Zone_26','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4515','CGCS2000_3_Degree_GK_Zone_27','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4516','CGCS2000_3_Degree_GK_Zone_28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4517','CGCS2000_3_Degree_GK_Zone_29','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4518','CGCS2000_3_Degree_GK_Zone_30','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4519','CGCS2000_3_Degree_GK_Zone_31','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4520','CGCS2000_3_Degree_GK_Zone_32','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4521','CGCS2000_3_Degree_GK_Zone_33','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4522','CGCS2000_3_Degree_GK_Zone_34','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4523','CGCS2000_3_Degree_GK_Zone_35','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4524','CGCS2000_3_Degree_GK_Zone_36','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4525','CGCS2000_3_Degree_GK_Zone_37','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4526','CGCS2000_3_Degree_GK_Zone_38','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4527','CGCS2000_3_Degree_GK_Zone_39','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4528','CGCS2000_3_Degree_GK_Zone_40','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4529','CGCS2000_3_Degree_GK_Zone_41','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4530','CGCS2000_3_Degree_GK_Zone_42','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4531','CGCS2000_3_Degree_GK_Zone_43','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4532','CGCS2000_3_Degree_GK_Zone_44','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4533','CGCS2000_3_Degree_GK_Zone_45','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4534','CGCS2000_3_Degree_GK_CM_75E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4535','CGCS2000_3_Degree_GK_CM_78E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4536','CGCS2000_3_Degree_GK_CM_81E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4537','CGCS2000_3_Degree_GK_CM_84E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4538','CGCS2000_3_Degree_GK_CM_87E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4539','CGCS2000_3_Degree_GK_CM_90E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4540','CGCS2000_3_Degree_GK_CM_93E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4541','CGCS2000_3_Degree_GK_CM_96E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4542','CGCS2000_3_Degree_GK_CM_99E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4543','CGCS2000_3_Degree_GK_CM_102E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4544','CGCS2000_3_Degree_GK_CM_105E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4545','CGCS2000_3_Degree_GK_CM_108E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4546','CGCS2000_3_Degree_GK_CM_111E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4547','CGCS2000_3_Degree_GK_CM_114E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4548','CGCS2000_3_Degree_GK_CM_117E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4549','CGCS2000_3_Degree_GK_CM_120E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4550','CGCS2000_3_Degree_GK_CM_123E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4551','CGCS2000_3_Degree_GK_CM_126E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4552','CGCS2000_3_Degree_GK_CM_129E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4553','CGCS2000_3_Degree_GK_CM_132E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4554','CGCS2000_3_Degree_GK_CM_135E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4559','RRAF_1991_UTM_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4568','New_Beijing_Gauss_Kruger_Zone_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4569','New_Beijing_Gauss_Kruger_Zone_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4570','New_Beijing_Gauss_Kruger_Zone_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4571','New_Beijing_Gauss_Kruger_Zone_16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4572','New_Beijing_Gauss_Kruger_Zone_17','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4573','New_Beijing_Gauss_Kruger_Zone_18','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4574','New_Beijing_Gauss_Kruger_Zone_19','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4575','New_Beijing_Gauss_Kruger_Zone_20','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4576','New_Beijing_Gauss_Kruger_Zone_21','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4577','New_Beijing_Gauss_Kruger_Zone_22','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4578','New_Beijing_Gauss_Kruger_Zone_23','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4579','New_Beijing_Gauss_Kruger_CM_75E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4580','New_Beijing_Gauss_Kruger_CM_81E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4581','New_Beijing_Gauss_Kruger_CM_87E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4582','New_Beijing_Gauss_Kruger_CM_93E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4583','New_Beijing_Gauss_Kruger_CM_99E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4584','New_Beijing_Gauss_Kruger_CM_105E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4585','New_Beijing_Gauss_Kruger_CM_111E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4586','New_Beijing_Gauss_Kruger_CM_117E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4587','New_Beijing_Gauss_Kruger_CM_123E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4588','New_Beijing_Gauss_Kruger_CM_129E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4589','New_Beijing_Gauss_Kruger_CM_135E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4647','ETRS_1989_UTM_Zone_N32','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4652','New_Beijing_3_Degree_Gauss_Kruger_Zone_25','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4653','New_Beijing_3_Degree_Gauss_Kruger_Zone_26','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4654','New_Beijing_3_Degree_Gauss_Kruger_Zone_27','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4655','New_Beijing_3_Degree_Gauss_Kruger_Zone_28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4656','New_Beijing_3_Degree_Gauss_Kruger_Zone_29','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4766','New_Beijing_3_Degree_Gauss_Kruger_Zone_30','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4767','New_Beijing_3_Degree_Gauss_Kruger_Zone_31','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4768','New_Beijing_3_Degree_Gauss_Kruger_Zone_32','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4769','New_Beijing_3_Degree_Gauss_Kruger_Zone_33','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4770','New_Beijing_3_Degree_Gauss_Kruger_Zone_34','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4771','New_Beijing_3_Degree_Gauss_Kruger_Zone_35','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4772','New_Beijing_3_Degree_Gauss_Kruger_Zone_36','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4773','New_Beijing_3_Degree_Gauss_Kruger_Zone_37','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4774','New_Beijing_3_Degree_Gauss_Kruger_Zone_38','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4775','New_Beijing_3_Degree_Gauss_Kruger_Zone_39','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4776','New_Beijing_3_Degree_Gauss_Kruger_Zone_40','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4777','New_Beijing_3_Degree_Gauss_Kruger_Zone_41','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4778','New_Beijing_3_Degree_Gauss_Kruger_Zone_42','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4779','New_Beijing_3_Degree_Gauss_Kruger_Zone_43','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4780','New_Beijing_3_Degree_Gauss_Kruger_Zone_44','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4781','New_Beijing_3_Degree_Gauss_Kruger_Zone_45','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4782','New_Beijing_3_Degree_Gauss_Kruger_CM_75E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4783','New_Beijing_3_Degree_Gauss_Kruger_CM_78E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4784','New_Beijing_3_Degree_Gauss_Kruger_CM_81E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4785','New_Beijing_3_Degree_Gauss_Kruger_CM_84E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4786','New_Beijing_3_Degree_Gauss_Kruger_CM_87E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4787','New_Beijing_3_Degree_Gauss_Kruger_CM_90E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4788','New_Beijing_3_Degree_Gauss_Kruger_CM_93E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4789','New_Beijing_3_Degree_Gauss_Kruger_CM_96E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4790','New_Beijing_3_Degree_Gauss_Kruger_CM_99E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4791','New_Beijing_3_Degree_Gauss_Kruger_CM_102E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4792','New_Beijing_3_Degree_Gauss_Kruger_CM_105E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4793','New_Beijing_3_Degree_Gauss_Kruger_CM_108E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4794','New_Beijing_3_Degree_Gauss_Kruger_CM_111E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4795','New_Beijing_3_Degree_Gauss_Kruger_CM_114E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4796','New_Beijing_3_Degree_Gauss_Kruger_CM_117E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4797','New_Beijing_3_Degree_Gauss_Kruger_CM_120E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4798','New_Beijing_3_Degree_Gauss_Kruger_CM_123E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4799','New_Beijing_3_Degree_Gauss_Kruger_CM_126E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4800','New_Beijing_3_Degree_Gauss_Kruger_CM_129E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4822','New_Beijing_3_Degree_Gauss_Kruger_CM_135E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4826','WGS_1984_Cape_Verde_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','4839','ETRS_1989_LCC_Germany_N-E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5014','PTRA08_UTM_Zone_25N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5015','PTRA08_UTM_Zone_26N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5016','PTRA08_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5018','Lisbon_Portuguese_Grid_New','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5048','ETRS_1989_TM35FIN_NE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5069','NAD_1927_Contiguous_USA_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5070','NAD_1983_Contiguous_USA_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5071','NAD_1983_HARN_Contiguous_USA_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5072','NAD_1983_NSRS2007_Contiguous_USA_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5105','ETRS_1989_NTM_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5106','ETRS_1989_NTM_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5107','ETRS_1989_NTM_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5108','ETRS_1989_NTM_Zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5109','ETRS_1989_NTM_Zone_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5110','ETRS_1989_NTM_Zone_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5111','ETRS_1989_NTM_Zone_11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5112','ETRS_1989_NTM_Zone_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5113','ETRS_1989_NTM_Zone_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5114','ETRS_1989_NTM_Zone_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5115','ETRS_1989_NTM_Zone_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5116','ETRS_1989_NTM_Zone_16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5117','ETRS_1989_NTM_Zone_17','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5118','ETRS_1989_NTM_Zone_18','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5119','ETRS_1989_NTM_Zone_19','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5120','ETRS_1989_NTM_Zone_20','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5121','ETRS_1989_NTM_Zone_21','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5122','ETRS_1989_NTM_Zone_22','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5123','ETRS_1989_NTM_Zone_23','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5124','ETRS_1989_NTM_Zone_24','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5125','ETRS_1989_NTM_Zone_25','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5126','ETRS_1989_NTM_Zone_26','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5127','ETRS_1989_NTM_Zone_27','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5128','ETRS_1989_NTM_Zone_28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5129','ETRS_1989_NTM_Zone_29','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5130','ETRS_1989_NTM_Zone_30','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5167','Korean_1985_Korea_East_Sea_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5168','Korean_1985_Korea_Central_Belt_Jeju','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5173','Korean_1985_Modified_Korea_West_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5174','Korean_1985_Modified_Korea_Central_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5175','Korean_1985_Modified_Korea_Central_Belt_Jeju','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5176','Korean_1985_Modified_Korea_East_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5177','Korean_1985_Modified_Korea_East_Sea_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5178','Korean_1985_Korea_Unified_Coordinate_System','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5179','Korea_2000_Korea_Unified_Coordinate_System','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5180','Korea_2000_Korea_West_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5181','Korea_2000_Korea_Central_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5182','Korea_2000_Korea_Central_Belt_Jeju','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5183','Korea_2000_Korea_East_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5184','Korea_2000_Korea_East_Sea_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5185','Korea_2000_Korea_West_Belt_2010','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5186','Korea_2000_Korea_Central_Belt_2010','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5187','Korea_2000_Korea_East_Belt_2010','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5188','Korea_2000_Korea_East_Sea_Belt_2010','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5221','S-JTSK_Ferro_Krovak_East_North','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5223','WGS_1984_UTM_Gabon_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5234','Kandawala_Sri_Lanka_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5235','SLD99_Sri_Lanka_Grid_1999','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5243','ETRS_1989_LCC_Germany_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5247','GDBD2009_GEORSO','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5253','TUREF_TM27','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5254','TUREF_TM30','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5255','TUREF_TM33','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5256','TUREF_TM36','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5257','TUREF_TM39','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5258','TUREF_TM42','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5259','TUREF_TM45','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5266','DRUKREF_03_Bhutan_National_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5269','TUREF_3_Degree_GK_Zone_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5270','TUREF_3_Degree_GK_Zone_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5271','TUREF_3_Degree_GK_Zone_11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5272','TUREF_3_Degree_GK_Zone_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5273','TUREF_3_Degree_GK_Zone_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5274','TUREF_3_Degree_GK_Zone_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5275','TUREF_3_Degree_GK_Zone_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5292','DRUKREF_03_Bumthang_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5293','DRUKREF_03_Chhukha_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5294','DRUKREF_03_Dagana_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5295','DRUKREF_03_Gasa_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5296','DRUKREF_03_Ha_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5297','DRUKREF_03_Lhuentse_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5298','DRUKREF_03_Mongar_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5299','DRUKREF_03_Paro_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5300','DRUKREF_03_Pemagatshel_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5301','DRUKREF_03_Punakha_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5302','DRUKREF_03_Samdrup_Jongkhar_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5303','DRUKREF_03_Samtse_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5304','DRUKREF_03_Sarpang_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5305','DRUKREF_03_Thimphu_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5306','DRUKREF_03_Trashigang_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5307','DRUKREF_03_Trongsa_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5308','DRUKREF_03_Tsirang_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5309','DRUKREF_03_Wangdue_Phodrang_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5310','DRUKREF_03_Yangtse_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5311','DRUKREF_03_Zhemgang_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5316','ETRS_1989_FAROE_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5320','NAD_1983_Teranet_Ontario_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5321','NAD_1983_CSRS_Teranet_Ontario_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5325','ISN_2004_Lambert_2004','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5329','Gunung_Segara_Jakarta_NEIEZ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5330','Batavia_Jakarta_NEIEZ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5331','Makassar_Jakarta_NEIEZ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5337','Aratu_UTM_Zone_25S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5343','POSGAR_2007_Argentina_Zone_1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5344','POSGAR_2007_Argentina_Zone_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5345','POSGAR_2007_Argentina_Zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5346','POSGAR_2007_Argentina_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5347','POSGAR_2007_Argentina_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5348','POSGAR_2007_Argentina_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5349','POSGAR_2007_Argentina_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5355','MARGEN_UTM_Zone_20S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5356','MARGEN_UTM_Zone_19S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5357','MARGEN_UTM_Zone_21S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5361','SIRGAS-Chile_UTM_Zone_19S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5362','SIRGAS-Chile_UTM_Zone_18S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5367','CRTM05','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5382','SIRGAS-ROU98_UTM_Zone_21S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5383','SIRGAS-ROU98_UTM_Zone_22S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5387','Peru96_UTM_Zone_18S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5388','Peru96_UTM_Zone_17S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5389','Peru96_UTM_Zone_19S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5396','SIRGAS_2000_UTM_Zone_26S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5456','Ocotepeque_1935_Costa_Rica_Norte','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5457','Ocotepeque_1935_Costa_Rica_Sur','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5459','Ocotepeque_1935_Guatemala_Sur','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5460','Ocotepeque_1935_El_Salvador_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5461','Ocotepeque_1935_Nicaragua_Norte','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5462','Ocotepeque_1935_Nicaragua_Sur','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5463','SAD_1969_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5469','Panama-Colon_1911_Panama_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5472','Panama-Colon_1911_Panama_Polyconic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5479','RSRGD2000_MSLC2000','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5480','RSRGD2000_BCLC2000','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5481','RSRGD2000_PCLC2000','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5482','RSRGD2000_RSPS2000','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5490','RGAF09_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5513','S-JTSK_Krovak','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5514','S-JTSK_Krovak_East_North','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5518','Chatham_Island_1971_Map_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5519','Chatham_Islands_1979_Map_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5520','DHDN_3_Degree_Gauss_Zone_1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5523','WGS_1984_UTM_Gabon_TM_2011','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5530','SAD_1969_96_Brazil_Polyconic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5531','SAD_1969_96_UTM_Zone_21S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5532','SAD_1969_96_UTM_Zone_22S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5533','SAD_1969_96_UTM_Zone_23S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5534','SAD_1969_96_UTM_Zone_24S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5535','SAD_1969_96_UTM_Zone_25S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5536','Corrego_Alegre_1961_UTM_Zone_21S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5537','Corrego_Alegre_1961_UTM_Zone_22S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5538','Corrego_Alegre_1961_UTM_Zone_23S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5539','Corrego_Alegre_1961_UTM_Zone_24S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5550','PNG94_PNGMG94_Zone_54','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5551','PNG94_PNGMG94_Zone_55','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5552','PNG94_PNGMG94_Zone_56','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5559','Ocotepeque_1935_Guatemala_Norte','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5562','Ukraine_2000_GK_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5563','Ukraine_2000_GK_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5564','Ukraine_2000_GK_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5565','Ukraine_2000_GK_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5566','Ukraine_2000_GK_CM_21E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5567','Ukraine_2000_GK_CM_27E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5568','Ukraine_2000_GK_CM_33E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5569','Ukraine_2000_GK_CM_39E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5570','Ukraine_2000_3_Degree_GK_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5571','Ukraine_2000_3_Degree_GK_Zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5572','Ukraine_2000_3_Degree_GK_Zone_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5573','Ukraine_2000_3_Degree_GK_Zone_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5574','Ukraine_2000_3_Degree_GK_Zone_11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5575','Ukraine_2000_3_Degree_GK_Zone_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5576','Ukraine_2000_3_Degree_GK_Zone_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5577','Ukraine_2000_3_Degree_GK_CM_21E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5578','Ukraine_2000_3_Degree_GK_CM_24E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5579','Ukraine_2000_3_Degree_GK_CM_27E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5580','Ukraine_2000_3_Degree_GK_CM_30E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5581','Ukraine_2000_3_Degree_GK_CM_33E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5582','Ukraine_2000_3_Degree_GK_CM_36E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5583','Ukraine_2000_3_Degree_GK_CM_39E','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5588','NAD_1927_New_Brunswick_Stereographic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5589','Sibun_Gorge_1922_Colony_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5596','FEH2010_Fehmarnbelt_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5623','NAD_1927_StatePlane_Michigan_East_Old_FIPS_2101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5624','NAD_1927_StatePlane_Michigan_Central_Old_FIPS_2102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5625','NAD_1927_StatePlane_Michigan_West_Old_FIPS_2103','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5627','ED_1950_TM_6_NE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5629','Moznet_UTM_Zone_38S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5631','Pulkovo_1942_Adj_1958_GK_Zone_2_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5632','PTRA08_LCC_Europe','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5633','PTRA08_LAEA_Europe','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5634','REGCAN95_LCC_Europe','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5635','REGCAN95_LAEA_Europe','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5636','TUREF_LAEA_Europe','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5637','TUREF_LCC_Europe','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5638','ISN_2004_LAEA_Europe','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5639','ISN_2004_LCC_Europe','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5641','SIRGAS_2000_Brazil_Mercator','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5643','ED_1950_Southern_Permian_Basin_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5644','RGR_1992_UTM_39S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5646','NAD_1983_StatePlane_Vermont_FIPS_4400_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5649','ETRS_1989_UTM_Zone_31N_zE-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5650','ETRS_1989_UTM_Zone_33N_zE-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5651','ETRS_1989_UTM_Zone_31N_N-zE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5652','ETRS_1989_UTM_Zone_32N_N-zE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5653','ETRS_1989_UTM_Zone_33N_N-zE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5654','NAD_1983_HARN_StatePlane_Vermont_FIPS_4400_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5655','NAD_1983_NSRS2007_StatePlane_Vermont_FIPS_4400_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5659','Monte_Mario_TM_Emilia-Romagna','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5663','Pulkovo_1942_Adj_1958_GK_Zone_3_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5664','Pulkovo_1942_Adj_1983_GK_Zone_2_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5665','Pulkovo_1942_Adj_1983_GK_Zone_3_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5666','PD/83_3_Degree_GK_Zone_3_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5667','PD/83_3_Degree_GK_Zone_4_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5668','RD/83_3_Degree_GK_Zone_4_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5669','RD/83_3_Degree_GK_Zone_5_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5670','Pulkovo_1942_Adj_1958_3_Degree_GK_Zone_3_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5671','Pulkovo_1942_Adj_1958_3_Degree_GK_Zone_4_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5672','Pulkovo_1942_Adj_1958_3_Degree_GK_Zone_5_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5673','Pulkovo_1942_Adj_1983_3_Degree_GK_Zone_3_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5674','Pulkovo_1942_Adj_1983_3_Degree_GK_Zone_4_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5675','Pulkovo_1942_Adj_1983_3_Degree_GK_Zone_5_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5676','DHDN_3_Degree_GK_Zone_2_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5677','DHDN_3_Degree_GK_Zone_3_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5678','DHDN_3_Degree_GK_Zone_4_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5679','DHDN_3_Degree_GK_Zone_5_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5680','DHDN_3_Degree_GK_Zone_1_E-N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5682','DB_REF_3-Degree_GK_Zone_2_(E-N)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5683','DB_REF_3-Degree_GK_Zone_3_(E-N)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5684','DB_REF_3-Degree_GK_Zone_4_(E-N)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5685','DB_REF_3-Degree_GK_Zone_5_(E-N)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5700','NZGD_2000_UTM_Zone_1S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5825','AGD_1966_ACT_Standard_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5836','Yemen_NGN_1996_UTM_Zone_37N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5837','Yemen_NGN_1996_UTM_Zone_40N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5839','Peru96_UTM_Zone_17S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5842','WGS_1984_TM_12_SE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5844','RGRDC_2005_Congo_TM_Zone_30','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5858','SAD_1969_96_UTM_Zone_22S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5875','SAD_1969_96_UTM_Zone_18S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5876','SAD_1969_96_UTM_Zone_19S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5877','SAD_1969_96_UTM_Zone_20S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5879','Cadastre_1997_UTM_Zone_38S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5880','SIRGAS_2000_Brazil_Polyconic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5887','TGD2005_Tonga_Map_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5890','JAXA_Snow_Depth_Polar_Stereographic_North','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5921','WGS_1984_EPSG_Arctic_Regional_zone_A1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5922','WGS_1984_EPSG_Arctic_Regional_zone_A2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5923','WGS_1984_EPSG_Arctic_Regional_zone_A3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5924','WGS_1984_EPSG_Arctic_Regional_zone_A4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5925','WGS_1984_EPSG_Arctic_Regional_zone_A5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5926','WGS_1984_EPSG_Arctic_Regional_zone_B1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5927','WGS_1984_EPSG_Arctic_Regional_zone_B2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5928','WGS_1984_EPSG_Arctic_Regional_zone_B3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5929','WGS_1984_EPSG_Arctic_Regional_zone_B4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5930','WGS_1984_EPSG_Arctic_Regional_zone_B5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5931','WGS_1984_EPSG_Arctic_Regional_zone_C1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5932','WGS_1984_EPSG_Arctic_Regional_zone_C2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5933','WGS_1984_EPSG_Arctic_Regional_zone_C3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5934','WGS_1984_EPSG_Arctic_Regional_zone_C4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5935','WGS_1984_EPSG_Arctic_Regional_zone_C5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5936','WGS_1984_EPSG_Alaska_Polar_Stereographic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5937','WGS_1984_EPSG_Canada_Polar_Stereographic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5938','WGS_1984_EPSG_Greenland_Polar_Stereographic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5939','WGS_1984_EPSG_Norway_Polar_Stereographic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','5940','WGS_1984_EPSG_Russia_Polar_Stereographic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6050','GR96_EPSG_Arctic_zone_1-25','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6051','GR96_EPSG_Arctic_zone_2-18','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6052','GR96_EPSG_Arctic_zone_2-20','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6053','GR96_EPSG_Arctic_zone_3-29','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6054','GR96_EPSG_Arctic_zone_3-31','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6055','GR96_EPSG_Arctic_zone_3-33','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6056','GR96_EPSG_Arctic_zone_4-20','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6057','GR96_EPSG_Arctic_zone_4-22','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6058','GR96_EPSG_Arctic_zone_4-24','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6059','GR96_EPSG_Arctic_zone_5-41','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6060','GR96_EPSG_Arctic_zone_5-43','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6061','GR96_EPSG_Arctic_zone_5-45','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6062','GR96_EPSG_Arctic_zone_6-26','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6063','GR96_EPSG_Arctic_zone_6-28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6064','GR96_EPSG_Arctic_zone_6-30','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6065','GR96_EPSG_Arctic_zone_7-11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6066','GR96_EPSG_Arctic_zone_7-13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6067','GR96_EPSG_Arctic_zone_8-20','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6068','GR96_EPSG_Arctic_zone_8-22','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6069','ETRS_1989_EPSG_Arctic_zone_2-22','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6070','ETRS_1989_EPSG_Arctic_zone_3-11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6071','ETRS_1989_EPSG_Arctic_zone_4-26','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6072','ETRS_1989_EPSG_Arctic_zone_4-28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6073','ETRS_1989_EPSG_Arctic_zone_5-11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6074','ETRS_1989_EPSG_Arctic_zone_5-13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6075','WGS_1984_EPSG_Arctic_zone_2-24','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6076','WGS_1984_EPSG_Arctic_zone_2-26','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6077','WGS_1984_EPSG_Arctic_zone_3-13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6078','WGS_1984_EPSG_Arctic_zone_3-15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6079','WGS_1984_EPSG_Arctic_zone_3-17','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6080','WGS_1984_EPSG_Arctic_zone_3-19','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6081','WGS_1984_EPSG_Arctic_zone_4-30','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6082','WGS_1984_EPSG_Arctic_zone_4-32','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6083','WGS_1984_EPSG_Arctic_zone_4-34','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6084','WGS_1984_EPSG_Arctic_zone_4-36','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6085','WGS_1984_EPSG_Arctic_zone_4-38','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6086','WGS_1984_EPSG_Arctic_zone_4-40','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6087','WGS_1984_EPSG_Arctic_zone_5-15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6088','WGS_1984_EPSG_Arctic_zone_5-17','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6089','WGS_1984_EPSG_Arctic_zone_5-19','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6090','WGS_1984_EPSG_Arctic_zone_5-21','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6091','WGS_1984_EPSG_Arctic_zone_5-23','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6092','WGS_1984_EPSG_Arctic_zone_5-25','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6093','WGS_1984_EPSG_Arctic_zone_5-27','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6094','NAD_1983_NSRS2007_EPSG_Arctic_zone_5-29','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6095','NAD_1983_NSRS2007_EPSG_Arctic_zone_5-31','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6096','NAD_1983_NSRS2007_EPSG_Arctic_zone_6-14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6097','NAD_1983_NSRS2007_EPSG_Arctic_zone_6-16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6098','NAD_1983_CSRS_EPSG_Arctic_zone_1-23','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6099','NAD_1983_CSRS_EPSG_Arctic_zone_2-14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6100','NAD_1983_CSRS_EPSG_Arctic_zone_2-16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6101','NAD_1983_CSRS_EPSG_Arctic_zone_3-25','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6102','NAD_1983_CSRS_EPSG_Arctic_zone_3-27','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6103','NAD_1983_CSRS_EPSG_Arctic_zone_3-29','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6104','NAD_1983_CSRS_EPSG_Arctic_zone_4-14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6105','NAD_1983_CSRS_EPSG_Arctic_zone_4-16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6106','NAD_1983_CSRS_EPSG_Arctic_zone_4-18','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6107','NAD_1983_CSRS_EPSG_Arctic_zone_5-33','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6108','NAD_1983_CSRS_EPSG_Arctic_zone_5-35','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6109','NAD_1983_CSRS_EPSG_Arctic_zone_5-37','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6110','NAD_1983_CSRS_EPSG_Arctic_zone_5-39','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6111','NAD_1983_CSRS_EPSG_Arctic_zone_6-18','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6112','NAD_1983_CSRS_EPSG_Arctic_zone_6-20','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6113','NAD_1983_CSRS_EPSG_Arctic_zone_6-22','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6114','NAD_1983_CSRS_EPSG_Arctic_zone_6-24','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6115','WGS_1984_EPSG_Arctic_zone_1-27','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6116','WGS_1984_EPSG_Arctic_zone_1-29','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6117','WGS_1984_EPSG_Arctic_zone_1-31','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6118','WGS_1984_EPSG_Arctic_zone_1-21','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6119','WGS_1984_EPSG_Arctic_zone_2-28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6120','WGS_1984_EPSG_Arctic_zone_2-10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6121','WGS_1984_EPSG_Arctic_zone_2-12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6122','WGS_1984_EPSG_Arctic_zone_3-21','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6123','WGS_1984_EPSG_Arctic_zone_3-23','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6124','WGS_1984_EPSG_Arctic_zone_4-12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6125','ETRS_1989_EPSG_Arctic_zone_5-47','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6128','Grand_Cayman_National_Grid_1959','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6129','Sister_Islands_National_Grid_1961','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6141','Cayman_Islands_National_Grid_2011','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6204','Macedonian_State_Coordinate_System','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6210','SIRGAS_2000_UTM_Zone_23N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6211','SIRGAS_2000_UTM_Zone_24N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6244','MAGNA_Arauca_2007','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6245','MAGNA_Armenia_Quindio_2006','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6246','MAGNA_Barranquilla_Atlantico_1997','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6247','MAGNA_Bogota_DC_2005','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6248','MAGNA_Bucaramanga_Santander_2008','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6249','MAGNA_Cali_Valle_del_Cauca_2009','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6250','MAGNA_Cartagena_Bolivar_2005','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6251','MAGNA_Cucuta_Norte_de_Santander_2011','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6252','MAGNA_Florencia_Caqueta_2007','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6253','MAGNA_Ibague_Tolima_2007','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6254','MAGNA_Inirida_Guainia_2008','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6255','MAGNA_Leticia_Amazonas_1994','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6256','MAGNA_Manizales_Caldas_2011','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6257','MAGNA_Medellin_Antioquia_2010','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6258','MAGNA_Mitu_Vaupes_2011','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6259','MAGNA_Mocoa_Putumayo_2011','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6260','MAGNA_Monteria_Cordoba_2006','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6261','MAGNA_Neiva_Huila_2006','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6262','MAGNA_Pasto_Narino_2008','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6263','MAGNA_Pereira_Risaralda_2007','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6264','MAGNA_Popayan_Cauca_2006','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6265','MAGNA_Puerto_Carreno_Vichada_2011','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6266','MAGNA_Quibdo_Choco_2011','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6267','MAGNA_Riohacha_La_Guajira_2006','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6268','MAGNA_San_Andres_2007','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6269','MAGNA_San_Jose_del_Guaviare_2011','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6270','MAGNA_Santa_Marta_Magdalena_2007','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6271','MAGNA_Sucre_2006','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6272','MAGNA_Tunja_Boyaca_1997','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6273','MAGNA_Valledupar_Cesar_2011','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6274','MAGNA_Villavicencio_Meta_2011','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6275','MAGNA_Yopal_Casanare_2006','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6307','NAD_1983_CORS96_SPCS_Puerto_Rico_and_Virgin_Islands','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6312','CGRS_1993_Cyprus_Local_Transverse_Mercator','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6316','Macedonia_State_Coordinate_System_zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6328','NAD_1983_2011_UTM_Zone_59N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6329','NAD_1983_2011_UTM_Zone_60N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6330','NAD_1983_2011_UTM_Zone_1N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6331','NAD_1983_2011_UTM_Zone_2N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6332','NAD_1983_2011_UTM_Zone_3N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6333','NAD_1983_2011_UTM_Zone_4N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6334','NAD_1983_2011_UTM_Zone_5N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6335','NAD_1983_2011_UTM_Zone_6N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6336','NAD_1983_2011_UTM_Zone_7N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6337','NAD_1983_2011_UTM_Zone_8N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6338','NAD_1983_2011_UTM_Zone_9N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6339','NAD_1983_2011_UTM_Zone_10N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6340','NAD_1983_2011_UTM_Zone_11N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6341','NAD_1983_2011_UTM_Zone_12N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6342','NAD_1983_2011_UTM_Zone_13N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6343','NAD_1983_2011_UTM_Zone_14N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6344','NAD_1983_2011_UTM_Zone_15N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6345','NAD_1983_2011_UTM_Zone_16N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6346','NAD_1983_2011_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6347','NAD_1983_2011_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6348','NAD_1983_2011_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6350','NAD_1983_2011_Contiguous_USA_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6351','NAD_1983_2011_EPSG_Arctic_zone_5-29','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6352','NAD_1983_2011_EPSG_Arctic_zone_5-31','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6353','NAD_1983_2011_EPSG_Arctic_zone_6-14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6354','NAD_1983_2011_EPSG_Arctic_zone_6-16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6355','NAD_1983_2011_StatePlane_Alabama_East_FIPS_0101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6356','NAD_1983_2011_StatePlane_Alabama_West_FIPS_0102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6362','Mexico_ITRF92_LCC','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6366','Mexico_ITRF2008_UTM_Zone_11N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6367','Mexico_ITRF2008_UTM_Zone_12N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6368','Mexico_ITRF2008_UTM_Zone_13N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6369','Mexico_ITRF2008_UTM_Zone_14N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6370','Mexico_ITRF2008_UTM_Zone_15N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6371','Mexico_ITRF2008_UTM_Zone_16N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6372','Mexico_ITRF2008_LCC','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6381','Ukraine_2000_TM_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6382','Ukraine_2000_TM_Zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6383','Ukraine_2000_TM_Zone_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6384','Ukraine_2000_TM_Zone_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6385','Ukraine_2000_TM_Zone_11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6386','Ukraine_2000_TM_Zone_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6387','Ukraine_2000_TM_Zone_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6391','Cayman_Islands_National_Grid_2011','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6393','NAD_1983_2011_Alaska_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6394','NAD_1983_2011_StatePlane_Alaska_1_FIPS_5001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6395','NAD_1983_2011_StatePlane_Alaska_2_FIPS_5002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6396','NAD_1983_2011_StatePlane_Alaska_3_FIPS_5003','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6397','NAD_1983_2011_StatePlane_Alaska_4_FIPS_5004','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6398','NAD_1983_2011_StatePlane_Alaska_5_FIPS_5005','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6399','NAD_1983_2011_StatePlane_Alaska_6_FIPS_5006','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6400','NAD_1983_2011_StatePlane_Alaska_7_FIPS_5007','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6401','NAD_1983_2011_StatePlane_Alaska_8_FIPS_5008','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6402','NAD_1983_2011_StatePlane_Alaska_9_FIPS_5009','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6403','NAD_1983_2011_StatePlane_Alaska_10_FIPS_5010','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6404','NAD_1983_2011_StatePlane_Arizona_Central_FIPS_0202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6405','NAD_1983_2011_StatePlane_Arizona_Central_FIPS_0202_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6406','NAD_1983_2011_StatePlane_Arizona_East_FIPS_0201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6407','NAD_1983_2011_StatePlane_Arizona_East_FIPS_0201_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6408','NAD_1983_2011_StatePlane_Arizona_West_FIPS_0203','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6409','NAD_1983_2011_StatePlane_Arizona_West_FIPS_0203_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6410','NAD_1983_2011_StatePlane_Arkansas_North_FIPS_0301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6411','NAD_1983_2011_StatePlane_Arkansas_North_FIPS_0301_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6412','NAD_1983_2011_StatePlane_Arkansas_South_FIPS_0302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6413','NAD_1983_2011_StatePlane_Arkansas_South_FIPS_0302_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6414','NAD_1983_2011_California_Teale_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6415','NAD_1983_2011_StatePlane_California_I_FIPS_0401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6416','NAD_1983_2011_StatePlane_California_I_FIPS_0401_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6417','NAD_1983_2011_StatePlane_California_II_FIPS_0402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6418','NAD_1983_2011_StatePlane_California_II_FIPS_0402_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6419','NAD_1983_2011_StatePlane_California_III_FIPS_0403','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6420','NAD_1983_2011_StatePlane_California_III_FIPS_0403_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6421','NAD_1983_2011_StatePlane_California_IV_FIPS_0404','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6422','NAD_1983_2011_StatePlane_California_IV_FIPS_0404_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6423','NAD_1983_2011_StatePlane_California_V_FIPS_0405','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6424','NAD_1983_2011_StatePlane_California_V_FIPS_0405_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6425','NAD_1983_2011_StatePlane_California_VI_FIPS_0406','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6426','NAD_1983_2011_StatePlane_California_VI_FIPS_0406_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6427','NAD_1983_2011_StatePlane_Colorado_Central_FIPS_0502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6428','NAD_1983_2011_StatePlane_Colorado_Central_FIPS_0502_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6429','NAD_1983_2011_StatePlane_Colorado_North_FIPS_0501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6430','NAD_1983_2011_StatePlane_Colorado_North_FIPS_0501_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6431','NAD_1983_2011_StatePlane_Colorado_South_FIPS_0503','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6432','NAD_1983_2011_StatePlane_Colorado_South_FIPS_0503_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6433','NAD_1983_2011_StatePlane_Connecticut_FIPS_0600','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6434','NAD_1983_2011_StatePlane_Connecticut_FIPS_0600_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6435','NAD_1983_2011_StatePlane_Delaware_FIPS_0700','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6436','NAD_1983_2011_StatePlane_Delaware_FIPS_0700_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6437','NAD_1983_2011_StatePlane_Florida_East_FIPS_0901','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6438','NAD_1983_2011_StatePlane_Florida_East_FIPS_0901_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6439','NAD_1983_2011_Florida_GDL_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6440','NAD_1983_2011_StatePlane_Florida_North_FIPS_0903','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6441','NAD_1983_2011_StatePlane_Florida_North_FIPS_0903_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6442','NAD_1983_2011_StatePlane_Florida_West_FIPS_0902','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6443','NAD_1983_2011_StatePlane_Florida_West_FIPS_0902_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6444','NAD_1983_2011_StatePlane_Georgia_East_FIPS_1001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6445','NAD_1983_2011_StatePlane_Georgia_East_FIPS_1001_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6446','NAD_1983_2011_StatePlane_Georgia_West_FIPS_1002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6447','NAD_1983_2011_StatePlane_Georgia_West_FIPS_1002_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6448','NAD_1983_2011_StatePlane_Idaho_Central_FIPS_1102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6449','NAD_1983_2011_StatePlane_Idaho_Central_FIPS_1102_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6450','NAD_1983_2011_StatePlane_Idaho_East_FIPS_1101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6451','NAD_1983_2011_StatePlane_Idaho_East_FIPS_1101_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6452','NAD_1983_2011_StatePlane_Idaho_West_FIPS_1103','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6453','NAD_1983_2011_StatePlane_Idaho_West_FIPS_1103_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6454','NAD_1983_2011_StatePlane_Illinois_East_FIPS_1201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6455','NAD_1983_2011_StatePlane_Illinois_East_FIPS_1201_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6456','NAD_1983_2011_StatePlane_Illinois_West_FIPS_1202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6457','NAD_1983_2011_StatePlane_Illinois_West_FIPS_1202_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6458','NAD_1983_2011_StatePlane_Indiana_East_FIPS_1301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6459','NAD_1983_2011_StatePlane_Indiana_East_FIPS_1301_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6460','NAD_1983_2011_StatePlane_Indiana_West_FIPS_1302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6461','NAD_1983_2011_StatePlane_Indiana_West_FIPS_1302_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6462','NAD_1983_2011_StatePlane_Iowa_North_FIPS_1401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6463','NAD_1983_2011_StatePlane_Iowa_North_FIPS_1401_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6464','NAD_1983_2011_StatePlane_Iowa_South_FIPS_1402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6465','NAD_1983_2011_StatePlane_Iowa_South_FIPS_1402_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6466','NAD_1983_2011_StatePlane_Kansas_North_FIPS_1501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6467','NAD_1983_2011_StatePlane_Kansas_North_FIPS_1501_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6468','NAD_1983_2011_StatePlane_Kansas_South_FIPS_1502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6469','NAD_1983_2011_StatePlane_Kansas_South_FIPS_1502_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6470','NAD_1983_2011_StatePlane_Kentucky_North_FIPS_1601','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6471','NAD_1983_2011_StatePlane_Kentucky_North_FIPS_1601_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6472','NAD_1983_2011_StatePlane_Kentucky_FIPS_1600','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6473','NAD_1983_2011_StatePlane_Kentucky_FIPS_1600_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6474','NAD_1983_2011_StatePlane_Kentucky_South_FIPS_1602','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6475','NAD_1983_2011_StatePlane_Kentucky_South_FIPS_1602_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6476','NAD_1983_2011_StatePlane_Louisiana_North_FIPS_1701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6477','NAD_1983_2011_StatePlane_Louisiana_North_FIPS_1701_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6478','NAD_1983_2011_StatePlane_Louisiana_South_FIPS_1702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6479','NAD_1983_2011_StatePlane_Louisiana_South_FIPS_1702_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6480','NAD_1983_2011_Maine_2000_Central_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6481','NAD_1983_2011_Maine_2000_East_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6482','NAD_1983_2011_Maine_2000_West_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6483','NAD_1983_2011_StatePlane_Maine_East_FIPS_1801','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6484','NAD_1983_2011_StatePlane_Maine_East_FIPS_1801_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6485','NAD_1983_2011_StatePlane_Maine_West_FIPS_1802','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6486','NAD_1983_2011_StatePlane_Maine_West_FIPS_1802_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6487','NAD_1983_2011_StatePlane_Maryland_FIPS_1900','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6488','NAD_1983_2011_StatePlane_Maryland_FIPS_1900_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6489','NAD_1983_2011_StatePlane_Massachusetts_Island_FIPS_2002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6490','NAD_1983_2011_StatePlane_Massachusetts_Isl_FIPS_2002_FtUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6491','NAD_1983_2011_StatePlane_Massachusetts_Mainland_FIPS_2001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6492','NAD_1983_2011_StatePlane_Massachusetts_Mnld_FIPS_2001_FtUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6493','NAD_1983_2011_StatePlane_Michigan_Central_FIPS_2112','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6494','NAD_1983_2011_StatePlane_Michigan_Central_FIPS_2112_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6495','NAD_1983_2011_StatePlane_Michigan_North_FIPS_2111','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6496','NAD_1983_2011_StatePlane_Michigan_North_FIPS_2111_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6497','NAD_1983_2011_Michigan_GeoRef_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6498','NAD_1983_2011_StatePlane_Michigan_South_FIPS_2113','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6499','NAD_1983_2011_StatePlane_Michigan_South_FIPS_2113_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6500','NAD_1983_2011_StatePlane_Minnesota_Central_FIPS_2202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6501','NAD_1983_2011_StatePlane_Minnesota_Central_FIPS_2202_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6502','NAD_1983_2011_StatePlane_Minnesota_North_FIPS_2201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6503','NAD_1983_2011_StatePlane_Minnesota_North_FIPS_2201_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6504','NAD_1983_2011_StatePlane_Minnesota_South_FIPS_2203','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6505','NAD_1983_2011_StatePlane_Minnesota_South_FIPS_2203_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6506','NAD_1983_2011_StatePlane_Mississippi_East_FIPS_2301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6507','NAD_1983_2011_StatePlane_Mississippi_East_FIPS_2301_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6508','NAD_1983_2011_Mississippi_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6509','NAD_1983_2011_StatePlane_Mississippi_West_FIPS_2302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6510','NAD_1983_2011_StatePlane_Mississippi_West_FIPS_2302_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6511','NAD_1983_2011_StatePlane_Missouri_Central_FIPS_2402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6512','NAD_1983_2011_StatePlane_Missouri_East_FIPS_2401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6513','NAD_1983_2011_StatePlane_Missouri_West_FIPS_2403','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6514','NAD_1983_2011_StatePlane_Montana_FIPS_2500','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6515','NAD_1983_2011_StatePlane_Montana_FIPS_2500_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6516','NAD_1983_2011_StatePlane_Nebraska_FIPS_2600','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6518','NAD_1983_2011_StatePlane_Nevada_Central_FIPS_2702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6519','NAD_1983_2011_StatePlane_Nevada_Central_FIPS_2702_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6520','NAD_1983_2011_StatePlane_Nevada_East_FIPS_2701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6521','NAD_1983_2011_StatePlane_Nevada_East_FIPS_2701_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6522','NAD_1983_2011_StatePlane_Nevada_West_FIPS_2703','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6523','NAD_1983_2011_StatePlane_Nevada_West_FIPS_2703_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6524','NAD_1983_2011_StatePlane_New_Hampshire_FIPS_2800','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6525','NAD_1983_2011_StatePlane_New_Hampshire_FIPS_2800_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6526','NAD_1983_2011_StatePlane_New_Jersey_FIPS_2900','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6527','NAD_1983_2011_StatePlane_New_Jersey_FIPS_2900_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6528','NAD_1983_2011_StatePlane_New_Mexico_Central_FIPS_3002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6529','NAD_1983_2011_StatePlane_New_Mexico_Central_FIPS_3002_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6530','NAD_1983_2011_StatePlane_New_Mexico_East_FIPS_3001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6531','NAD_1983_2011_StatePlane_New_Mexico_East_FIPS_3001_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6532','NAD_1983_2011_StatePlane_New_Mexico_West_FIPS_3003','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6533','NAD_1983_2011_StatePlane_New_Mexico_West_FIPS_3003_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6534','NAD_1983_2011_StatePlane_New_York_Central_FIPS_3102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6535','NAD_1983_2011_StatePlane_New_York_Central_FIPS_3102_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6536','NAD_1983_2011_StatePlane_New_York_East_FIPS_3101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6537','NAD_1983_2011_StatePlane_New_York_East_FIPS_3101_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6538','NAD_1983_2011_StatePlane_New_York_Long_Island_FIPS_3104','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6539','NAD_1983_2011_StatePlane_New_York_Long_Isl_FIPS_3104_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6540','NAD_1983_2011_StatePlane_New_York_West_FIPS_3103','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6541','NAD_1983_2011_StatePlane_New_York_West_FIPS_3103_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6542','NAD_1983_2011_StatePlane_North_Carolina_FIPS_3200','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6543','NAD_1983_2011_StatePlane_North_Carolina_FIPS_3200_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6544','NAD_1983_2011_StatePlane_North_Dakota_North_FIPS_3301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6545','NAD_1983_2011_StatePlane_North_Dakota_North_FIPS_3301_FtI','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6546','NAD_1983_2011_StatePlane_North_Dakota_South_FIPS_3302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6547','NAD_1983_2011_StatePlane_North_Dakota_South_FIPS_3302_FtI','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6548','NAD_1983_2011_StatePlane_Ohio_North_FIPS_3401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6549','NAD_1983_2011_StatePlane_Ohio_North_FIPS_3401_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6550','NAD_1983_2011_StatePlane_Ohio_South_FIPS_3402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6551','NAD_1983_2011_StatePlane_Ohio_South_FIPS_3402_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6552','NAD_1983_2011_StatePlane_Oklahoma_North_FIPS_3501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6553','NAD_1983_2011_StatePlane_Oklahoma_North_FIPS_3501_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6554','NAD_1983_2011_StatePlane_Oklahoma_South_FIPS_3502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6555','NAD_1983_2011_StatePlane_Oklahoma_South_FIPS_3502_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6556','NAD_1983_2011_Oregon_Statewide_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6557','NAD_1983_2011_Oregon_Statewide_Lambert_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6558','NAD_1983_2011_StatePlane_Oregon_North_FIPS_3601','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6559','NAD_1983_2011_StatePlane_Oregon_North_FIPS_3601_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6560','NAD_1983_2011_StatePlane_Oregon_South_FIPS_3602','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6561','NAD_1983_2011_StatePlane_Oregon_South_FIPS_3602_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6562','NAD_1983_2011_StatePlane_Pennsylvania_North_FIPS_3701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6563','NAD_1983_2011_StatePlane_Pennsylvania_North_FIPS_3701_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6564','NAD_1983_2011_StatePlane_Pennsylvania_South_FIPS_3702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6565','NAD_1983_2011_StatePlane_Pennsylvania_South_FIPS_3702_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6566','NAD_1983_2011_StatePlane_Puerto_Rico_Virgin_Isls_FIPS_5200','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6567','NAD_1983_2011_StatePlane_Rhode_Island_FIPS_3800','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6568','NAD_1983_2011_StatePlane_Rhode_Island_FIPS_3800_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6569','NAD_1983_2011_StatePlane_South_Carolina_FIPS_3900','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6570','NAD_1983_2011_StatePlane_South_Carolina_FIPS_3900_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6571','NAD_1983_2011_StatePlane_South_Dakota_North_FIPS_4001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6572','NAD_1983_2011_StatePlane_South_Dakota_North_FIPS_4001_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6573','NAD_1983_2011_StatePlane_South_Dakota_South_FIPS_4002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6574','NAD_1983_2011_StatePlane_South_Dakota_South_FIPS_4002_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6575','NAD_1983_2011_StatePlane_Tennessee_FIPS_4100','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6576','NAD_1983_2011_StatePlane_Tennessee_FIPS_4100_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6577','NAD_1983_2011_StatePlane_Texas_Central_FIPS_4203','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6578','NAD_1983_2011_StatePlane_Texas_Central_FIPS_4203_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6579','NAD_1983_2011_Texas_Centric_Mapping_System_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6580','NAD_1983_2011_Texas_Centric_Mapping_System_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6581','NAD_1983_2011_StatePlane_Texas_North_FIPS_4201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6582','NAD_1983_2011_StatePlane_Texas_North_FIPS_4201_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6583','NAD_1983_2011_StatePlane_Texas_North_Central_FIPS_4202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6584','NAD_1983_2011_StatePlane_Texas_North_Central_FIPS_4202_FtUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6585','NAD_1983_2011_StatePlane_Texas_South_FIPS_4205','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6586','NAD_1983_2011_StatePlane_Texas_South_FIPS_4205_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6587','NAD_1983_2011_StatePlane_Texas_South_Central_FIPS_4204','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6588','NAD_1983_2011_StatePlane_Texas_South_Central_FIPS_4204_FtUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6589','NAD_1983_2011_StatePlane_Vermont_FIPS_4400','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6590','NAD_1983_2011_StatePlane_Vermont_FIPS_4400_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6591','NAD_1983_2011_Virginia_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6592','NAD_1983_2011_StatePlane_Virginia_North_FIPS_4501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6593','NAD_1983_2011_StatePlane_Virginia_North_FIPS_4501_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6594','NAD_1983_2011_StatePlane_Virginia_South_FIPS_4502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6595','NAD_1983_2011_StatePlane_Virginia_South_FIPS_4502_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6596','NAD_1983_2011_StatePlane_Washington_North_FIPS_4601','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6597','NAD_1983_2011_StatePlane_Washington_North_FIPS_4601_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6598','NAD_1983_2011_StatePlane_Washington_South_FIPS_4602','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6599','NAD_1983_2011_StatePlane_Washington_South_FIPS_4602_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6600','NAD_1983_2011_StatePlane_West_Virginia_North_FIPS_4701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6601','NAD_1983_2011_StatePlane_West_Virginia_North_FIPS_4701_FtUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6602','NAD_1983_2011_StatePlane_West_Virginia_South_FIPS_4702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6603','NAD_1983_2011_StatePlane_West_Virginia_South_FIPS_4702_FtUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6605','NAD_1983_2011_StatePlane_Wisconsin_Central_FIPS_4802_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6606','NAD_1983_2011_StatePlane_Wisconsin_North_FIPS_4801','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6607','NAD_1983_2011_StatePlane_Wisconsin_North_FIPS_4801_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6608','NAD_1983_2011_StatePlane_Wisconsin_South_FIPS_4803','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6609','NAD_1983_2011_StatePlane_Wisconsin_South_FIPS_4803_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6610','NAD_1983_2011_Wisconsin_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6611','NAD_1983_2011_StatePlane_Wyoming_East_FIPS_4901','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6612','NAD_1983_2011_StatePlane_Wyoming_East_FIPS_4901_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6613','NAD_1983_2011_StatePlane_Wyoming_East_Central_FIPS_4902','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6614','NAD_1983_2011_StatePlane_Wyoming_E_Central_FIPS_4902_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6615','NAD_1983_2011_StatePlane_Wyoming_West_FIPS_4904','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6616','NAD_1983_2011_StatePlane_Wyoming_West_FIPS_4904_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6617','NAD_1983_2011_StatePlane_Wyoming_West_Central_FIPS_4903','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6618','NAD_1983_2011_StatePlane_Wyoming_W_Central_FIPS_4903_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6619','NAD_1983_2011_StatePlane_Utah_Central_FIPS_4302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6620','NAD_1983_2011_StatePlane_Utah_North_FIPS_4301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6621','NAD_1983_2011_StatePlane_Utah_South_FIPS_4303','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6622','NAD_1983_CSRS_Quebec_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6623','NAD_1983_Quebec_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6624','NAD_1983_CSRS_Quebec_Albers','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6625','NAD_1983_2011_StatePlane_Utah_Central_FIPS_4302_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6626','NAD_1983_2011_StatePlane_Utah_North_FIPS_4301_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6627','NAD_1983_2011_StatePlane_Utah_South_FIPS_4303_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6628','NAD_1983_PA11_StatePlane_Hawaii_1_FIPS_5101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6629','NAD_1983_PA11_StatePlane_Hawaii_2_FIPS_5102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6630','NAD_1983_PA11_StatePlane_Hawaii_3_FIPS_5103','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6631','NAD_1983_PA11_StatePlane_Hawaii_4_FIPS_5104','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6632','NAD_1983_PA11_StatePlane_Hawaii_5_FIPS_5105','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6633','NAD_1983_PA11_StatePlane_Hawaii_3_FIPS_5103_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6634','NAD_1983_PA11_UTM_Zone_4N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6635','NAD_1983_PA11_UTM_Zone_5N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6636','NAD_1983_PA11_UTM_Zone_2S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6637','NAD_1983_MA11_Guam_Map_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6646','Karbala_1979_Iraq_National_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6669','JGD_2011_Japan_Zone_1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6670','JGD_2011_Japan_Zone_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6671','JGD_2011_Japan_Zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6672','JGD_2011_Japan_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6673','JGD_2011_Japan_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6674','JGD_2011_Japan_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6675','JGD_2011_Japan_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6676','JGD_2011_Japan_Zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6677','JGD_2011_Japan_Zone_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6678','JGD_2011_Japan_Zone_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6679','JGD_2011_Japan_Zone_11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6680','JGD_2011_Japan_Zone_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6681','JGD_2011_Japan_Zone_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6682','JGD_2011_Japan_Zone_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6683','JGD_2011_Japan_Zone_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6684','JGD_2011_Japan_Zone_16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6685','JGD_2011_Japan_Zone_17','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6686','JGD_2011_Japan_Zone_18','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6687','JGD_2011_Japan_Zone_19','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6688','JGD_2011_UTM_Zone_51N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6689','JGD_2011_UTM_Zone_52N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6690','JGD_2011_UTM_Zone_53N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6691','JGD_2011_UTM_Zone_54N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6692','JGD_2011_UTM_Zone_55N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6703','WGS_1984_TM_60_SW','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6707','RDN2008_TM32','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6708','RDN2008_TM33','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6709','RDN2008_TM34','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6720','WGS_1984_CIG92','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6721','GDA_1994_CIG94','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6722','WGS_1984_CKIG92','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6723','GDA_1994_CKIG94','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6732','GDA_1994_MGA_zone_41','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6733','GDA_1994_MGA_zone_42','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6734','GDA_1994_MGA_zone_43','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6735','GDA_1994_MGA_zone_44','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6736','GDA_1994_MGA_Zone_46','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6737','GDA_1994_MGA_Zone_47','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6738','GDA_1994_MGA_Zone_59','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6784','OCRS_Baker_NAD_1983_CORS96_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6785','OCRS_Baker_NAD_1983_CORS96_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6786','OCRS_Baker_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6787','OCRS_Baker_NAD_1983_2011_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6788','OCRS_Bend-Klamath_Falls_NAD_1983_CORS96_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6789','OCRS_Bend-Klamath_Falls_NAD_1983_CORS96_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6790','OCRS_Bend-Klamath_Falls_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6791','OCRS_Bend-Klamath_Falls_NAD_1983_2011_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6792','OCRS_Bend-Redmond-Prineville_NAD_1983_CORS96_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6793','OCRS_Bend-Redmond-Prineville_NAD_1983_CORS96_LCC_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6794','OCRS_Bend-Redmond-Prineville_NAD_1983_2011_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6795','OCRS_Bend-Redmond-Prineville_NAD_1983_2011_LCC_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6796','OCRS_Bend-Burns_NAD_1983_CORS96_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6797','OCRS_Bend-Burns_NAD_1983_CORS96_LCC_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6798','OCRS_Bend-Burns_NAD_1983_2011_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6799','OCRS_Bend-Burns_NAD_1983_2011_LCC_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6800','OCRS_Canyonville-Grants_Pass_NAD_1983_CORS96_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6801','OCRS_Canyonville-Grants_Pass_NAD_1983_CORS96_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6802','OCRS_Canyonville-Grants_Pass_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6803','OCRS_Canyonville-Grants_Pass_NAD_1983_2011_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6804','OCRS_Columbia_River_East_NAD_1983_CORS96_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6805','OCRS_Columbia_River_East_NAD_1983_CORS96_LCC_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6806','OCRS_Columbia_River_East_NAD_1983_2011_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6807','OCRS_Columbia_River_East_NAD_1983_2011_LCC_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6808','OCRS_Columbia_River_West_NAD_1983_CORS96_OM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6809','OCRS_Columbia_River_West_NAD_1983_CORS96_OM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6810','OCRS_Columbia_River_West_NAD_1983_2011_OM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6811','OCRS_Columbia_River_West_NAD_1983_2011_OM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6812','OCRS_Cottage_Grove-Canyonville_NAD_1983_CORS96_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6813','OCRS_Cottage_Grove-Canyonville_NAD_1983_CORS96_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6814','OCRS_Cottage_Grove-Canyonville_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6815','OCRS_Cottage_Grove-Canyonville_NAD_1983_2011_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6816','OCRS_Dufur-Madras_NAD_1983_CORS96_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6817','OCRS_Dufur-Madras_NAD_1983_CORS96_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6818','OCRS_Dufur-Madras_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6819','OCRS_Dufur-Madras_NAD_1983_2011_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6820','OCRS_Eugene_NAD_1983_CORS96_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6821','OCRS_Eugene_NAD_1983_CORS96_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6822','OCRS_Eugene_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6823','OCRS_Eugene_NAD_1983_2011_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6824','OCRS_Grants_Pass-Ashland_NAD_1983_CORS96_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6825','OCRS_Grants_Pass-Ashland_NAD_1983_CORS96_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6826','OCRS_Grants_Pass-Ashland_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6827','OCRS_Grants_Pass-Ashland_NAD_1983_2011_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6828','OCRS_Gresham-Warm_Springs_NAD_1983_CORS96_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6829','OCRS_Gresham-Warm_Springs_NAD_1983_CORS96_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6830','OCRS_Gresham-Warm_Springs_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6831','OCRS_Gresham-Warm_Springs_NAD_1983_2011_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6832','OCRS_La_Grande_NAD_1983_CORS96_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6833','OCRS_La_Grande_NAD_1983_CORS96_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6834','OCRS_La_Grande_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6835','OCRS_La_Grande_NAD_1983_2011_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6836','OCRS_Ontario_NAD_1983_CORS96_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6837','OCRS_Ontario_NAD_1983_CORS96_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6838','OCRS_Ontario_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6839','OCRS_Ontario_NAD_1983_2011_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6840','OCRS_Oregon_Coast_NAD_1983_CORS96_OM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6841','OCRS_Oregon_Coast_NAD_1983_CORS96_OM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6842','OCRS_Oregon_Coast_NAD_1983_2011_OM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6843','OCRS_Oregon_Coast_NAD_1983_2011_OM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6844','OCRS_Pendleton_NAD_1983_CORS96_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6845','OCRS_Pendleton_NAD_1983_CORS96_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6846','OCRS_Pendleton_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6847','OCRS_Pendleton_NAD_1983_2011_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6848','OCRS_Pendleton-La_Grande_NAD_1983_CORS96_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6849','OCRS_Pendleton-La_Grande_NAD_1983_CORS96_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6850','OCRS_Pendleton-La_Grande_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6851','OCRS_Pendleton-La_Grande_NAD_1983_2011_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6852','OCRS_Portland_NAD_1983_CORS96_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6853','OCRS_Portland_NAD_1983_CORS96_LCC_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6854','OCRS_Portland_NAD_1983_2011_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6855','OCRS_Portland_NAD_1983_2011_LCC_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6856','OCRS_Salem_NAD_1983_CORS96_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6857','OCRS_Salem_NAD_1983_CORS96_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6858','OCRS_Salem_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6859','OCRS_Salem_NAD_1983_2011_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6860','OCRS_Santiam_Pass_NAD_1983_CORS96_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6861','OCRS_Santiam_Pass_NAD_1983_CORS96_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6862','OCRS_Santiam_Pass_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6863','OCRS_Santiam_Pass_NAD_1983_2011_TM_Feet_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6867','NAD_1983_CORS96_Oregon_Statewide_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6868','NAD_1983_CORS96_Oregon_Statewide_Lambert_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6870','ETRS_1989_Albania_2010','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6875','RDN2008_Italy_zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6876','RDN2008_Zone_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6879','NAD_1983_2011_StatePlane_Wisconsin_Central_FIPS_4802','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6880','NAD_1983_2011_StatePlane_Nebraska_FIPS_2600_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6884','NAD_1983_CORS96_StatePlane_Oregon_North_FIPS_3601','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6885','NAD_1983_CORS96_StatePlane_Oregon_North_FIPS_3601_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6886','NAD_1983_CORS96_StatePlane_Oregon_South_FIPS_3602','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6887','NAD_1983_CORS96_StatePlane_Oregon_South_FIPS_3602_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6915','South_East_Island_1943_UTM_Zone_40N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6922','NAD_1983_Kansas_LCC','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6923','NAD_1983_Kansas_LCC_ftUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6924','NAD_1983_2011_Kansas_LCC','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6925','NAD_1983_2011_Kansas_LCC_ftUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6931','WGS_1984_EASE-Grid_2.0_North','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6932','WGS_1984_EASE-Grid_2.0_South','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6933','WGS_1984_EASE-Grid_2.0_Global','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6956','VN_2000_TM-3_zone_481','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6957','VN_2000_TM-3_zone_482','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6958','VN_2000_TM-3_zone_491','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6959','VN_2000_TM-3_Da_Nang_zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6962','ETRS_1989_Albania_LCC_2010','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6984','Israeli_Grid_05','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','6991','Israeli_Grid_05-12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7005','Nahrwan_1934_UTM_zone_37N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7006','Nahrwan_1934_UTM_zone_38N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7007','Nahrwan_1934_UTM_zone_39N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7057','NAD_1983_(2011)_IaRCS_zone_1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7058','NAD_1983_(2011)_IaRCS_zone_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7059','NAD_1983_(2011)_IaRCS_zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7060','NAD_1983_(2011)_IaRCS_zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7061','NAD_1983_(2011)_IaRCS_zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7062','NAD_1983_(2011)_IaRCS_zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7063','NAD_1983_(2011)_IaRCS_zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7064','NAD_1983_(2011)_IaRCS_zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7065','NAD_1983_(2011)_IaRCS_zone_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7066','NAD_1983_(2011)_IaRCS_zone_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7067','NAD_1983_(2011)_IaRCS_zone_11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7068','NAD_1983_(2011)_IaRCS_zone_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7069','NAD_1983_(2011)_IaRCS_zone_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7070','NAD_1983_(2011)_IaRCS_zone_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7074','RGTAAF07_UTM_zone_37S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7075','RGTAAF07_UTM_zone_38S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7076','RGTAAF07_UTM_zone_39S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7077','RGTAAF07_UTM_zone_40S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7078','RGTAAF07_UTM_zone_41S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7079','RGTAAF07_UTM_zone_42S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7080','RGTAAF07_UTM_zone_43S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7081','RGTAAF07_UTM_zone_44S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7082','RGTAAF07_Terre_Adelie_Polar_Stereographic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7109','NAD_1983_2011_RMTCRS_St_Mary_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7110','NAD_1983_2011_RMTCRS_Blackfeet_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7111','NAD_1983_2011_RMTCRS_Milk_River_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7112','NAD_1983_2011_RMTCRS_Fort_Belknap_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7113','NAD_1983_2011_RMTCRS_Fort_Peck_Assiniboine_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7114','NAD_1983_2011_RMTCRS_Fort_Peck_Sioux_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7115','NAD_1983_2011_RMTCRS_Crow_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7116','NAD_1983_2011_RMTCRS_Bobcat_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7117','NAD_1983_2011_RMTCRS_Billings_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7118','NAD_1983_2011_RMTCRS_Wind_River_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7119','NAD_1983_2011_RMTCRS_St_Mary_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7120','NAD_1983_2011_RMTCRS_Blackfeet_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7121','NAD_1983_2011_RMTCRS_Milk_River_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7122','NAD_1983_2011_RMTCRS_Fort_Belknap_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7123','NAD_1983_2011_RMTCRS_Fort_Peck_Assiniboine_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7124','NAD_1983_2011_RMTCRS_Fort_Peck_Sioux_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7125','NAD_1983_2011_RMTCRS_Crow_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7126','NAD_1983_2011_RMTCRS_Bobcat_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7127','NAD_1983_2011_RMTCRS_Billings_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7128','NAD_1983_2011_RMTCRS_Wind_River_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7131','NAD_1983_2011_San_Francisco_CS13_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7132','NAD_1983_2011_San_Francisco_CS13_ftUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7142','Palestine_1923_Palestine_Grid_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7257','NAD_1983_2011_InGCS_Adams_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7258','NAD_1983_2011_InGCS_Adams_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7259','NAD_1983_2011_InGCS_Allen_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7260','NAD_1983_2011_InGCS_Allen_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7261','NAD_1983_2011_InGCS_Bartholomew_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7262','NAD_1983_2011_InGCS_Bartholomew_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7263','NAD_1983_2011_InGCS_Benton_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7264','NAD_1983_2011_InGCS_Benton_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7265','NAD_1983_2011_InGCS_Blackford-Delaware_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7266','NAD_1983_2011_InGCS_Blackford-Delaware_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7267','NAD_1983_2011_InGCS_Boone-Hendricks_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7268','NAD_1983_2011_InGCS_Boone-Hendricks_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7269','NAD_1983_2011_InGCS_Brown_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7270','NAD_1983_2011_InGCS_Brown_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7271','NAD_1983_2011_InGCS_Carroll_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7272','NAD_1983_2011_InGCS_Carroll_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7273','NAD_1983_2011_InGCS_Cass_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7274','NAD_1983_2011_InGCS_Cass_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7275','NAD_1983_2011_InGCS_Clark-Floyd-Scott_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7276','NAD_1983_2011_InGCS_Clark-Floyd-Scott_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7277','NAD_1983_2011_InGCS_Clay_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7278','NAD_1983_2011_InGCS_Clay_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7279','NAD_1983_2011_InGCS_Clinton_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7280','NAD_1983_2011_InGCS_Clinton_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7281','NAD_1983_2011_InGCS_Crawford-Lawrence-Orange_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7282','NAD_1983_2011_InGCS_Crawford-Lawrence-Orange_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7283','NAD_1983_2011_InGCS_Daviess-Greene_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7284','NAD_1983_2011_InGCS_Daviess-Greene_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7285','NAD_1983_2011_InGCS_Dearborn-Ohio-Switzerland_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7286','NAD_1983_2011_InGCS_Dearborn-Ohio-Switzerland_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7287','NAD_1983_2011_InGCS_Decatur-Rush_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7288','NAD_1983_2011_InGCS_Decatur-Rush_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7289','NAD_1983_2011_InGCS_DeKalb_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7290','NAD_1983_2011_InGCS_DeKalb_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7291','NAD_1983_2011_InGCS_Dubois-Martin_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7292','NAD_1983_2011_InGCS_Dubois-Martin_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7293','NAD_1983_2011_InGCS_Elkhart-Kosciusko-Wabash_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7294','NAD_1983_2011_InGCS_Elkhart-Kosciusko-Wabash_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7295','NAD_1983_2011_InGCS_Fayette-Franklin-Union_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7296','NAD_1983_2011_InGCS_Fayette-Franklin-Union_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7297','NAD_1983_2011_InGCS_Fountain-Warren_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7298','NAD_1983_2011_InGCS_Fountain-Warren_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7299','NAD_1983_2011_InGCS_Fulton-Marshall-St_Joseph_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7300','NAD_1983_2011_InGCS_Fulton-Marshall-St_Joseph_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7301','NAD_1983_2011_InGCS_Gibson_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7302','NAD_1983_2011_InGCS_Gibson_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7303','NAD_1983_2011_InGCS_Grant_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7304','NAD_1983_2011_InGCS_Grant_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7305','NAD_1983_2011_InGCS_Hamilton-Tipton_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7306','NAD_1983_2011_InGCS_Hamilton-Tipton_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7307','NAD_1983_2011_InGCS_Hancock-Madison_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7308','NAD_1983_2011_InGCS_Hancock-Madison_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7309','NAD_1983_2011_InGCS_Harrison-Washington_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7310','NAD_1983_2011_InGCS_Harrison-Washington_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7311','NAD_1983_2011_InGCS_Henry_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7312','NAD_1983_2011_InGCS_Henry_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7313','NAD_1983_2011_InGCS_Howard-Miami_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7314','NAD_1983_2011_InGCS_Howard-Miami_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7315','NAD_1983_2011_InGCS_Huntington-Whitley_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7316','NAD_1983_2011_InGCS_Huntington-Whitley_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7317','NAD_1983_2011_InGCS_Jackson_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7318','NAD_1983_2011_InGCS_Jackson_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7319','NAD_1983_2011_InGCS_Jasper-Porter_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7320','NAD_1983_2011_InGCS_Jasper-Porter_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7321','NAD_1983_2011_InGCS_Jay_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7322','NAD_1983_2011_InGCS_Jay_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7323','NAD_1983_2011_InGCS_Jefferson_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7324','NAD_1983_2011_InGCS_Jefferson_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7325','NAD_1983_2011_InGCS_Jennings_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7326','NAD_1983_2011_InGCS_Jennings_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7327','NAD_1983_2011_InGCS_Johnson-Marion_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7328','NAD_1983_2011_InGCS_Johnson-Marion_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7329','NAD_1983_2011_InGCS_Knox_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7330','NAD_1983_2011_InGCS_Knox_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7331','NAD_1983_2011_InGCS_LaGrange-Noble_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7332','NAD_1983_2011_InGCS_LaGrange-Noble_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7333','NAD_1983_2011_InGCS_Lake-Newton_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7334','NAD_1983_2011_InGCS_Lake-Newton_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7335','NAD_1983_2011_InGCS_LaPorte-Pulaski-Starke_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7336','NAD_1983_2011_InGCS_LaPorte-Pulaski-Starke_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7337','NAD_1983_2011_InGCS_Monroe-Morgan_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7338','NAD_1983_2011_InGCS_Monroe-Morgan_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7339','NAD_1983_2011_InGCS_Montgomery-Putnam_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7340','NAD_1983_2011_InGCS_Montgomery-Putnam_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7341','NAD_1983_2011_InGCS_Owen_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7342','NAD_1983_2011_InGCS_Owen_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7343','NAD_1983_2011_InGCS_Parke-Vermillion_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7344','NAD_1983_2011_InGCS_Parke-Vermillion_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7345','NAD_1983_2011_InGCS_Perry_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7346','NAD_1983_2011_InGCS_Perry_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7347','NAD_1983_2011_InGCS_Pike-Warrick_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7348','NAD_1983_2011_InGCS_Pike-Warrick_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7349','NAD_1983_2011_InGCS_Posey_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7350','NAD_1983_2011_InGCS_Posey_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7351','NAD_1983_2011_InGCS_Randolph-Wayne_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7352','NAD_1983_2011_InGCS_Randolph-Wayne_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7353','NAD_1983_2011_InGCS_Ripley_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7354','NAD_1983_2011_InGCS_Ripley_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7355','NAD_1983_2011_InGCS_Shelby_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7356','NAD_1983_2011_InGCS_Shelby_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7357','NAD_1983_2011_InGCS_Spencer_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7358','NAD_1983_2011_InGCS_Spencer_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7359','NAD_1983_2011_InGCS_Steuben_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7360','NAD_1983_2011_InGCS_Steuben_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7361','NAD_1983_2011_InGCS_Sullivan_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7362','NAD_1983_2011_InGCS_Sullivan_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7363','NAD_1983_2011_InGCS_Tippecanoe-White_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7364','NAD_1983_2011_InGCS_Tippecanoe-White_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7365','NAD_1983_2011_InGCS_Vanderburgh_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7366','NAD_1983_2011_InGCS_Vanderburgh_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7367','NAD_1983_2011_InGCS_Vigo_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7368','NAD_1983_2011_InGCS_Vigo_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7369','NAD_1983_2011_InGCS_Wells_(m)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7370','NAD_1983_2011_InGCS_Wells_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7374','ONGD14_UTM_Zone_39N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7375','ONGD14_UTM_Zone_40N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7376','ONGD14_UTM_Zone_41N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7528','NAD_1983_2011_WISCRS_Adams_and_Juneau_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7529','NAD_1983_2011_WISCRS_Ashland_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7530','NAD_1983_2011_WISCRS_Barron_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7531','NAD_1983_2011_WISCRS_Bayfield_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7532','NAD_1983_2011_WISCRS_Brown_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7533','NAD_1983_2011_WISCRS_Buffalo_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7534','NAD_1983_2011_WISCRS_Burnett_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7535','NAD_1983_2011_WISCRS_Calumet_Fond_du_Lac_Outagamie_Winnebago_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7536','NAD_1983_2011_WISCRS_Chippewa_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7537','NAD_1983_2011_WISCRS_Clark_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7538','NAD_1983_2011_WISCRS_Columbia_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7539','NAD_1983_2011_WISCRS_Crawford_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7540','NAD_1983_2011_WISCRS_Dane_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7541','NAD_1983_2011_WISCRS_Dodge_and_Jefferson_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7542','NAD_1983_2011_WISCRS_Door_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7543','NAD_1983_2011_WISCRS_Douglas_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7544','NAD_1983_2011_WISCRS_Dunn_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7545','NAD_1983_2011_WISCRS_EauClaire_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7546','NAD_1983_2011_WISCRS_Florence_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7547','NAD_1983_2011_WISCRS_Forest_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7548','NAD_1983_2011_WISCRS_Grant_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7549','NAD_1983_2011_WISCRS_Green_and_Lafayette_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7550','NAD_1983_2011_WISCRS_Green_Lake_and_Marquette_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7551','NAD_1983_2011_WISCRS_Iowa_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7552','NAD_1983_2011_WISCRS_Iron_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7553','NAD_1983_2011_WISCRS_Jackson_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7554','NAD_1983_2011_WISCRS_Kenosha_Milwaukee_Ozaukee_Racine_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7555','NAD_1983_2011_WISCRS_Kewaunee_Manitowoc_Sheboygan_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7556','NAD_1983_2011_WISCRS_La_Crosse_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7557','NAD_1983_2011_WISCRS_Langlade_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7558','NAD_1983_2011_WISCRS_Lincoln_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7559','NAD_1983_2011_WISCRS_Marathon_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7560','NAD_1983_2011_WISCRS_Marinette_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7561','NAD_1983_2011_WISCRS_Menominee_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7562','NAD_1983_2011_WISCRS_Monroe_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7563','NAD_1983_2011_WISCRS_Oconto_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7564','NAD_1983_2011_WISCRS_Oneida_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7565','NAD_1983_2011_WISCRS_Pepin_and_Pierce_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7566','NAD_1983_2011_WISCRS_Polk_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7567','NAD_1983_2011_WISCRS_Portage_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7568','NAD_1983_2011_WISCRS_Price_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7569','NAD_1983_2011_WISCRS_Richland_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7570','NAD_1983_2011_WISCRS_Rock_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7571','NAD_1983_2011_WISCRS_Rusk_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7572','NAD_1983_2011_WISCRS_Sauk_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7573','NAD_1983_2011_WISCRS_Sawyer_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7574','NAD_1983_2011_WISCRS_Shawano_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7575','NAD_1983_2011_WISCRS_St_Croix_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7576','NAD_1983_2011_WISCRS_Taylor_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7577','NAD_1983_2011_WISCRS_Trempealeau_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7578','NAD_1983_2011_WISCRS_Vernon_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7579','NAD_1983_2011_WISCRS_Vilas_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7580','NAD_1983_2011_WISCRS_Walworth_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7581','NAD_1983_2011_WISCRS_Washburn_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7582','NAD_1983_2011_WISCRS_Washington_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7583','NAD_1983_2011_WISCRS_Waukesha_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7584','NAD_1983_2011_WISCRS_Waupaca_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7585','NAD_1983_2011_WISCRS_Waushara_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7586','NAD_1983_2011_WISCRS_Wood_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7587','NAD_1983_2011_WISCRS_Adams_and_Juneau_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7588','NAD_1983_2011_WISCRS_Ashland_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7589','NAD_1983_2011_WISCRS_Barron_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7590','NAD_1983_2011_WISCRS_Bayfield_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7591','NAD_1983_2011_WISCRS_Brown_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7592','NAD_1983_2011_WISCRS_Buffalo_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7593','NAD_1983_2011_WISCRS_Burnett_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7594','NAD_1983_2011_WISCRS_Calumet_Fond_du_Lac_Outagamie_Winnebago_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7595','NAD_1983_2011_WISCRS_Chippewa_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7596','NAD_1983_2011_WISCRS_Clark_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7597','NAD_1983_2011_WISCRS_Columbia_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7598','NAD_1983_2011_WISCRS_Crawford_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7599','NAD_1983_2011_WISCRS_Dane_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7600','NAD_1983_2011_WISCRS_Dodge_and_Jefferson_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7601','NAD_1983_2011_WISCRS_Door_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7602','NAD_1983_2011_WISCRS_Douglas_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7603','NAD_1983_2011_WISCRS_Dunn_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7604','NAD_1983_2011_WISCRS_Eau_Claire_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7605','NAD_1983_2011_WISCRS_Florence_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7606','NAD_1983_2011_WISCRS_Forest_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7607','NAD_1983_2011_WISCRS_Grant_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7608','NAD_1983_2011_WISCRS_Green_and_Lafayette_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7609','NAD_1983_2011_WISCRS_Green_Lake_and_Marquette_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7610','NAD_1983_2011_WISCRS_Iowa_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7611','NAD_1983_2011_WISCRS_Iron_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7612','NAD_1983_2011_WISCRS_Jackson_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7613','NAD_1983_2011_WISCRS_Kenosha_Milwaukee_Ozaukee_Racine_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7614','NAD_1983_2011_WISCRS_Kewaunee_Manitowoc_Sheboygan_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7615','NAD_1983_2011_WISCRS_La_Crosse_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7616','NAD_1983_2011_WISCRS_Langlade_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7617','NAD_1983_2011_WISCRS_Lincoln_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7618','NAD_1983_2011_WISCRS_Marathon_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7619','NAD_1983_2011_WISCRS_Marinette_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7620','NAD_1983_2011_WISCRS_Menominee_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7621','NAD_1983_2011_WISCRS_Monroe_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7622','NAD_1983_2011_WISCRS_Oconto_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7623','NAD_1983_2011_WISCRS_Oneida_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7624','NAD_1983_2011_WISCRS_Pepin_and_Pierce_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7625','NAD_1983_2011_WISCRS_Polk_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7626','NAD_1983_2011_WISCRS_Portage_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7627','NAD_1983_2011_WISCRS_Price_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7628','NAD_1983_2011_WISCRS_Richland_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7629','NAD_1983_2011_WISCRS_Rock_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7630','NAD_1983_2011_WISCRS_Rusk_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7631','NAD_1983_2011_WISCRS_Sauk_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7632','NAD_1983_2011_WISCRS_Sawyer_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7633','NAD_1983_2011_WISCRS_Shawano_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7634','NAD_1983_2011_WISCRS_St_Croix_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7635','NAD_1983_2011_WISCRS_Taylor_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7636','NAD_1983_2011_WISCRS_Trempealeau_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7637','NAD_1983_2011_WISCRS_Vernon_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7638','NAD_1983_2011_WISCRS_Vilas_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7639','NAD_1983_2011_WISCRS_Walworth_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7640','NAD_1983_2011_WISCRS_Washburn_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7641','NAD_1983_2011_WISCRS_Washington_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7642','NAD_1983_2011_WISCRS_Waukesha_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7643','NAD_1983_2011_WISCRS_Waupaca_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7644','NAD_1983_2011_WISCRS_Waushara_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7645','NAD_1983_2011_WISCRS_Wood_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7755','WGS_1984_India_NSF_LCC','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7756','WGS_1984_Andhra_Pradesh','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7757','WGS_1984_Arunachal_Pradesh','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7758','WGS_1984_Assam','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7759','WGS_1984_Bihar','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7760','WGS_1984_Delhi','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7761','WGS_1984_Gujarat','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7762','WGS_1984_Haryana','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7763','WGS_1984_Himachal_Pradesh','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7764','WGS_1984_Jammu_and_Kashmir','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7765','WGS_1984_Jharkhand','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7766','WGS_1984_Madhya_Pradesh','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7767','WGS_1984_Maharashtra','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7768','WGS_1984_Manipur','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7769','WGS_1984_Meghalaya','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7770','WGS_1984_Nagaland','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7771','WGS_1984_India_Northeast','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7772','WGS_1984_Orissa','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7773','WGS_1984_Punjab','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7774','WGS_1984_Rajasthan','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7775','WGS_1984_Uttar_Pradesh','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7776','WGS_1984_Uttaranchal','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7777','WGS_1984_Andaman_and_Nicobar_Islands','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7778','WGS_1984_Chhattisgarh','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7779','WGS_1984_Goa','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7780','WGS_1984_Karnataka','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7781','WGS_1984_Kerala','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7782','WGS_1984_Lakshadweep','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7783','WGS_1984_Mizoram','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7784','WGS_1984_Sikkim','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7785','WGS_1984_Tamil_Nadu','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7786','WGS_1984_Tripura','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7787','WGS_1984_West_Bengal','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7791','RDN2008_UTM_zone_32N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7792','RDN2008_UTM_zone_33N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7793','RDN2008_UTM_zone_34N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7794','RDN2008_Italy_zone_(E-N)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7795','RDN2008_Zone_12_(E-N)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7799','BGS2005_UTM_zone_34N_(N-E)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7800','BGS2005_UTM_zone_35N_(N-E)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7801','BGS2005_CCS2005','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7803','BGS2005_UTM_zone_34N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7804','BGS2005_UTM_zone_35N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7805','BGS2005_UTM_zone_36N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7825','Pulkovo_1942_CS63_zone_X1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7826','Pulkovo_1942_CS63_zone_X2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7827','Pulkovo_1942_CS63_zone_X3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7828','Pulkovo_1942_CS63_zone_X4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7829','Pulkovo_1942_CS63_zone_X5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7830','Pulkovo_1942_CS63_zone_X6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7831','Pulkovo_1942_CS63_zone_X7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7845','GDA2020_GA_LCC','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7846','GDA2020_MGA_Zone_46','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7847','GDA2020_MGA_Zone_47','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7848','GDA2020_MGA_Zone_48','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7849','GDA2020_MGA_Zone_49','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7850','GDA2020_MGA_Zone_50','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7851','GDA2020_MGA_Zone_51','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7852','GDA2020_MGA_Zone_52','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7853','GDA2020_MGA_Zone_53','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7854','GDA2020_MGA_Zone_54','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7855','GDA2020_MGA_Zone_55','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7856','GDA2020_MGA_Zone_56','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7857','GDA2020_MGA_Zone_57','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7858','GDA2020_MGA_Zone_58','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7859','GDA2020_MGA_Zone_59','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7877','Astro_DOS_71_4_SHLG71','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7878','Astro_DOS_71_4_UTM_zone_30S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7882','St_Helena_Tritan_SHLG(Tritan)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7883','St_Helena_Tritan_UTM_zone_30S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7899','GDA2020_Vicgrid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7991','NAD27_MTM_zone_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','7992','Malongo_1987_UTM_zone_33S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8013','GDA2020_ALB2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8014','GDA2020_BIO2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8015','GDA2020_BRO2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8016','GDA2020_BCG2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8017','GDA2020_CARN2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8018','GDA2020_CIG2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8019','GDA2020_CKIG2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8020','GDA2020_COL2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8021','GDA2020_ESP2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8022','GDA2020_EXM2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8023','GDA2020_GCG2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8024','GDA2020_GOLD2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8025','GDA2020_JCG2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8026','GDA2020_KALB2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8027','GDA2020_KAR2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8028','GDA2020_KUN2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8029','GDA2020_LCG2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8030','GDA2020_MRCG2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8031','GDA2020_PCG2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8032','GDA2020_PHG2020','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8058','GDA2020_NSW_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8059','GDA2020_South_Australia_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8065','NAD_1983_(2011)_PCCS_zone_1_(ft)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8066','NAD_1983_(2011)_PCCS_zone_2_(ft)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8067','NAD_1983_(2011)_PCCS_zone_3_(ft)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8068','NAD_1983_(2011)_PCCS_zone_4_(ft)','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8082','NAD_1983_(CSRS)_v6_MTM_Nova_Scotia_zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8083','NAD_1983_(CSRS)_v6_MTM_Nova_Scotia_zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8090','NAD_1983_HARN_WISCRS_Florence_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8091','NAD_1983_HARN_WISCRS_Florence_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8092','NAD_1983_HARN_WISCRS_EauClaire_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8093','NAD_1983_HARN_WISCRS_EauClaire_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8095','NAD_1983_HARN_WISCRS_Wood_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8096','NAD_1983_HARN_WISCRS_Wood_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8097','NAD_1983_HARN_WISCRS_Waushara_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8098','NAD_1983_HARN_WISCRS_Waushara_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8099','NAD_1983_HARN_WISCRS_Waupaca_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8100','NAD_1983_HARN_WISCRS_Waupaca_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8101','NAD_1983_HARN_WISCRS_Waukesha_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8102','NAD_1983_HARN_WISCRS_Waukesha_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8103','NAD_1983_HARN_WISCRS_Washington_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8104','NAD_1983_HARN_WISCRS_Washington_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8105','NAD_1983_HARN_WISCRS_Washburn_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8106','NAD_1983_HARN_WISCRS_Washburn_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8107','NAD_1983_HARN_WISCRS_Walworth_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8108','NAD_1983_HARN_WISCRS_Walworth_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8109','NAD_1983_HARN_WISCRS_Vilas_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8110','NAD_1983_HARN_WISCRS_Vilas_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8111','NAD_1983_HARN_WISCRS_Vernon_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8112','NAD_1983_HARN_WISCRS_Vernon_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8113','NAD_1983_HARN_WISCRS_Trempealeau_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8114','NAD_1983_HARN_WISCRS_Trempealeau_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8115','NAD_1983_HARN_WISCRS_Taylor_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8116','NAD_1983_HARN_WISCRS_Taylor_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8117','NAD_1983_HARN_WISCRS_St_Croix_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8118','NAD_1983_HARN_WISCRS_St_Croix_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8119','NAD_1983_HARN_WISCRS_Shawano_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8120','NAD_1983_HARN_WISCRS_Shawano_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8121','NAD_1983_HARN_WISCRS_Sawyer_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8122','NAD_1983_HARN_WISCRS_Sawyer_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8123','NAD_1983_HARN_WISCRS_Sauk_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8124','NAD_1983_HARN_WISCRS_Sauk_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8125','NAD_1983_HARN_WISCRS_Rusk_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8126','NAD_1983_HARN_WISCRS_Rusk_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8127','NAD_1983_HARN_WISCRS_Rock_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8128','NAD_1983_HARN_WISCRS_Rock_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8129','NAD_1983_HARN_WISCRS_Richland_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8130','NAD_1983_HARN_WISCRS_Richland_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8131','NAD_1983_HARN_WISCRS_Price_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8132','NAD_1983_HARN_WISCRS_Price_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8133','NAD_1983_HARN_WISCRS_Portage_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8134','NAD_1983_HARN_WISCRS_Portage_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8135','NAD_1983_HARN_WISCRS_Polk_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8136','NAD_1983_HARN_WISCRS_Polk_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8137','NAD_1983_HARN_WISCRS_Pepin_and_Pierce_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8138','NAD_1983_HARN_WISCRS_Pepin_and_Pierce_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8139','NAD_1983_HARN_WISCRS_Oneida_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8140','NAD_1983_HARN_WISCRS_Oneida_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8141','NAD_1983_HARN_WISCRS_Oconto_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8142','NAD_1983_HARN_WISCRS_Oconto_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8143','NAD_1983_HARN_WISCRS_Monroe_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8144','NAD_1983_HARN_WISCRS_Monroe_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8145','NAD_1983_HARN_WISCRS_Menominee_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8146','NAD_1983_HARN_WISCRS_Menominee_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8147','NAD_1983_HARN_WISCRS_Marinette_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8148','NAD_1983_HARN_WISCRS_Marinette_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8149','NAD_1983_HARN_WISCRS_Marathon_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8150','NAD_1983_HARN_WISCRS_Marathon_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8151','NAD_1983_HARN_WISCRS_Lincoln_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8152','NAD_1983_HARN_WISCRS_Lincoln_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8153','NAD_1983_HARN_WISCRS_Langlade_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8154','NAD_1983_HARN_WISCRS_Langlade_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8155','NAD_1983_HARN_WISCRS_LaCrosse_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8156','NAD_1983_HARN_WISCRS_LaCrosse_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8157','NAD_1983_HARN_WISCRS_Kewaunee_Manitowoc_and_Sheboygan_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8158','NAD_1983_HARN_WISCRS_Kewaunee_Manitowoc_and_Sheboygan_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8159','NAD_1983_HARN_WISCRS_Kenosha_Milwaukee_Ozaukee_and_Racine_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8160','NAD_1983_HARN_WISCRS_Kenosha_Milwaukee_Ozaukee_and_Racine_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8161','NAD_1983_HARN_WISCRS_Jackson_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8162','NAD_1983_HARN_WISCRS_Jackson_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8163','NAD_1983_HARN_WISCRS_Iron_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8164','NAD_1983_HARN_WISCRS_Iron_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8165','NAD_1983_HARN_WISCRS_Iowa_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8166','NAD_1983_HARN_WISCRS_Iowa_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8167','NAD_1983_HARN_WISCRS_Green_Lake_and_Marquette_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8168','NAD_1983_HARN_WISCRS_Green_Lake_and_Marquette_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8169','NAD_1983_HARN_WISCRS_Green_and_Lafayette_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8170','NAD_1983_HARN_WISCRS_Green_and_Lafayette_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8171','NAD_1983_HARN_WISCRS_Grant_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8172','NAD_1983_HARN_WISCRS_Grant_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8173','NAD_1983_HARN_WISCRS_Forest_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8177','NAD_1983_HARN_WISCRS_Forest_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8179','NAD_1983_HARN_WISCRS_Dunn_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8180','NAD_1983_HARN_WISCRS_Dunn_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8181','NAD_1983_HARN_WISCRS_Douglas_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8182','NAD_1983_HARN_WISCRS_Douglas_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8184','NAD_1983_HARN_WISCRS_Door_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8185','NAD_1983_HARN_WISCRS_Door_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8187','NAD_1983_HARN_WISCRS_Dodge_and_Jefferson_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8189','NAD_1983_HARN_WISCRS_Dodge_and_Jefferson_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8191','NAD_1983_HARN_WISCRS_Dane_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8193','NAD_1983_HARN_WISCRS_Dane_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8196','NAD_1983_HARN_WISCRS_Crawford_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8197','NAD_1983_HARN_WISCRS_Crawford_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8198','NAD_1983_HARN_WISCRS_Columbia_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8200','NAD_1983_HARN_WISCRS_Columbia_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8201','NAD_1983_HARN_WISCRS_Clark_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8202','NAD_1983_HARN_WISCRS_Clark_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8203','NAD_1983_HARN_WISCRS_Chippewa_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8204','NAD_1983_HARN_WISCRS_Chippewa_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8205','NAD_1983_HARN_WISCRS_Calumet_Fond_du_Lac_Outagamie_and_Winnebago_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8206','NAD_1983_HARN_WISCRS_Calumet_Fond_du_Lac_Outagamie_and_Winnebago_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8207','NAD_1983_HARN_WISCRS_Burnett_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8208','NAD_1983_HARN_WISCRS_Burnett_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8209','NAD_1983_HARN_WISCRS_Buffalo_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8210','NAD_1983_HARN_WISCRS_Buffalo_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8212','NAD_1983_HARN_WISCRS_Brown_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8213','NAD_1983_HARN_WISCRS_Brown_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8214','NAD_1983_HARN_WISCRS_Bayfield_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8216','NAD_1983_HARN_WISCRS_Bayfield_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8218','NAD_1983_HARN_WISCRS_Barron_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8220','NAD_1983_HARN_WISCRS_Barron_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8222','NAD_1983_HARN_WISCRS_Ashland_County_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8224','NAD_1983_HARN_WISCRS_Ashland_County_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8225','NAD_1983_HARN_WISCRS_Adams_and_Juneau_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8226','NAD_1983_HARN_WISCRS_Adams_and_Juneau_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8311','OCRS_Burns-Harper_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8312','OCRS_Burns-Harper_NAD_1983_2011_TM_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8313','OCRS_Canyon_City-Burns_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8314','OCRS_Canyon_City-Burns_NAD_1983_2011_TM_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8315','OCRS_Coast_Range_North_NAD_1983_2011_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8316','OCRS_Coast_Range_North_NAD_1983_2011_LCC_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8317','OCRS_Dayville-Prairie_City_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8318','OCRS_Dayville-Prairie_City_NAD_1983_2011_TM_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8319','OCRS_Denio-Burns_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8320','OCRS_Denio-Burns_NAD_1983_2011_TM_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8321','OCRS_Halfway_NAD_1983_2011_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8322','OCRS_Halfway_NAD_1983_2011_LCC_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8323','OCRS_Medford-Diamond_Lake_NAD_1983_2011_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8324','OCRS_Medford-Diamond_Lake_NAD_1983_2011_LCC_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8325','OCRS_Mitchell_NAD_1983_2011_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8326','OCRS_Mitchell_NAD_1983_2011_LCC_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8327','OCRS_North_Central_NAD_1983_2011_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8328','OCRS_North_Central_NAD_1983_2011_LCC_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8329','OCRS_Ochoco_Summit_NAD_1983_2011_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8330','OCRS_Ochoco_Summit_NAD_1983_2011_LCC_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8331','OCRS_Owyhee_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8332','OCRS_Owyhee_NAD_1983_2011_TM_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8333','OCRS_Pilot_Rock-Ukiah_NAD_1983_2011_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8334','OCRS_Pilot_Rock-Ukiah_NAD_1983_2011_LCC_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8335','OCRS_Prairie_City-Brogan_NAD_1983_2011_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8336','OCRS_Prairie_City-Brogan_NAD_1983_2011_LCC_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8337','OCRS_Riley-Lakeview_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8338','OCRS_Riley-Lakeview_NAD_1983_2011_TM_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8339','OCRS_Siskiyou_Pass_NAD_1983_2011_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8340','OCRS_Siskiyou_Pass_NAD_1983_2011_LCC_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8341','OCRS_Ukiah-Fox_NAD_1983_2011_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8342','OCRS_Ukiah-Fox_NAD_1983_2011_LCC_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8343','OCRS_Wallowa_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8344','OCRS_Wallowa_NAD_1983_2011_TM_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8345','OCRS_Warner_Highway_NAD_1983_2011_LCC_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8346','OCRS_Warner_Highway_NAD_1983_2011_LCC_Ft_Intl','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8347','OCRS_Willamette_Pass_NAD_1983_2011_TM_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','8348','OCRS_Willamette_Pass_NAD_1983_2011_TM_Ft_Intl','ESRI');
INSERT INTO "conversion" VALUES('ESRI','8379','unnamed',NULL,NULL,'EPSG','4485','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.25,'EPSG','9102','EPSG','8802','Longitude of natural origin',-114.9666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0001,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','8379','NAD_1983_NCRS_Las_Vegas_(m)',NULL,NULL,'EPSG','4400','EPSG','4269','ESRI','8379','EPSG','4485',NULL,0);
INSERT INTO "coordinate_system" VALUES('ESRI','Foot_US','Cartesian',2);
INSERT INTO "axis" VALUES('ESRI','1','Easting','E','east','ESRI','Foot_US',1,'EPSG','9003');
INSERT INTO "axis" VALUES('ESRI','2','Northing','N','north','ESRI','Foot_US',2,'EPSG','9003');
INSERT INTO "conversion" VALUES('ESRI','8380','unnamed',NULL,NULL,'EPSG','4485','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.25,'EPSG','9102','EPSG','8802','Longitude of natural origin',-114.9666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0001,'EPSG','9201','EPSG','8806','False easting',328083.3333,'EPSG','9003','EPSG','8807','False northing',656166.6667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','8380','NAD_1983_NCRS_Las_Vegas_(ftUS)',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','8380','EPSG','4485',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','8381','unnamed',NULL,NULL,'EPSG','4487','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.25,'EPSG','9102','EPSG','8802','Longitude of natural origin',-114.9666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000135,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',400000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','8381','NAD_1983_NCRS_Las_Vegas_high_(m)',NULL,NULL,'EPSG','4400','EPSG','4269','ESRI','8381','EPSG','4487',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','8382','unnamed',NULL,NULL,'EPSG','4487','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.25,'EPSG','9102','EPSG','8802','Longitude of natural origin',-114.9666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000135,'EPSG','9201','EPSG','8806','False easting',984250.0,'EPSG','9003','EPSG','8807','False northing',1312333.3333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','8382','NAD_1983_NCRS_Las_Vegas_high_(ftUS)',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','8382','EPSG','4487',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','8383','NAD_1983_(2011)_NCRS_Las_Vegas_(m)',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','8379','EPSG','4485',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','8384','NAD_1983_(2011)_NCRS_Las_Vegas_(ftUS)',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','8380','EPSG','4485',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','8385','NAD_1983_(2011)_NCRS_Las_Vegas_high_(m)',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','8381','EPSG','4487',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','8387','NAD_1983_(2011)_NCRS_Las_Vegas_high_(ftUS)',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','8382','EPSG','4487',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','8391','GDA_1994_WEIPA94',NULL,NULL,'EPSG','4400','EPSG','4283','EPSG','8389','EPSG','4491',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','8682','SRB_ETRS89_UTM_zone_34N',NULL,NULL,'EPSG','4400','ESRI','8685','EPSG','16034','EPSG','3534',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','8836','MTRF-2000_UTM_zone_36N',NULL,NULL,'EPSG','4400','ESRI','8818','EPSG','16036','EPSG','4524',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','8837','MTRF-2000_UTM_zone_37N',NULL,NULL,'EPSG','4400','ESRI','8818','EPSG','16037','EPSG','4526',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','8838','MTRF-2000_UTM_zone_38N',NULL,NULL,'EPSG','4400','ESRI','8818','EPSG','16038','EPSG','4527',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','8839','MTRF-2000_UTM_zone_39N',NULL,NULL,'EPSG','4400','ESRI','8818','EPSG','16039','EPSG','4528',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','8840','MTRF-2000_UTM_zone_40N',NULL,NULL,'EPSG','4400','ESRI','8818','EPSG','16040','EPSG','3106',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','8857','WGS_1984_Equal_Earth_Greenwich',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["WGS_1984_Equal_Earth_Greenwich",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equal_Earth"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','8858','WGS_1984_Equal_Earth_Americas',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["WGS_1984_Equal_Earth_Americas",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equal_Earth"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-90.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','8859','WGS_1984_Equal_Earth_Asia_Pacific',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["WGS_1984_Equal_Earth_Asia_Pacific",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equal_Earth"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",150.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','20002','Pulkovo_1995_GK_Zone_2',NULL,NULL,'EPSG','4400','EPSG','4200','EPSG','16202','EPSG','1805',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','20003','Pulkovo_1995_GK_Zone_3',NULL,NULL,'EPSG','4400','EPSG','4200','EPSG','16203','EPSG','1792',NULL,0);
INSERT INTO alias_name VALUES('projected_crs','EPSG','20004','Pulkovo_1995_GK_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20005','Pulkovo_1995_GK_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20006','Pulkovo_1995_GK_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20007','Pulkovo_1995_GK_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20008','Pulkovo_1995_GK_Zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20009','Pulkovo_1995_GK_Zone_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20010','Pulkovo_1995_GK_Zone_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20011','Pulkovo_1995_GK_Zone_11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20012','Pulkovo_1995_GK_Zone_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20013','Pulkovo_1995_GK_Zone_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20014','Pulkovo_1995_GK_Zone_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20015','Pulkovo_1995_GK_Zone_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20016','Pulkovo_1995_GK_Zone_16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20017','Pulkovo_1995_GK_Zone_17','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20018','Pulkovo_1995_GK_Zone_18','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20019','Pulkovo_1995_GK_Zone_19','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20020','Pulkovo_1995_GK_Zone_20','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20021','Pulkovo_1995_GK_Zone_21','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20022','Pulkovo_1995_GK_Zone_22','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20023','Pulkovo_1995_GK_Zone_23','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20024','Pulkovo_1995_GK_Zone_24','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20025','Pulkovo_1995_GK_Zone_25','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20026','Pulkovo_1995_GK_Zone_26','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20027','Pulkovo_1995_GK_Zone_27','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20028','Pulkovo_1995_GK_Zone_28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20029','Pulkovo_1995_GK_Zone_29','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20030','Pulkovo_1995_GK_Zone_30','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20031','Pulkovo_1995_GK_Zone_31','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20032','Pulkovo_1995_GK_Zone_32','ESRI');
INSERT INTO "projected_crs" VALUES('ESRI','20062','Pulkovo_1995_GK_Zone_2N',NULL,NULL,'EPSG','4400','EPSG','4200','EPSG','16302','EPSG','1805',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','20063','Pulkovo_1995_GK_Zone_3N',NULL,NULL,'EPSG','4400','EPSG','4200','EPSG','16303','EPSG','1792',NULL,0);
INSERT INTO alias_name VALUES('projected_crs','EPSG','20064','Pulkovo_1995_GK_Zone_4N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20065','Pulkovo_1995_GK_Zone_5N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20066','Pulkovo_1995_GK_Zone_6N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20067','Pulkovo_1995_GK_Zone_7N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20068','Pulkovo_1995_GK_Zone_8N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20069','Pulkovo_1995_GK_Zone_9N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20070','Pulkovo_1995_GK_Zone_10N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20071','Pulkovo_1995_GK_Zone_11N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20072','Pulkovo_1995_GK_Zone_12N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20073','Pulkovo_1995_GK_Zone_13N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20074','Pulkovo_1995_GK_Zone_14N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20075','Pulkovo_1995_GK_Zone_15N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20076','Pulkovo_1995_GK_Zone_16N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20077','Pulkovo_1995_GK_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20078','Pulkovo_1995_GK_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20079','Pulkovo_1995_GK_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20080','Pulkovo_1995_GK_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20081','Pulkovo_1995_GK_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20082','Pulkovo_1995_GK_Zone_22N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20083','Pulkovo_1995_GK_Zone_23N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20084','Pulkovo_1995_GK_Zone_24N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20085','Pulkovo_1995_GK_Zone_25N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20086','Pulkovo_1995_GK_Zone_26N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20087','Pulkovo_1995_GK_Zone_27N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20088','Pulkovo_1995_GK_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20089','Pulkovo_1995_GK_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20090','Pulkovo_1995_GK_Zone_30N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20091','Pulkovo_1995_GK_Zone_31N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20092','Pulkovo_1995_GK_Zone_32N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20135','Adindan_UTM_Zone_35N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20136','Adindan_UTM_Zone_36N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20137','Adindan_UTM_Zone_37N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20138','Adindan_UTM_Zone_38N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20248','AGD_1966_AMG_Zone_48','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20249','AGD_1966_AMG_Zone_49','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20250','AGD_1966_AMG_Zone_50','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20251','AGD_1966_AMG_Zone_51','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20252','AGD_1966_AMG_Zone_52','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20253','AGD_1966_AMG_Zone_53','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20254','AGD_1966_AMG_Zone_54','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20255','AGD_1966_AMG_Zone_55','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20256','AGD_1966_AMG_Zone_56','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20257','AGD_1966_AMG_Zone_57','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20258','AGD_1966_AMG_Zone_58','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20348','AGD_1984_AMG_Zone_48','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20349','AGD_1984_AMG_Zone_49','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20350','AGD_1984_AMG_Zone_50','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20351','AGD_1984_AMG_Zone_51','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20352','AGD_1984_AMG_Zone_52','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20353','AGD_1984_AMG_Zone_53','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20354','AGD_1984_AMG_Zone_54','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20355','AGD_1984_AMG_Zone_55','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20356','AGD_1984_AMG_Zone_56','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20357','AGD_1984_AMG_Zone_57','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20358','AGD_1984_AMG_Zone_58','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20436','Ain_el_Abd_UTM_Zone_36N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20437','Ain_el_Abd_UTM_Zone_37N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20438','Ain_el_Abd_UTM_Zone_38N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20439','Ain_el_Abd_UTM_Zone_39N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20440','Ain_el_Abd_UTM_Zone_40N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20499','Bahrain_State_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20538','Afgooye_UTM_Zone_38N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20539','Afgooye_UTM_Zone_39N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20790','Portuguese_National_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20791','Lisbon_Lisbon_Portuguese_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20822','Aratu_UTM_Zone_22S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20823','Aratu_UTM_Zone_23S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20824','Aratu_UTM_Zone_24S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20934','Arc_1950_UTM_Zone_34S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20935','Arc_1950_UTM_Zone_35S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','20936','Arc_1950_UTM_Zone_36S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21035','Arc_1960_UTM_Zone_35S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21036','Arc_1960_UTM_Zone_36S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21037','Arc_1960_UTM_Zone_37S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21095','Arc_1960_UTM_Zone_35N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21096','Arc_1960_UTM_Zone_36N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21097','Arc_1960_UTM_Zone_37N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21148','Batavia_UTM_Zone_48S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21149','Batavia_UTM_Zone_49S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21150','Batavia_UTM_Zone_50S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21291','Barbados_1938_British_West_Indies_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21292','Barbados_1938_Barbados_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21413','Beijing_1954_GK_Zone_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21414','Beijing_1954_GK_Zone_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21415','Beijing_1954_GK_Zone_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21416','Beijing_1954_GK_Zone_16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21417','Beijing_1954_GK_Zone_17','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21418','Beijing_1954_GK_Zone_18','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21419','Beijing_1954_GK_Zone_19','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21420','Beijing_1954_GK_Zone_20','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21421','Beijing_1954_GK_Zone_21','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21422','Beijing_1954_GK_Zone_22','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21423','Beijing_1954_GK_Zone_23','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21473','Beijing_1954_GK_Zone_13N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21474','Beijing_1954_GK_Zone_14N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21475','Beijing_1954_GK_Zone_15N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21476','Beijing_1954_GK_Zone_16N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21477','Beijing_1954_GK_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21478','Beijing_1954_GK_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21479','Beijing_1954_GK_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21480','Beijing_1954_GK_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21481','Beijing_1954_GK_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21482','Beijing_1954_GK_Zone_22N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21483','Beijing_1954_GK_Zone_23N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21500','Belge_Lambert_1950','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21780','Bern_1898_Bern_LV03C','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21781','CH1903_LV03','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21782','CH1903_LV03C-G','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21817','Bogota_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21818','Bogota_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21891','Colombia_West_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21892','Colombia_Bogota_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21893','Colombia_East_Central_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21894','Colombia_East_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21896','Colombia_West_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21897','Colombia_Bogota_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21898','Colombia_East_Central_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','21899','Colombia_East_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22032','Camacupa_UTM_Zone_32S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22033','Camacupa_UTM_Zone_33S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22091','Camacupa_TM_11_30_SE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22092','Camacupa_TM_12_SE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22171','POSGAR_1998_Argentina_Zone_1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22172','POSGAR_1998_Argentina_Zone_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22173','POSGAR_1998_Argentina_Zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22174','POSGAR_1998_Argentina_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22175','POSGAR_1998_Argentina_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22176','POSGAR_1998_Argentina_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22177','POSGAR_1998_Argentina_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22181','POSGAR_1994_Argentina_Zone_1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22182','POSGAR_1994_Argentina_Zone_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22183','POSGAR_1994_Argentina_Zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22184','POSGAR_1994_Argentina_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22185','POSGAR_1994_Argentina_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22186','POSGAR_1994_Argentina_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22187','POSGAR_1994_Argentina_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22191','Argentina_Zone_1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22192','Argentina_Zone_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22193','Argentina_Zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22194','Argentina_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22195','Argentina_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22196','Argentina_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22197','Argentina_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22234','Cape_UTM_Zone_34S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22235','Cape_UTM_Zone_35S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22236','Cape_UTM_Zone_36S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22332','Carthage_UTM_Zone_32N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22391','Nord_Tunisie','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22392','Sud_Tunisie','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22521','Corrego_Alegre_UTM_Zone_21S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22522','Corrego_Alegre_UTM_Zone_22S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22523','Corrego_Alegre_UTM_Zone_23S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22524','Corrego_Alegre_UTM_Zone_24S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22525','Corrego_Alegre_UTM_Zone_25S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22700','Deir_ez_Zor_Levant_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22770','Deir_ez_Zor_Syria_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22780','Deir_ez_Zor_Levant_Stereographic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22832','Douala_UTM_Zone_32N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22991','Egypt_Blue_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22992','Egypt_Red_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22993','Egypt_Purple_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','22994','Egypt_Extended_Purple_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23028','ED_1950_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23029','ED_1950_UTM_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23030','ED_1950_UTM_Zone_30N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23031','ED_1950_UTM_Zone_31N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23032','ED_1950_UTM_Zone_32N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23033','ED_1950_UTM_Zone_33N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23034','ED_1950_UTM_Zone_34N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23035','ED_1950_UTM_Zone_35N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23036','ED_1950_UTM_Zone_36N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23037','ED_1950_UTM_Zone_37N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23038','ED_1950_UTM_Zone_38N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23090','ED_1950_TM_0_N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23095','ED_1950_TM_5_NE','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23239','Fahud_UTM_Zone_39N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23240','Fahud_UTM_Zone_40N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23433','Garoua_UTM_Zone_33N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23700','Hungarian_1972_Egyseges_Orszagos_Vetuleti','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23830','DGN_1995_Indonesia_TM-3_Zone_46.2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23831','DGN_1995_Indonesia_TM-3_Zone_47.1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23832','DGN_1995_Indonesia_TM-3_Zone_47.2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23833','DGN_1995_Indonesia_TM-3_Zone_48.1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23834','DGN_1995_Indonesia_TM-3_Zone_48.2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23835','DGN_1995_Indonesia_TM-3_Zone_49.1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23836','DGN_1995_Indonesia_TM-3_Zone_49.2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23837','DGN_1995_Indonesia_TM-3_Zone_50.1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23838','DGN_1995_Indonesia_TM-3_Zone_50.2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23839','DGN_1995_Indonesia_TM-3_Zone_51.1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23840','DGN_1995_Indonesia_TM-3_Zone_51.2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23841','DGN_1995_Indonesia_TM-3_Zone_52.1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23842','DGN_1995_Indonesia_TM-3_Zone_52.2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23843','DGN_1995_Indonesia_TM-3_Zone_53.1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23844','DGN_1995_Indonesia_TM-3_Zone_53.2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23845','DGN_1995_Indonesia_TM-3_Zone_54.1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23846','Indonesian_1974_UTM_Zone_46N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23847','Indonesian_1974_UTM_Zone_47N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23848','Indonesian_1974_UTM_Zone_48N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23849','Indonesian_1974_UTM_Zone_49N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23850','Indonesian_1974_UTM_Zone_50N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23851','Indonesian_1974_UTM_Zone_51N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23852','Indonesian_1974_UTM_Zone_52N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23853','Indonesian_1974_UTM_Zone_53N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23866','DGN_1995_UTM_Zone_46N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23867','DGN_1995_UTM_Zone_47N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23868','DGN_1995_UTM_Zone_48N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23869','DGN_1995_UTM_Zone_49N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23870','DGN_1995_UTM_Zone_50N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23871','DGN_1995_UTM_Zone_51N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23872','DGN_1995_UTM_Zone_52N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23877','DGN_1995_UTM_Zone_47S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23878','DGN_1995_UTM_Zone_48S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23879','DGN_1995_UTM_Zone_49S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23880','DGN_1995_UTM_Zone_50S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23881','DGN_1995_UTM_Zone_51S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23882','DGN_1995_UTM_Zone_52S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23883','DGN_1995_UTM_Zone_53S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23884','DGN_1995_UTM_Zone_54S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23886','Indonesian_1974_UTM_Zone_46S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23887','Indonesian_1974_UTM_Zone_47S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23888','Indonesian_1974_UTM_Zone_48S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23889','Indonesian_1974_UTM_Zone_49S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23890','Indonesian_1974_UTM_Zone_50S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23891','Indonesian_1974_UTM_Zone_51S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23892','Indonesian_1974_UTM_Zone_52S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23893','Indonesian_1974_UTM_Zone_53S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23894','Indonesian_1974_UTM_Zone_54S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23946','Indian_1954_UTM_Zone_46N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23947','Indian_1954_UTM_Zone_47N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','23948','Indian_1954_UTM_Zone_48N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24047','Indian_1975_UTM_Zone_47N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24048','Indian_1975_UTM_Zone_48N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24100','Jamaica_1875_Old_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24200','Jamaica_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24305','Kalianpur_1937_UTM_Zone_45N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24306','Kalianpur_1937_UTM_Zone_46N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24311','Kalianpur_1962_UTM_Zone_41N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24312','Kalianpur_1962_UTM_Zone_42N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24313','Kalianpur_1962_UTM_Zone_43N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24342','Kalianpur_1975_UTM_Zone_42N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24343','Kalianpur_1975_UTM_Zone_43N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24344','Kalianpur_1975_UTM_Zone_44N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24345','Kalianpur_1975_UTM_Zone_45N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24346','Kalianpur_1975_UTM_Zone_46N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24347','Kalianpur_1975_UTM_Zone_47N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24370','Kalianpur_1880_India_Zone_0','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24371','Kalianpur_1880_India_Zone_I','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24372','Kalianpur_1880_India_Zone_IIa','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24373','Kalianpur_1880_India_Zone_III','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24374','Kalianpur_1880_India_Zone_IV','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24375','Kalianpur_1937_India_Zone_IIb','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24376','Kalianpur_1962_India_Zone_I','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24377','Kalianpur_1962_India_Zone_IIa','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24378','Kalianpur_1975_India_Zone_I','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24379','Kalianpur_1975_India_Zone_IIa','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24380','Kalianpur_1975_India_Zone_IIb','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24381','Kalianpur_1975_India_Zone_III','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24382','Kalianpur_1880_India_Zone_IIb','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24383','Kalianpur_1975_India_Zone_IV','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24500','Kertau_Singapore_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24547','Kertau_UTM_Zone_47N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24548','Kertau_UTM_Zone_48N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24571','Kertau_RSO_Malaya_Chains','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24600','KOC_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24718','La_Canoa_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24719','La_Canoa_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24720','La_Canoa_UTM_Zone_20N','ESRI');
INSERT INTO "area" VALUES('ESRI','3','Venezuela - east of 60~W, N hemisphere','Venezuela - east of 60~W, N hemisphere',7.6,10.0,-61.0,-58.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','24721','La_Canoa_UTM_Zone_21N',NULL,NULL,'EPSG','4400','EPSG','4247','EPSG','16021','ESRI','3',NULL,0);
INSERT INTO alias_name VALUES('projected_crs','EPSG','24817','PSAD_1956_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24818','PSAD_1956_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24819','PSAD_1956_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24820','PSAD_1956_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24821','PSAD_1956_UTM_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24877','PSAD_1956_UTM_Zone_17S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24878','PSAD_1956_UTM_Zone_18S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24879','PSAD_1956_UTM_Zone_19S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24880','PSAD_1956_UTM_Zone_20S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24881','PSAD_1956_UTM_Zone_21S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24882','PSAD_1956_UTM_Zone_22S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24891','Peru_West_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24892','Peru_Central_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','24893','Peru_East_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25000','Ghana_Metre_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25231','Lome_UTM_Zone_31N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25391','Philippines_Zone_I','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25392','Philippines_Zone_II','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25393','Philippines_Zone_III','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25394','Philippines_Zone_IV','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25395','Philippines_Zone_V','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25828','ETRS_1989_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25829','ETRS_1989_UTM_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25830','ETRS_1989_UTM_Zone_30N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25831','ETRS_1989_UTM_Zone_31N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25832','ETRS_1989_UTM_Zone_32N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25833','ETRS_1989_UTM_Zone_33N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25834','ETRS_1989_UTM_Zone_34N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25835','ETRS_1989_UTM_Zone_35N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25836','ETRS_1989_UTM_Zone_36N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25837','ETRS_1989_UTM_Zone_37N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25838','ETRS_1989_UTM_Zone_38N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25884','ETRS_1989_TM_Baltic_1993','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','25932','Malongo_1987_UTM_Zone_32S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26191','Nord_Maroc','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26192','Sud_Maroc','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26193','Sahara','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26194','Merchich_Sahara_Nord','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26195','Merchich_Sahara_Sud','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26237','Massawa_UTM_Zone_37N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26331','Minna_UTM_Zone_31N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26332','Minna_UTM_Zone_32N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26391','Nigeria_West_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26392','Nigeria_Mid_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26393','Nigeria_East_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26432','Mhast_UTM_Zone_32S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26591','Monte_Mario_Rome_Italy_1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26592','Monte_Mario_Rome_Italy_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26632','Mporaloko_UTM_Zone_32N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26692','Mporaloko_UTM_Zone_32S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26701','NAD_1927_UTM_Zone_1N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26702','NAD_1927_UTM_Zone_2N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26703','NAD_1927_UTM_Zone_3N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26704','NAD_1927_UTM_Zone_4N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26705','NAD_1927_UTM_Zone_5N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26706','NAD_1927_UTM_Zone_6N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26707','NAD_1927_UTM_Zone_7N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26708','NAD_1927_UTM_Zone_8N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26709','NAD_1927_UTM_Zone_9N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26710','NAD_1927_UTM_Zone_10N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26711','NAD_1927_UTM_Zone_11N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26712','NAD_1927_UTM_Zone_12N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26713','NAD_1927_UTM_Zone_13N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26714','NAD_1927_UTM_Zone_14N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26715','NAD_1927_UTM_Zone_15N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26716','NAD_1927_UTM_Zone_16N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26717','NAD_1927_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26718','NAD_1927_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26719','NAD_1927_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26720','NAD_1927_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26721','NAD_1927_UTM_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26722','NAD_1927_UTM_Zone_22N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26729','NAD_1927_StatePlane_Alabama_East_FIPS_0101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26730','NAD_1927_StatePlane_Alabama_West_FIPS_0102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26731','NAD_1927_StatePlane_Alaska_1_FIPS_5001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26732','NAD_1927_StatePlane_Alaska_2_FIPS_5002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26733','NAD_1927_StatePlane_Alaska_3_FIPS_5003','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26734','NAD_1927_StatePlane_Alaska_4_FIPS_5004','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26735','NAD_1927_StatePlane_Alaska_5_FIPS_5005','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26736','NAD_1927_StatePlane_Alaska_6_FIPS_5006','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26737','NAD_1927_StatePlane_Alaska_7_FIPS_5007','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26738','NAD_1927_StatePlane_Alaska_8_FIPS_5008','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26739','NAD_1927_StatePlane_Alaska_9_FIPS_5009','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26740','NAD_1927_StatePlane_Alaska_10_FIPS_5010','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26741','NAD_1927_StatePlane_California_I_FIPS_0401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26742','NAD_1927_StatePlane_California_II_FIPS_0402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26743','NAD_1927_StatePlane_California_III_FIPS_0403','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26744','NAD_1927_StatePlane_California_IV_FIPS_0404','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26745','NAD_1927_StatePlane_California_V_FIPS_0405','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26746','NAD_1927_StatePlane_California_VI_FIPS_0406','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26747','NAD_1927_StatePlane_California_VII_FIPS_0407','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26748','NAD_1927_StatePlane_Arizona_East_FIPS_0201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26749','NAD_1927_StatePlane_Arizona_Central_FIPS_0202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26750','NAD_1927_StatePlane_Arizona_West_FIPS_0203','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26751','NAD_1927_StatePlane_Arkansas_North_FIPS_0301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26752','NAD_1927_StatePlane_Arkansas_South_FIPS_0302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26753','NAD_1927_StatePlane_Colorado_North_FIPS_0501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26754','NAD_1927_StatePlane_Colorado_Central_FIPS_0502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26755','NAD_1927_StatePlane_Colorado_South_FIPS_0503','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26756','NAD_1927_StatePlane_Connecticut_FIPS_0600','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26757','NAD_1927_StatePlane_Delaware_FIPS_0700','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26758','NAD_1927_StatePlane_Florida_East_FIPS_0901','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26759','NAD_1927_StatePlane_Florida_West_FIPS_0902','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26760','NAD_1927_StatePlane_Florida_North_FIPS_0903','ESRI');
INSERT INTO "conversion" VALUES('ESRI','26761','unnamed',NULL,NULL,'EPSG','1546','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',18.83333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-155.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','26761','NAD_1927_StatePlane_Hawaii_1_FIPS_5101',NULL,NULL,'ESRI','Foot_US','EPSG','4267','ESRI','26761','EPSG','1546',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','26762','unnamed',NULL,NULL,'EPSG','1547','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',20.33333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-156.6666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','26762','NAD_1927_StatePlane_Hawaii_2_FIPS_5102',NULL,NULL,'ESRI','Foot_US','EPSG','4267','ESRI','26762','EPSG','1547',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','26763','unnamed',NULL,NULL,'EPSG','1548','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',21.16666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-158.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','26763','NAD_1927_StatePlane_Hawaii_3_FIPS_5103',NULL,NULL,'ESRI','Foot_US','EPSG','4267','ESRI','26763','EPSG','1548',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','26764','unnamed',NULL,NULL,'EPSG','1549','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',21.83333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-159.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','26764','NAD_1927_StatePlane_Hawaii_4_FIPS_5104',NULL,NULL,'ESRI','Foot_US','EPSG','4267','ESRI','26764','EPSG','1549',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','26765','unnamed',NULL,NULL,'EPSG','1550','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',21.66666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-160.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','26765','NAD_1927_StatePlane_Hawaii_5_FIPS_5105',NULL,NULL,'ESRI','Foot_US','EPSG','4267','ESRI','26765','EPSG','1550',NULL,1);
INSERT INTO alias_name VALUES('projected_crs','EPSG','26766','NAD_1927_StatePlane_Georgia_East_FIPS_1001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26767','NAD_1927_StatePlane_Georgia_West_FIPS_1002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26768','NAD_1927_StatePlane_Idaho_East_FIPS_1101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26769','NAD_1927_StatePlane_Idaho_Central_FIPS_1102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26770','NAD_1927_StatePlane_Idaho_West_FIPS_1103','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26771','NAD_1927_StatePlane_Illinois_East_FIPS_1201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26772','NAD_1927_StatePlane_Illinois_West_FIPS_1202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26773','NAD_1927_StatePlane_Indiana_East_FIPS_1301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26774','NAD_1927_StatePlane_Indiana_West_FIPS_1302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26775','NAD_1927_StatePlane_Iowa_North_FIPS_1401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26776','NAD_1927_StatePlane_Iowa_South_FIPS_1402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26777','NAD_1927_StatePlane_Kansas_North_FIPS_1501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26778','NAD_1927_StatePlane_Kansas_South_FIPS_1502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26779','NAD_1927_StatePlane_Kentucky_North_FIPS_1601','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26780','NAD_1927_StatePlane_Kentucky_South_FIPS_1602','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26781','NAD_1927_StatePlane_Louisiana_North_FIPS_1701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26782','NAD_1927_StatePlane_Louisiana_South_FIPS_1702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26783','NAD_1927_StatePlane_Maine_East_FIPS_1801','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26784','NAD_1927_StatePlane_Maine_West_FIPS_1802','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26785','NAD_1927_StatePlane_Maryland_FIPS_1900','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26786','NAD_1927_StatePlane_Massachusetts_Mainland_FIPS_2001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26787','NAD_1927_StatePlane_Massachusetts_Island_FIPS_2002','ESRI');
INSERT INTO "conversion" VALUES('ESRI','26788','unnamed',NULL,NULL,'EPSG','1723','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.78333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-87.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.48333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.08333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','26788','NAD_1927_StatePlane_Michigan_North_FIPS_2111',NULL,NULL,'ESRI','Foot_US','EPSG','4267','ESRI','26788','EPSG','1723',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','26789','unnamed',NULL,NULL,'EPSG','1724','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.31666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.33333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.18333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.7,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','26789','NAD_1927_StatePlane_Michigan_Central_FIPS_2112',NULL,NULL,'ESRI','Foot_US','EPSG','4267','ESRI','26789','EPSG','1724',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','26790','unnamed',NULL,NULL,'EPSG','1725','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.33333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.1,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','26790','NAD_1927_StatePlane_Michigan_South_FIPS_2113',NULL,NULL,'ESRI','Foot_US','EPSG','4267','ESRI','26790','EPSG','1725',NULL,0);
INSERT INTO alias_name VALUES('projected_crs','EPSG','26791','NAD_1927_StatePlane_Minnesota_North_FIPS_2201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26792','NAD_1927_StatePlane_Minnesota_Central_FIPS_2202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26793','NAD_1927_StatePlane_Minnesota_South_FIPS_2203','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26794','NAD_1927_StatePlane_Mississippi_East_FIPS_2301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26795','NAD_1927_StatePlane_Mississippi_West_FIPS_2302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26796','NAD_1927_StatePlane_Missouri_East_FIPS_2401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26797','NAD_1927_StatePlane_Missouri_Central_FIPS_2402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26798','NAD_1927_StatePlane_Missouri_West_FIPS_2403','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26799','NAD_1927_StatePlane_California_VII_FIPS_0407','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26801','NAD_Michigan_StatePlane_Michigan_East_Old_FIPS_2101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26802','NAD_Michigan_StatePlane_Michigan_Central_Old_FIPS_2102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26803','NAD_Michigan_StatePlane_Michigan_West_Old_FIPS_2103','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26811','NAD_Michigan_StatePlane_Michigan_North_FIPS_2111','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26812','NAD_Michigan_StatePlane_Michigan_Central_FIPS_2112','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26813','NAD_Michigan_StatePlane_Michigan_South_FIPS_2113','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26847','NAD_1983_StatePlane_Maine_East_FIPS_1801_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26848','NAD_1983_StatePlane_Maine_West_FIPS_1802_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26849','NAD_1983_StatePlane_Minnesota_North_FIPS_2201_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26850','NAD_1983_StatePlane_Minnesota_Central_FIPS_2202_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26851','NAD_1983_StatePlane_Minnesota_South_FIPS_2203_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26852','NAD_1983_StatePlane_Nebraska_FIPS_2600_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26853','NAD_1983_StatePlane_West_Virginia_North_FIPS_4701_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26854','NAD_1983_StatePlane_West_Virginia_South_FIPS_4702_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26855','NAD_1983_HARN_StatePlane_Maine_East_FIPS_1801_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26856','NAD_1983_HARN_StatePlane_Maine_West_FIPS_1802_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26857','NAD_1983_HARN_StatePlane_Minnesota_North_FIPS_2201_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26858','NAD_1983_HARN_StatePlane_Minnesota_Central_FIPS_2202_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26859','NAD_1983_HARN_StatePlane_Minnesota_South_FIPS_2203_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26860','NAD_1983_HARN_StatePlane_Nebraska_FIPS_2600_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26861','NAD_1983_HARN_StatePlane_West_Virginia_North_FIPS_4701_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26862','NAD_1983_HARN_StatePlane_West_Virginia_South_FIPS_4702_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26863','NAD_1983_NSRS2007_StatePlane_Maine_East_FIPS_1801_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26864','NAD_1983_NSRS2007_StatePlane_Maine_West_FIPS_1802_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26865','NAD_1983_NSRS2007_StatePlane_Minnesota_North_FIPS_2201_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26866','NAD_1983_NSRS2007_StatePlane_Minnesota_Central_FIPS_2202_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26867','NAD_1983_NSRS2007_StatePlane_Minnesota_South_FIPS_2203_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26868','NAD_1983_NSRS2007_StatePlane_Nebraska_FIPS_2600_Ft_US','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26869','NAD_1983_NSRS2007_StatePlane_West_Virginia_North_FIPS_4701_FtUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26870','NAD_1983_NSRS2007_StatePlane_West_Virginia_South_FIPS_4702_FtUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26891','NAD_1983_CSRS_MTM_11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26892','NAD_1983_CSRS_MTM_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26893','NAD_1983_CSRS_MTM_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26894','NAD_1983_CSRS_MTM_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26895','NAD_1983_CSRS_MTM_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26896','NAD_1983_CSRS_MTM_16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26897','NAD_1983_CSRS_MTM_17','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26898','NAD_1983_CSRS_MTM_1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26899','NAD_1983_CSRS_MTM_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26901','NAD_1983_UTM_Zone_1N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26902','NAD_1983_UTM_Zone_2N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26903','NAD_1983_UTM_Zone_3N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26904','NAD_1983_UTM_Zone_4N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26905','NAD_1983_UTM_Zone_5N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26906','NAD_1983_UTM_Zone_6N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26907','NAD_1983_UTM_Zone_7N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26908','NAD_1983_UTM_Zone_8N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26909','NAD_1983_UTM_Zone_9N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26910','NAD_1983_UTM_Zone_10N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26911','NAD_1983_UTM_Zone_11N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26912','NAD_1983_UTM_Zone_12N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26913','NAD_1983_UTM_Zone_13N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26914','NAD_1983_UTM_Zone_14N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26915','NAD_1983_UTM_Zone_15N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26916','NAD_1983_UTM_Zone_16N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26917','NAD_1983_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26918','NAD_1983_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26919','NAD_1983_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26920','NAD_1983_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26921','NAD_1983_UTM_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26922','NAD_1983_UTM_Zone_22N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26923','NAD_1983_UTM_Zone_23N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26929','NAD_1983_StatePlane_Alabama_East_FIPS_0101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26930','NAD_1983_StatePlane_Alabama_West_FIPS_0102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26931','NAD_1983_StatePlane_Alaska_1_FIPS_5001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26932','NAD_1983_StatePlane_Alaska_2_FIPS_5002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26933','NAD_1983_StatePlane_Alaska_3_FIPS_5003','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26934','NAD_1983_StatePlane_Alaska_4_FIPS_5004','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26935','NAD_1983_StatePlane_Alaska_5_FIPS_5005','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26936','NAD_1983_StatePlane_Alaska_6_FIPS_5006','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26937','NAD_1983_StatePlane_Alaska_7_FIPS_5007','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26938','NAD_1983_StatePlane_Alaska_8_FIPS_5008','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26939','NAD_1983_StatePlane_Alaska_9_FIPS_5009','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26940','NAD_1983_StatePlane_Alaska_10_FIPS_5010','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26941','NAD_1983_StatePlane_California_I_FIPS_0401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26942','NAD_1983_StatePlane_California_II_FIPS_0402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26943','NAD_1983_StatePlane_California_III_FIPS_0403','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26944','NAD_1983_StatePlane_California_IV_FIPS_0404','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26945','NAD_1983_StatePlane_California_V_FIPS_0405','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26946','NAD_1983_StatePlane_California_VI_FIPS_0406','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26948','NAD_1983_StatePlane_Arizona_East_FIPS_0201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26949','NAD_1983_StatePlane_Arizona_Central_FIPS_0202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26950','NAD_1983_StatePlane_Arizona_West_FIPS_0203','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26951','NAD_1983_StatePlane_Arkansas_North_FIPS_0301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26952','NAD_1983_StatePlane_Arkansas_South_FIPS_0302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26953','NAD_1983_StatePlane_Colorado_North_FIPS_0501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26954','NAD_1983_StatePlane_Colorado_Central_FIPS_0502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26955','NAD_1983_StatePlane_Colorado_South_FIPS_0503','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26956','NAD_1983_StatePlane_Connecticut_FIPS_0600','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26957','NAD_1983_StatePlane_Delaware_FIPS_0700','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26958','NAD_1983_StatePlane_Florida_East_FIPS_0901','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26959','NAD_1983_StatePlane_Florida_West_FIPS_0902','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26960','NAD_1983_StatePlane_Florida_North_FIPS_0903','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26961','NAD_1983_StatePlane_Hawaii_1_FIPS_5101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26962','NAD_1983_StatePlane_Hawaii_2_FIPS_5102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26963','NAD_1983_StatePlane_Hawaii_3_FIPS_5103','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26964','NAD_1983_StatePlane_Hawaii_4_FIPS_5104','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26965','NAD_1983_StatePlane_Hawaii_5_FIPS_5105','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26966','NAD_1983_StatePlane_Georgia_East_FIPS_1001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26967','NAD_1983_StatePlane_Georgia_West_FIPS_1002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26968','NAD_1983_StatePlane_Idaho_East_FIPS_1101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26969','NAD_1983_StatePlane_Idaho_Central_FIPS_1102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26970','NAD_1983_StatePlane_Idaho_West_FIPS_1103','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26971','NAD_1983_StatePlane_Illinois_East_FIPS_1201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26972','NAD_1983_StatePlane_Illinois_West_FIPS_1202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26973','NAD_1983_StatePlane_Indiana_East_FIPS_1301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26974','NAD_1983_StatePlane_Indiana_West_FIPS_1302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26975','NAD_1983_StatePlane_Iowa_North_FIPS_1401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26976','NAD_1983_StatePlane_Iowa_South_FIPS_1402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26977','NAD_1983_StatePlane_Kansas_North_FIPS_1501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26978','NAD_1983_StatePlane_Kansas_South_FIPS_1502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26979','NAD_1983_StatePlane_Kentucky_North_FIPS_1601','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26980','NAD_1983_StatePlane_Kentucky_South_FIPS_1602','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26981','NAD_1983_StatePlane_Louisiana_North_FIPS_1701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26982','NAD_1983_StatePlane_Louisiana_South_FIPS_1702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26983','NAD_1983_StatePlane_Maine_East_FIPS_1801','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26984','NAD_1983_StatePlane_Maine_West_FIPS_1802','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26985','NAD_1983_StatePlane_Maryland_FIPS_1900','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26986','NAD_1983_StatePlane_Massachusetts_Mainland_FIPS_2001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26987','NAD_1983_StatePlane_Massachusetts_Island_FIPS_2002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26988','NAD_1983_StatePlane_Michigan_North_FIPS_2111','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26989','NAD_1983_StatePlane_Michigan_Central_FIPS_2112','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26990','NAD_1983_StatePlane_Michigan_South_FIPS_2113','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26991','NAD_1983_StatePlane_Minnesota_North_FIPS_2201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26992','NAD_1983_StatePlane_Minnesota_Central_FIPS_2202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26993','NAD_1983_StatePlane_Minnesota_South_FIPS_2203','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26994','NAD_1983_StatePlane_Mississippi_East_FIPS_2301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26995','NAD_1983_StatePlane_Mississippi_West_FIPS_2302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26996','NAD_1983_StatePlane_Missouri_East_FIPS_2401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26997','NAD_1983_StatePlane_Missouri_Central_FIPS_2402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','26998','NAD_1983_StatePlane_Missouri_West_FIPS_2403','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27037','Nahrwan_1967_UTM_Zone_37N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27038','Nahrwan_1967_UTM_Zone_38N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27039','Nahrwan_1967_UTM_Zone_39N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27040','Nahrwan_1967_UTM_Zone_40N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27120','Naparima_1972_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27200','GD_1949_New_Zealand_Map_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27205','NZGD_1949_Mount_Eden_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27206','NZGD_1949_Bay_of_Plenty_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27207','NZGD_1949_Poverty_Bay_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27208','NZGD_1949_Hawkes_Bay_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27209','NZGD_1949_Taranaki_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27210','NZGD_1949_Tuhirangi_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27211','NZGD_1949_Wanganui_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27212','NZGD_1949_Wairarapa_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27213','NZGD_1949_Wellington_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27214','NZGD_1949_Collingwood_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27215','NZGD_1949_Nelson_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27216','NZGD_1949_Karamea_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27217','NZGD_1949_Buller_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27218','NZGD_1949_Grey_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27219','NZGD_1949_Amuri_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27220','NZGD_1949_Marlborough_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27221','NZGD_1949_Hokitika_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27222','NZGD_1949_Okarito_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27223','NZGD_1949_Jacksons_Bay_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27224','NZGD_1949_Mount_Pleasant_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27225','NZGD_1949_Gawler_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27226','NZGD_1949_Timaru_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27227','NZGD_1949_Lindis_Peak_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27228','NZGD_1949_Mount_Nicholas_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27229','NZGD_1949_Mount_York_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27230','NZGD_1949_Observation_Point_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27231','NZGD_1949_North_Taieri_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27232','NZGD_1949_Bluff_Circuit','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27258','NZGD_1949_UTM_Zone_58S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27259','NZGD_1949_UTM_Zone_59S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27260','NZGD_1949_UTM_Zone_60S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27291','New_Zealand_North_Island','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27292','New_Zealand_South_Island','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27391','NGO_1948_Oslo_Norway_Zone_1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27392','NGO_1948_Oslo_Norway_Zone_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27393','NGO_1948_Oslo_Norway_Zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27394','NGO_1948_Oslo_Norway_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27395','NGO_1948_Oslo_Norway_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27396','NGO_1948_Oslo_Norway_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27397','NGO_1948_Oslo_Norway_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27398','NGO_1948_Oslo_Norway_Zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27429','Datum_73_UTM_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27492','Datum_73_Modified_Portuguese_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27493','Datum_73_Modified_Portuguese_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27500','Nord_de_Guerre','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27561','NTF_Paris_Lambert_Nord_France','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27562','NTF_Paris_Lambert_Centre_France','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27563','NTF_Paris_Lambert_Sud_France','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27564','NTF_Paris_Lambert_Corse','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27571','NTF_Paris_Lambert_Zone_I','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27572','NTF_Paris_Lambert_Zone_II','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27573','NTF_Paris_Lambert_Zone_III','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27574','NTF_Paris_Lambert_Zone_IV','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27581','NTF_Paris_France_I','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27582','NTF_Paris_France_II','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27583','NTF_Paris_France_III','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27584','NTF_Paris_France_IV','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27591','NTF_Paris_Nord_France','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27592','NTF_Paris_Centre_France','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27593','NTF_Paris_Sud_France','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27594','NTF_Paris_Corse','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','27700','British_National_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28191','Palestine_1923_Palestine_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28192','Palestine_1923_Palestine_Belt','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28193','Palestine_1923_Israel_CS_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28232','Pointe_Noire_UTM_Zone_32S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28348','GDA_1994_MGA_Zone_48','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28349','GDA_1994_MGA_Zone_49','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28350','GDA_1994_MGA_Zone_50','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28351','GDA_1994_MGA_Zone_51','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28352','GDA_1994_MGA_Zone_52','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28353','GDA_1994_MGA_Zone_53','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28354','GDA_1994_MGA_Zone_54','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28355','GDA_1994_MGA_Zone_55','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28356','GDA_1994_MGA_Zone_56','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28357','GDA_1994_MGA_Zone_57','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28358','GDA_1994_MGA_Zone_58','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28402','Pulkovo_1942_GK_Zone_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28403','Pulkovo_1942_GK_Zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28404','Pulkovo_1942_GK_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28405','Pulkovo_1942_GK_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28406','Pulkovo_1942_GK_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28407','Pulkovo_1942_GK_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28408','Pulkovo_1942_GK_Zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28409','Pulkovo_1942_GK_Zone_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28410','Pulkovo_1942_GK_Zone_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28411','Pulkovo_1942_GK_Zone_11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28412','Pulkovo_1942_GK_Zone_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28413','Pulkovo_1942_GK_Zone_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28414','Pulkovo_1942_GK_Zone_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28415','Pulkovo_1942_GK_Zone_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28416','Pulkovo_1942_GK_Zone_16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28417','Pulkovo_1942_GK_Zone_17','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28418','Pulkovo_1942_GK_Zone_18','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28419','Pulkovo_1942_GK_Zone_19','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28420','Pulkovo_1942_GK_Zone_20','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28421','Pulkovo_1942_GK_Zone_21','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28422','Pulkovo_1942_GK_Zone_22','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28423','Pulkovo_1942_GK_Zone_23','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28424','Pulkovo_1942_GK_Zone_24','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28425','Pulkovo_1942_GK_Zone_25','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28426','Pulkovo_1942_GK_Zone_26','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28427','Pulkovo_1942_GK_Zone_27','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28428','Pulkovo_1942_GK_Zone_28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28429','Pulkovo_1942_GK_Zone_29','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28430','Pulkovo_1942_GK_Zone_30','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28431','Pulkovo_1942_GK_Zone_31','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28432','Pulkovo_1942_GK_Zone_32','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28462','Pulkovo_1942_GK_Zone_2N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28463','Pulkovo_1942_GK_Zone_3N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28464','Pulkovo_1942_GK_Zone_4N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28465','Pulkovo_1942_GK_Zone_5N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28466','Pulkovo_1942_GK_Zone_6N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28467','Pulkovo_1942_GK_Zone_7N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28468','Pulkovo_1942_GK_Zone_8N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28469','Pulkovo_1942_GK_Zone_9N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28470','Pulkovo_1942_GK_Zone_10N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28471','Pulkovo_1942_GK_Zone_11N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28472','Pulkovo_1942_GK_Zone_12N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28473','Pulkovo_1942_GK_Zone_13N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28474','Pulkovo_1942_GK_Zone_14N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28475','Pulkovo_1942_GK_Zone_15N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28476','Pulkovo_1942_GK_Zone_16N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28477','Pulkovo_1942_GK_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28478','Pulkovo_1942_GK_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28479','Pulkovo_1942_GK_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28480','Pulkovo_1942_GK_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28481','Pulkovo_1942_GK_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28482','Pulkovo_1942_GK_Zone_22N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28483','Pulkovo_1942_GK_Zone_23N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28484','Pulkovo_1942_GK_Zone_24N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28485','Pulkovo_1942_GK_Zone_25N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28486','Pulkovo_1942_GK_Zone_26N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28487','Pulkovo_1942_GK_Zone_27N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28488','Pulkovo_1942_GK_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28489','Pulkovo_1942_GK_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28490','Pulkovo_1942_GK_Zone_30N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28491','Pulkovo_1942_GK_Zone_31N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28492','Pulkovo_1942_GK_Zone_32N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28600','Qatar_National_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28991','RD_Old','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','28992','RD_New','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29100','SAD_1969_Brazil_Polyconic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29101','SAD_1969_Brazil_Polyconic','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29118','SAD_1969_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29119','SAD_1969_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29120','SAD_1969_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29121','SAD_1969_UTM_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29122','SAD_1969_UTM_Zone_22N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29168','SAD_1969_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29169','SAD_1969_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29170','SAD_1969_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29171','SAD_1969_UTM_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29172','SAD_1969_UTM_Zone_22N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29177','SAD_1969_UTM_Zone_17S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29178','SAD_1969_UTM_Zone_18S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29179','SAD_1969_UTM_Zone_19S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29180','SAD_1969_UTM_Zone_20S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29181','SAD_1969_UTM_Zone_21S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29182','SAD_1969_UTM_Zone_22S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29183','SAD_1969_UTM_Zone_23S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29184','SAD_1969_UTM_Zone_24S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29185','SAD_1969_UTM_Zone_25S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29187','SAD_1969_UTM_Zone_17S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29188','SAD_1969_UTM_Zone_18S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29189','SAD_1969_UTM_Zone_19S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29190','SAD_1969_UTM_Zone_20S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29191','SAD_1969_UTM_Zone_21S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29192','SAD_1969_UTM_Zone_22S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29193','SAD_1969_UTM_Zone_23S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29194','SAD_1969_UTM_Zone_24S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29195','SAD_1969_UTM_Zone_25S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29220','Sapper_Hill_1943_UTM_Zone_20S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29221','Sapper_Hill_1943_UTM_Zone_21S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29333','Schwarzeck_UTM_Zone_33S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29635','Sudan_UTM_Zone_35N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29636','Sudan_UTM_Zone_36N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29701','Tananarive_1925_Paris_Laborde_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29738','Tananarive_1925_UTM_Zone_38S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29739','Tananarive_1925_UTM_Zone_39S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29849','Timbalai_1948_UTM_Zone_49N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29850','Timbalai_1948_UTM_Zone_50N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29871','Timbalai_1948_RSO_Borneo_Chains','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29872','Timbalai_1948_RSO_Borneo_Feet','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29873','Timbalai_1948_RSO_Borneo_Meters','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29900','TM65_Irish_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29901','OSNI_1952_Irish_National_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29902','TM65_Irish_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','29903','TM75_Irish_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30161','Japan_Zone_1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30162','Japan_Zone_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30163','Japan_Zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30164','Japan_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30165','Japan_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30166','Japan_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30167','Japan_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30168','Japan_Zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30169','Japan_Zone_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30170','Japan_Zone_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30171','Japan_Zone_11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30172','Japan_Zone_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30173','Japan_Zone_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30174','Japan_Zone_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30175','Japan_Zone_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30176','Japan_Zone_16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30177','Japan_Zone_17','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30178','Japan_Zone_18','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30179','Japan_Zone_19','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30200','Trinidad_1903_Trinidad_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30339','TC_1948_UTM_Zone_39N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30340','TC_1948_UTM_Zone_40N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30491','Nord_Algerie_Ancienne','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30492','Sud_Algerie_Ancienne','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30493','Voirol_1879_Nord_Algerie_Ancienne','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30494','Voirol_1879_Sud_Algerie_Ancienne','ESRI');
INSERT INTO "conversion" VALUES('ESRI','30591','unnamed',NULL,NULL,'EPSG','1728','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',3.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.999625544,'EPSG','9201','EPSG','8806','False easting',500135.0,'EPSG','9001','EPSG','8807','False northing',300090.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','30591','Nord_Algerie',NULL,NULL,'EPSG','4400','ESRI','4305','ESRI','30591','EPSG','1728',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','30592','unnamed',NULL,NULL,'EPSG','1729','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',37.0,'EPSG','9105','EPSG','8802','Longitude of natural origin',3.0,'EPSG','9105','EPSG','8805','Scale factor at natural origin',0.999625769,'EPSG','9201','EPSG','8806','False easting',500135.0,'EPSG','9001','EPSG','8807','False northing',300090.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','30592','Sud_Algerie',NULL,NULL,'EPSG','4400','ESRI','4305','ESRI','30592','EPSG','1729',NULL,1);
INSERT INTO alias_name VALUES('projected_crs','EPSG','30729','Nord_Sahara_1959_UTM_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30730','Nord_Sahara_1959_UTM_Zone_30N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30731','Nord_Sahara_1959_UTM_Zone_31N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30732','Nord_Sahara_1959_UTM_Zone_32N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30791','Nord_Sahara_1959_Voirol_Unifie_Nord','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30792','Nord_Sahara_1959_Voirol_Unifie_Sud','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','30800','Swedish_National_Grid','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31028','Yoff_1972_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31121','Zanderij_1972_UTM_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31154','Zanderij_TM_54_NW','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31170','Zanderij_Suriname_Old_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31171','Zanderij_Suriname_TM','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31251','MGI_Ferro_Austria_GK_West','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31252','MGI_Ferro_Austria_GK_Central','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31253','MGI_Ferro_Austria_GK_East','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31254','MGI_Austria_GK_West','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31255','MGI_Austria_GK_Central','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31256','MGI_Austria_GK_East','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31257','MGI_Austria_GK_M28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31258','MGI_Austria_GK_M31','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31259','MGI_Austria_GK_M34','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31265','MGI_3_Degree_Gauss_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31266','MGI_3_Degree_Gauss_Zone_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31267','MGI_3_Degree_Gauss_Zone_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31268','MGI_3_Degree_Gauss_Zone_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31275','MGI_Balkans_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31276','MGI_Balkans_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31277','MGI_Balkans_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31278','MGI_Balkans_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31279','MGI_Balkans_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31281','Austria_West_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31282','Austria_Central_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31283','Austria_East_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31284','MGI_M28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31285','MGI_M31','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31286','MGI_M34','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31287','MGI_Austria_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31288','MGI_Ferro_M28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31289','MGI_Ferro_M31','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31290','MGI_Ferro_M34','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31291','Austria_West_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31292','Austria_Central_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31293','Austria_East_Zone','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31294','MGI_M28','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31295','MGI_M31','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31296','MGI_M34','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31297','MGI_Austria_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31370','Belge_Lambert_1972','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31461','DHDN_3_Degree_Gauss_Zone_1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31462','DHDN_3_Degree_Gauss_Zone_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31463','DHDN_3_Degree_Gauss_Zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31464','DHDN_3_Degree_Gauss_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31465','DHDN_3_Degree_Gauss_Zone_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31466','DHDN_3_Degree_Gauss_Zone_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31467','DHDN_3_Degree_Gauss_Zone_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31468','DHDN_3_Degree_Gauss_Zone_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31469','DHDN_3_Degree_Gauss_Zone_5','ESRI');
INSERT INTO "projected_crs" VALUES('ESRI','31491','Germany_Zone_1',NULL,NULL,'EPSG','4400','EPSG','4314','EPSG','16201','EPSG','3892',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','31492','Germany_Zone_2',NULL,NULL,'EPSG','4400','EPSG','4314','EPSG','16262','EPSG','1624',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','31493','Germany_Zone_3',NULL,NULL,'EPSG','4400','EPSG','4314','EPSG','16263','EPSG','1625',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','31494','Germany_Zone_4',NULL,NULL,'EPSG','4400','EPSG','4314','EPSG','16264','EPSG','1626',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','31495','Germany_Zone_5',NULL,NULL,'EPSG','4400','EPSG','4314','EPSG','16265','EPSG','1627',NULL,0);
INSERT INTO alias_name VALUES('projected_crs','EPSG','31528','Conakry_1905_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31529','Conakry_1905_UTM_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31600','Stereo_33','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31700','Stereo_70','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31838','NGN_UTM_Zone_38N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31839','NGN_UTM_Zone_39N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31901','KUDAMS_KTM','ESRI');
INSERT INTO "projected_crs" VALUES('ESRI','31917','SIRGAS_UTM_Zone_17N',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16017','EPSG','1823',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','31918','SIRGAS_UTM_Zone_18N',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16018','EPSG','1825',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','31919','SIRGAS_UTM_Zone_19N',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16019','EPSG','1827',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','31920','SIRGAS_UTM_Zone_20N',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16020','EPSG','1829',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','31921','SIRGAS_UTM_Zone_21N',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16021','EPSG','1831',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','31922','SIRGAS_UTM_Zone_22N',NULL,NULL,'EPSG','4400','EPSG','4170','EPSG','16022','EPSG','1833',NULL,1);
INSERT INTO alias_name VALUES('projected_crs','EPSG','31965','SIRGAS_2000_UTM_Zone_11N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31966','SIRGAS_2000_UTM_Zone_12N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31967','SIRGAS_2000_UTM_Zone_13N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31968','SIRGAS_2000_UTM_Zone_14N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31969','SIRGAS_2000_UTM_Zone_15N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31970','SIRGAS_2000_UTM_Zone_16N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31971','SIRGAS_2000_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31972','SIRGAS_2000_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31973','SIRGAS_2000_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31974','SIRGAS_2000_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31975','SIRGAS_2000_UTM_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31976','SIRGAS_2000_UTM_Zone_22N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31977','SIRGAS_2000_UTM_Zone_17S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31978','SIRGAS_2000_UTM_Zone_18S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31979','SIRGAS_2000_UTM_Zone_19S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31980','SIRGAS_2000_UTM_Zone_20S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31981','SIRGAS_2000_UTM_Zone_21S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31982','SIRGAS_2000_UTM_Zone_22S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31983','SIRGAS_2000_UTM_Zone_23S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31984','SIRGAS_2000_UTM_Zone_24S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31985','SIRGAS_2000_UTM_Zone_25S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31986','SIRGAS_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31987','SIRGAS_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31988','SIRGAS_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31989','SIRGAS_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31990','SIRGAS_UTM_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31991','SIRGAS_UTM_Zone_22N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31992','SIRGAS_UTM_Zone_17S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31993','SIRGAS_UTM_Zone_18S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31994','SIRGAS_UTM_Zone_19S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31995','SIRGAS_UTM_Zone_20S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31996','SIRGAS_UTM_Zone_21S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31997','SIRGAS_UTM_Zone_22S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31998','SIRGAS_UTM_Zone_23S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','31999','SIRGAS_UTM_Zone_24S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32000','SIRGAS_UTM_Zone_25S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32001','NAD_1927_StatePlane_Montana_North_FIPS_2501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32002','NAD_1927_StatePlane_Montana_Central_FIPS_2502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32003','NAD_1927_StatePlane_Montana_South_FIPS_2503','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32005','NAD_1927_StatePlane_Nebraska_North_FIPS_2601','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32006','NAD_1927_StatePlane_Nebraska_South_FIPS_2602','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32007','NAD_1927_StatePlane_Nevada_East_FIPS_2701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32008','NAD_1927_StatePlane_Nevada_Central_FIPS_2702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32009','NAD_1927_StatePlane_Nevada_West_FIPS_2703','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32010','NAD_1927_StatePlane_New_Hampshire_FIPS_2800','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32011','NAD_1927_StatePlane_New_Jersey_FIPS_2900','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32012','NAD_1927_StatePlane_New_Mexico_East_FIPS_3001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32013','NAD_1927_StatePlane_New_Mexico_Central_FIPS_3002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32014','NAD_1927_StatePlane_New_Mexico_West_FIPS_3003','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32015','NAD_1927_StatePlane_New_York_East_FIPS_3101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32016','NAD_1927_StatePlane_New_York_Central_FIPS_3102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32017','NAD_1927_StatePlane_New_York_West_FIPS_3103','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32018','NAD_1927_StatePlane_New_York_Long_Island_FIPS_3104','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32019','NAD_1927_StatePlane_North_Carolina_FIPS_3200','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32020','NAD_1927_StatePlane_North_Dakota_North_FIPS_3301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32021','NAD_1927_StatePlane_North_Dakota_South_FIPS_3302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32022','NAD_1927_StatePlane_Ohio_North_FIPS_3401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32023','NAD_1927_StatePlane_Ohio_South_FIPS_3402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32024','NAD_1927_StatePlane_Oklahoma_North_FIPS_3501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32025','NAD_1927_StatePlane_Oklahoma_South_FIPS_3502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32026','NAD_1927_StatePlane_Oregon_North_FIPS_3601','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32027','NAD_1927_StatePlane_Oregon_South_FIPS_3602','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32028','NAD_1927_StatePlane_Pennsylvania_North_FIPS_3701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32029','NAD_1927_StatePlane_Pennsylvania_South_FIPS_3702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32030','NAD_1927_StatePlane_Rhode_Island_FIPS_3800','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32031','NAD_1927_StatePlane_South_Carolina_North_FIPS_3901','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32033','NAD_1927_StatePlane_South_Carolina_South_FIPS_3902','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32034','NAD_1927_StatePlane_South_Dakota_North_FIPS_4001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32035','NAD_1927_StatePlane_South_Dakota_South_FIPS_4002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32036','NAD_1927_StatePlane_Tennessee_FIPS_4100','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32037','NAD_1927_StatePlane_Texas_North_FIPS_4201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32038','NAD_1927_StatePlane_Texas_North_Central_FIPS_4202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32039','NAD_1927_StatePlane_Texas_Central_FIPS_4203','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32040','NAD_1927_StatePlane_Texas_South_Central_FIPS_4204','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32041','NAD_1927_StatePlane_Texas_South_FIPS_4205','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32042','NAD_1927_StatePlane_Utah_North_FIPS_4301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32043','NAD_1927_StatePlane_Utah_Central_FIPS_4302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32044','NAD_1927_StatePlane_Utah_South_FIPS_4303','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32045','NAD_1927_StatePlane_Vermont_FIPS_4400','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32046','NAD_1927_StatePlane_Virginia_North_FIPS_4501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32047','NAD_1927_StatePlane_Virginia_South_FIPS_4502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32048','NAD_1927_StatePlane_Washington_North_FIPS_4601','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32049','NAD_1927_StatePlane_Washington_South_FIPS_4602','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32050','NAD_1927_StatePlane_West_Virginia_North_FIPS_4701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32051','NAD_1927_StatePlane_West_Virginia_South_FIPS_4702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32052','NAD_1927_StatePlane_Wisconsin_North_FIPS_4801','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32053','NAD_1927_StatePlane_Wisconsin_Central_FIPS_4802','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32054','NAD_1927_StatePlane_Wisconsin_South_FIPS_4803','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32055','NAD_1927_StatePlane_Wyoming_East_FIPS_4901','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32056','NAD_1927_StatePlane_Wyoming_East_Central_FIPS_4902','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32057','NAD_1927_StatePlane_Wyoming_West_Central_FIPS_4903','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32058','NAD_1927_StatePlane_Wyoming_West_FIPS_4904','ESRI');
INSERT INTO "conversion" VALUES('ESRI','32059','unnamed',NULL,NULL,'EPSG','1194','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',17.83333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-66.43333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',18.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',18.43333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','32059','NAD_1927_StatePlane_Puerto_Rico_FIPS_5201',NULL,NULL,'ESRI','Foot_US','EPSG','4267','ESRI','32059','EPSG','1194',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','32060','unnamed',NULL,NULL,'EPSG','1254','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',17.83333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-66.43333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',18.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',18.43333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','32060','NAD_1927_StatePlane_Virgin_Islands_St_Croix_FIPS_5202',NULL,NULL,'ESRI','Foot_US','EPSG','4267','ESRI','32060','EPSG','1254',NULL,0);
INSERT INTO alias_name VALUES('projected_crs','EPSG','32061','NAD_1927_Guatemala_Norte','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32062','NAD_1927_Guatemala_Sur','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32064','NAD_1927_BLM_Zone_14N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32065','NAD_1927_BLM_Zone_15N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32066','NAD_1927_BLM_Zone_16N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32067','NAD_1927_BLM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32074','NAD_1927_BLM_Zone_14N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32075','NAD_1927_BLM_Zone_15N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32076','NAD_1927_BLM_Zone_16N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32077','NAD_1927_BLM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32081','NAD_1927_MTM_1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32082','NAD_1927_MTM_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32083','NAD_1927_MTM_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32084','NAD_1927_MTM_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32085','NAD_1927_MTM_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32086','NAD_1927_MTM_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32098','NAD_1927_Quebec_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32099','NAD_1927_StatePlane_Louisiana_Offshore_FIPS_1703','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32100','NAD_1983_StatePlane_Montana_FIPS_2500','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32104','NAD_1983_StatePlane_Nebraska_FIPS_2600','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32107','NAD_1983_StatePlane_Nevada_East_FIPS_2701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32108','NAD_1983_StatePlane_Nevada_Central_FIPS_2702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32109','NAD_1983_StatePlane_Nevada_West_FIPS_2703','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32110','NAD_1983_StatePlane_New_Hampshire_FIPS_2800','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32111','NAD_1983_StatePlane_New_Jersey_FIPS_2900','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32112','NAD_1983_StatePlane_New_Mexico_East_FIPS_3001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32113','NAD_1983_StatePlane_New_Mexico_Central_FIPS_3002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32114','NAD_1983_StatePlane_New_Mexico_West_FIPS_3003','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32115','NAD_1983_StatePlane_New_York_East_FIPS_3101','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32116','NAD_1983_StatePlane_New_York_Central_FIPS_3102','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32117','NAD_1983_StatePlane_New_York_West_FIPS_3103','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32118','NAD_1983_StatePlane_New_York_Long_Island_FIPS_3104','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32119','NAD_1983_StatePlane_North_Carolina_FIPS_3200','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32120','NAD_1983_StatePlane_North_Dakota_North_FIPS_3301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32121','NAD_1983_StatePlane_North_Dakota_South_FIPS_3302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32122','NAD_1983_StatePlane_Ohio_North_FIPS_3401','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32123','NAD_1983_StatePlane_Ohio_South_FIPS_3402','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32124','NAD_1983_StatePlane_Oklahoma_North_FIPS_3501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32125','NAD_1983_StatePlane_Oklahoma_South_FIPS_3502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32126','NAD_1983_StatePlane_Oregon_North_FIPS_3601','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32127','NAD_1983_StatePlane_Oregon_South_FIPS_3602','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32128','NAD_1983_StatePlane_Pennsylvania_North_FIPS_3701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32129','NAD_1983_StatePlane_Pennsylvania_South_FIPS_3702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32130','NAD_1983_StatePlane_Rhode_Island_FIPS_3800','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32133','NAD_1983_StatePlane_South_Carolina_FIPS_3900','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32134','NAD_1983_StatePlane_South_Dakota_North_FIPS_4001','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32135','NAD_1983_StatePlane_South_Dakota_South_FIPS_4002','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32136','NAD_1983_StatePlane_Tennessee_FIPS_4100','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32137','NAD_1983_StatePlane_Texas_North_FIPS_4201','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32138','NAD_1983_StatePlane_Texas_North_Central_FIPS_4202','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32139','NAD_1983_StatePlane_Texas_Central_FIPS_4203','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32140','NAD_1983_StatePlane_Texas_South_Central_FIPS_4204','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32141','NAD_1983_StatePlane_Texas_South_FIPS_4205','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32142','NAD_1983_StatePlane_Utah_North_FIPS_4301','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32143','NAD_1983_StatePlane_Utah_Central_FIPS_4302','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32144','NAD_1983_StatePlane_Utah_South_FIPS_4303','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32145','NAD_1983_StatePlane_Vermont_FIPS_4400','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32146','NAD_1983_StatePlane_Virginia_North_FIPS_4501','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32147','NAD_1983_StatePlane_Virginia_South_FIPS_4502','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32148','NAD_1983_StatePlane_Washington_North_FIPS_4601','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32149','NAD_1983_StatePlane_Washington_South_FIPS_4602','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32150','NAD_1983_StatePlane_West_Virginia_North_FIPS_4701','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32151','NAD_1983_StatePlane_West_Virginia_South_FIPS_4702','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32152','NAD_1983_StatePlane_Wisconsin_North_FIPS_4801','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32153','NAD_1983_StatePlane_Wisconsin_Central_FIPS_4802','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32154','NAD_1983_StatePlane_Wisconsin_South_FIPS_4803','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32155','NAD_1983_StatePlane_Wyoming_East_FIPS_4901','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32156','NAD_1983_StatePlane_Wyoming_East_Central_FIPS_4902','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32157','NAD_1983_StatePlane_Wyoming_West_Central_FIPS_4903','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32158','NAD_1983_StatePlane_Wyoming_West_FIPS_4904','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32161','NAD_1983_StatePlane_Puerto_Rico_Virgin_Islands_FIPS_5200','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32164','NAD_1983_BLM_Zone_14N_ftUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32165','NAD_1983_BLM_Zone_15N_ftUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32166','NAD_1983_BLM_Zone_16N_ftUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32167','NAD_1983_BLM_Zone_17N_ftUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32180','NAD_1983_MTM_2_SCoPQ','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32181','NAD_1983_MTM_1','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32182','NAD_1983_MTM_2','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32183','NAD_1983_MTM_3','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32184','NAD_1983_MTM_4','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32185','NAD_1983_MTM_5','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32186','NAD_1983_MTM_6','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32187','NAD_1983_MTM_7','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32188','NAD_1983_MTM_8','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32189','NAD_1983_MTM_9','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32190','NAD_1983_MTM_10','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32191','NAD_1983_MTM_11','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32192','NAD_1983_MTM_12','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32193','NAD_1983_MTM_13','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32194','NAD_1983_MTM_14','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32195','NAD_1983_MTM_15','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32196','NAD_1983_MTM_16','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32197','NAD_1983_MTM_17','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32198','NAD_1983_Quebec_Lambert','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32199','NAD_1983_StatePlane_Louisiana_Offshore_FIPS_1703','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32201','WGS_1972_UTM_Zone_1N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32202','WGS_1972_UTM_Zone_2N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32203','WGS_1972_UTM_Zone_3N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32204','WGS_1972_UTM_Zone_4N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32205','WGS_1972_UTM_Zone_5N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32206','WGS_1972_UTM_Zone_6N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32207','WGS_1972_UTM_Zone_7N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32208','WGS_1972_UTM_Zone_8N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32209','WGS_1972_UTM_Zone_9N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32210','WGS_1972_UTM_Zone_10N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32211','WGS_1972_UTM_Zone_11N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32212','WGS_1972_UTM_Zone_12N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32213','WGS_1972_UTM_Zone_13N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32214','WGS_1972_UTM_Zone_14N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32215','WGS_1972_UTM_Zone_15N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32216','WGS_1972_UTM_Zone_16N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32217','WGS_1972_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32218','WGS_1972_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32219','WGS_1972_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32220','WGS_1972_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32221','WGS_1972_UTM_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32222','WGS_1972_UTM_Zone_22N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32223','WGS_1972_UTM_Zone_23N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32224','WGS_1972_UTM_Zone_24N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32225','WGS_1972_UTM_Zone_25N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32226','WGS_1972_UTM_Zone_26N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32227','WGS_1972_UTM_Zone_27N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32228','WGS_1972_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32229','WGS_1972_UTM_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32230','WGS_1972_UTM_Zone_30N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32231','WGS_1972_UTM_Zone_31N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32232','WGS_1972_UTM_Zone_32N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32233','WGS_1972_UTM_Zone_33N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32234','WGS_1972_UTM_Zone_34N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32235','WGS_1972_UTM_Zone_35N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32236','WGS_1972_UTM_Zone_36N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32237','WGS_1972_UTM_Zone_37N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32238','WGS_1972_UTM_Zone_38N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32239','WGS_1972_UTM_Zone_39N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32240','WGS_1972_UTM_Zone_40N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32241','WGS_1972_UTM_Zone_41N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32242','WGS_1972_UTM_Zone_42N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32243','WGS_1972_UTM_Zone_43N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32244','WGS_1972_UTM_Zone_44N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32245','WGS_1972_UTM_Zone_45N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32246','WGS_1972_UTM_Zone_46N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32247','WGS_1972_UTM_Zone_47N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32248','WGS_1972_UTM_Zone_48N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32249','WGS_1972_UTM_Zone_49N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32250','WGS_1972_UTM_Zone_50N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32251','WGS_1972_UTM_Zone_51N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32252','WGS_1972_UTM_Zone_52N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32253','WGS_1972_UTM_Zone_53N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32254','WGS_1972_UTM_Zone_54N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32255','WGS_1972_UTM_Zone_55N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32256','WGS_1972_UTM_Zone_56N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32257','WGS_1972_UTM_Zone_57N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32258','WGS_1972_UTM_Zone_58N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32259','WGS_1972_UTM_Zone_59N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32260','WGS_1972_UTM_Zone_60N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32301','WGS_1972_UTM_Zone_1S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32302','WGS_1972_UTM_Zone_2S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32303','WGS_1972_UTM_Zone_3S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32304','WGS_1972_UTM_Zone_4S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32305','WGS_1972_UTM_Zone_5S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32306','WGS_1972_UTM_Zone_6S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32307','WGS_1972_UTM_Zone_7S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32308','WGS_1972_UTM_Zone_8S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32309','WGS_1972_UTM_Zone_9S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32310','WGS_1972_UTM_Zone_10S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32311','WGS_1972_UTM_Zone_11S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32312','WGS_1972_UTM_Zone_12S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32313','WGS_1972_UTM_Zone_13S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32314','WGS_1972_UTM_Zone_14S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32315','WGS_1972_UTM_Zone_15S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32316','WGS_1972_UTM_Zone_16S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32317','WGS_1972_UTM_Zone_17S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32318','WGS_1972_UTM_Zone_18S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32319','WGS_1972_UTM_Zone_19S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32320','WGS_1972_UTM_Zone_20S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32321','WGS_1972_UTM_Zone_21S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32322','WGS_1972_UTM_Zone_22S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32323','WGS_1972_UTM_Zone_23S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32324','WGS_1972_UTM_Zone_24S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32325','WGS_1972_UTM_Zone_25S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32326','WGS_1972_UTM_Zone_26S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32327','WGS_1972_UTM_Zone_27S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32328','WGS_1972_UTM_Zone_28S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32329','WGS_1972_UTM_Zone_29S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32330','WGS_1972_UTM_Zone_30S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32331','WGS_1972_UTM_Zone_31S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32332','WGS_1972_UTM_Zone_32S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32333','WGS_1972_UTM_Zone_33S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32334','WGS_1972_UTM_Zone_34S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32335','WGS_1972_UTM_Zone_35S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32336','WGS_1972_UTM_Zone_36S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32337','WGS_1972_UTM_Zone_37S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32338','WGS_1972_UTM_Zone_38S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32339','WGS_1972_UTM_Zone_39S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32340','WGS_1972_UTM_Zone_40S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32341','WGS_1972_UTM_Zone_41S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32342','WGS_1972_UTM_Zone_42S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32343','WGS_1972_UTM_Zone_43S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32344','WGS_1972_UTM_Zone_44S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32345','WGS_1972_UTM_Zone_45S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32346','WGS_1972_UTM_Zone_46S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32347','WGS_1972_UTM_Zone_47S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32348','WGS_1972_UTM_Zone_48S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32349','WGS_1972_UTM_Zone_49S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32350','WGS_1972_UTM_Zone_50S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32351','WGS_1972_UTM_Zone_51S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32352','WGS_1972_UTM_Zone_52S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32353','WGS_1972_UTM_Zone_53S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32354','WGS_1972_UTM_Zone_54S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32355','WGS_1972_UTM_Zone_55S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32356','WGS_1972_UTM_Zone_56S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32357','WGS_1972_UTM_Zone_57S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32358','WGS_1972_UTM_Zone_58S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32359','WGS_1972_UTM_Zone_59S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32360','WGS_1972_UTM_Zone_60S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32601','WGS_1984_UTM_Zone_1N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32602','WGS_1984_UTM_Zone_2N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32603','WGS_1984_UTM_Zone_3N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32604','WGS_1984_UTM_Zone_4N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32605','WGS_1984_UTM_Zone_5N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32606','WGS_1984_UTM_Zone_6N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32607','WGS_1984_UTM_Zone_7N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32608','WGS_1984_UTM_Zone_8N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32609','WGS_1984_UTM_Zone_9N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32610','WGS_1984_UTM_Zone_10N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32611','WGS_1984_UTM_Zone_11N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32612','WGS_1984_UTM_Zone_12N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32613','WGS_1984_UTM_Zone_13N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32614','WGS_1984_UTM_Zone_14N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32615','WGS_1984_UTM_Zone_15N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32616','WGS_1984_UTM_Zone_16N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32617','WGS_1984_UTM_Zone_17N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32618','WGS_1984_UTM_Zone_18N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32619','WGS_1984_UTM_Zone_19N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32620','WGS_1984_UTM_Zone_20N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32621','WGS_1984_UTM_Zone_21N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32622','WGS_1984_UTM_Zone_22N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32623','WGS_1984_UTM_Zone_23N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32624','WGS_1984_UTM_Zone_24N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32625','WGS_1984_UTM_Zone_25N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32626','WGS_1984_UTM_Zone_26N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32627','WGS_1984_UTM_Zone_27N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32628','WGS_1984_UTM_Zone_28N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32629','WGS_1984_UTM_Zone_29N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32630','WGS_1984_UTM_Zone_30N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32631','WGS_1984_UTM_Zone_31N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32632','WGS_1984_UTM_Zone_32N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32633','WGS_1984_UTM_Zone_33N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32634','WGS_1984_UTM_Zone_34N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32635','WGS_1984_UTM_Zone_35N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32636','WGS_1984_UTM_Zone_36N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32637','WGS_1984_UTM_Zone_37N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32638','WGS_1984_UTM_Zone_38N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32639','WGS_1984_UTM_Zone_39N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32640','WGS_1984_UTM_Zone_40N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32641','WGS_1984_UTM_Zone_41N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32642','WGS_1984_UTM_Zone_42N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32643','WGS_1984_UTM_Zone_43N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32644','WGS_1984_UTM_Zone_44N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32645','WGS_1984_UTM_Zone_45N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32646','WGS_1984_UTM_Zone_46N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32647','WGS_1984_UTM_Zone_47N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32648','WGS_1984_UTM_Zone_48N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32649','WGS_1984_UTM_Zone_49N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32650','WGS_1984_UTM_Zone_50N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32651','WGS_1984_UTM_Zone_51N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32652','WGS_1984_UTM_Zone_52N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32653','WGS_1984_UTM_Zone_53N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32654','WGS_1984_UTM_Zone_54N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32655','WGS_1984_UTM_Zone_55N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32656','WGS_1984_UTM_Zone_56N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32657','WGS_1984_UTM_Zone_57N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32658','WGS_1984_UTM_Zone_58N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32659','WGS_1984_UTM_Zone_59N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32660','WGS_1984_UTM_Zone_60N','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32661','UPS_North','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32662','WGS_1984_Plate_Carree','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32664','WGS_1984_BLM_Zone_14N_ftUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32665','WGS_1984_BLM_Zone_15N_ftUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32666','WGS_1984_BLM_Zone_16N_ftUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32667','WGS_1984_BLM_Zone_17N_ftUS','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32701','WGS_1984_UTM_Zone_1S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32702','WGS_1984_UTM_Zone_2S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32703','WGS_1984_UTM_Zone_3S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32704','WGS_1984_UTM_Zone_4S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32705','WGS_1984_UTM_Zone_5S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32706','WGS_1984_UTM_Zone_6S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32707','WGS_1984_UTM_Zone_7S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32708','WGS_1984_UTM_Zone_8S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32709','WGS_1984_UTM_Zone_9S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32710','WGS_1984_UTM_Zone_10S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32711','WGS_1984_UTM_Zone_11S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32712','WGS_1984_UTM_Zone_12S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32713','WGS_1984_UTM_Zone_13S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32714','WGS_1984_UTM_Zone_14S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32715','WGS_1984_UTM_Zone_15S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32716','WGS_1984_UTM_Zone_16S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32717','WGS_1984_UTM_Zone_17S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32718','WGS_1984_UTM_Zone_18S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32719','WGS_1984_UTM_Zone_19S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32720','WGS_1984_UTM_Zone_20S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32721','WGS_1984_UTM_Zone_21S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32722','WGS_1984_UTM_Zone_22S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32723','WGS_1984_UTM_Zone_23S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32724','WGS_1984_UTM_Zone_24S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32725','WGS_1984_UTM_Zone_25S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32726','WGS_1984_UTM_Zone_26S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32727','WGS_1984_UTM_Zone_27S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32728','WGS_1984_UTM_Zone_28S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32729','WGS_1984_UTM_Zone_29S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32730','WGS_1984_UTM_Zone_30S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32731','WGS_1984_UTM_Zone_31S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32732','WGS_1984_UTM_Zone_32S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32733','WGS_1984_UTM_Zone_33S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32734','WGS_1984_UTM_Zone_34S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32735','WGS_1984_UTM_Zone_35S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32736','WGS_1984_UTM_Zone_36S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32737','WGS_1984_UTM_Zone_37S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32738','WGS_1984_UTM_Zone_38S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32739','WGS_1984_UTM_Zone_39S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32740','WGS_1984_UTM_Zone_40S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32741','WGS_1984_UTM_Zone_41S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32742','WGS_1984_UTM_Zone_42S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32743','WGS_1984_UTM_Zone_43S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32744','WGS_1984_UTM_Zone_44S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32745','WGS_1984_UTM_Zone_45S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32746','WGS_1984_UTM_Zone_46S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32747','WGS_1984_UTM_Zone_47S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32748','WGS_1984_UTM_Zone_48S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32749','WGS_1984_UTM_Zone_49S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32750','WGS_1984_UTM_Zone_50S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32751','WGS_1984_UTM_Zone_51S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32752','WGS_1984_UTM_Zone_52S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32753','WGS_1984_UTM_Zone_53S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32754','WGS_1984_UTM_Zone_54S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32755','WGS_1984_UTM_Zone_55S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32756','WGS_1984_UTM_Zone_56S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32757','WGS_1984_UTM_Zone_57S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32758','WGS_1984_UTM_Zone_58S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32759','WGS_1984_UTM_Zone_59S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32760','WGS_1984_UTM_Zone_60S','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32761','UPS_South','ESRI');
INSERT INTO alias_name VALUES('projected_crs','EPSG','32766','WGS_1984_TM_36_SE','ESRI');
INSERT INTO "projected_crs" VALUES('ESRI','53001','Sphere_Plate_Carree',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Plate_Carree",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Plate_Carree"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53002','Sphere_Equidistant_Cylindrical',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Equidistant_Cylindrical",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",60.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53003','Sphere_Miller_Cylindrical',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Miller_Cylindrical",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Miller_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53004','Sphere_Mercator',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Mercator",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Mercator"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53008','Sphere_Sinusoidal',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Sinusoidal",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Sinusoidal"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53009','Sphere_Mollweide',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Mollweide",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Mollweide"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53010','Sphere_Eckert_VI',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Eckert_VI",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Eckert_VI"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53011','Sphere_Eckert_V',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Eckert_V",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Eckert_V"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53012','Sphere_Eckert_IV',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Eckert_IV",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Eckert_IV"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53013','Sphere_Eckert_III',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Eckert_III",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Eckert_III"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53014','Sphere_Eckert_II',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Eckert_II",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Eckert_II"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53015','Sphere_Eckert_I',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Eckert_I",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Eckert_I"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53016','Sphere_Gall_Stereographic',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Gall_Stereographic",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Gall_Stereographic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53017','Sphere_Behrmann',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Behrmann",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Behrmann"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53018','Sphere_Winkel_I',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Winkel_I",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Winkel_I"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",50.45977625218981],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53019','Sphere_Winkel_II',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Winkel_II",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Winkel_II"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",50.45977625218981],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53021','Sphere_Polyconic',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Polyconic",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Polyconic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53022','Sphere_Quartic_Authalic',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Quartic_Authalic",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Quartic_Authalic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53023','Sphere_Loximuthal',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Loximuthal",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Loximuthal"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Central_Parallel",40.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53024','Sphere_Bonne',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Bonne",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Bonne"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",60.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53025','Sphere_Hotine',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Hotine",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Hotine_Oblique_Mercator_Two_Point_Natural_Origin"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Latitude_Of_1st_Point",0.0],PARAMETER["Latitude_Of_2nd_Point",60.0],PARAMETER["Scale_Factor",1.0],PARAMETER["Longitude_Of_1st_Point",0.0],PARAMETER["Longitude_Of_2nd_Point",60.0],PARAMETER["Latitude_Of_Center",40.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53026','Sphere_Stereographic',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Stereographic",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Stereographic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Scale_Factor",1.0],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53027','Sphere_Equidistant_Conic',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Equidistant_Conic",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Conic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",60.0],PARAMETER["Standard_Parallel_2",60.0],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53028','Sphere_Cassini',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Cassini",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Cassini"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Scale_Factor",1.0],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53029','Sphere_Van_der_Grinten_I',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Van_der_Grinten_I",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Van_der_Grinten_I"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53030','Sphere_Robinson',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Robinson",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Robinson"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53031','Sphere_Two_Point_Equidistant',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Two_Point_Equidistant",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Two_Point_Equidistant"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Latitude_Of_1st_Point",0.0],PARAMETER["Latitude_Of_2nd_Point",60.0],PARAMETER["Longitude_Of_1st_Point",0.0],PARAMETER["Longitude_Of_2nd_Point",60.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53032','Sphere_Azimuthal_Equidistant',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Azimuthal_Equidistant",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Azimuthal_Equidistant"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53034','Sphere_Cylindrical_Equal_Area',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Cylindrical_Equal_Area",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Cylindrical_Equal_Area"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53035','Sphere_Equal_Earth_Greenwich',NULL,NULL,NULL,NULL,'ESRI','104047',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Equal_Earth_Greenwich",GEOGCS["GCS_Sphere_GRS_1980_Mean_Radius",DATUM["D_Sphere_GRS_1980_Mean_Radius",SPHEROID["Sphere_GRS_1980_Mean_Radius",6371008.7714,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equal_Earth"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53036','Sphere_Equal_Earth_Americas',NULL,NULL,NULL,NULL,'ESRI','104047',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Equal_Earth_Americas",GEOGCS["GCS_Sphere_GRS_1980_Mean_Radius",DATUM["D_Sphere_GRS_1980_Mean_Radius",SPHEROID["Sphere_GRS_1980_Mean_Radius",6371008.7714,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equal_Earth"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-90.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53037','Sphere_Equal_Earth_Asia_Pacific',NULL,NULL,NULL,NULL,'ESRI','104047',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Equal_Earth_Asia_Pacific",GEOGCS["GCS_Sphere_GRS_1980_Mean_Radius",DATUM["D_Sphere_GRS_1980_Mean_Radius",SPHEROID["Sphere_GRS_1980_Mean_Radius",6371008.7714,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equal_Earth"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",150.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53042','Sphere_Winkel_Tripel_NGS',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Winkel_Tripel_NGS",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Winkel_Tripel"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",50.467],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53043','Sphere_Aitoff',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Aitoff",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Aitoff"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53044','Sphere_Hammer_Aitoff',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Hammer_Aitoff",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Hammer_Aitoff"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53045','Sphere_Flat_Polar_Quartic',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Flat_Polar_Quartic",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Flat_Polar_Quartic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53046','Sphere_Craster_Parabolic',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Craster_Parabolic",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Craster_Parabolic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53048','Sphere_Times',NULL,NULL,NULL,NULL,'EPSG','4035',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Times",GEOGCS["GCS_Sphere",DATUM["D_Sphere",SPHEROID["Sphere",6371000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Times"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53049','Sphere_Vertical_Perspective',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Vertical_Perspective",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Vertical_Near_Side_Perspective"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Longitude_Of_Center",0.0],PARAMETER["Latitude_Of_Center",0.0],PARAMETER["Height",35800000.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53074','Sphere_Wagner_IV',NULL,NULL,NULL,NULL,'EPSG','4047',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Wagner_IV",GEOGCS["GCS_Sphere_GRS_1980_Authalic",DATUM["D_Sphere_GRS_1980_Authalic",SPHEROID["Sphere_GRS_1980_Authalic",6371007.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Wagner_IV"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53075','Sphere_Wagner_V',NULL,NULL,NULL,NULL,'ESRI','104047',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Wagner_V",GEOGCS["GCS_Sphere_GRS_1980_Mean_Radius",DATUM["D_Sphere_GRS_1980_Mean_Radius",SPHEROID["Sphere_GRS_1980_Mean_Radius",6371008.7714,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Wagner_V"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53076','Sphere_Wagner_VII',NULL,NULL,NULL,NULL,'EPSG','4047',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Wagner_VII",GEOGCS["GCS_Sphere_GRS_1980_Authalic",DATUM["D_Sphere_GRS_1980_Authalic",SPHEROID["Sphere_GRS_1980_Authalic",6371007.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Wagner_VII"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53077','Sphere_Natural_Earth',NULL,NULL,NULL,NULL,'ESRI','104047',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Natural_Earth",GEOGCS["GCS_Sphere_GRS_1980_Mean_Radius",DATUM["D_Sphere_GRS_1980_Mean_Radius",SPHEROID["Sphere_GRS_1980_Mean_Radius",6371008.7714,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Natural_Earth"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53078','Sphere_Natural_Earth_II',NULL,NULL,NULL,NULL,'ESRI','104047',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Natural_Earth_II",GEOGCS["GCS_Sphere_GRS_1980_Mean_Radius",DATUM["D_Sphere_GRS_1980_Mean_Radius",SPHEROID["Sphere_GRS_1980_Mean_Radius",6371008.7714,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Natural_Earth_II"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53079','Sphere_Patterson',NULL,NULL,NULL,NULL,'ESRI','104047',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Patterson",GEOGCS["GCS_Sphere_GRS_1980_Mean_Radius",DATUM["D_Sphere_GRS_1980_Mean_Radius",SPHEROID["Sphere_GRS_1980_Mean_Radius",6371008.7714,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Patterson"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','53080','Sphere_Compact_Miller',NULL,NULL,NULL,NULL,'ESRI','104047',NULL,NULL,'EPSG','1262','PROJCS["Sphere_Compact_Miller",GEOGCS["GCS_Sphere_GRS_1980_Mean_Radius",DATUM["D_Sphere_GRS_1980_Mean_Radius",SPHEROID["Sphere_GRS_1980_Mean_Radius",6371008.7714,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Compact_Miller"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54001','World_Plate_Carree',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Plate_Carree",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Plate_Carree"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54002','World_Equidistant_Cylindrical',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Equidistant_Cylindrical",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",60.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54003','World_Miller_Cylindrical',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Miller_Cylindrical",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Miller_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54004','World_Mercator',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Mercator",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Mercator"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54008','World_Sinusoidal',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Sinusoidal",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Sinusoidal"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54009','World_Mollweide',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Mollweide",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Mollweide"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54010','World_Eckert_VI',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Eckert_VI",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Eckert_VI"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54011','World_Eckert_V',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Eckert_V",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Eckert_V"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54012','World_Eckert_IV',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Eckert_IV",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Eckert_IV"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54013','World_Eckert_III',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Eckert_III",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Eckert_III"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54014','World_Eckert_II',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Eckert_II",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Eckert_II"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54015','World_Eckert_I',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Eckert_I",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Eckert_I"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54016','World_Gall_Stereographic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Gall_Stereographic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Gall_Stereographic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54017','World_Behrmann',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Behrmann",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Behrmann"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54018','World_Winkel_I',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Winkel_I",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Winkel_I"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",50.45977625218981],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54019','World_Winkel_II',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Winkel_II",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Winkel_II"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",50.45977625218981],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54021','World_Polyconic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Polyconic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Polyconic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54022','World_Quartic_Authalic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Quartic_Authalic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Quartic_Authalic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54023','World_Loximuthal',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Loximuthal",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Loximuthal"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Central_Parallel",40.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54024','World_Bonne',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Bonne",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Bonne"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",60.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54025','World_Hotine',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Hotine",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Hotine_Oblique_Mercator_Two_Point_Natural_Origin"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Latitude_Of_1st_Point",0.0],PARAMETER["Latitude_Of_2nd_Point",60.0],PARAMETER["Scale_Factor",1.0],PARAMETER["Longitude_Of_1st_Point",0.0],PARAMETER["Longitude_Of_2nd_Point",60.0],PARAMETER["Latitude_Of_Center",40.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54026','World_Stereographic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Stereographic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Stereographic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Scale_Factor",1.0],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54027','World_Equidistant_Conic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Equidistant_Conic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Conic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",60.0],PARAMETER["Standard_Parallel_2",60.0],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54028','World_Cassini',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Cassini",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Cassini"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Scale_Factor",1.0],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54029','World_Van_der_Grinten_I',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Van_der_Grinten_I",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Van_der_Grinten_I"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54030','World_Robinson',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Robinson",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Robinson"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54031','World_Two_Point_Equidistant',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Two_Point_Equidistant",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Two_Point_Equidistant"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Latitude_Of_1st_Point",0.0],PARAMETER["Latitude_Of_2nd_Point",60.0],PARAMETER["Longitude_Of_1st_Point",0.0],PARAMETER["Longitude_Of_2nd_Point",60.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54032','World_Azimuthal_Equidistant',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Azimuthal_Equidistant",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Azimuthal_Equidistant"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54034','World_Cylindrical_Equal_Area',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Cylindrical_Equal_Area",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Cylindrical_Equal_Area"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54035','WGS_1984_Equal_Earth_Greenwich',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["WGS_1984_Equal_Earth_Greenwich",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equal_Earth"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',1);
INSERT INTO "projected_crs" VALUES('ESRI','54036','WGS_1984_Equal_Earth_Americas',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["WGS_1984_Equal_Earth_Americas",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equal_Earth"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-90.0],UNIT["Meter",1.0]]',1);
INSERT INTO "projected_crs" VALUES('ESRI','54037','WGS_1984_Equal_Earth_Asia_Pacific',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["WGS_1984_Equal_Earth_Asia_Pacific",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equal_Earth"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",150.0],UNIT["Meter",1.0]]',1);
INSERT INTO "projected_crs" VALUES('ESRI','54042','World_Winkel_Tripel_NGS',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Winkel_Tripel_NGS",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Winkel_Tripel"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",50.467],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54043','World_Aitoff',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Aitoff",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Aitoff"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54044','World_Hammer_Aitoff',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Hammer_Aitoff",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Hammer_Aitoff"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54045','World_Flat_Polar_Quartic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Flat_Polar_Quartic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Flat_Polar_Quartic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54046','World_Craster_Parabolic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Craster_Parabolic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Craster_Parabolic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54048','World_Times',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Times",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Times"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54049','World_Vertical_Perspective',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Vertical_Perspective",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Vertical_Near_Side_Perspective"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Longitude_Of_Center",0.0],PARAMETER["Latitude_Of_Center",0.0],PARAMETER["Height",35800000.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54050','World_Fuller',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Fuller",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Fuller"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Option",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54051','World_Cube',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Cube",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Cube"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Option",1.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54052','World_Goode_Homolosine_Land',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Goode_Homolosine_Land",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Goode_Homolosine"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Option",1.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54053','World_Goode_Homolosine_Ocean',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Goode_Homolosine_Ocean",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Goode_Homolosine"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-160.0],PARAMETER["Option",2.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54074','World_Wagner_IV',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Wagner_IV",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Wagner_IV"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54075','World_Wagner_V',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Wagner_V",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Wagner_V"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54076','World_Wagner_VII',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Wagner_VII",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Wagner_VII"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54077','World_Natural_Earth',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Natural_Earth",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Natural_Earth"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54078','World_Natural_Earth_II',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Natural_Earth_II",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Natural_Earth_II"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54079','World_Patterson',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Patterson",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Patterson"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54080','World_Compact_Miller',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["World_Compact_Miller",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Compact_Miller"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54090','WGS_1984_Peirce_quincuncial_North_Pole_square',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["WGS_1984_Peirce_quincuncial_North_Pole_square",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Peirce_Quincuncial"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Scale_Factor",1.0],PARAMETER["Latitude_Of_Origin",90.0],PARAMETER["Option",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','54091','WGS_1984_Peirce_quincuncial_North_Pole_diamond',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["WGS_1984_Peirce_quincuncial_North_Pole_diamond",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Peirce_Quincuncial"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Scale_Factor",1.0],PARAMETER["Latitude_Of_Origin",90.0],PARAMETER["Option",1.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','65061','NAD_1927_StatePlane_Guam_FIPS_5400',NULL,NULL,NULL,NULL,'EPSG','4267',NULL,NULL,'EPSG','1110','PROJCS["NAD_1927_StatePlane_Guam_FIPS_5400",GEOGCS["GCS_North_American_1927",DATUM["D_North_American_1927",SPHEROID["Clarke_1866",6378206.4,294.9786982]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Polyconic"],PARAMETER["False_Easting",164041.6666666667],PARAMETER["False_Northing",164041.6666666667],PARAMETER["Central_Meridian",144.7487507055556],PARAMETER["Latitude_Of_Origin",13.47246635277778],UNIT["Foot_US",0.3048006096012192]]',0);
INSERT INTO "conversion" VALUES('ESRI','65062','unnamed',NULL,NULL,'EPSG','1027','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',-14.26666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-170.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9003','EPSG','8807','False northing',312234.65,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','65062','American_Samoa_1962_StatePlane_American_Samoa_FIPS_5300',NULL,NULL,'ESRI','Foot_US','EPSG','4169','ESRI','65062','EPSG','1027',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','65161','NAD_1983_StatePlane_Guam_FIPS_5400',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'EPSG','1110','PROJCS["NAD_1983_StatePlane_Guam_FIPS_5400",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Polyconic"],PARAMETER["False_Easting",50000.0],PARAMETER["False_Northing",50000.0],PARAMETER["Central_Meridian",144.7487507055556],PARAMETER["Latitude_Of_Origin",13.47246635277778],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','65163','unnamed',NULL,NULL,'EPSG','1386','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-85.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.08333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',1500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','65163','NAD_1983_StatePlane_Kentucky_FIPS_1600',NULL,NULL,'EPSG','4400','EPSG','4269','ESRI','65163','EPSG','1386',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102001','Canada_Albers_Equal_Area_Conic',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'EPSG','1061','PROJCS["Canada_Albers_Equal_Area_Conic",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-96.0],PARAMETER["Standard_Parallel_1",50.0],PARAMETER["Standard_Parallel_2",70.0],PARAMETER["Latitude_Of_Origin",40.0],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102002','unnamed',NULL,NULL,'EPSG','1061','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',50.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',70.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102002','Canada_Lambert_Conformal_Conic',NULL,NULL,'EPSG','4400','EPSG','4269','ESRI','102002','EPSG','1061',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102003','USA_Contiguous_Albers_Equal_Area_Conic',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'EPSG','1323','PROJCS["USA_Contiguous_Albers_Equal_Area_Conic",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-96.0],PARAMETER["Standard_Parallel_1",29.5],PARAMETER["Standard_Parallel_2",45.5],PARAMETER["Latitude_Of_Origin",37.5],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102004','unnamed',NULL,NULL,'EPSG','1323','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',33.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102004','USA_Contiguous_Lambert_Conformal_Conic',NULL,NULL,'EPSG','4400','EPSG','4269','ESRI','102004','EPSG','1323',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102005','USA_Contiguous_Equidistant_Conic',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'EPSG','1323','PROJCS["USA_Contiguous_Equidistant_Conic",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Conic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-96.0],PARAMETER["Standard_Parallel_1",33.0],PARAMETER["Standard_Parallel_2",45.0],PARAMETER["Latitude_Of_Origin",39.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102006','NAD_1983_Alaska_Albers',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'EPSG','1330','PROJCS["NAD_1983_Alaska_Albers",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-154.0],PARAMETER["Standard_Parallel_1",55.0],PARAMETER["Standard_Parallel_2",65.0],PARAMETER["Latitude_Of_Origin",50.0],UNIT["Meter",1.0]]',1);
INSERT INTO "projected_crs" VALUES('ESRI','102007','Hawaii_Albers_Equal_Area_Conic',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'EPSG','1334','PROJCS["Hawaii_Albers_Equal_Area_Conic",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-157.0],PARAMETER["Standard_Parallel_1",8.0],PARAMETER["Standard_Parallel_2",18.0],PARAMETER["Latitude_Of_Origin",13.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102008','North_America_Albers_Equal_Area_Conic',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'EPSG','1325','PROJCS["North_America_Albers_Equal_Area_Conic",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-96.0],PARAMETER["Standard_Parallel_1",20.0],PARAMETER["Standard_Parallel_2",60.0],PARAMETER["Latitude_Of_Origin",40.0],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102009','unnamed',NULL,NULL,'EPSG','1325','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',20.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',60.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102009','North_America_Lambert_Conformal_Conic',NULL,NULL,'EPSG','4400','EPSG','4269','ESRI','102009','EPSG','1325',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102010','North_America_Equidistant_Conic',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'EPSG','1325','PROJCS["North_America_Equidistant_Conic",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Conic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-96.0],PARAMETER["Standard_Parallel_1",20.0],PARAMETER["Standard_Parallel_2",60.0],PARAMETER["Latitude_Of_Origin",40.0],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','4','Africa','Africa',-35.0,39.0,-25.0,55.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102011','Africa_Sinusoidal',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','4','PROJCS["Africa_Sinusoidal",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Sinusoidal"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",15.0],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','5','Asia','Asia',-10.0,85.0,25.0,-175.0,0);
INSERT INTO "conversion" VALUES('ESRI','102012','unnamed',NULL,NULL,'ESRI','5','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',0.0,'EPSG','9102','EPSG','8822','Longitude of false origin',105.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',30.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',62.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102012','Asia_Lambert_Conformal_Conic',NULL,NULL,'EPSG','4400','EPSG','4326','ESRI','102012','ESRI','5',NULL,0);
INSERT INTO "area" VALUES('ESRI','6','Europe','Europe',34.0,85.0,-30.0,50.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102013','Europe_Albers_Equal_Area_Conic',NULL,NULL,NULL,NULL,'EPSG','4230',NULL,NULL,'ESRI','6','PROJCS["Europe_Albers_Equal_Area_Conic",GEOGCS["GCS_European_1950",DATUM["D_European_1950",SPHEROID["International_1924",6378388.0,297.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",10.0],PARAMETER["Standard_Parallel_1",43.0],PARAMETER["Standard_Parallel_2",62.0],PARAMETER["Latitude_Of_Origin",30.0],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102014','unnamed',NULL,NULL,'ESRI','6','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',30.0,'EPSG','9102','EPSG','8822','Longitude of false origin',10.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',62.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102014','Europe_Lambert_Conformal_Conic',NULL,NULL,'EPSG','4400','EPSG','4230','ESRI','102014','ESRI','6',NULL,0);
INSERT INTO "area" VALUES('ESRI','7','South America','South America',-60.0,15.0,-90.0,-30.0,0);
INSERT INTO "conversion" VALUES('ESRI','102015','unnamed',NULL,NULL,'ESRI','7','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-32.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-60.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-5.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-42.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102015','South_America_Lambert_Conformal_Conic',NULL,NULL,'EPSG','4400','EPSG','4618','ESRI','102015','ESRI','7',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102016','North_Pole_Azimuthal_Equidistant',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','3475','PROJCS["North_Pole_Azimuthal_Equidistant",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Azimuthal_Equidistant"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Latitude_Of_Origin",90.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102017','North_Pole_Lambert_Azimuthal_Equal_Area',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','3475','PROJCS["North_Pole_Lambert_Azimuthal_Equal_Area",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Lambert_Azimuthal_Equal_Area"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Latitude_Of_Origin",90.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102018','North_Pole_Stereographic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','3475','PROJCS["North_Pole_Stereographic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Stereographic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Scale_Factor",1.0],PARAMETER["Latitude_Of_Origin",90.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102019','South_Pole_Azimuthal_Equidistant',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','3474','PROJCS["South_Pole_Azimuthal_Equidistant",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Azimuthal_Equidistant"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Latitude_Of_Origin",-90.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102020','South_Pole_Lambert_Azimuthal_Equal_Area',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','3474','PROJCS["South_Pole_Lambert_Azimuthal_Equal_Area",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Lambert_Azimuthal_Equal_Area"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Latitude_Of_Origin",-90.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102021','South_Pole_Stereographic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','3474','PROJCS["South_Pole_Stereographic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Stereographic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Scale_Factor",1.0],PARAMETER["Latitude_Of_Origin",-90.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102022','Africa_Albers_Equal_Area_Conic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','4','PROJCS["Africa_Albers_Equal_Area_Conic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",25.0],PARAMETER["Standard_Parallel_1",20.0],PARAMETER["Standard_Parallel_2",-23.0],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102023','Africa_Equidistant_Conic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','4','PROJCS["Africa_Equidistant_Conic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Conic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",25.0],PARAMETER["Standard_Parallel_1",20.0],PARAMETER["Standard_Parallel_2",-23.0],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102024','unnamed',NULL,NULL,'ESRI','4','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',0.0,'EPSG','9102','EPSG','8822','Longitude of false origin',25.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',20.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-23.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102024','Africa_Lambert_Conformal_Conic',NULL,NULL,'EPSG','4400','EPSG','4326','ESRI','102024','ESRI','4',NULL,0);
INSERT INTO "area" VALUES('ESRI','8','Asia - North','Asia - North',10.0,85.0,25.0,-175.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102025','Asia_North_Albers_Equal_Area_Conic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','8','PROJCS["Asia_North_Albers_Equal_Area_Conic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",95.0],PARAMETER["Standard_Parallel_1",15.0],PARAMETER["Standard_Parallel_2",65.0],PARAMETER["Latitude_Of_Origin",30.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102026','Asia_North_Equidistant_Conic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','8','PROJCS["Asia_North_Equidistant_Conic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Conic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",95.0],PARAMETER["Standard_Parallel_1",15.0],PARAMETER["Standard_Parallel_2",65.0],PARAMETER["Latitude_Of_Origin",30.0],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102027','unnamed',NULL,NULL,'ESRI','8','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',30.0,'EPSG','9102','EPSG','8822','Longitude of false origin',95.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',15.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',65.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102027','Asia_North_Lambert_Conformal_Conic',NULL,NULL,'EPSG','4400','EPSG','4326','ESRI','102027','ESRI','8',NULL,0);
INSERT INTO "area" VALUES('ESRI','9','Asia - South','Asia - South',-10.0,30.0,25.0,165.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102028','Asia_South_Albers_Equal_Area_Conic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','9','PROJCS["Asia_South_Albers_Equal_Area_Conic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",125.0],PARAMETER["Standard_Parallel_1",7.0],PARAMETER["Standard_Parallel_2",-32.0],PARAMETER["Latitude_Of_Origin",-15.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102029','Asia_South_Equidistant_Conic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','9','PROJCS["Asia_South_Equidistant_Conic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Conic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",125.0],PARAMETER["Standard_Parallel_1",7.0],PARAMETER["Standard_Parallel_2",-32.0],PARAMETER["Latitude_Of_Origin",-15.0],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102030','unnamed',NULL,NULL,'ESRI','9','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-15.0,'EPSG','9102','EPSG','8822','Longitude of false origin',125.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',7.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-32.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102030','Asia_South_Lambert_Conformal_Conic',NULL,NULL,'EPSG','4400','EPSG','4326','ESRI','102030','ESRI','9',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102031','Europe_Equidistant_Conic',NULL,NULL,NULL,NULL,'EPSG','4230',NULL,NULL,'ESRI','6','PROJCS["Europe_Equidistant_Conic",GEOGCS["GCS_European_1950",DATUM["D_European_1950",SPHEROID["International_1924",6378388.0,297.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Conic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",10.0],PARAMETER["Standard_Parallel_1",43.0],PARAMETER["Standard_Parallel_2",62.0],PARAMETER["Latitude_Of_Origin",30.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102032','South_America_Equidistant_Conic',NULL,NULL,NULL,NULL,'EPSG','4618',NULL,NULL,'ESRI','7','PROJCS["South_America_Equidistant_Conic",GEOGCS["GCS_South_American_1969",DATUM["D_South_American_1969",SPHEROID["GRS_1967_Truncated",6378160.0,298.25]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Conic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-60.0],PARAMETER["Standard_Parallel_1",-5.0],PARAMETER["Standard_Parallel_2",-42.0],PARAMETER["Latitude_Of_Origin",-32.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102033','South_America_Albers_Equal_Area_Conic',NULL,NULL,NULL,NULL,'EPSG','4618',NULL,NULL,'ESRI','7','PROJCS["South_America_Albers_Equal_Area_Conic",GEOGCS["GCS_South_American_1969",DATUM["D_South_American_1969",SPHEROID["GRS_1967_Truncated",6378160.0,298.25]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-60.0],PARAMETER["Standard_Parallel_1",-5.0],PARAMETER["Standard_Parallel_2",-42.0],PARAMETER["Latitude_Of_Origin",-32.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102034','North_Pole_Gnomonic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','3475','PROJCS["North_Pole_Gnomonic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Gnomonic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Longitude_Of_Center",0.0],PARAMETER["Latitude_Of_Center",90.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102035','North_Pole_Orthographic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','3475','PROJCS["North_Pole_Orthographic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Orthographic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Longitude_Of_Center",0.0],PARAMETER["Latitude_Of_Center",90.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102036','South_Pole_Gnomonic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','3474','PROJCS["South_Pole_Gnomonic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Gnomonic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Longitude_Of_Center",0.0],PARAMETER["Latitude_Of_Center",-90.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102037','South_Pole_Orthographic',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','3474','PROJCS["South_Pole_Orthographic",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Orthographic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Longitude_Of_Center",0.0],PARAMETER["Latitude_Of_Center",-90.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102038','The_World_From_Space',NULL,NULL,NULL,NULL,'ESRI','37008',NULL,NULL,'EPSG','1262','PROJCS["The_World_From_Space",GEOGCS["GCS_Sphere_ARC_INFO",DATUM["D_Sphere_ARC_INFO",SPHEROID["Sphere_ARC_INFO",6370997.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Orthographic"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Longitude_Of_Center",-72.5333333334],PARAMETER["Latitude_Of_Center",42.5333333333],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102039','USA_Contiguous_Albers_Equal_Area_Conic_USGS_version',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'EPSG','1323','PROJCS["USA_Contiguous_Albers_Equal_Area_Conic_USGS_version",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-96.0],PARAMETER["Standard_Parallel_1",29.5],PARAMETER["Standard_Parallel_2",45.5],PARAMETER["Latitude_Of_Origin",23.0],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102040','unnamed',NULL,NULL,'EPSG','3266','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',127.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102040','Korean_1985_Korea_Unified_Coordinate_System',NULL,NULL,'EPSG','4400','EPSG','4162','ESRI','102040','EPSG','3266',NULL,1);
INSERT INTO "area" VALUES('ESRI','10','USA - Washington - Bellevue','USA - Washington - Bellevue',47.5,47.69,-122.26,-122.06,0);
INSERT INTO "conversion" VALUES('ESRI','102041','unnamed',NULL,NULL,'ESRI','10','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.8333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.73333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.896666667,'EPSG','9003','EPSG','8827','Northing at false origin',0.24,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102041','COB_NAD83_2007',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','102041','ESRI','10',NULL,0);
INSERT INTO "area" VALUES('ESRI','11','USA - USFS - Eastern Region','USA - USFS - Eastern Region',35.9,49.5,-97.3,-66.8,0);
INSERT INTO "projected_crs" VALUES('ESRI','102042','NAD_1983_USFS_R9_Albers',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'ESRI','11','PROJCS["NAD_1983_USFS_R9_Albers",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-82.25],PARAMETER["Standard_Parallel_1",38.25],PARAMETER["Standard_Parallel_2",47.25],PARAMETER["Latitude_Of_Origin",35.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102043','NAD_1983_CORS96_UTM_Zone_20N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16020','EPSG','2251',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102044','NAD_1983_NSRS2007_UTM_Zone_20N',NULL,NULL,'EPSG','4400','EPSG','4759','EPSG','16020','EPSG','2251',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102045','NAD_1983_2011_UTM_Zone_20N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16020','EPSG','2251',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102046','NAD_1983_2011_UTM_Zone_59N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16059','EPSG','3372',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102047','NAD_1983_2011_UTM_Zone_60N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16060','EPSG','3373',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102048','NAD_1983_2011_UTM_Zone_1N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16001','EPSG','3374',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102049','NAD_1983_2011_UTM_Zone_2N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16002','EPSG','3375',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102050','NAD_1983_2011_UTM_Zone_3N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16003','EPSG','2133',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102051','NAD_1983_2011_UTM_Zone_4N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16004','EPSG','2134',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102052','NAD_1983_2011_UTM_Zone_5N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16005','EPSG','2135',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102053','NAD_1983_2011_UTM_Zone_6N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16006','EPSG','2136',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102054','NAD_1983_2011_UTM_Zone_7N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16007','EPSG','3494',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102055','NAD_1983_2011_UTM_Zone_8N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16008','EPSG','3495',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102056','NAD_1983_2011_UTM_Zone_9N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16009','EPSG','3496',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102057','NAD_1983_2011_UTM_Zone_10N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16010','EPSG','3497',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102058','NAD_1983_2011_UTM_Zone_11N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16011','EPSG','3498',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102059','NAD_1983_2011_UTM_Zone_12N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16012','EPSG','3499',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102060','D48_Slovenia_TM',NULL,NULL,'EPSG','4400','ESRI','104131','EPSG','19845','EPSG','1212',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102061','Everest_Modified_1969_RSO_Malaya_Meters',NULL,NULL,NULL,NULL,'ESRI','37006',NULL,NULL,'EPSG','1690','PROJCS["Everest_Modified_1969_RSO_Malaya_Meters",GEOGCS["GCS_Everest_Modified_1969",DATUM["D_Everest_Modified_1969",SPHEROID["Everest_Modified_1969",6377295.664,300.8017]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Rectified_Skew_Orthomorphic_Natural_Origin"],PARAMETER["False_Easting",804670.24],PARAMETER["False_Northing",0.0],PARAMETER["Scale_Factor",0.99984],PARAMETER["Azimuth",-36.97420943711801],PARAMETER["Longitude_Of_Center",102.25],PARAMETER["Latitude_Of_Center",4.0],PARAMETER["XY_Plane_Rotation",-36.86989764584402],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102062','Kertau_RSO_Malaya_Meters',NULL,NULL,NULL,NULL,'EPSG','4245',NULL,NULL,'EPSG','1690','PROJCS["Kertau_RSO_Malaya_Meters",GEOGCS["GCS_Kertau",DATUM["D_Kertau",SPHEROID["Everest_1830_Modified",6377304.063,300.8017]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Rectified_Skew_Orthomorphic_Natural_Origin"],PARAMETER["False_Easting",804671.299775],PARAMETER["False_Northing",0.0],PARAMETER["Scale_Factor",0.99984],PARAMETER["Azimuth",-36.97420943711801],PARAMETER["Longitude_Of_Center",102.25],PARAMETER["Latitude_Of_Center",4.0],PARAMETER["XY_Plane_Rotation",-36.86989764584402],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102063','unnamed',NULL,NULL,'EPSG','1218','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',7.000480277777778,'EPSG','9102','EPSG','8802','Longitude of natural origin',80.77171111111112,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',160933.56048,'EPSG','9001','EPSG','8807','False northing',160933.56048,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102063','Kandawala_Ceylon_Belt_Meters',NULL,NULL,'EPSG','4400','EPSG','4244','ESRI','102063','EPSG','1218',NULL,0);
INSERT INTO "coordinate_system" VALUES('ESRI','Yard_Indian_1937','Cartesian',2);
INSERT INTO "axis" VALUES('ESRI','3','Easting','E','east','ESRI','Yard_Indian_1937',1,'EPSG','9085');
INSERT INTO "axis" VALUES('ESRI','4','Northing','N','north','ESRI','Yard_Indian_1937',2,'EPSG','9085');
INSERT INTO "conversion" VALUES('ESRI','102064','unnamed',NULL,NULL,'EPSG','1218','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',7.000480277777778,'EPSG','9102','EPSG','8802','Longitude of natural origin',80.77171111111112,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',176000.0,'EPSG','9085','EPSG','8807','False northing',176000.0,'EPSG','9085',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102064','Kandawala_Ceylon_Belt_Indian_Yards_1937',NULL,NULL,'ESRI','Yard_Indian_1937','EPSG','4244','ESRI','102064','EPSG','1218',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102065','S-JTSK_Krovak',NULL,NULL,NULL,NULL,'EPSG','4156',NULL,NULL,'EPSG','1306','PROJCS["S-JTSK_Krovak",GEOGCS["GCS_S_JTSK",DATUM["D_S_JTSK",SPHEROID["Bessel_1841",6377397.155,299.1528128]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Krovak"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Pseudo_Standard_Parallel_1",78.5],PARAMETER["Scale_Factor",0.9999],PARAMETER["Azimuth",30.28813975277778],PARAMETER["Longitude_Of_Center",24.83333333333333],PARAMETER["Latitude_Of_Center",49.5],PARAMETER["X_Scale",1.0],PARAMETER["Y_Scale",1.0],PARAMETER["XY_Plane_Rotation",0.0],UNIT["Meter",1.0]]',1);
INSERT INTO "projected_crs" VALUES('ESRI','102066','S-JTSK_Ferro_Krovak_East_North',NULL,NULL,NULL,NULL,'EPSG','4818',NULL,NULL,'EPSG','1306','PROJCS["S-JTSK_Ferro_Krovak_East_North",GEOGCS["GCS_S_JTSK_Ferro",DATUM["D_S_JTSK",SPHEROID["Bessel_1841",6377397.155,299.1528128]],PRIMEM["Ferro",-17.66666666666667],UNIT["Degree",0.0174532925199433]],PROJECTION["Krovak"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Pseudo_Standard_Parallel_1",78.5],PARAMETER["Scale_Factor",0.9999],PARAMETER["Azimuth",30.28813975277778],PARAMETER["Longitude_Of_Center",42.5],PARAMETER["Latitude_Of_Center",49.5],PARAMETER["X_Scale",-1.0],PARAMETER["Y_Scale",1.0],PARAMETER["XY_Plane_Rotation",90.0],UNIT["Meter",1.0]]',1);
INSERT INTO "projected_crs" VALUES('ESRI','102067','S-JTSK_Krovak_East_North',NULL,NULL,NULL,NULL,'EPSG','4156',NULL,NULL,'EPSG','1306','PROJCS["S-JTSK_Krovak_East_North",GEOGCS["GCS_S_JTSK",DATUM["D_S_JTSK",SPHEROID["Bessel_1841",6377397.155,299.1528128]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Krovak"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Pseudo_Standard_Parallel_1",78.5],PARAMETER["Scale_Factor",0.9999],PARAMETER["Azimuth",30.28813975277778],PARAMETER["Longitude_Of_Center",24.83333333333333],PARAMETER["Latitude_Of_Center",49.5],PARAMETER["X_Scale",-1.0],PARAMETER["Y_Scale",1.0],PARAMETER["XY_Plane_Rotation",90.0],UNIT["Meter",1.0]]',1);
INSERT INTO "projected_crs" VALUES('ESRI','102068','EMEP_50_Kilometer_Grid',NULL,NULL,NULL,NULL,'ESRI','104128',NULL,NULL,'ESRI','6','PROJCS["EMEP_50_Kilometer_Grid",GEOGCS["GCS_Sphere_EMEP",DATUM["D_Sphere_EMEP",SPHEROID["Sphere_EMEP",6370000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Stereographic_North_Pole"],PARAMETER["False_Easting",8.0],PARAMETER["False_Northing",110.0],PARAMETER["Central_Meridian",-32.0],PARAMETER["Standard_Parallel_1",60.0],UNIT["50_Kilometers",50000.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102069','EMEP_150_Kilometer_Grid',NULL,NULL,NULL,NULL,'ESRI','104128',NULL,NULL,'ESRI','6','PROJCS["EMEP_150_Kilometer_Grid",GEOGCS["GCS_Sphere_EMEP",DATUM["D_Sphere_EMEP",SPHEROID["Sphere_EMEP",6370000.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Stereographic_North_Pole"],PARAMETER["False_Easting",3.0],PARAMETER["False_Northing",37.0],PARAMETER["Central_Meridian",-32.0],PARAMETER["Standard_Parallel_1",60.0],UNIT["150_Kilometers",150000.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102070','unnamed',NULL,NULL,'EPSG','2989','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.416666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999997,'EPSG','9201','EPSG','8806','False easting',47000.0,'EPSG','9001','EPSG','8807','False northing',50000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102070','Guernsey_Grid',NULL,NULL,'EPSG','4400','EPSG','4326','ESRI','102070','EPSG','2989',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102071','unnamed',NULL,NULL,'EPSG','2283','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',149.0092948333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000086,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',4510193.4939,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102071','AGD_1966_ACT_Grid_AGC_Zone',NULL,NULL,'EPSG','4400','EPSG','4202','ESRI','102071','EPSG','2283',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102072','unnamed',NULL,NULL,'EPSG','1562','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',141.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99994,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102072','AGD_1966_ISG_54_2',NULL,NULL,'EPSG','4400','EPSG','4202','ESRI','102072','EPSG','1562',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102073','unnamed',NULL,NULL,'EPSG','1562','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',143.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99994,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102073','AGD_1966_ISG_54_3',NULL,NULL,'EPSG','4400','EPSG','4202','ESRI','102073','EPSG','1562',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102074','unnamed',NULL,NULL,'EPSG','1563','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',145.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99994,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102074','AGD_1966_ISG_55_1',NULL,NULL,'EPSG','4400','EPSG','4202','ESRI','102074','EPSG','1563',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102075','unnamed',NULL,NULL,'EPSG','1563','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',147.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99994,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102075','AGD_1966_ISG_55_2',NULL,NULL,'EPSG','4400','EPSG','4202','ESRI','102075','EPSG','1563',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102076','unnamed',NULL,NULL,'EPSG','1563','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',149.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99994,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102076','AGD_1966_ISG_55_3',NULL,NULL,'EPSG','4400','EPSG','4202','ESRI','102076','EPSG','1563',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102077','unnamed',NULL,NULL,'EPSG','1564','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',151.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99994,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102077','AGD_1966_ISG_56_1',NULL,NULL,'EPSG','4400','EPSG','4202','ESRI','102077','EPSG','1564',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102078','unnamed',NULL,NULL,'EPSG','1564','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',153.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99994,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102078','AGD_1966_ISG_56_2',NULL,NULL,'EPSG','4400','EPSG','4202','ESRI','102078','EPSG','1564',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102079','unnamed',NULL,NULL,'EPSG','1564','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',155.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99994,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102079','AGD_1966_ISG_56_3',NULL,NULL,'EPSG','4400','EPSG','4202','ESRI','102079','EPSG','1564',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102080','unnamed',NULL,NULL,'EPSG','1135','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',127.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102080','Korea_2000_Korea_Unified_Coordinate_System',NULL,NULL,'EPSG','4400','EPSG','4737','ESRI','102080','EPSG','1135',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102081','Korea_2000_Korea_West_Belt_2010',NULL,NULL,'EPSG','4400','EPSG','4737','EPSG','5101','EPSG','1498',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102082','Korea_2000_Korea_Central_Belt_2010',NULL,NULL,'EPSG','4400','EPSG','4737','EPSG','5102','EPSG','1497',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102083','Korea_2000_Korea_East_Belt_2010',NULL,NULL,'EPSG','4400','EPSG','4737','EPSG','5103','EPSG','1496',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102084','Korea_2000_Korea_East_Sea_Belt_2010',NULL,NULL,'EPSG','4400','EPSG','4737','EPSG','5104','EPSG','3720',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102085','unnamed',NULL,NULL,'EPSG','1498','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',125.0028902777778,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102085','Korean_1985_Modified_Korea_West_Belt',NULL,NULL,'EPSG','4400','EPSG','4162','ESRI','102085','EPSG','1498',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102086','unnamed',NULL,NULL,'EPSG','3730','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',127.0028902777778,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102086','Korean_1985_Modified_Korea_Central_Belt',NULL,NULL,'EPSG','4400','EPSG','4162','ESRI','102086','EPSG','3730',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102087','unnamed',NULL,NULL,'EPSG','3721','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',127.0028902777778,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',550000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102087','Korean_1985_Modified_Korea_Central_Belt_Jeju',NULL,NULL,'EPSG','4400','EPSG','4162','ESRI','102087','EPSG','3721',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102088','unnamed',NULL,NULL,'EPSG','1496','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',129.0028902777778,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102088','Korean_1985_Modified_Korea_East_Belt',NULL,NULL,'EPSG','4400','EPSG','4162','ESRI','102088','EPSG','1496',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102089','unnamed',NULL,NULL,'EPSG','3720','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',131.0028902777778,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102089','Korean_1985_Modified_Korea_East_Sea_Belt',NULL,NULL,'EPSG','4400','EPSG','4162','ESRI','102089','EPSG','3720',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102090','unnamed',NULL,NULL,'EPSG','1047','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',32.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-64.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',550000.0,'EPSG','9001','EPSG','8807','False northing',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102090','Bermuda_2000_National_Grid',NULL,NULL,'EPSG','4400','EPSG','4762','ESRI','102090','EPSG','1047',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102091','Monte_Mario_Italy_1',NULL,NULL,'EPSG','4400','EPSG','4265','EPSG','18121','EPSG','1718',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102092','Monte_Mario_Italy_2',NULL,NULL,'EPSG','4400','EPSG','4265','EPSG','18122','EPSG','1719',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102093','Roma_1940_Gauss_Boaga_Est',NULL,NULL,'EPSG','4400','ESRI','104127','EPSG','18122','EPSG','1719',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102094','Roma_1940_Gauss_Boaga_Ovest',NULL,NULL,'EPSG','4400','ESRI','104127','EPSG','18121','EPSG','1718',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102095','unnamed',NULL,NULL,'EPSG','3342','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',18.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-77.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',750000.0,'EPSG','9001','EPSG','8807','False northing',650000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102095','JAD_2001_Jamaica_Grid',NULL,NULL,'EPSG','4400','EPSG','4758','ESRI','102095','EPSG','3342',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102096','Bab_South_Palau_Azimuthal_Equidistant',NULL,NULL,NULL,NULL,'ESRI','104112',NULL,NULL,'EPSG','1185','PROJCS["Bab_South_Palau_Azimuthal_Equidistant",GEOGCS["GCS_Bab_South",DATUM["D_Bab_South",SPHEROID["Clarke_1866",6378206.4,294.9786982]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Azimuthal_Equidistant"],PARAMETER["False_Easting",50000.0],PARAMETER["False_Northing",150000.0],PARAMETER["Central_Meridian",134.4504448611111],PARAMETER["Latitude_Of_Origin",7.35122211111111],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102097','ETRS_1989_UTM_Zone_26N',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','16026','EPSG','2855',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102098','ETRS_1989_UTM_Zone_27N',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','16027','EPSG','2856',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102099','ETRS_1989_UTM_Zone_39N',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','16039','EPSG','2868',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102100','WGS_1984_Web_Mercator_Auxiliary_Sphere',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','3544','PROJCS["WGS_1984_Web_Mercator_Auxiliary_Sphere",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Mercator_Auxiliary_Sphere"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",0.0],PARAMETER["Auxiliary_Sphere_Type",0.0],UNIT["Meter",1.0]]',1);
INSERT INTO "conversion" VALUES('ESRI','102101','unnamed',NULL,NULL,'EPSG','1741','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',6.05625,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102101','NGO_1948_Norway_Zone_1',NULL,NULL,'EPSG','4400','EPSG','4273','ESRI','102101','EPSG','1741',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102102','unnamed',NULL,NULL,'EPSG','1742','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',8.389583333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102102','NGO_1948_Norway_Zone_2',NULL,NULL,'EPSG','4400','EPSG','4273','ESRI','102102','EPSG','1742',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102103','unnamed',NULL,NULL,'EPSG','1743','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',10.72291666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102103','NGO_1948_Norway_Zone_3',NULL,NULL,'EPSG','4400','EPSG','4273','ESRI','102103','EPSG','1743',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102104','unnamed',NULL,NULL,'EPSG','1744','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',13.22291666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102104','NGO_1948_Norway_Zone_4',NULL,NULL,'EPSG','4400','EPSG','4273','ESRI','102104','EPSG','1744',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102105','unnamed',NULL,NULL,'EPSG','1745','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',16.88958333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102105','NGO_1948_Norway_Zone_5',NULL,NULL,'EPSG','4400','EPSG','4273','ESRI','102105','EPSG','1745',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102106','unnamed',NULL,NULL,'EPSG','1746','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',20.88958333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102106','NGO_1948_Norway_Zone_6',NULL,NULL,'EPSG','4400','EPSG','4273','ESRI','102106','EPSG','1746',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102107','unnamed',NULL,NULL,'EPSG','1747','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',24.88958333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102107','NGO_1948_Norway_Zone_7',NULL,NULL,'EPSG','4400','EPSG','4273','ESRI','102107','EPSG','1747',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102108','unnamed',NULL,NULL,'EPSG','1748','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',29.05625,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102108','NGO_1948_Norway_Zone_8',NULL,NULL,'EPSG','4400','EPSG','4273','ESRI','102108','EPSG','1748',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102109','ETRS_1989_Slovenia_TM',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','19845','EPSG','1212',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102110','unnamed',NULL,NULL,'EPSG','1096','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.5,'EPSG','9102','EPSG','8822','Longitude of false origin',3.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',49.0,'EPSG','9102','EPSG','8826','Easting at false origin',700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',6600000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102110','RGF_1993_Lambert_93',NULL,NULL,'EPSG','4400','EPSG','4171','ESRI','102110','EPSG','1096',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102111','unnamed',NULL,NULL,'EPSG','2889','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-44.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-176.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',350000.0,'EPSG','9001','EPSG','8807','False northing',650000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102111','Chatham_Islands_1979_Map_Grid',NULL,NULL,'EPSG','4400','EPSG','4673','ESRI','102111','EPSG','2889',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102112','unnamed',NULL,NULL,'EPSG','2889','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',-44.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-176.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102112','NZGD_2000_Chatham_Island_Circuit',NULL,NULL,'EPSG','4400','EPSG','4167','ESRI','102112','EPSG','2889',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102113','WGS_1984_Web_Mercator',NULL,NULL,NULL,NULL,'EPSG','4055',NULL,NULL,'EPSG','3544','PROJCS["WGS_1984_Web_Mercator",GEOGCS["GCS_WGS_1984_Major_Auxiliary_Sphere",DATUM["D_WGS_1984_Major_Auxiliary_Sphere",SPHEROID["WGS_1984_Major_Auxiliary_Sphere",6378137.0,0.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Mercator"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",0.0],UNIT["Meter",1.0]]',1);
INSERT INTO "projected_crs" VALUES('ESRI','102114','Old_Hawaiian_UTM_Zone_4N',NULL,NULL,'EPSG','4400','EPSG','4135','EPSG','16004','EPSG','3488',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102115','Old_Hawaiian_UTM_Zone_5N',NULL,NULL,'EPSG','4400','EPSG','4135','EPSG','16005','EPSG','3491',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102116','American_Samoa_1962_UTM_Zone_2S',NULL,NULL,'EPSG','4400','EPSG','4169','EPSG','16102','EPSG','1027',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102117','NAD_1927_Alaska_Albers_Meters',NULL,NULL,NULL,NULL,'EPSG','4267',NULL,NULL,'EPSG','1330','PROJCS["NAD_1927_Alaska_Albers_Meters",GEOGCS["GCS_North_American_1927",DATUM["D_North_American_1927",SPHEROID["Clarke_1866",6378206.4,294.9786982]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-154.0],PARAMETER["Standard_Parallel_1",55.0],PARAMETER["Standard_Parallel_2",65.0],PARAMETER["Latitude_Of_Origin",50.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102118','NAD_1927_Georgia_Statewide_Albers',NULL,NULL,NULL,NULL,'EPSG','4267',NULL,NULL,'EPSG','1380','PROJCS["NAD_1927_Georgia_Statewide_Albers",GEOGCS["GCS_North_American_1927",DATUM["D_North_American_1927",SPHEROID["Clarke_1866",6378206.4,294.9786982]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-83.5],PARAMETER["Standard_Parallel_1",29.5],PARAMETER["Standard_Parallel_2",45.5],PARAMETER["Latitude_Of_Origin",23.0],UNIT["Foot_US",0.3048006096012192]]',0);
INSERT INTO "coordinate_system" VALUES('ESRI','Foot','Cartesian',2);
INSERT INTO "axis" VALUES('ESRI','5','Easting','E','east','ESRI','Foot',1,'EPSG','9002');
INSERT INTO "axis" VALUES('ESRI','6','Northing','N','north','ESRI','Foot',2,'EPSG','9002');
INSERT INTO "conversion" VALUES('ESRI','102119','unnamed',NULL,NULL,'EPSG','1412','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.16666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',27.41666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',34.91666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',3000000.0,'EPSG','9002','EPSG','8827','Northing at false origin',3000000.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102119','NAD_1927_Texas_Statewide_Mapping_System',NULL,NULL,'ESRI','Foot','EPSG','4267','ESRI','102119','EPSG','1412',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102120','unnamed',NULL,NULL,'EPSG','1391','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',45.30916666666666,'EPSG','9102','EPSG','8812','Longitude of projection centre',-86.0,'EPSG','9102','EPSG','8813','Azimuth of initial line',337.25556,'EPSG','9102','EPSG','8814','Angle from Rectified to Skew Grid',337.25556,'EPSG','9102','EPSG','8815','Scale factor on initial line',0.9996,'EPSG','9201','EPSG','8806','False easting',8355401.583,'EPSG','9003','EPSG','8807','False northing',-14284780.538,'EPSG','9003',0);
INSERT INTO "projected_crs" VALUES('ESRI','102120','NAD_1927_Michigan_GeoRef_Feet_US',NULL,NULL,'ESRI','Foot_US','EPSG','4267','ESRI','102120','EPSG','1391',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102121','NAD_1983_Michigan_GeoRef_Feet_US',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102120','EPSG','1391',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102122','unnamed',NULL,NULL,'EPSG','1391','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',45.30916666666666,'EPSG','9102','EPSG','8812','Longitude of projection centre',-86.0,'EPSG','9102','EPSG','8813','Azimuth of initial line',337.25556,'EPSG','9102','EPSG','8814','Angle from Rectified to Skew Grid',337.25556,'EPSG','9102','EPSG','8815','Scale factor on initial line',0.9996,'EPSG','9201','EPSG','8806','False easting',2546731.496,'EPSG','9001','EPSG','8807','False northing',-4354009.816,'EPSG','9001',0);
INSERT INTO "projected_crs" VALUES('ESRI','102122','NAD_1927_Michigan_GeoRef_Meters',NULL,NULL,'EPSG','4400','EPSG','4267','ESRI','102122','EPSG','1391',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102123','unnamed',NULL,NULL,'EPSG','1391','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',45.30916666666666,'EPSG','9102','EPSG','8812','Longitude of projection centre',-86.0,'EPSG','9102','EPSG','8813','Azimuth of initial line',337.25556,'EPSG','9102','EPSG','8814','Angle from Rectified to Skew Grid',337.25556,'EPSG','9102','EPSG','8815','Scale factor on initial line',0.9996,'EPSG','9201','EPSG','8806','False easting',2546731.496,'EPSG','9001','EPSG','8807','False northing',-4354009.816,'EPSG','9001',1);
INSERT INTO "projected_crs" VALUES('ESRI','102123','NAD_1983_Michigan_GeoRef_Meters',NULL,NULL,'EPSG','4400','EPSG','4269','ESRI','102123','EPSG','1391',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102124','NAD_1927_UTM_Zone_1N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16001','EPSG','3374',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102125','NAD_1927_UTM_Zone_2N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16002','EPSG','3375',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102126','NAD_1927_UTM_Zone_59N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16059','EPSG','3372',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102127','NAD_1927_UTM_Zone_60N',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','16060','EPSG','3373',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102128','NAD_1983_UTM_Zone_1N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16001','EPSG','3374',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102129','NAD_1983_UTM_Zone_2N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16002','EPSG','3375',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102130','NAD_1983_UTM_Zone_59N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16059','EPSG','3372',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102131','NAD_1983_UTM_Zone_60N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16060','EPSG','3373',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102132','NGO_1948_UTM_Zone_32N',NULL,NULL,'EPSG','4400','EPSG','4273','EPSG','16032','EPSG','2062',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102133','NGO_1948_UTM_Zone_33N',NULL,NULL,'EPSG','4400','EPSG','4273','EPSG','16033','EPSG','2064',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102134','NGO_1948_UTM_Zone_34N',NULL,NULL,'EPSG','4400','EPSG','4273','EPSG','16034','EPSG','2066',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102135','NGO_1948_UTM_Zone_35N',NULL,NULL,'EPSG','4400','EPSG','4273','EPSG','16035','EPSG','2068',NULL,0);
INSERT INTO "area" VALUES('ESRI','12','Norway - Baerum Kommune','Norway - Baerum Kommune',59.8254,60.0366,10.3371,10.6725,0);
INSERT INTO "conversion" VALUES('ESRI','102136','unnamed',NULL,NULL,'ESRI','12','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',10.72291666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',19999.32,'EPSG','9001','EPSG','8807','False northing',-202977.79,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102136','NGO_1948_Baerum_Kommune',NULL,NULL,'EPSG','4400','EPSG','4273','ESRI','102136','ESRI','12',NULL,0);
INSERT INTO "area" VALUES('ESRI','13','Norway - Bergenhalvoen Kommune','Norway - Bergenhalvoen Kommune',60.1651,60.5437,5.1374,5.6993,0);
INSERT INTO "conversion" VALUES('ESRI','102137','unnamed',NULL,NULL,'ESRI','13','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',6.05625,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',-200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102137','NGO_1948_Bergenhalvoen',NULL,NULL,'EPSG','4400','EPSG','4273','ESRI','102137','ESRI','13',NULL,0);
INSERT INTO "area" VALUES('ESRI','14','Norway - Oslo Kommune','Norway - Oslo Kommune',59.81,60.14,10.48,10.97,0);
INSERT INTO "conversion" VALUES('ESRI','102138','unnamed',NULL,NULL,'ESRI','14','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',10.72291666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',-212979.18,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102138','NGO_1948_Oslo_Kommune',NULL,NULL,'EPSG','4400','EPSG','4273','ESRI','102138','ESRI','14',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102139','EUREF_FIN_TM35FIN',NULL,NULL,'EPSG','4400','ESRI','104129','EPSG','16035','EPSG','1095',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102140','unnamed',NULL,NULL,'EPSG','1118','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',22.31213333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',114.1785555555556,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',836694.05,'EPSG','9001','EPSG','8807','False northing',819069.8,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102140','Hong_Kong_1980_Grid',NULL,NULL,'EPSG','4400','EPSG','4611','ESRI','102140','EPSG','1118',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102141','Hong_Kong_1980_UTM_Zone_49N',NULL,NULL,'EPSG','4400','EPSG','4611','EPSG','16049','EPSG','1118',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102142','Hong_Kong_1980_UTM_Zone_50N',NULL,NULL,'EPSG','4400','EPSG','4611','EPSG','16050','EPSG','1118',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102143','QND_1995_UTM_39N',NULL,NULL,'EPSG','4400','EPSG','4614','EPSG','16039','EPSG','1195',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102144','Merchich_Degree_UTM_Zone_28N',NULL,NULL,'EPSG','4400','ESRI','104261','EPSG','16028','EPSG','1256',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102145','JGD_2000_UTM_Zone_51N',NULL,NULL,'EPSG','4400','EPSG','4612','EPSG','16051','EPSG','3959',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102146','JGD_2000_UTM_Zone_52N',NULL,NULL,'EPSG','4400','EPSG','4612','EPSG','16052','EPSG','3960',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102147','JGD_2000_UTM_Zone_53N',NULL,NULL,'EPSG','4400','EPSG','4612','EPSG','16053','EPSG','3961',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102148','JGD_2000_UTM_Zone_54N',NULL,NULL,'EPSG','4400','EPSG','4612','EPSG','16054','EPSG','3962',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102149','JGD_2000_UTM_Zone_55N',NULL,NULL,'EPSG','4400','EPSG','4612','EPSG','16055','EPSG','3963',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102150','JGD_2000_UTM_Zone_56N',NULL,NULL,'EPSG','4400','EPSG','4612','EPSG','16056','EPSG','1983',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102151','Tokyo_UTM_Zone_51N',NULL,NULL,'EPSG','4400','EPSG','4301','EPSG','16051','EPSG','2951',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102152','Tokyo_UTM_Zone_52N',NULL,NULL,'EPSG','4400','EPSG','4301','EPSG','16052','EPSG','2952',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102153','Tokyo_UTM_Zone_53N',NULL,NULL,'EPSG','4400','EPSG','4301','EPSG','16053','EPSG','2953',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102154','Tokyo_UTM_Zone_54N',NULL,NULL,'EPSG','4400','EPSG','4301','EPSG','16054','EPSG','2954',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102155','Tokyo_UTM_Zone_55N',NULL,NULL,'EPSG','4400','EPSG','4301','EPSG','16055','EPSG','2955',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102156','Tokyo_UTM_Zone_56N',NULL,NULL,'EPSG','4400','EPSG','4301','EPSG','16056','EPSG','1983',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102157','ETRS_1989_Kosovo_Grid (Gauss Kruger)',NULL,NULL,'EPSG','3534','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',7500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102157','ETRS_1989_Kosovo_Grid',NULL,NULL,'EPSG','4400','EPSG','4258','ESRI','102157','EPSG','3534',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102158','Jordan_JTM',NULL,NULL,'EPSG','4400','ESRI','104130','EPSG','19995','EPSG','1130',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102159','unnamed',NULL,NULL,'EPSG','1147','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',22.21239722222222,'EPSG','9102','EPSG','8802','Longitude of natural origin',113.5364694444444,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',20000.0,'EPSG','9001','EPSG','8807','False northing',20000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102159','Observatorio_Meteorologico_1965_Macau_Grid',NULL,NULL,'EPSG','4400','ESRI','104126','ESRI','102159','EPSG','1147',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102160','unnamed',NULL,NULL,'EPSG','1193','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-8.131906111111112,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200180.598,'EPSG','9001','EPSG','8807','False northing',299913.01,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102160','Datum_73_Hayford_Gauss_IGeoE',NULL,NULL,'EPSG','4400','EPSG','4274','ESRI','102160','EPSG','1193',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102161','unnamed',NULL,NULL,'EPSG','1193','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-8.131906111111112,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',180.598,'EPSG','9001','EPSG','8807','False northing',-86.99,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102161','Datum_73_Hayford_Gauss_IPCC',NULL,NULL,'EPSG','4400','EPSG','4274','ESRI','102161','EPSG','1193',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102162','Graciosa_Base_SW_1948_UTM_Zone_26N',NULL,NULL,'EPSG','4400','ESRI','37241','EPSG','16026','EPSG','1301',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102163','Lisboa_Bessel_Bonne',NULL,NULL,NULL,NULL,'ESRI','104105',NULL,NULL,'EPSG','1193','PROJCS["Lisboa_Bessel_Bonne",GEOGCS["GCS_Datum_Lisboa_Bessel",DATUM["D_Datum_Lisboa_Bessel",SPHEROID["Bessel_1841",6377397.155,299.1528128]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Bonne"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-8.131906111111112],PARAMETER["Standard_Parallel_1",39.66666666666666],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102164','unnamed',NULL,NULL,'EPSG','1193','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-8.131906111111112,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102164','Lisboa_Hayford_Gauss_IGeoE',NULL,NULL,'EPSG','4400','ESRI','104106','ESRI','102164','EPSG','1193',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102165','unnamed',NULL,NULL,'EPSG','1193','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',39.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-8.131906111111112,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102165','Lisboa_Hayford_Gauss_IPCC',NULL,NULL,'EPSG','4400','ESRI','104106','ESRI','102165','EPSG','1193',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102166','Observatorio_Meteorologico_1939_UTM_Zone_25N',NULL,NULL,'EPSG','4400','ESRI','37245','EPSG','16025','EPSG','1344',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102167','Porto_Santo_1936_UTM_Zone_28N',NULL,NULL,'EPSG','4400','EPSG','4615','EPSG','16028','EPSG','1314',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102168','Sao_Braz_UTM_Zone_26N',NULL,NULL,'EPSG','4400','ESRI','37249','EPSG','16026','EPSG','1345',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102169','Selvagem_Grande_1938_UTM_Zone_28N',NULL,NULL,'EPSG','4400','EPSG','4616','EPSG','16028','EPSG','2779',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102170','unnamed',NULL,NULL,'EPSG','2285','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-37.0,'EPSG','9102','EPSG','8822','Longitude of false origin',145.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-36.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-38.0,'EPSG','9102','EPSG','8826','Easting at false origin',2500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102170','AGD_1966_VICGRID',NULL,NULL,'EPSG','4400','EPSG','4202','ESRI','102170','EPSG','2285',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102171','unnamed',NULL,NULL,'EPSG','2285','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-37.0,'EPSG','9102','EPSG','8822','Longitude of false origin',145.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-36.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-38.0,'EPSG','9102','EPSG','8826','Easting at false origin',2500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102171','GDA_1994_VICGRID94',NULL,NULL,'EPSG','4400','EPSG','4283','ESRI','102171','EPSG','2285',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102172','unnamed',NULL,NULL,'EPSG','2986','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-32.0,'EPSG','9102','EPSG','8822','Longitude of false origin',135.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-28.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-36.0,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102172','GDA_1994_South_Australia_Lambert',NULL,NULL,'EPSG','4400','EPSG','4283','ESRI','102172','EPSG','2986',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102173','ETRS_1989_UWPP_1992 (Gauss Kruger)',NULL,NULL,'EPSG','1192','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',19.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9993,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',-5300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102173','ETRS_1989_UWPP_1992',NULL,NULL,'EPSG','4400','EPSG','4258','ESRI','102173','EPSG','1192',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102174','ETRS_1989_UWPP_2000_PAS_5 (Gauss Kruger)',NULL,NULL,'EPSG','1520','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999923,'EPSG','9201','EPSG','8806','False easting',5500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102174','ETRS_1989_UWPP_2000_PAS_5',NULL,NULL,'EPSG','4400','EPSG','4258','ESRI','102174','EPSG','1520',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102175','ETRS_1989_UWPP_2000_PAS_6 (Gauss Kruger)',NULL,NULL,'EPSG','1521','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',18.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999923,'EPSG','9201','EPSG','8806','False easting',6500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102175','ETRS_1989_UWPP_2000_PAS_6',NULL,NULL,'EPSG','4400','EPSG','4258','ESRI','102175','EPSG','1521',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102176','ETRS_1989_UWPP_2000_PAS_7 (Gauss Kruger)',NULL,NULL,'EPSG','1522','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999923,'EPSG','9201','EPSG','8806','False easting',7500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102176','ETRS_1989_UWPP_2000_PAS_7',NULL,NULL,'EPSG','4400','EPSG','4258','ESRI','102176','EPSG','1522',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102177','ETRS_1989_UWPP_2000_PAS_8 (Gauss Kruger)',NULL,NULL,'EPSG','1523','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',24.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999923,'EPSG','9201','EPSG','8806','False easting',8500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102177','ETRS_1989_UWPP_2000_PAS_8',NULL,NULL,'EPSG','4400','EPSG','4258','ESRI','102177','EPSG','1523',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102178','NAD_1927_10TM_AEP_Forest',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','19881','EPSG','2376',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102179','NAD_1927_10TM_AEP_Resource',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','19882','EPSG','2376',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102180','NAD_1927_3TM_111',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','17722','EPSG','3543',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102181','NAD_1927_3TM_114',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','17723','EPSG','3542',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102182','NAD_1927_3TM_117',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','17724','EPSG','3541',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102183','NAD_1927_3TM_120',NULL,NULL,'EPSG','4400','EPSG','4267','EPSG','17726','EPSG','3540',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102184','NAD_1983_10TM_AEP_Forest',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','19881','EPSG','2376',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102185','NAD_1983_10TM_AEP_Resource',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','19882','EPSG','2376',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102186','NAD_1983_3TM_111',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','17722','EPSG','3543',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102187','NAD_1983_3TM_114',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','17723','EPSG','3542',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102188','NAD_1983_3TM_117',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','17724','EPSG','3541',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102189','NAD_1983_3TM_120',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','17726','EPSG','3540',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102190','NAD_1983_BC_Environment_Albers',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'EPSG','2832','PROJCS["NAD_1983_BC_Environment_Albers",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",1000000.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-126.0],PARAMETER["Standard_Parallel_1",50.0],PARAMETER["Standard_Parallel_2",58.5],PARAMETER["Latitude_Of_Origin",45.0],UNIT["Meter",1.0]]',1);
INSERT INTO "conversion" VALUES('ESRI','102191','unnamed',NULL,NULL,'EPSG','1703','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',33.3,'EPSG','9102','EPSG','8802','Longitude of natural origin',-5.4,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999625769,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102191','Nord_Maroc_Degree',NULL,NULL,'EPSG','4400','ESRI','104261','ESRI','102191','EPSG','1703',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102192','unnamed',NULL,NULL,'EPSG','2787','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',29.7,'EPSG','9102','EPSG','8802','Longitude of natural origin',-5.4,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999615596,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102192','Sud_Maroc_Degree',NULL,NULL,'EPSG','4400','ESRI','104261','ESRI','102192','EPSG','2787',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102193','unnamed',NULL,NULL,'EPSG','1705','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',26.1,'EPSG','9102','EPSG','8802','Longitude of natural origin',-5.4,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1200000.0,'EPSG','9001','EPSG','8807','False northing',400000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102193','Sahara_Degree',NULL,NULL,'EPSG','4400','ESRI','104261','ESRI','102193','EPSG','1705',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102194','UWPP_1992 (Gauss Kruger)',NULL,NULL,'EPSG','1192','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',19.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9993,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',-5300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102194','UWPP_1992',NULL,NULL,'EPSG','4400','ESRI','104258','ESRI','102194','EPSG','1192',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102195','UWPP_2000_PAS_5 (Gauss Kruger)',NULL,NULL,'EPSG','1520','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999923,'EPSG','9201','EPSG','8806','False easting',5500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102195','UWPP_2000_PAS_5',NULL,NULL,'EPSG','4400','ESRI','104258','ESRI','102195','EPSG','1520',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102196','UWPP_2000_PAS_6 (Gauss Kruger)',NULL,NULL,'EPSG','1521','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',18.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999923,'EPSG','9201','EPSG','8806','False easting',6500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102196','UWPP_2000_PAS_6',NULL,NULL,'EPSG','4400','ESRI','104258','ESRI','102196','EPSG','1521',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102197','UWPP_2000_PAS_7 (Gauss Kruger)',NULL,NULL,'EPSG','1522','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999923,'EPSG','9201','EPSG','8806','False easting',7500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102197','UWPP_2000_PAS_7',NULL,NULL,'EPSG','4400','ESRI','104258','ESRI','102197','EPSG','1522',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102198','UWPP_2000_PAS_8 (Gauss Kruger)',NULL,NULL,'EPSG','1523','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',24.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999923,'EPSG','9201','EPSG','8806','False easting',8500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102198','UWPP_2000_PAS_8',NULL,NULL,'EPSG','4400','ESRI','104258','ESRI','102198','EPSG','1523',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102199','unnamed',NULL,NULL,'EPSG','1347','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',50.797815,'EPSG','9102','EPSG','8822','Longitude of false origin',4.359215833333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',49.83333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',51.16666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',649328.0,'EPSG','9001','EPSG','8827','Northing at false origin',665262.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102199','Belge_Lambert_2008',NULL,NULL,'EPSG','4400','EPSG','4258','ESRI','102199','EPSG','1347',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102200','NAD_1983_HARN_UTM_Zone_2S',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16102','EPSG','3110',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102201','unnamed',NULL,NULL,'EPSG','3255','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',13.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',144.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102201','NAD_1983_HARN_Guam_Map_Grid',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102201','EPSG','3255',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102202','NAD_1983_HARN_UTM_Zone_4N',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16004','EPSG','3488',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102203','NAD_1983_HARN_UTM_Zone_5N',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16005','EPSG','3491',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102204','unnamed',NULL,NULL,'EPSG','3303','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',24.0,'EPSG','9102','EPSG','8822','Longitude of false origin',45.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',21.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',27.0,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102204','Ain_el_Abd_1970_Aramco_Lambert_2',NULL,NULL,'EPSG','4400','EPSG','4204','ESRI','102204','EPSG','3303',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102205','NAD_1983_HARN_UTM_Zone_11N',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16011','EPSG','3852',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102206','NAD_1983_HARN_UTM_Zone_12N',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16012','EPSG','3499',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102207','NAD_1983_HARN_UTM_Zone_13N',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16013','EPSG','3500',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102208','unnamed',NULL,NULL,'EPSG','2960','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-67.875,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99998,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102208','NAD_1983_HARN_Maine_2000_East_Zone',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102208','EPSG','2960',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102209','unnamed',NULL,NULL,'EPSG','2959','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-69.125,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99998,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102209','NAD_1983_HARN_Maine_2000_Central_Zone',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102209','EPSG','2959',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102210','unnamed',NULL,NULL,'EPSG','2958','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-70.375,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99998,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102210','NAD_1983_HARN_Maine_2000_West_Zone',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102210','EPSG','2958',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102211','NAD_1983_HARN_UTM_Zone_18N',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','16018','EPSG','3868',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102212','unnamed',NULL,NULL,'EPSG','1419','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-107.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',41.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.0,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102212','NAD_1983_WyLAM',NULL,NULL,'EPSG','4400','EPSG','4269','ESRI','102212','EPSG','1419',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102213','NAD_1983_UTM_Zone_58N',NULL,NULL,'EPSG','4400','EPSG','4269','EPSG','16058','EPSG','2116',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102214','unnamed',NULL,NULL,'EPSG','1062','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',15.83333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-24.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',15.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',16.66666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',161587.83,'EPSG','9001','EPSG','8827','Northing at false origin',128511.202,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102214','WGS_1984_Cape_Verde_Grid',NULL,NULL,'EPSG','4400','EPSG','4326','ESRI','102214','EPSG','1062',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102215','unnamed',NULL,NULL,'EPSG','1061','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',0.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',49.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',77.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',-8000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102215','WGS_1984_Canada_Atlas_LCC',NULL,NULL,'EPSG','4400','EPSG','4326','ESRI','102215','EPSG','1061',NULL,0);
INSERT INTO "area" VALUES('ESRI','15','Australia - Perth Coast','Australia - Perth Coast',-33.41666666666666,-31.33333333333333,115.4416666666667,116.0833333333333,0);
INSERT INTO "conversion" VALUES('ESRI','102216','unnamed',NULL,NULL,'ESRI','15','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',115.8166666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99999906,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',3800000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102216','GDA_1994_Perth_Coastal_Grid_1994',NULL,NULL,'EPSG','4400','EPSG','4283','ESRI','102216','ESRI','15',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102217','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',1706033.333333333,'EPSG','9003','EPSG','8807','False northing',-14698133.33333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102217','NAD_1983_NSRS2007_Wisconsin_TM_US_Ft',NULL,NULL,'ESRI','Foot_US','EPSG','4759','ESRI','102217','EPSG','1418',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102218','NAD_1983_USFS_R6_Albers',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'EPSG','2381','PROJCS["NAD_1983_USFS_R6_Albers",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",600000.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-120.0],PARAMETER["Standard_Parallel_1",43.0],PARAMETER["Standard_Parallel_2",48.0],PARAMETER["Latitude_Of_Origin",34.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102219','NAD_1983_Wisconsin_TM_US_Ft',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102217','EPSG','1418',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102220','NAD_1983_HARN_Wisconsin_TM_US_Ft',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','102217','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102221','unnamed',NULL,NULL,'EPSG','1074','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',10.46666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.33333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',9.933333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',11.0,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',271820.522,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102221','Ocotepeque_1935_Costa_Rica_Lambert_Norte',NULL,NULL,'EPSG','4400','EPSG','5451','ESRI','102221','EPSG','1074',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102222','unnamed',NULL,NULL,'EPSG','1074','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',9.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-83.66666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',8.466666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',9.533333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',327987.436,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102222','Ocotepeque_1935_Costa_Rica_Lambert_Sur',NULL,NULL,'EPSG','4400','EPSG','5451','ESRI','102222','EPSG','1074',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102223','unnamed',NULL,NULL,'EPSG','1074','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-84.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102223','WGS_1984_Costa_Rica_TM_90',NULL,NULL,'EPSG','4400','EPSG','4326','ESRI','102223','EPSG','1074',NULL,0);
INSERT INTO "area" VALUES('ESRI','16','Mongolia - west of 96~E','Mongolia - west of 96~E',43.01,50.89,87.76,96.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102224','MONREF_1997_UTM_Zone_46N',NULL,NULL,'EPSG','4400','ESRI','104134','EPSG','16046','ESRI','16',NULL,0);
INSERT INTO "area" VALUES('ESRI','17','Mongolia - between 96~E and 102~E','Mongolia - between 96~E and 102~E',42.14,52.15,96.0,102.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102225','MONREF_1997_UTM_Zone_47N',NULL,NULL,'EPSG','4400','ESRI','104134','EPSG','16047','ESRI','17',NULL,0);
INSERT INTO "area" VALUES('ESRI','18','Mongolia - between 102~E and 108~E','Mongolia - between 102~E and 108~E',41.58,51.42,102.0,108.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102226','MONREF_1997_UTM_Zone_48N',NULL,NULL,'EPSG','4400','ESRI','104134','EPSG','16048','ESRI','18',NULL,0);
INSERT INTO "area" VALUES('ESRI','19','Mongolia - between 108~E and 114~E','Mongolia - between 108~E and 114~E',42.35,50.23,108.0,114.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102227','MONREF_1997_UTM_Zone_49N',NULL,NULL,'EPSG','4400','ESRI','104134','EPSG','16049','ESRI','19',NULL,0);
INSERT INTO "area" VALUES('ESRI','20','Mongolia - east of 114~E','Mongolia - east of 114~E',44.9,50.32,114.0,119.94,0);
INSERT INTO "projected_crs" VALUES('ESRI','102228','MONREF_1997_UTM_Zone_50N',NULL,NULL,'EPSG','4400','ESRI','104134','EPSG','16050','ESRI','20',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102229','unnamed',NULL,NULL,'EPSG','2154','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-85.83333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99996,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102229','NAD_1983_HARN_StatePlane_Alabama_East_FIPS_0101',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102229','EPSG','2154',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102230','unnamed',NULL,NULL,'EPSG','2155','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999333333333333,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102230','NAD_1983_HARN_StatePlane_Alabama_West_FIPS_0102',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102230','EPSG','2155',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102231','unnamed',NULL,NULL,'EPSG','3091','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',4.599047222222222,'EPSG','9102','EPSG','8802','Longitude of natural origin',-80.08091666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1000000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102231','Colombia_West_West_Zone',NULL,NULL,'EPSG','4400','EPSG','4218','ESRI','102231','EPSG','3091',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102232','unnamed',NULL,NULL,'EPSG','3089','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',4.683333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-74.15,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000399787532524,'EPSG','9201','EPSG','8806','False easting',92334.879,'EPSG','9001','EPSG','8807','False northing',109320.965,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102232','Bogota_Ciudad_Bogota',NULL,NULL,'EPSG','4400','EPSG','4218','ESRI','102232','EPSG','3089',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102233','unnamed',NULL,NULL,'EPSG','3089','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',4.680486111111112,'EPSG','9102','EPSG','8802','Longitude of natural origin',-74.14659166666668,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000399803265436,'EPSG','9201','EPSG','8806','False easting',92334.879,'EPSG','9001','EPSG','8807','False northing',109320.965,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102233','MAGNA_Ciudad_Bogota',NULL,NULL,'EPSG','4400','EPSG','4686','ESRI','102233','EPSG','3089',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102234','NAD_1983_CSRS_UTM_Zone_14N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16014','EPSG','3413',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102235','NAD_1983_CSRS_UTM_Zone_15N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16015','EPSG','3414',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102236','NAD_1983_CSRS_UTM_Zone_16N',NULL,NULL,'EPSG','4400','EPSG','4617','EPSG','16016','EPSG','3415',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102237','Pohnpei_Az_Eq_1971',NULL,NULL,NULL,NULL,'ESRI','104109',NULL,NULL,'EPSG','1161','PROJCS["Pohnpei_Az_Eq_1971",GEOGCS["GCS_Pohnpei",DATUM["D_Pohnpei",SPHEROID["Clarke_1866",6378206.4,294.9786982]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Azimuthal_Equidistant"],PARAMETER["False_Easting",80122.82],PARAMETER["False_Northing",80747.24],PARAMETER["Central_Meridian",158.2092992222222],PARAMETER["Latitude_Of_Origin",6.965075694444445],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102238','Saipan_Az_Eq_1969',NULL,NULL,NULL,NULL,'EPSG','4675',NULL,NULL,'EPSG','1181','PROJCS["Saipan_Az_Eq_1969",GEOGCS["GCS_Guam_1963",DATUM["D_Guam_1963",SPHEROID["Clarke_1866",6378206.4,294.9786982]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Azimuthal_Equidistant"],PARAMETER["False_Easting",50000.0],PARAMETER["False_Northing",50000.0],PARAMETER["Central_Meridian",145.7112869444444],PARAMETER["Latitude_Of_Origin",15.16755722222222],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102239','Guam_Geodetic_Triangulation_Network_1963',NULL,NULL,NULL,NULL,'EPSG','4675',NULL,NULL,'EPSG','1110','PROJCS["Guam_Geodetic_Triangulation_Network_1963",GEOGCS["GCS_Guam_1963",DATUM["D_Guam_1963",SPHEROID["Clarke_1866",6378206.4,294.9786982]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Azimuthal_Equidistant"],PARAMETER["False_Easting",50000.0],PARAMETER["False_Northing",50000.0],PARAMETER["Central_Meridian",144.7487507055556],PARAMETER["Latitude_Of_Origin",13.47246635277778],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102240','unnamed',NULL,NULL,'EPSG','1110','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',13.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',144.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102240','Guam_Geodetic_Network_1993',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102240','EPSG','1110',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102241','unnamed',NULL,NULL,'EPSG','2175','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-122.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102241','NAD_1983_HARN_StatePlane_California_I_FIPS_0401',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102241','EPSG','2175',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102242','unnamed',NULL,NULL,'EPSG','2176','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-122.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.83333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102242','NAD_1983_HARN_StatePlane_California_II_FIPS_0402',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102242','EPSG','2176',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102243','unnamed',NULL,NULL,'EPSG','2177','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.06666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.43333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102243','NAD_1983_HARN_StatePlane_California_III_FIPS_0403',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102243','EPSG','2177',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102244','unnamed',NULL,NULL,'EPSG','2178','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',35.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-119.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',36.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',37.25,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102244','NAD_1983_HARN_StatePlane_California_IV_FIPS_0404',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102244','EPSG','2178',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102245','unnamed',NULL,NULL,'EPSG','2182','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-118.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',35.46666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102245','NAD_1983_HARN_StatePlane_California_V_FIPS_0405',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102245','EPSG','2182',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102246','unnamed',NULL,NULL,'EPSG','2180','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',32.16666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-116.25,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',32.78333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',33.88333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102246','NAD_1983_HARN_StatePlane_California_VI_FIPS_0406',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102246','EPSG','2180',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102247','NAD_1983_CORS96_Alaska_Albers',NULL,NULL,NULL,NULL,'EPSG','6783',NULL,NULL,'EPSG','1330','PROJCS["NAD_1983_CORS96_Alaska_Albers",GEOGCS["GCS_NAD_1983_CORS96",DATUM["D_NAD_1983_CORS96",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-154.0],PARAMETER["Standard_Parallel_1",55.0],PARAMETER["Standard_Parallel_2",65.0],PARAMETER["Latitude_Of_Origin",50.0],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102248','unnamed',NULL,NULL,'EPSG','2167','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-110.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',213360.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102248','NAD_1983_HARN_StatePlane_Arizona_East_FIPS_0201',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102248','EPSG','2167',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102249','unnamed',NULL,NULL,'EPSG','2166','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-111.9166666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',213360.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102249','NAD_1983_HARN_StatePlane_Arizona_Central_FIPS_0202',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102249','EPSG','2166',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102250','unnamed',NULL,NULL,'EPSG','2168','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-113.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999333333333333,'EPSG','9201','EPSG','8806','False easting',213360.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102250','NAD_1983_HARN_StatePlane_Arizona_West_FIPS_0203',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102250','EPSG','2168',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102251','unnamed',NULL,NULL,'EPSG','2169','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.93333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.23333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102251','NAD_1983_HARN_StatePlane_Arkansas_North_FIPS_0301',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102251','EPSG','2169',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102252','unnamed',NULL,NULL,'EPSG','2170','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',32.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',33.3,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',34.76666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',400000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102252','NAD_1983_HARN_StatePlane_Arkansas_South_FIPS_0302',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102252','EPSG','2170',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102253','unnamed',NULL,NULL,'EPSG','2184','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-105.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',39.71666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',914401.8289,'EPSG','9001','EPSG','8827','Northing at false origin',304800.6096,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102253','NAD_1983_HARN_StatePlane_Colorado_North_FIPS_0501',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102253','EPSG','2184',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102254','unnamed',NULL,NULL,'EPSG','2183','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-105.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.45,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.75,'EPSG','9102','EPSG','8826','Easting at false origin',914401.8289,'EPSG','9001','EPSG','8827','Northing at false origin',304800.6096,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102254','NAD_1983_HARN_StatePlane_Colorado_Central_FIPS_0502',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102254','EPSG','2183',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102255','unnamed',NULL,NULL,'EPSG','2185','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-105.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.23333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.43333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',914401.8289,'EPSG','9001','EPSG','8827','Northing at false origin',304800.6096,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102255','NAD_1983_HARN_StatePlane_Colorado_South_FIPS_0503',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102255','EPSG','2185',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102256','unnamed',NULL,NULL,'EPSG','1377','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-72.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',41.2,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.86666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',304800.6096,'EPSG','9001','EPSG','8827','Northing at false origin',152400.3048,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102256','NAD_1983_HARN_StatePlane_Connecticut_FIPS_0600',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102256','EPSG','1377',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102257','unnamed',NULL,NULL,'EPSG','1378','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-75.41666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999995,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102257','NAD_1983_HARN_StatePlane_Delaware_FIPS_0700',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102257','EPSG','1378',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102258','unnamed',NULL,NULL,'EPSG','2186','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',24.33333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-81.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999411764705882,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102258','NAD_1983_HARN_StatePlane_Florida_East_FIPS_0901',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102258','EPSG','2186',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102259','unnamed',NULL,NULL,'EPSG','2188','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',24.33333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-82.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999411764705882,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102259','NAD_1983_HARN_StatePlane_Florida_West_FIPS_0902',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102259','EPSG','2188',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102260','unnamed',NULL,NULL,'EPSG','2187','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',29.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',29.58333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',30.75,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102260','NAD_1983_HARN_StatePlane_Florida_North_FIPS_0903',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102260','EPSG','2187',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102261','unnamed',NULL,NULL,'EPSG','1546','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',18.83333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-155.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102261','NAD_1983_HARN_StatePlane_Hawaii_1_FIPS_5101',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102261','EPSG','1546',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102262','unnamed',NULL,NULL,'EPSG','1547','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',20.33333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-156.6666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102262','NAD_1983_HARN_StatePlane_Hawaii_2_FIPS_5102',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102262','EPSG','1547',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102263','unnamed',NULL,NULL,'EPSG','1548','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',21.16666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-158.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102263','NAD_1983_HARN_StatePlane_Hawaii_3_FIPS_5103',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102263','EPSG','1548',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102264','unnamed',NULL,NULL,'EPSG','1549','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',21.83333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-159.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102264','NAD_1983_HARN_StatePlane_Hawaii_4_FIPS_5104',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102264','EPSG','1549',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102265','unnamed',NULL,NULL,'EPSG','1550','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',21.66666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-160.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102265','NAD_1983_HARN_StatePlane_Hawaii_5_FIPS_5105',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102265','EPSG','1550',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102266','unnamed',NULL,NULL,'EPSG','2189','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-82.16666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102266','NAD_1983_HARN_StatePlane_Georgia_East_FIPS_1001',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102266','EPSG','2189',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102267','unnamed',NULL,NULL,'EPSG','2190','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-84.16666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102267','NAD_1983_HARN_StatePlane_Georgia_West_FIPS_1002',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102267','EPSG','2190',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102268','unnamed',NULL,NULL,'EPSG','2192','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-112.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999473684210526,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102268','NAD_1983_HARN_StatePlane_Idaho_East_FIPS_1101',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102268','EPSG','2192',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102269','unnamed',NULL,NULL,'EPSG','2191','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-114.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999473684210526,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102269','NAD_1983_HARN_StatePlane_Idaho_Central_FIPS_1102',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102269','EPSG','2191',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102270','unnamed',NULL,NULL,'EPSG','2193','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-115.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999333333333333,'EPSG','9201','EPSG','8806','False easting',800000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102270','NAD_1983_HARN_StatePlane_Idaho_West_FIPS_1103',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102270','EPSG','2193',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102271','unnamed',NULL,NULL,'EPSG','2194','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.33333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999975,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102271','NAD_1983_HARN_StatePlane_Illinois_East_FIPS_1201',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102271','EPSG','2194',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102272','unnamed',NULL,NULL,'EPSG','2195','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.16666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999411764705882,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102272','NAD_1983_HARN_StatePlane_Illinois_West_FIPS_1202',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102272','EPSG','2195',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102273','unnamed',NULL,NULL,'EPSG','2196','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-85.66666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',250000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102273','NAD_1983_HARN_StatePlane_Indiana_East_FIPS_1301',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102273','EPSG','2196',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102274','unnamed',NULL,NULL,'EPSG','2197','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.08333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',900000.0,'EPSG','9001','EPSG','8807','False northing',250000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102274','NAD_1983_HARN_StatePlane_Indiana_West_FIPS_1302',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102274','EPSG','2197',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102275','unnamed',NULL,NULL,'EPSG','2198','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.06666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.26666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',1500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102275','NAD_1983_HARN_StatePlane_Iowa_North_FIPS_1401',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102275','EPSG','2198',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102276','unnamed',NULL,NULL,'EPSG','2199','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.61666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102276','NAD_1983_HARN_StatePlane_Iowa_South_FIPS_1402',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102276','EPSG','2199',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102277','unnamed',NULL,NULL,'EPSG','2200','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.71666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102277','NAD_1983_HARN_StatePlane_Kansas_North_FIPS_1501',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102277','EPSG','2200',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102278','unnamed',NULL,NULL,'EPSG','2201','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.26666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.56666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',400000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102278','NAD_1983_HARN_StatePlane_Kansas_South_FIPS_1502',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102278','EPSG','2201',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102279','unnamed',NULL,NULL,'EPSG','2202','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.25,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.96666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.96666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102279','NAD_1983_HARN_StatePlane_Kentucky_North_FIPS_1601',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102279','EPSG','2202',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102280','unnamed',NULL,NULL,'EPSG','2203','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-85.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',36.73333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',37.93333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102280','NAD_1983_HARN_StatePlane_Kentucky_South_FIPS_1602',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102280','EPSG','2203',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102281','unnamed',NULL,NULL,'EPSG','2204','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',30.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',31.16666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',32.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102281','NAD_1983_HARN_StatePlane_Louisiana_North_FIPS_1701',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102281','EPSG','2204',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102282','unnamed',NULL,NULL,'EPSG','2529','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',28.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.33333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',29.3,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',30.7,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102282','NAD_1983_HARN_StatePlane_Louisiana_South_FIPS_1702',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102282','EPSG','2529',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102283','unnamed',NULL,NULL,'EPSG','2206','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-68.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102283','NAD_1983_HARN_StatePlane_Maine_East_FIPS_1801',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102283','EPSG','2206',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102284','unnamed',NULL,NULL,'EPSG','2207','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-70.16666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',900000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102284','NAD_1983_HARN_StatePlane_Maine_West_FIPS_1802',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102284','EPSG','2207',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102285','unnamed',NULL,NULL,'EPSG','1389','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-77.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.3,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.45,'EPSG','9102','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102285','NAD_1983_HARN_StatePlane_Maryland_FIPS_1900',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102285','EPSG','1389',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102286','unnamed',NULL,NULL,'EPSG','2209','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-71.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',41.71666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',42.68333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',200000.0,'EPSG','9001','EPSG','8827','Northing at false origin',750000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102286','NAD_1983_HARN_StatePlane_Massachusetts_Mainland_FIPS_2001',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102286','EPSG','2209',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102287','unnamed',NULL,NULL,'EPSG','2208','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-70.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',41.28333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.48333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102287','NAD_1983_HARN_StatePlane_Massachusetts_Island_FIPS_2002',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102287','EPSG','2208',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102288','unnamed',NULL,NULL,'EPSG','1723','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.78333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-87.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.48333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.08333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',8000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102288','NAD_1983_HARN_StatePlane_Michigan_North_FIPS_2111',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102288','EPSG','1723',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102289','unnamed',NULL,NULL,'EPSG','1724','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.31666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.36666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.18333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.7,'EPSG','9102','EPSG','8826','Easting at false origin',6000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102289','NAD_1983_HARN_StatePlane_Michigan_Central_FIPS_2112',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102289','EPSG','1724',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102290','unnamed',NULL,NULL,'EPSG','1725','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.36666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.1,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',4000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102290','NAD_1983_HARN_StatePlane_Michigan_South_FIPS_2113',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102290','EPSG','1725',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102291','unnamed',NULL,NULL,'EPSG','2214','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.1,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.63333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',800000.0,'EPSG','9001','EPSG','8827','Northing at false origin',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102291','NAD_1983_HARN_StatePlane_Minnesota_North_FIPS_2201',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102291','EPSG','2214',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102292','unnamed',NULL,NULL,'EPSG','2213','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.25,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.61666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.05,'EPSG','9102','EPSG','8826','Easting at false origin',800000.0,'EPSG','9001','EPSG','8827','Northing at false origin',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102292','NAD_1983_HARN_StatePlane_Minnesota_Central_FIPS_2202',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102292','EPSG','2213',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102293','unnamed',NULL,NULL,'EPSG','2215','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.78333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.21666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',800000.0,'EPSG','9001','EPSG','8827','Northing at false origin',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102293','NAD_1983_HARN_StatePlane_Minnesota_South_FIPS_2203',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102293','EPSG','2215',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102294','unnamed',NULL,NULL,'EPSG','2216','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',29.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.83333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102294','NAD_1983_HARN_StatePlane_Mississippi_East_FIPS_2301',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102294','EPSG','2216',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102295','unnamed',NULL,NULL,'EPSG','2217','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',29.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.33333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102295','NAD_1983_HARN_StatePlane_Mississippi_West_FIPS_2302',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102295','EPSG','2217',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102296','unnamed',NULL,NULL,'EPSG','2219','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',35.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999333333333333,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102296','NAD_1983_HARN_StatePlane_Missouri_East_FIPS_2401',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102296','EPSG','2219',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102297','unnamed',NULL,NULL,'EPSG','2218','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',35.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999333333333333,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102297','NAD_1983_HARN_StatePlane_Missouri_Central_FIPS_2402',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102297','EPSG','2218',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102298','unnamed',NULL,NULL,'EPSG','2220','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.16666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-94.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999411764705882,'EPSG','9201','EPSG','8806','False easting',850000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102298','NAD_1983_HARN_StatePlane_Missouri_West_FIPS_2403',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102298','EPSG','2220',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102299','Berghaus_Star_AAG',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1262','PROJCS["Berghaus_Star_AAG",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Berghaus_Star"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-52.0],PARAMETER["Latitude_Of_Origin",90.0],PARAMETER["XY_Plane_Rotation",36.0],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102300','unnamed',NULL,NULL,'EPSG','1395','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.25,'EPSG','9102','EPSG','8822','Longitude of false origin',-109.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',49.0,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102300','NAD_1983_HARN_StatePlane_Montana_FIPS_2500',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102300','EPSG','1395',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102304','unnamed',NULL,NULL,'EPSG','1396','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.0,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102304','NAD_1983_HARN_StatePlane_Nebraska_FIPS_2600',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102304','EPSG','1396',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102305','CRTM05',NULL,NULL,'EPSG','4400','EPSG','5365','EPSG','5366','EPSG','3849',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102306','unnamed',NULL,NULL,'EPSG','1171','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',84.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102306','Nepal_Nagarkot_TM',NULL,NULL,'EPSG','4400','EPSG','6207','ESRI','102306','EPSG','1171',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102307','unnamed',NULL,NULL,'EPSG','2224','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-115.5833333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',8000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102307','NAD_1983_HARN_StatePlane_Nevada_East_FIPS_2701',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102307','EPSG','2224',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102308','unnamed',NULL,NULL,'EPSG','2223','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-116.6666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',6000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102308','NAD_1983_HARN_StatePlane_Nevada_Central_FIPS_2702',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102308','EPSG','2223',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102309','unnamed',NULL,NULL,'EPSG','2225','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-118.5833333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',800000.0,'EPSG','9001','EPSG','8807','False northing',4000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102309','NAD_1983_HARN_StatePlane_Nevada_West_FIPS_2703',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102309','EPSG','2225',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102310','unnamed',NULL,NULL,'EPSG','1398','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-71.66666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102310','NAD_1983_HARN_StatePlane_New_Hampshire_FIPS_2800',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102310','EPSG','1398',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102311','unnamed',NULL,NULL,'EPSG','1399','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-74.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102311','NAD_1983_HARN_StatePlane_New_Jersey_FIPS_2900',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102311','EPSG','1399',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102312','unnamed',NULL,NULL,'EPSG','2228','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-104.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999090909090909,'EPSG','9201','EPSG','8806','False easting',165000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102312','NAD_1983_HARN_StatePlane_New_Mexico_East_FIPS_3001',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102312','EPSG','2228',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102313','unnamed',NULL,NULL,'EPSG','2231','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-106.25,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102313','NAD_1983_HARN_StatePlane_New_Mexico_Central_FIPS_3002',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102313','EPSG','2231',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102314','unnamed',NULL,NULL,'EPSG','2232','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-107.8333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999166666666667,'EPSG','9201','EPSG','8806','False easting',830000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102314','NAD_1983_HARN_StatePlane_New_Mexico_West_FIPS_3003',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102314','EPSG','2232',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102315','unnamed',NULL,NULL,'EPSG','2234','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-74.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102315','NAD_1983_HARN_StatePlane_New_York_East_FIPS_3101',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102315','EPSG','2234',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102316','unnamed',NULL,NULL,'EPSG','2233','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-76.58333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102316','NAD_1983_HARN_StatePlane_New_York_Central_FIPS_3102',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102316','EPSG','2233',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102317','unnamed',NULL,NULL,'EPSG','2236','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-78.58333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',350000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102317','NAD_1983_HARN_StatePlane_New_York_West_FIPS_3103',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102317','EPSG','2236',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102318','unnamed',NULL,NULL,'EPSG','2235','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.16666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-74.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.66666666666666,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.03333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',300000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102318','NAD_1983_HARN_StatePlane_New_York_Long_Island_FIPS_3104',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102318','EPSG','2235',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102319','CGRS_1993_LTM',NULL,NULL,'EPSG','4400','EPSG','6311','EPSG','6308','EPSG','3236',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102320','unnamed',NULL,NULL,'EPSG','2237','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.43333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.73333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102320','NAD_1983_HARN_StatePlane_North_Dakota_North_FIPS_3301',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102320','EPSG','2237',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102321','unnamed',NULL,NULL,'EPSG','2238','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.18333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.48333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102321','NAD_1983_HARN_StatePlane_North_Dakota_South_FIPS_3302',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102321','EPSG','2238',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102322','unnamed',NULL,NULL,'EPSG','2239','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-82.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.43333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.7,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102322','NAD_1983_HARN_StatePlane_Ohio_North_FIPS_3401',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102322','EPSG','2239',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102323','unnamed',NULL,NULL,'EPSG','2240','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-82.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.73333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.03333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102323','NAD_1983_HARN_StatePlane_Ohio_South_FIPS_3402',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102323','EPSG','2240',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102324','unnamed',NULL,NULL,'EPSG','2241','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',35.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',35.56666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.76666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102324','NAD_1983_HARN_StatePlane_Oklahoma_North_FIPS_3501',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102324','EPSG','2241',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102325','unnamed',NULL,NULL,'EPSG','2242','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',33.93333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',35.23333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102325','NAD_1983_HARN_StatePlane_Oklahoma_South_FIPS_3502',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102325','EPSG','2242',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102326','unnamed',NULL,NULL,'EPSG','2243','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.0,'EPSG','9102','EPSG','8826','Easting at false origin',2500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102326','NAD_1983_HARN_StatePlane_Oregon_North_FIPS_3601',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102326','EPSG','2243',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102327','unnamed',NULL,NULL,'EPSG','2244','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.0,'EPSG','9102','EPSG','8826','Easting at false origin',1500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102327','NAD_1983_HARN_StatePlane_Oregon_South_FIPS_3602',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102327','EPSG','2244',NULL,1);
INSERT INTO "area" VALUES('ESRI','21','Germany - west of 12~E','Germany - west of 12~E',47.27,55.9,5.5,12.0,0);
INSERT INTO "conversion" VALUES('ESRI','102328','unnamed',NULL,NULL,'ESRI','21','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',9.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',2500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102328','ETRS_1989_UTM_Zone_32N_7stellen',NULL,NULL,'EPSG','4400','EPSG','4258','ESRI','102328','ESRI','21',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102329','ETRS_1989_UTM_Zone_32N_8stellen',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','4648','EPSG','2862',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102330','unnamed',NULL,NULL,'EPSG','1408','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.08333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-71.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99999375,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102330','NAD_1983_HARN_StatePlane_Rhode_Island_FIPS_3800',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102330','EPSG','1408',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102331','PTRA08_UTM_Zone_25N',NULL,NULL,'EPSG','4400','EPSG','5013','EPSG','16025','EPSG','3682',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102332','PTRA08_UTM_Zone_26N',NULL,NULL,'EPSG','4400','EPSG','5013','EPSG','16026','EPSG','3677',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102333','PTRA08_UTM_Zone_28N',NULL,NULL,'EPSG','4400','EPSG','5013','EPSG','16028','EPSG','3678',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102334','unnamed',NULL,NULL,'EPSG','2249','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.41666666666666,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.68333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102334','NAD_1983_HARN_StatePlane_South_Dakota_North_FIPS_4001',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102334','EPSG','2249',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102335','unnamed',NULL,NULL,'EPSG','2250','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.3333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.83333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.4,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102335','NAD_1983_HARN_StatePlane_South_Dakota_South_FIPS_4002',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102335','EPSG','2250',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102336','unnamed',NULL,NULL,'EPSG','1411','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-86.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',35.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.41666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102336','NAD_1983_HARN_StatePlane_Tennessee_FIPS_4100',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102336','EPSG','1411',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102337','unnamed',NULL,NULL,'EPSG','2253','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-101.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.65,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.18333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',200000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102337','NAD_1983_HARN_StatePlane_Texas_North_FIPS_4201',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102337','EPSG','2253',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102338','unnamed',NULL,NULL,'EPSG','2254','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.66666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',32.13333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',33.96666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102338','NAD_1983_HARN_StatePlane_Texas_North_Central_FIPS_4202',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102338','EPSG','2254',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102339','unnamed',NULL,NULL,'EPSG','2252','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',29.66666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.3333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',30.11666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',31.88333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102339','NAD_1983_HARN_StatePlane_Texas_Central_FIPS_4203',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102339','EPSG','2252',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102340','unnamed',NULL,NULL,'EPSG','2527','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',27.83333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-99.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',28.38333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',30.28333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102340','NAD_1983_HARN_StatePlane_Texas_South_Central_FIPS_4204',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102340','EPSG','2527',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102341','unnamed',NULL,NULL,'EPSG','2528','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',25.66666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',26.16666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',27.83333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',300000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102341','NAD_1983_HARN_StatePlane_Texas_South_FIPS_4205',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102341','EPSG','2528',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102342','unnamed',NULL,NULL,'EPSG','2258','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-111.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.71666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102342','NAD_1983_HARN_StatePlane_Utah_North_FIPS_4301',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102342','EPSG','2258',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102343','unnamed',NULL,NULL,'EPSG','2257','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-111.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',39.01666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.65,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102343','NAD_1983_HARN_StatePlane_Utah_Central_FIPS_4302',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102343','EPSG','2257',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102344','unnamed',NULL,NULL,'EPSG','2259','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-111.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.21666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.35,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102344','NAD_1983_HARN_StatePlane_Utah_South_FIPS_4303',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102344','EPSG','2259',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102345','unnamed',NULL,NULL,'EPSG','1414','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-72.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999642857142857,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102345','NAD_1983_HARN_StatePlane_Vermont_FIPS_4400',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102345','EPSG','1414',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102346','unnamed',NULL,NULL,'EPSG','2260','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-78.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.2,'EPSG','9102','EPSG','8826','Easting at false origin',3500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102346','NAD_1983_HARN_StatePlane_Virginia_North_FIPS_4501',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102346','EPSG','2260',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102347','unnamed',NULL,NULL,'EPSG','2261','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-78.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',36.76666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',37.96666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',3500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102347','NAD_1983_HARN_StatePlane_Virginia_South_FIPS_4502',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102347','EPSG','2261',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102348','unnamed',NULL,NULL,'EPSG','2273','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.8333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.73333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102348','NAD_1983_HARN_StatePlane_Washington_North_FIPS_4601',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102348','EPSG','2273',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102349','unnamed',NULL,NULL,'EPSG','2274','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.83333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.33333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102349','NAD_1983_HARN_StatePlane_Washington_South_FIPS_4602',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102349','EPSG','2274',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102350','unnamed',NULL,NULL,'EPSG','2264','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-79.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',39.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.25,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102350','NAD_1983_HARN_StatePlane_West_Virginia_North_FIPS_4701',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102350','EPSG','2264',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102351','unnamed',NULL,NULL,'EPSG','2265','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.48333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.88333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102351','NAD_1983_HARN_StatePlane_West_Virginia_South_FIPS_4702',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102351','EPSG','2265',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102352','unnamed',NULL,NULL,'EPSG','2267','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.16666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.56666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.76666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102352','NAD_1983_HARN_StatePlane_Wisconsin_North_FIPS_4801',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102352','EPSG','2267',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102353','unnamed',NULL,NULL,'EPSG','2266','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.5,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102353','NAD_1983_HARN_StatePlane_Wisconsin_Central_FIPS_4802',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102353','EPSG','2266',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102354','unnamed',NULL,NULL,'EPSG','2268','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.73333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.06666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102354','NAD_1983_HARN_StatePlane_Wisconsin_South_FIPS_4803',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102354','EPSG','2268',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102355','unnamed',NULL,NULL,'EPSG','2269','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-105.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102355','NAD_1983_HARN_StatePlane_Wyoming_East_FIPS_4901',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102355','EPSG','2269',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102356','unnamed',NULL,NULL,'EPSG','2270','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-107.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102356','NAD_1983_HARN_StatePlane_Wyoming_East_Central_FIPS_4902',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102356','EPSG','2270',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102357','unnamed',NULL,NULL,'EPSG','2272','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-108.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102357','NAD_1983_HARN_StatePlane_Wyoming_West_Central_FIPS_4903',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102357','EPSG','2272',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102358','unnamed',NULL,NULL,'EPSG','2271','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-110.0833333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',800000.0,'EPSG','9001','EPSG','8807','False northing',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102358','NAD_1983_HARN_StatePlane_Wyoming_West_FIPS_4904',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102358','EPSG','2271',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102359','unnamed',NULL,NULL,'ESRI','21','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',3500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102359','ETRS_1989_UTM_Zone_33N_7stellen',NULL,NULL,'EPSG','4400','EPSG','4258','ESRI','102359','ESRI','21',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102360','ETRS_1989_UTM_Zone_33N_8stellen',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','5648','EPSG','2862',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102361','unnamed',NULL,NULL,'EPSG','3634','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',17.83333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-66.43333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',18.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',18.43333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',200000.0,'EPSG','9001','EPSG','8827','Northing at false origin',200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102361','NAD_1983_HARN_StatePlane_Puerto_Rico_Virgin_Islands_FIPS_5200',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102361','EPSG','3634',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102362','ETRS_1989_UTM_Zone_N32',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','4648','EPSG','2861',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102363','NAD_1983_HARN_StatePlane_Kentucky_FIPS_1600',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','65163','EPSG','1386',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102364','NAD_1983_CORS96_UTM_Zone_59N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16059','EPSG','3372',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102365','NAD_1983_CORS96_UTM_Zone_60N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16060','EPSG','3373',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102366','unnamed',NULL,NULL,'EPSG','2156','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',57.0,'EPSG','9102','EPSG','8812','Longitude of projection centre',-133.6666666666667,'EPSG','9102','EPSG','8813','Azimuth of initial line',-36.86989764583333,'EPSG','9102','EPSG','8814','Angle from Rectified to Skew Grid',-36.86989764583333,'EPSG','9102','EPSG','8815','Scale factor on initial line',0.9999,'EPSG','9201','EPSG','8806','False easting',5000000.0,'EPSG','9001','EPSG','8807','False northing',-5000000.0,'EPSG','9001',0);
INSERT INTO "projected_crs" VALUES('ESRI','102366','NAD_1983_CORS96_StatePlane_Alaska_1_FIPS_5001',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102366','EPSG','2156',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102367','NAD_1983_CORS96_StatePlane_Alaska_2_FIPS_5002',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','15032','EPSG','2158',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102368','NAD_1983_CORS96_StatePlane_Alaska_3_FIPS_5003',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','15033','EPSG','2159',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102369','NAD_1983_CORS96_StatePlane_Alaska_4_FIPS_5004',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','15034','EPSG','2160',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102370','NAD_1983_CORS96_StatePlane_Alaska_5_FIPS_5005',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','15035','EPSG','2161',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102371','NAD_1983_CORS96_StatePlane_Alaska_6_FIPS_5006',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','15036','EPSG','2162',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102372','NAD_1983_CORS96_StatePlane_Alaska_7_FIPS_5007',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','15037','EPSG','2163',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102373','NAD_1983_CORS96_StatePlane_Alaska_8_FIPS_5008',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','15038','EPSG','2164',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102374','NAD_1983_CORS96_StatePlane_Alaska_9_FIPS_5009',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','15039','EPSG','2165',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102375','unnamed',NULL,NULL,'EPSG','2157','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',51.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-176.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',51.83333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',53.83333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102375','NAD_1983_CORS96_StatePlane_Alaska_10_FIPS_5010',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102375','EPSG','2157',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102376','NAD_1983_CORS96_StatePlane_Oregon_North_FIPS_3601',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102326','EPSG','2243',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102377','NAD_1983_CORS96_StatePlane_Oregon_South_FIPS_3602',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102327','EPSG','2244',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102378','unnamed',NULL,NULL,'EPSG','2243','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.0,'EPSG','9102','EPSG','8826','Easting at false origin',8202099.737532808,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102378','NAD_1983_CORS96_StatePlane_Oregon_North_FIPS_3601_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102378','EPSG','2243',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102379','unnamed',NULL,NULL,'EPSG','2244','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.0,'EPSG','9102','EPSG','8826','Easting at false origin',4921259.842519685,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102379','NAD_1983_CORS96_StatePlane_Oregon_South_FIPS_3602_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102379','EPSG','2244',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102380','unnamed',NULL,NULL,'EPSG','1406','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.75,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.5,'EPSG','9102','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102380','NAD_1983_CORS96_Oregon_Statewide_Lambert',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102380','EPSG','1406',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102381','unnamed',NULL,NULL,'EPSG','1406','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.75,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.5,'EPSG','9102','EPSG','8826','Easting at false origin',1312335.958005249,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102381','NAD_1983_CORS96_Oregon_Statewide_Lambert_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102381','EPSG','1406',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102382','NAD_1983_2011_UTM_Zone_13N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16013','EPSG','3500',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102383','NAD_1983_2011_UTM_Zone_14N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16014','EPSG','3501',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102384','NAD_1983_2011_UTM_Zone_15N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16015','EPSG','3502',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102385','NAD_1983_2011_UTM_Zone_16N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16016','EPSG','3503',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102386','NAD_1983_2011_UTM_Zone_17N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16017','EPSG','3504',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102387','NAD_1983_2011_UTM_Zone_18N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16018','EPSG','3505',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102388','NAD_1983_2011_UTM_Zone_19N',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','16019','EPSG','3506',NULL,1);
INSERT INTO "area" VALUES('ESRI','22','USA - North Dakota - Fargo','USA - North Dakota - Fargo',46.7,47.0,-96.93,-96.75,0);
INSERT INTO "projected_crs" VALUES('ESRI','102389','NAD_1983_Fargo_Ground_Coordinate_System',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'ESRI','22','PROJCS["NAD_1983_Fargo_Ground_Coordinate_System",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Rectified_Skew_Orthomorphic_Natural_Origin"],PARAMETER["False_Easting",2869344.93],PARAMETER["False_Northing",-16657672.6488],PARAMETER["Scale_Factor",1.000038773618],PARAMETER["Azimuth",2.63389226],PARAMETER["Longitude_Of_Center",-96.88886388888889],PARAMETER["Latitude_Of_Center",46.99163611111111],PARAMETER["XY_Plane_Rotation",0.0],UNIT["Foot_US",0.3048006096012192]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102390','NAD_1983_HARN_Fargo_Ground_Coordinate_System',NULL,NULL,NULL,NULL,'EPSG','4152',NULL,NULL,'ESRI','22','PROJCS["NAD_1983_HARN_Fargo_Ground_Coordinate_System",GEOGCS["GCS_North_American_1983_HARN",DATUM["D_North_American_1983_HARN",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Rectified_Skew_Orthomorphic_Natural_Origin"],PARAMETER["False_Easting",2869344.93],PARAMETER["False_Northing",-16657672.6488],PARAMETER["Scale_Factor",1.000038773618],PARAMETER["Azimuth",2.63389226],PARAMETER["Longitude_Of_Center",-96.88886388888889],PARAMETER["Latitude_Of_Center",46.99163611111111],PARAMETER["XY_Plane_Rotation",0.0],UNIT["Foot_US",0.3048006096012192]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102391','NAD_1983_2011_Fargo_Ground_Coordinate_System',NULL,NULL,NULL,NULL,'EPSG','6318',NULL,NULL,'ESRI','22','PROJCS["NAD_1983_2011_Fargo_Ground_Coordinate_System",GEOGCS["GCS_NAD_1983_2011",DATUM["D_NAD_1983_2011",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Rectified_Skew_Orthomorphic_Natural_Origin"],PARAMETER["False_Easting",2869344.93],PARAMETER["False_Northing",-16657672.6488],PARAMETER["Scale_Factor",1.000038773618],PARAMETER["Azimuth",2.63389226],PARAMETER["Longitude_Of_Center",-96.88886388888889],PARAMETER["Latitude_Of_Center",46.99163611111111],PARAMETER["XY_Plane_Rotation",0.0],UNIT["Foot_US",0.3048006096012192]]',0);
INSERT INTO "conversion" VALUES('ESRI','102392','unnamed',NULL,NULL,'EPSG','2160','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-150.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102392','NAD_1983_2011_StatePlane_Alaska_4_FIPS_5004_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102392','EPSG','2160',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102393','unnamed',NULL,NULL,'EPSG','2161','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-154.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102393','NAD_1983_2011_StatePlane_Alaska_5_FIPS_5005_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102393','EPSG','2161',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102394','unnamed',NULL,NULL,'EPSG','2162','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-158.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102394','NAD_1983_2011_StatePlane_Alaska_6_FIPS_5006_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102394','EPSG','2162',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102395','unnamed',NULL,NULL,'EPSG','2163','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-162.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102395','NAD_1983_2011_StatePlane_Alaska_7_FIPS_5007_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102395','EPSG','2163',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102396','unnamed',NULL,NULL,'EPSG','2164','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-166.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102396','NAD_1983_2011_StatePlane_Alaska_8_FIPS_5008_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102396','EPSG','2164',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102397','unnamed',NULL,NULL,'EPSG','2165','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-170.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102397','NAD_1983_2011_StatePlane_Alaska_9_FIPS_5009_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102397','EPSG','2165',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102398','unnamed',NULL,NULL,'EPSG','2157','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',51.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-176.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',51.83333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',53.83333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',3280833.333333333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102398','NAD_1983_2011_StatePlane_Alaska_10_FIPS_5010_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102398','EPSG','2157',NULL,0);
INSERT INTO "area" VALUES('ESRI','23','USA - Montana, North Dakota, and South Dakota','USA - Montana, North Dakota, and South Dakota',44.3,49.1,-116.1,-96.3,0);
INSERT INTO "projected_crs" VALUES('ESRI','102399','NAD_1983_Albers_BLM_MT_ND_SD',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'ESRI','23','PROJCS["NAD_1983_Albers_BLM_MT_ND_SD",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-106.0],PARAMETER["Standard_Parallel_1",43.5],PARAMETER["Standard_Parallel_2",48.0],PARAMETER["Latitude_Of_Origin",42.5],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102400','unnamed',NULL,NULL,'ESRI','2','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',51.1666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-0.158333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999999,'EPSG','9201','EPSG','8806','False easting',78250.0,'EPSG','9001','EPSG','8807','False northing',-2800.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102400','London_Survey_Grid',NULL,NULL,'EPSG','4400','ESRI','104050','ESRI','102400','ESRI','2',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102401','NAD_1983_CORS96_UTM_Zone_1N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16001','EPSG','3374',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102402','NAD_1983_CORS96_UTM_Zone_2N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16002','EPSG','3375',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102403','NAD_1983_CORS96_UTM_Zone_3N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16003','EPSG','2133',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102404','NAD_1983_CORS96_UTM_Zone_4N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16004','EPSG','2133',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102405','NAD_1983_CORS96_UTM_Zone_5N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16005','EPSG','2135',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102406','NAD_1983_CORS96_UTM_Zone_6N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16006','EPSG','2136',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102407','NAD_1983_CORS96_UTM_Zone_7N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16007','EPSG','3494',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102408','NAD_1983_CORS96_UTM_Zone_8N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16008','EPSG','3495',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102409','NAD_1983_CORS96_UTM_Zone_9N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16009','EPSG','3496',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102410','NAD_1983_CORS96_UTM_Zone_10N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16010','EPSG','3497',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102411','NAD_1983_CORS96_UTM_Zone_11N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16011','EPSG','3498',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102412','NAD_1983_CORS96_UTM_Zone_12N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16012','EPSG','3499',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102413','NAD_1983_CORS96_UTM_Zone_13N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16013','EPSG','3500',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102414','NAD_1983_CORS96_UTM_Zone_14N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16014','EPSG','3501',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102415','NAD_1983_CORS96_UTM_Zone_15N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16015','EPSG','3502',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102416','NAD_1983_CORS96_UTM_Zone_16N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16016','EPSG','3503',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102417','NAD_1983_CORS96_UTM_Zone_17N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16017','EPSG','3504',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102418','NAD_1983_CORS96_UTM_Zone_18N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16018','EPSG','3505',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102419','NAD_1983_CORS96_UTM_Zone_19N',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','16019','EPSG','3506',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102420','unnamed',NULL,NULL,'EPSG','1120','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',65.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-19.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',64.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',65.75,'EPSG','9102','EPSG','8826','Easting at false origin',1700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102420','ISN_2004_Lambert_2004',NULL,NULL,'EPSG','4400','EPSG','5324','ESRI','102420','EPSG','1120',NULL,1);
INSERT INTO "area" VALUES('ESRI','24','ARC System - Zone 1','ARC System - Zone 1',0.0,32.0,-180.0,180.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102421','WGS_1984_ARC_System_Zone_01',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','24','PROJCS["WGS_1984_ARC_System_Zone_01",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",22.94791772],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','25','ARC System - Zone 2','ARC System - Zone 2',32.0,48.0,-180.0,180.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102422','WGS_1984_ARC_System_Zone_02',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','25','PROJCS["WGS_1984_ARC_System_Zone_02",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",41.12682127],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','26','ARC System - Zone 3','ARC System - Zone 3',48.0,56.0,-180.0,180.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102423','WGS_1984_ARC_System_Zone_03',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','26','PROJCS["WGS_1984_ARC_System_Zone_03",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",52.28859923],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','27','ARC System - Zone 4','ARC System - Zone 4',56.0,64.0,-180.0,180.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102424','WGS_1984_ARC_System_Zone_04',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','27','PROJCS["WGS_1984_ARC_System_Zone_04",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",60.32378942],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','28','ARC System - Zone 5','ARC System - Zone 5',64.0,68.0,-180.0,180.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102425','WGS_1984_ARC_System_Zone_05',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','28','PROJCS["WGS_1984_ARC_System_Zone_05",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",66.09421768],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','29','ARC System - Zone 6','ARC System - Zone 6',68.0,72.0,-180.0,180.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102426','WGS_1984_ARC_System_Zone_06',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','29','PROJCS["WGS_1984_ARC_System_Zone_06",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",70.10896259],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','30','ARC System - Zone 7','ARC System - Zone 7',72.0,76.0,-180.0,180.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102427','WGS_1984_ARC_System_Zone_07',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','30','PROJCS["WGS_1984_ARC_System_Zone_07",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",74.13230145],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','31','ARC System - Zone 8','ARC System - Zone 8',76.0,80.0,-180.0,180.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102428','WGS_1984_ARC_System_Zone_08',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','31','PROJCS["WGS_1984_ARC_System_Zone_08",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",78.1728375],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','32','ARC System - Zone 9','ARC System - Zone 9',80.0,90.0,-180.0,180.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102429','WGS_1984_ARC_System_Zone_09',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','32','PROJCS["WGS_1984_ARC_System_Zone_09",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Azimuthal_Equidistant"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Latitude_Of_Origin",90.0],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','33','ARC System - Zone 10','ARC System - Zone 10',-32.0,0.0,-180.0,180.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102430','WGS_1984_ARC_System_Zone_10',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','33','PROJCS["WGS_1984_ARC_System_Zone_10",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",-22.94791772],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','34','ARC System - Zone 11','ARC System - Zone 11',-48.0,-32.0,-180.0,180.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102431','WGS_1984_ARC_System_Zone_11',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','34','PROJCS["WGS_1984_ARC_System_Zone_11",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",-41.12682127],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','35','ARC System - Zone 12','ARC System - Zone 12',-56.0,-48.0,-180.0,180.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102432','WGS_1984_ARC_System_Zone_12',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','35','PROJCS["WGS_1984_ARC_System_Zone_12",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",-52.28859923],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','36','ARC System - Zone 13','ARC System - Zone 13',-64.0,-56.0,-180.0,180.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102433','WGS_1984_ARC_System_Zone_13',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','36','PROJCS["WGS_1984_ARC_System_Zone_13",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",-60.32378942],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','37','ARC System - Zone 14','ARC System - Zone 14',-68.0,-64.0,-180.0,180.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102434','WGS_1984_ARC_System_Zone_14',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','37','PROJCS["WGS_1984_ARC_System_Zone_14",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",-66.09421768],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','38','ARC System - Zone 15','ARC System - Zone 15',-72.0,-68.0,-180.0,180.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102435','WGS_1984_ARC_System_Zone_15',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','38','PROJCS["WGS_1984_ARC_System_Zone_15",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",-70.10896259],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','39','ARC System - Zone 16','ARC System - Zone 16',-76.0,-72.0,-180.0,180.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102436','WGS_1984_ARC_System_Zone_16',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','39','PROJCS["WGS_1984_ARC_System_Zone_16",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",-74.13230145],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','40','ARC System - Zone 17','ARC System - Zone 17',-80.0,-76.0,-180.0,180.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102437','WGS_1984_ARC_System_Zone_17',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','40','PROJCS["WGS_1984_ARC_System_Zone_17",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Equidistant_Cylindrical"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Standard_Parallel_1",-78.1728375],UNIT["Meter",1.0]]',0);
INSERT INTO "area" VALUES('ESRI','41','ARC System - Zone 18','ARC System - Zone 18',-90.0,-80.0,-180.0,180.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102438','WGS_1984_ARC_System_Zone_18',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'ESRI','41','PROJCS["WGS_1984_ARC_System_Zone_18",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Azimuthal_Equidistant"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",0.0],PARAMETER["Latitude_Of_Origin",-90.0],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102439','unnamed',NULL,NULL,'EPSG','2575','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-27.0,'EPSG','9102','EPSG','8822','Longitude of false origin',132.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-18.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-36.0,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102439','WGS_1984_Australian_Centre_for_Remote_Sensing_Lambert',NULL,NULL,'EPSG','4400','EPSG','4326','ESRI','102439','EPSG','2575',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102440','LKS_1992_Latvia_TM_0',NULL,NULL,'EPSG','4400','EPSG','4661','EPSG','19930','EPSG','1139',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102441','TWD_1967_TM_Taiwan',NULL,NULL,'EPSG','4400','EPSG','3821','EPSG','3820','EPSG','3982',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102442','TWD_1967_TM_Penghu',NULL,NULL,'EPSG','4400','EPSG','3821','EPSG','3818','EPSG','3591',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102443','TWD_1997_TM_Taiwan',NULL,NULL,'EPSG','4400','EPSG','3824','EPSG','3820','EPSG','3562',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102444','TWD_1997_TM_Penghu',NULL,NULL,'EPSG','4400','EPSG','3824','EPSG','3818','EPSG','3563',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102445','unnamed',NULL,NULL,'EPSG','2156','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',57.0,'EPSG','9102','EPSG','8812','Longitude of projection centre',-133.6666666666667,'EPSG','9102','EPSG','8813','Azimuth of initial line',-36.86989764583333,'EPSG','9102','EPSG','8814','Angle from Rectified to Skew Grid',-36.86989764583333,'EPSG','9102','EPSG','8815','Scale factor on initial line',0.9999,'EPSG','9201','EPSG','8806','False easting',16404166.66666666,'EPSG','9003','EPSG','8807','False northing',-16404166.66666666,'EPSG','9003',0);
INSERT INTO "projected_crs" VALUES('ESRI','102445','NAD_1983_2011_StatePlane_Alaska_1_FIPS_5001_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102445','EPSG','2156',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102446','unnamed',NULL,NULL,'EPSG','2158','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-142.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102446','NAD_1983_2011_StatePlane_Alaska_2_FIPS_5002_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102446','EPSG','2158',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102447','unnamed',NULL,NULL,'EPSG','2159','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',54.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-146.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102447','NAD_1983_2011_StatePlane_Alaska_3_FIPS_5003_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102447','EPSG','2159',NULL,0);
INSERT INTO "area" VALUES('ESRI','42','Macao','Macao',22.1,22.22,113.52,113.6,0);
INSERT INTO "conversion" VALUES('ESRI','102448','unnamed',NULL,NULL,'ESRI','42','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',22.21239722222222,'EPSG','9102','EPSG','8802','Longitude of natural origin',113.5364694444444,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',20000.0,'EPSG','9001','EPSG','8807','False northing',20000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102448','Macao_2008_Macao_Grid',NULL,NULL,'EPSG','4400','ESRI','104248','ESRI','102448','ESRI','42',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102449','NAD_1983_MA11_UTM_Zone_55N',NULL,NULL,'EPSG','4400','EPSG','6325','EPSG','16055','EPSG','4167',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102450','unnamed',NULL,NULL,'ESRI','12','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',19999.32,'EPSG','9001','EPSG','8807','False northing',-202977.79,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102450','NGO_1948_Oslo_Baerum_Kommune',NULL,NULL,'EPSG','4400','EPSG','4817','ESRI','102450','ESRI','12',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102451','unnamed',NULL,NULL,'ESRI','13','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-4.666666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',-200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102451','NGO_1948_Oslo_Bergenhalvoen',NULL,NULL,'EPSG','4400','EPSG','4817','ESRI','102451','ESRI','13',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102452','unnamed',NULL,NULL,'ESRI','14','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',58.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',0.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',-212979.18,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102452','NGO_1948_Oslo_Oslo_Kommune',NULL,NULL,'EPSG','4400','EPSG','4817','ESRI','102452','ESRI','14',NULL,0);
INSERT INTO "area" VALUES('ESRI','43','Philippines - West of 120~E, N hemisphere','Philippines - West of 120~E, N hemisphere',3.0,22.0,114.0,120.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102453','Luzon_1911_UTM_Zone_50N',NULL,NULL,'EPSG','4400','EPSG','4253','EPSG','16050','ESRI','43',NULL,0);
INSERT INTO "area" VALUES('ESRI','44','Philippines - 120~E to 126~E, N hemisphere','Philippines - 120~E to 126~E, N hemisphere',3.0,24.0,120.0,126.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102454','Luzon_1911_UTM_Zone_51N',NULL,NULL,'EPSG','4400','EPSG','4253','EPSG','16051','ESRI','44',NULL,0);
INSERT INTO "area" VALUES('ESRI','45','Philippines - East of 126~E, N hemisphere','Philippines - East of 126~E, N hemisphere',4.0,20.0,126.0,132.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102455','Luzon_1911_UTM_Zone_52N',NULL,NULL,'EPSG','4400','EPSG','4253','EPSG','16052','ESRI','45',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102456','PRS_1992_UTM_Zone_50N',NULL,NULL,'EPSG','4400','EPSG','4683','EPSG','16050','ESRI','43',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102457','PRS_1992_UTM_Zone_51N',NULL,NULL,'EPSG','4400','EPSG','4683','EPSG','16051','ESRI','44',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102458','PRS_1992_UTM_Zone_52N',NULL,NULL,'EPSG','4400','EPSG','4683','EPSG','16052','ESRI','45',NULL,0);
INSERT INTO "area" VALUES('ESRI','46','Idaho - Ada County','Idaho - Ada County',43.0,43.85,-116.6,-115.94,0);
INSERT INTO "conversion" VALUES('ESRI','102459','unnamed',NULL,NULL,'ESRI','46','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-115.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00011328,'EPSG','9201','EPSG','8806','False easting',2625138.996430666,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102459','NAD_1983_Idaho-Ada_County',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102459','ESRI','46',NULL,0);
INSERT INTO "area" VALUES('ESRI','47','HJAIA - Hartsfield-Jackson Atlanta Intl Airport','HJAIA - Hartsfield-Jackson Atlanta Intl Airport',33.590879,33.68427937,-84.502368,-84.351204,0);
INSERT INTO "projected_crs" VALUES('ESRI','102460','HJAIA_AirportGrid_2Mar10',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'ESRI','47','PROJCS["HJAIA_AirportGrid_2Mar10",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Local"],PARAMETER["False_Easting",11233.741],PARAMETER["False_Northing",3076.34],PARAMETER["Scale_Factor",1.000047],PARAMETER["Azimuth",-0.01935],PARAMETER["Longitude_Of_Center",-84.4306922136],PARAMETER["Latitude_Of_Center",33.6340844042],UNIT["Foot_US",0.3048006096012192]]',0);
INSERT INTO "conversion" VALUES('ESRI','102461','unnamed',NULL,NULL,'EPSG','1546','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',18.83333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-155.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102461','NAD_1983_HARN_StatePlane_Hawaii_1_FIPS_5101_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','102461','EPSG','1546',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102462','unnamed',NULL,NULL,'EPSG','1547','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',20.33333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-156.6666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102462','NAD_1983_HARN_StatePlane_Hawaii_2_FIPS_5102_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','102462','EPSG','1547',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102463','unnamed',NULL,NULL,'EPSG','1548','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',21.16666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-158.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99999,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102463','NAD_1983_HARN_StatePlane_Hawaii_3_FIPS_5103_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','102463','EPSG','1548',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102464','unnamed',NULL,NULL,'EPSG','1549','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',21.83333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-159.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99999,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102464','NAD_1983_HARN_StatePlane_Hawaii_4_FIPS_5104_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','102464','EPSG','1549',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102465','unnamed',NULL,NULL,'EPSG','1550','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',21.66666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-160.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102465','NAD_1983_HARN_StatePlane_Hawaii_5_FIPS_5105_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','102465','EPSG','1550',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102466','unnamed',NULL,NULL,'EPSG','2214','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.1,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.63333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',2624666.666666666,'EPSG','9003','EPSG','8827','Northing at false origin',328083.3333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102466','NAD_1983_HARN_StatePlane_Minnesota_North_FIPS_2201_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','102466','EPSG','2214',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102467','unnamed',NULL,NULL,'EPSG','2213','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.25,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.61666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.05,'EPSG','9102','EPSG','8826','Easting at false origin',2624666.666666666,'EPSG','9003','EPSG','8827','Northing at false origin',328083.3333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102467','NAD_1983_HARN_StatePlane_Minnesota_Central_FIPS_2202_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','102467','EPSG','2213',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102468','unnamed',NULL,NULL,'EPSG','2215','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.78333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.21666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',2624666.666666666,'EPSG','9003','EPSG','8827','Northing at false origin',328083.3333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102468','NAD_1983_HARN_StatePlane_Minnesota_South_FIPS_2203_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','102468','EPSG','2215',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102469','unnamed',NULL,NULL,'EPSG','1393','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',32.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9998335,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',1300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102469','NAD_1983_HARN_Mississippi_TM',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','102469','EPSG','1393',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102470','unnamed',NULL,NULL,'EPSG','1454','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',15.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',-1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102470','Cape_Lo15',NULL,NULL,'EPSG','4400','EPSG','4222','ESRI','102470','EPSG','1454',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102471','unnamed',NULL,NULL,'EPSG','1455','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',17.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',-1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102471','Cape_Lo17',NULL,NULL,'EPSG','4400','EPSG','4222','ESRI','102471','EPSG','1455',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102472','unnamed',NULL,NULL,'EPSG','1456','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',19.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',-1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102472','Cape_Lo19',NULL,NULL,'EPSG','4400','EPSG','4222','ESRI','102472','EPSG','1456',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102473','unnamed',NULL,NULL,'EPSG','1457','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',-1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102473','Cape_Lo21',NULL,NULL,'EPSG','4400','EPSG','4222','ESRI','102473','EPSG','1457',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102474','unnamed',NULL,NULL,'EPSG','1458','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',23.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',-1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102474','Cape_Lo23',NULL,NULL,'EPSG','4400','EPSG','4222','ESRI','102474','EPSG','1458',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102475','unnamed',NULL,NULL,'EPSG','1459','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',25.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',-1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102475','Cape_Lo25',NULL,NULL,'EPSG','4400','EPSG','4222','ESRI','102475','EPSG','1459',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102476','unnamed',NULL,NULL,'EPSG','1460','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',-1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102476','Cape_Lo27',NULL,NULL,'EPSG','4400','EPSG','4222','ESRI','102476','EPSG','1460',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102477','unnamed',NULL,NULL,'EPSG','1461','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',29.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',-1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102477','Cape_Lo29',NULL,NULL,'EPSG','4400','EPSG','4222','ESRI','102477','EPSG','1461',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102478','unnamed',NULL,NULL,'EPSG','1462','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',31.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',-1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102478','Cape_Lo31',NULL,NULL,'EPSG','4400','EPSG','4222','ESRI','102478','EPSG','1462',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102479','unnamed',NULL,NULL,'EPSG','1463','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',-1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102479','Cape_Lo33',NULL,NULL,'EPSG','4400','EPSG','4222','ESRI','102479','EPSG','1463',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102480','Hartebeesthoek94_Lo15',NULL,NULL,'EPSG','4400','EPSG','4148','ESRI','102470','EPSG','1454',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102481','Hartebeesthoek94_Lo17',NULL,NULL,'EPSG','4400','EPSG','4148','ESRI','102471','EPSG','1455',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102482','Hartebeesthoek94_Lo19',NULL,NULL,'EPSG','4400','EPSG','4148','ESRI','102472','EPSG','1456',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102483','Hartebeesthoek94_Lo21',NULL,NULL,'EPSG','4400','EPSG','4148','ESRI','102473','EPSG','1457',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102484','Hartebeesthoek94_Lo23',NULL,NULL,'EPSG','4400','EPSG','4148','ESRI','102474','EPSG','1458',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102485','Hartebeesthoek94_Lo25',NULL,NULL,'EPSG','4400','EPSG','4148','ESRI','102475','EPSG','1459',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102486','Hartebeesthoek94_Lo27',NULL,NULL,'EPSG','4400','EPSG','4148','ESRI','102476','EPSG','1460',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102487','Hartebeesthoek94_Lo29',NULL,NULL,'EPSG','4400','EPSG','4148','ESRI','102477','EPSG','1461',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102488','Hartebeesthoek94_Lo31',NULL,NULL,'EPSG','4400','EPSG','4148','ESRI','102478','EPSG','1462',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102489','Hartebeesthoek94_Lo33',NULL,NULL,'EPSG','4400','EPSG','4148','ESRI','102479','EPSG','1463',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102490','GDBD2009_GEORSO',NULL,NULL,NULL,NULL,'EPSG','5246',NULL,NULL,'EPSG','1055','PROJCS["GDBD2009_GEORSO",GEOGCS["GCS_GDBD2009",DATUM["D_GDBD2009",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Rectified_Skew_Orthomorphic_Natural_Origin"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Scale_Factor",0.99984],PARAMETER["Azimuth",53.31580995],PARAMETER["Longitude_Of_Center",115.0],PARAMETER["Latitude_Of_Center",4.0],PARAMETER["XY_Plane_Rotation",53.13010235415598],UNIT["Meter",1.0]]',1);
INSERT INTO "conversion" VALUES('ESRI','102491','unnamed',NULL,NULL,'EPSG','1026','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',36.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',2.7,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999625544,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102491','Nord_Algerie_Ancienne_Degree',NULL,NULL,'EPSG','4400','EPSG','4304','ESRI','102491','EPSG','1026',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102492','unnamed',NULL,NULL,'EPSG','1026','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',33.3,'EPSG','9102','EPSG','8802','Longitude of natural origin',2.7,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999625769,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',300000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102492','Sud_Algerie_Ancienne_Degree',NULL,NULL,'EPSG','4400','EPSG','4304','ESRI','102492','EPSG','1026',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102493','NAD_1983_PA11_UTM_Zone_4N',NULL,NULL,'EPSG','4400','EPSG','6322','EPSG','16004','EPSG','3488',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102494','NAD_1983_PA11_UTM_Zone_5N',NULL,NULL,'EPSG','4400','EPSG','6322','EPSG','16005','EPSG','3491',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102495','NAD_1983_MA11_Guam_Map_Grid',NULL,NULL,'EPSG','4400','EPSG','6325','ESRI','102201','EPSG','3255',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102496','NAD_1983_PA11_UTM_Zone_2S',NULL,NULL,'EPSG','4400','EPSG','6322','EPSG','16102','EPSG','3110',NULL,1);
INSERT INTO "area" VALUES('ESRI','48','GOES-16 East Full disk','GOES-16 East Full disk',-81.3282,81.3282,-156.2995,6.2995,0);
INSERT INTO "projected_crs" VALUES('ESRI','102497','GOES-16_East_ABI_Fixed_Grid_ITRF2000_incorrect_GCS',NULL,NULL,NULL,NULL,'ESRI','104124',NULL,NULL,'ESRI','48','PROJCS["GOES-16_East_ABI_Fixed_Grid_ITRF2000_incorrect_GCS",GEOGCS["GCS_ITRF_2000",DATUM["D_ITRF_2000",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Geostationary_Satellite"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Longitude_Of_Center",-75.0],PARAMETER["Height",35786023.0],PARAMETER["Option",0.0],UNIT["Meter",1.0]]',1);
INSERT INTO "projected_crs" VALUES('ESRI','102498','GOES-16_East_ABI_Fixed_Grid_ITRF2008',NULL,NULL,NULL,NULL,'ESRI','104257',NULL,NULL,'ESRI','48','PROJCS["GOES-16_East_ABI_Fixed_Grid_ITRF2008",GEOGCS["GCS_ITRF_2008",DATUM["D_ITRF_2008",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Geostationary_Satellite"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Longitude_Of_Center",-75.0],PARAMETER["Height",35786023.0],PARAMETER["Option",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102499','unnamed',NULL,NULL,'EPSG','1347','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',90.0,'EPSG','9102','EPSG','8822','Longitude of false origin',4.367486666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',49.8333339,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',51.16666723333333,'EPSG','9102','EPSG','8826','Easting at false origin',150000.01256,'EPSG','9001','EPSG','8827','Northing at false origin',5400088.4378,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102499','Belge_Lambert_1972_bad_FE_FN',NULL,NULL,'EPSG','4400','EPSG','4313','ESRI','102499','EPSG','1347',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102500','unnamed',NULL,NULL,'EPSG','4180','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-117.8333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00016,'EPSG','9201','EPSG','8806','False easting',131233.5958005249,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102500','OCRS_Baker_NAD_1983_CORS96_TM_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102500','EPSG','4180',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102501','unnamed',NULL,NULL,'EPSG','4182','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-119.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0002,'EPSG','9201','EPSG','8806','False easting',393700.7874015748,'EPSG','9002','EPSG','8807','False northing',196850.3937007874,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102501','OCRS_Bend-Burns_NAD_1983_CORS96_LCC_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102501','EPSG','4182',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102502','unnamed',NULL,NULL,'EPSG','4192','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-121.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0002,'EPSG','9201','EPSG','8806','False easting',262467.1916010499,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102502','OCRS_Bend-Klamath_Falls_NAD_1983_CORS96_TM_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102502','EPSG','4192',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102503','unnamed',NULL,NULL,'EPSG','4195','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-121.25,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00012,'EPSG','9201','EPSG','8806','False easting',262467.1916010499,'EPSG','9002','EPSG','8807','False northing',426509.186351706,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102503','OCRS_Bend-Redmond-Prineville_NAD_1983_CORS96_LCC_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102503','EPSG','4195',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102504','unnamed',NULL,NULL,'EPSG','4199','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-123.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00007,'EPSG','9201','EPSG','8806','False easting',131233.5958005249,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102504','OCRS_Canyonville-Grants_Pass_NAD_1983_CORS96_TM_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102504','EPSG','4199',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102505','unnamed',NULL,NULL,'EPSG','4200','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-120.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000008,'EPSG','9201','EPSG','8806','False easting',492125.9842519685,'EPSG','9002','EPSG','8807','False northing',98425.1968503937,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102505','OCRS_Columbia_River_East_NAD_1983_CORS96_LCC_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102505','EPSG','4200',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102506','unnamed',NULL,NULL,'EPSG','4202','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',45.91666666666666,'EPSG','9102','EPSG','8812','Longitude of projection centre',-123.0,'EPSG','9102','EPSG','8813','Azimuth of initial line',-65.0,'EPSG','9102','EPSG','8814','Angle from Rectified to Skew Grid',-65.0,'EPSG','9102','EPSG','8815','Scale factor on initial line',1.0,'EPSG','9201','EPSG','8806','False easting',22965879.26509186,'EPSG','9002','EPSG','8807','False northing',-9842519.685039369,'EPSG','9002',1);
INSERT INTO "projected_crs" VALUES('ESRI','102506','OCRS_Columbia_River_West_NAD_1983_CORS96_OM_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102506','EPSG','4202',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102507','unnamed',NULL,NULL,'EPSG','4203','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-123.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000023,'EPSG','9201','EPSG','8806','False easting',164041.9947506562,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102507','OCRS_Cottage_Grove-Canyonville_NAD_1983_CORS96_TM_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102507','EPSG','4203',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102508','unnamed',NULL,NULL,'EPSG','4204','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-121.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00011,'EPSG','9201','EPSG','8806','False easting',262467.1916010499,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102508','OCRS_Dufur-Madras_NAD_1983_CORS96_TM_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102508','EPSG','4204',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102509','unnamed',NULL,NULL,'EPSG','4197','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-123.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000015,'EPSG','9201','EPSG','8806','False easting',164041.9947506562,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102509','OCRS_Eugene_NAD_1983_CORS96_TM_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102509','EPSG','4197',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102510','unnamed',NULL,NULL,'EPSG','4198','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-123.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000043,'EPSG','9201','EPSG','8806','False easting',164041.9947506562,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102510','OCRS_Grants_Pass-Ashland_NAD_1983_CORS96_TM_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102510','EPSG','4198',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102511','unnamed',NULL,NULL,'EPSG','4201','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-122.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00005,'EPSG','9201','EPSG','8806','False easting',32808.39895013123,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102511','OCRS_Gresham-Warm_Springs_NAD_1983_CORS96_TM_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102511','EPSG','4201',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102512','unnamed',NULL,NULL,'EPSG','4206','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-118.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00013,'EPSG','9201','EPSG','8806','False easting',131233.5958005249,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102512','OCRS_La_Grande_NAD_1983_CORS96_TM_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102512','EPSG','4206',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102513','unnamed',NULL,NULL,'EPSG','4207','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.25,'EPSG','9102','EPSG','8802','Longitude of natural origin',-117.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0001,'EPSG','9201','EPSG','8806','False easting',262467.1916010499,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102513','OCRS_Ontario_NAD_1983_CORS96_TM_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102513','EPSG','4207',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102514','unnamed',NULL,NULL,'EPSG','4208','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',44.75,'EPSG','9102','EPSG','8812','Longitude of projection centre',-124.05,'EPSG','9102','EPSG','8813','Azimuth of initial line',5.0,'EPSG','9102','EPSG','8814','Angle from Rectified to Skew Grid',5.0,'EPSG','9102','EPSG','8815','Scale factor on initial line',1.0,'EPSG','9201','EPSG','8806','False easting',-984251.968503937,'EPSG','9002','EPSG','8807','False northing',-15091863.51706037,'EPSG','9002',1);
INSERT INTO "projected_crs" VALUES('ESRI','102514','OCRS_Oregon_Coast_NAD_1983_CORS96_OM_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102514','EPSG','4208',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102515','unnamed',NULL,NULL,'EPSG','4210','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.08333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-118.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000175,'EPSG','9201','EPSG','8806','False easting',98425.1968503937,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102515','OCRS_Pendleton-La_Grande_NAD_1983_CORS96_TM_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102515','EPSG','4210',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102516','unnamed',NULL,NULL,'EPSG','4209','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.25,'EPSG','9102','EPSG','8802','Longitude of natural origin',-119.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000045,'EPSG','9201','EPSG','8806','False easting',196850.3937007874,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102516','OCRS_Pendleton_NAD_1983_CORS96_TM_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102516','EPSG','4209',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102517','unnamed',NULL,NULL,'EPSG','4211','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-122.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000002,'EPSG','9201','EPSG','8806','False easting',328083.9895013123,'EPSG','9002','EPSG','8807','False northing',164041.9947506562,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102517','OCRS_Portland_NAD_1983_CORS96_LCC_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102517','EPSG','4211',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102518','unnamed',NULL,NULL,'EPSG','4212','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.33333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-123.0833333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00001,'EPSG','9201','EPSG','8806','False easting',164041.9947506562,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102518','OCRS_Salem_NAD_1983_CORS96_TM_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102518','EPSG','4212',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102519','unnamed',NULL,NULL,'EPSG','4213','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.08333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-122.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000155,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102519','OCRS_Santiam_Pass_NAD_1983_CORS96_TM_Feet_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','102519','EPSG','4213',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102520','NAD_1983_PA11_StatePlane_Hawaii_1_FIPS_5101',NULL,NULL,'EPSG','4400','EPSG','6322','ESRI','102261','EPSG','1546',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102521','NAD_1983_PA11_StatePlane_Hawaii_2_FIPS_5102',NULL,NULL,'EPSG','4400','EPSG','6322','ESRI','102262','EPSG','1547',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102522','NAD_1983_PA11_StatePlane_Hawaii_3_FIPS_5103',NULL,NULL,'EPSG','4400','EPSG','6322','ESRI','102263','EPSG','1548',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102523','NAD_1983_PA11_StatePlane_Hawaii_4_FIPS_5104',NULL,NULL,'EPSG','4400','EPSG','6322','ESRI','102264','EPSG','1549',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102524','NAD_1983_PA11_StatePlane_Hawaii_5_FIPS_5105',NULL,NULL,'EPSG','4400','EPSG','6322','ESRI','102265','EPSG','1550',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102525','NAD_1983_PA11_StatePlane_Hawaii_1_FIPS_5101_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','6322','ESRI','102461','EPSG','1546',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102526','NAD_1983_PA11_StatePlane_Hawaii_2_FIPS_5102_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','6322','ESRI','102462','EPSG','1547',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102527','NAD_1983_PA11_StatePlane_Hawaii_3_FIPS_5103_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','6322','ESRI','102463','EPSG','1548',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102528','NAD_1983_PA11_StatePlane_Hawaii_4_FIPS_5104_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','6322','ESRI','102464','EPSG','1549',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102529','NAD_1983_PA11_StatePlane_Hawaii_5_FIPS_5105_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','6322','ESRI','102465','EPSG','1550',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102530','unnamed',NULL,NULL,'EPSG','4180','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-117.8333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00016,'EPSG','9201','EPSG','8806','False easting',40000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102530','OCRS_Baker_NAD_1983_CORS96_TM_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102530','EPSG','4180',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102531','unnamed',NULL,NULL,'EPSG','4182','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-119.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0002,'EPSG','9201','EPSG','8806','False easting',120000.0,'EPSG','9001','EPSG','8807','False northing',60000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102531','OCRS_Bend-Burns_NAD_1983_CORS96_LCC_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102531','EPSG','4182',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102532','unnamed',NULL,NULL,'EPSG','4192','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-121.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0002,'EPSG','9201','EPSG','8806','False easting',80000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102532','OCRS_Bend-Klamath_Falls_NAD_1983_CORS96_TM_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102532','EPSG','4192',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102533','unnamed',NULL,NULL,'EPSG','4195','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-121.25,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00012,'EPSG','9201','EPSG','8806','False easting',80000.0,'EPSG','9001','EPSG','8807','False northing',130000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102533','OCRS_Bend-Redmond-Prineville_NAD_1983_CORS96_LCC_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102533','EPSG','4195',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102534','unnamed',NULL,NULL,'EPSG','4199','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-123.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00007,'EPSG','9201','EPSG','8806','False easting',40000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102534','OCRS_Canyonville-Grants_Pass_NAD_1983_CORS96_TM_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102534','EPSG','4199',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102535','unnamed',NULL,NULL,'EPSG','4200','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-120.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000008,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',30000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102535','OCRS_Columbia_River_East_NAD_1983_CORS96_LCC_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102535','EPSG','4200',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102536','unnamed',NULL,NULL,'EPSG','4202','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',45.91666666666666,'EPSG','9102','EPSG','8812','Longitude of projection centre',-123.0,'EPSG','9102','EPSG','8813','Azimuth of initial line',-65.0,'EPSG','9102','EPSG','8814','Angle from Rectified to Skew Grid',-65.0,'EPSG','9102','EPSG','8815','Scale factor on initial line',1.0,'EPSG','9201','EPSG','8806','False easting',7000000.0,'EPSG','9001','EPSG','8807','False northing',-3000000.0,'EPSG','9001',1);
INSERT INTO "projected_crs" VALUES('ESRI','102536','OCRS_Columbia_River_West_NAD_1983_CORS96_OM_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102536','EPSG','4202',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102537','unnamed',NULL,NULL,'EPSG','4203','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-123.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000023,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102537','OCRS_Cottage_Grove-Canyonville_NAD_1983_CORS96_TM_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102537','EPSG','4203',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102538','unnamed',NULL,NULL,'EPSG','4204','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-121.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00011,'EPSG','9201','EPSG','8806','False easting',80000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102538','OCRS_Dufur-Madras_NAD_1983_CORS96_TM_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102538','EPSG','4204',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102539','unnamed',NULL,NULL,'EPSG','4197','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-123.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000015,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102539','OCRS_Eugene_NAD_1983_CORS96_TM_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102539','EPSG','4197',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102540','unnamed',NULL,NULL,'EPSG','4198','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-123.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000043,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102540','OCRS_Grants_Pass-Ashland_NAD_1983_CORS96_TM_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102540','EPSG','4198',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102541','unnamed',NULL,NULL,'EPSG','4201','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-122.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00005,'EPSG','9201','EPSG','8806','False easting',10000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102541','OCRS_Gresham-Warm_Springs_NAD_1983_CORS96_TM_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102541','EPSG','4201',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102542','OCRS_La_Grande_NAD_1983_CORS96_TM_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','EPSG','6765','EPSG','4206',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102543','unnamed',NULL,NULL,'EPSG','4207','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.25,'EPSG','9102','EPSG','8802','Longitude of natural origin',-117.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0001,'EPSG','9201','EPSG','8806','False easting',80000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102543','OCRS_Ontario_NAD_1983_CORS96_TM_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102543','EPSG','4207',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102544','unnamed',NULL,NULL,'EPSG','4208','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',44.75,'EPSG','9102','EPSG','8812','Longitude of projection centre',-124.05,'EPSG','9102','EPSG','8813','Azimuth of initial line',5.0,'EPSG','9102','EPSG','8814','Angle from Rectified to Skew Grid',5.0,'EPSG','9102','EPSG','8815','Scale factor on initial line',1.0,'EPSG','9201','EPSG','8806','False easting',-300000.0,'EPSG','9001','EPSG','8807','False northing',-4600000.0,'EPSG','9001',1);
INSERT INTO "projected_crs" VALUES('ESRI','102544','OCRS_Oregon_Coast_NAD_1983_CORS96_OM_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102544','EPSG','4208',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102545','unnamed',NULL,NULL,'EPSG','4210','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.08333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-118.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000175,'EPSG','9201','EPSG','8806','False easting',30000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102545','OCRS_Pendleton-La_Grande_NAD_1983_CORS96_TM_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102545','EPSG','4210',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102546','unnamed',NULL,NULL,'EPSG','4209','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.25,'EPSG','9102','EPSG','8802','Longitude of natural origin',-119.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000045,'EPSG','9201','EPSG','8806','False easting',60000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102546','OCRS_Pendleton_NAD_1983_CORS96_TM_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102546','EPSG','4209',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102547','unnamed',NULL,NULL,'EPSG','4211','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-122.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000002,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',50000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102547','OCRS_Portland_NAD_1983_CORS96_LCC_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102547','EPSG','4211',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102548','unnamed',NULL,NULL,'EPSG','4212','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.33333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-123.0833333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00001,'EPSG','9201','EPSG','8806','False easting',50000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102548','OCRS_Salem_NAD_1983_CORS96_TM_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102548','EPSG','4212',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102549','unnamed',NULL,NULL,'EPSG','4213','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.08333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-122.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000155,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102549','OCRS_Santiam_Pass_NAD_1983_CORS96_TM_Meters',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','102549','EPSG','4213',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102550','unnamed',NULL,NULL,'EPSG','1524','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',9500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102550','ED_1950_Turkey_9',NULL,NULL,'EPSG','4400','EPSG','4230','ESRI','102550','EPSG','1524',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102551','unnamed',NULL,NULL,'EPSG','1525','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',30.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',10500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102551','ED_1950_Turkey_10',NULL,NULL,'EPSG','4400','EPSG','4230','ESRI','102551','EPSG','1525',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102552','unnamed',NULL,NULL,'EPSG','1526','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',33.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',11500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102552','ED_1950_Turkey_11',NULL,NULL,'EPSG','4400','EPSG','4230','ESRI','102552','EPSG','1526',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102553','unnamed',NULL,NULL,'EPSG','1527','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',36.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',12500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102553','ED_1950_Turkey_12',NULL,NULL,'EPSG','4400','EPSG','4230','ESRI','102553','EPSG','1527',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102554','unnamed',NULL,NULL,'EPSG','1528','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',39.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',13500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102554','ED_1950_Turkey_13',NULL,NULL,'EPSG','4400','EPSG','4230','ESRI','102554','EPSG','1528',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102555','unnamed',NULL,NULL,'EPSG','1529','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',42.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',14500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102555','ED_1950_Turkey_14',NULL,NULL,'EPSG','4400','EPSG','4230','ESRI','102555','EPSG','1529',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102556','unnamed',NULL,NULL,'EPSG','1530','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',45.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',15500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102556','ED_1950_Turkey_15',NULL,NULL,'EPSG','4400','EPSG','4230','ESRI','102556','EPSG','1530',NULL,0);
INSERT INTO "area" VALUES('ESRI','49','Kyrgyz Republic - 67~01''E to 70~01''E','Kyrgyz Republic - 67~01''E to 70~01''E',39.4,40.3,67.0166667,70.0166667,0);
INSERT INTO "conversion" VALUES('ESRI','102557','unnamed',NULL,NULL,'ESRI','49','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',68.51666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',1300000.0,'EPSG','9001','EPSG','8807','False northing',14743.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102557','Kyrg-06_TM_Zone_1',NULL,NULL,'EPSG','4400','ESRI','104009','ESRI','102557','ESRI','49',NULL,0);
INSERT INTO "area" VALUES('ESRI','50','Kyrgyz Republic - 70~01''E to 73~01''E','Kyrgyz Republic - 70~01''E to 73~01''E',39.1333333,42.9,70.0166667,73.0166667,0);
INSERT INTO "conversion" VALUES('ESRI','102558','unnamed',NULL,NULL,'ESRI','50','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',71.51666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',2300000.0,'EPSG','9001','EPSG','8807','False northing',14743.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102558','Kyrg-06_TM_Zone_2',NULL,NULL,'EPSG','4400','ESRI','104009','ESRI','102558','ESRI','50',NULL,0);
INSERT INTO "area" VALUES('ESRI','51','Kyrgyz Republic - 73~01''E to 76~01''E','Kyrgyz Republic - 73~01''E to 76~01''E',39.25,43.3333333,73.0166667,76.0166667,0);
INSERT INTO "conversion" VALUES('ESRI','102559','unnamed',NULL,NULL,'ESRI','51','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',74.51666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',3300000.0,'EPSG','9001','EPSG','8807','False northing',14743.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102559','Kyrg-06_TM_Zone_3',NULL,NULL,'EPSG','4400','ESRI','104009','ESRI','102559','ESRI','51',NULL,0);
INSERT INTO "area" VALUES('ESRI','52','Kyrgyz Republic - 76~01''E to 79~01''E','Kyrgyz Republic - 76~01''E to 79~01''E',40.1666667,43.0,76.0166667,79.0166667,0);
INSERT INTO "conversion" VALUES('ESRI','102560','unnamed',NULL,NULL,'ESRI','52','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',77.51666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',4300000.0,'EPSG','9001','EPSG','8807','False northing',14743.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102560','Kyrg-06_TM_Zone_4',NULL,NULL,'EPSG','4400','ESRI','104009','ESRI','102560','ESRI','52',NULL,0);
INSERT INTO "area" VALUES('ESRI','53','Kyrgyz Republic - 79~01''E to 82~01''E','Kyrgyz Republic - 79~01''E to 82~01''E',41.5,43.0,79.0166667,82.0166667,0);
INSERT INTO "conversion" VALUES('ESRI','102561','unnamed',NULL,NULL,'ESRI','53','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',80.51666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',5300000.0,'EPSG','9001','EPSG','8807','False northing',14743.5,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102561','Kyrg-06_TM_Zone_5',NULL,NULL,'EPSG','4400','ESRI','104009','ESRI','102561','ESRI','53',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102562','unnamed',NULL,NULL,'EPSG','1456','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',19.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102562','Hartebeesthoek94_Lo19_(E-N)',NULL,NULL,'EPSG','4400','EPSG','4148','ESRI','102562','EPSG','1456',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102563','unnamed',NULL,NULL,'EPSG','1457','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',21.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102563','Hartebeesthoek94_Lo21_(E-N)',NULL,NULL,'EPSG','4400','EPSG','4148','ESRI','102563','EPSG','1457',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102564','unnamed',NULL,NULL,'EPSG','1458','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',23.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102564','Hartebeesthoek94_Lo23_(E-N)',NULL,NULL,'EPSG','4400','EPSG','4148','ESRI','102564','EPSG','1458',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102565','unnamed',NULL,NULL,'EPSG','1459','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',25.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102565','Hartebeesthoek94_Lo25_(E-N)',NULL,NULL,'EPSG','4400','EPSG','4148','ESRI','102565','EPSG','1459',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102566','unnamed',NULL,NULL,'EPSG','1460','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',27.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102566','Hartebeesthoek94_Lo27_(E-N)',NULL,NULL,'EPSG','4400','EPSG','4148','ESRI','102566','EPSG','1460',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102567','unnamed',NULL,NULL,'EPSG','1461','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',0.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',29.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102567','Hartebeesthoek94_Lo29_(E-N)',NULL,NULL,'EPSG','4400','EPSG','4148','ESRI','102567','EPSG','1461',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102568','Hartebeesthoek94_Lo31_(E-N)',NULL,NULL,'EPSG','4400','EPSG','4148','EPSG','18042','EPSG','1462',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102569','New_Beijing_3_Degree_Gauss_Kruger_CM_132E',NULL,NULL,'EPSG','4400','EPSG','4555','EPSG','16174','EPSG','2730',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102570','WGS_1984_Complex_UTM_Zone_20N',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1911','PROJCS["WGS_1984_Complex_UTM_Zone_20N",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Transverse_Mercator_Complex"],PARAMETER["False_Easting",500000.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-63.0],PARAMETER["Scale_Factor",0.9996],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102571','WGS_1984_Complex_UTM_Zone_21N',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1913','PROJCS["WGS_1984_Complex_UTM_Zone_21N",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Transverse_Mercator_Complex"],PARAMETER["False_Easting",500000.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-57.0],PARAMETER["Scale_Factor",0.9996],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102572','WGS_1984_Complex_UTM_Zone_22N',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1915','PROJCS["WGS_1984_Complex_UTM_Zone_22N",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Transverse_Mercator_Complex"],PARAMETER["False_Easting",500000.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-51.0],PARAMETER["Scale_Factor",0.9996],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102573','WGS_1984_Complex_UTM_Zone_23N',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1917','PROJCS["WGS_1984_Complex_UTM_Zone_23N",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Transverse_Mercator_Complex"],PARAMETER["False_Easting",500000.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-45.0],PARAMETER["Scale_Factor",0.9996],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102574','WGS_1984_Complex_UTM_Zone_24N',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1919','PROJCS["WGS_1984_Complex_UTM_Zone_24N",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Transverse_Mercator_Complex"],PARAMETER["False_Easting",500000.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-39.0],PARAMETER["Scale_Factor",0.9996],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102575','WGS_1984_Complex_UTM_Zone_25N',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1921','PROJCS["WGS_1984_Complex_UTM_Zone_25N",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Transverse_Mercator_Complex"],PARAMETER["False_Easting",500000.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-33.0],PARAMETER["Scale_Factor",0.9996],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102576','WGS_1984_Complex_UTM_Zone_26N',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1923','PROJCS["WGS_1984_Complex_UTM_Zone_26N",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Transverse_Mercator_Complex"],PARAMETER["False_Easting",500000.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-27.0],PARAMETER["Scale_Factor",0.9996],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102577','WGS_1984_Complex_UTM_Zone_27N',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1925','PROJCS["WGS_1984_Complex_UTM_Zone_27N",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Transverse_Mercator_Complex"],PARAMETER["False_Easting",500000.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-21.0],PARAMETER["Scale_Factor",0.9996],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102578','WGS_1984_Complex_UTM_Zone_28N',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1927','PROJCS["WGS_1984_Complex_UTM_Zone_28N",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Transverse_Mercator_Complex"],PARAMETER["False_Easting",500000.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-15.0],PARAMETER["Scale_Factor",0.9996],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102579','WGS_1984_Complex_UTM_Zone_29N',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1929','PROJCS["WGS_1984_Complex_UTM_Zone_29N",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Transverse_Mercator_Complex"],PARAMETER["False_Easting",500000.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-9.0],PARAMETER["Scale_Factor",0.9996],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102580','WGS_1984_Complex_UTM_Zone_30N',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1931','PROJCS["WGS_1984_Complex_UTM_Zone_30N",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Transverse_Mercator_Complex"],PARAMETER["False_Easting",500000.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-3.0],PARAMETER["Scale_Factor",0.9996],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102581','unnamed',NULL,NULL,'EPSG','1731','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',49.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',2.337229166666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999877341,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',1200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102581','NTF_France_I_degrees',NULL,NULL,'EPSG','4400','EPSG','4275','ESRI','102581','EPSG','1731',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102582','unnamed',NULL,NULL,'EPSG','1734','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.8,'EPSG','9102','EPSG','8802','Longitude of natural origin',2.337229166666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99987742,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',2200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102582','NTF_France_II_degrees',NULL,NULL,'EPSG','4400','EPSG','4275','ESRI','102582','EPSG','1734',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102583','unnamed',NULL,NULL,'EPSG','1733','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.1,'EPSG','9102','EPSG','8802','Longitude of natural origin',2.337229166666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999877499,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',3200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102583','NTF_France_III_degrees',NULL,NULL,'EPSG','4400','EPSG','4275','ESRI','102583','EPSG','1733',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102584','unnamed',NULL,NULL,'EPSG','1327','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',42.165,'EPSG','9102','EPSG','8802','Longitude of natural origin',2.337229166666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99994471,'EPSG','9201','EPSG','8806','False easting',234.358,'EPSG','9001','EPSG','8807','False northing',4185861.369,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102584','NTF_France_IV_degrees',NULL,NULL,'EPSG','4400','EPSG','4275','ESRI','102584','EPSG','1327',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102585','NTF_Lambert_Zone_I',NULL,NULL,'EPSG','4400','EPSG','4275','ESRI','102581','EPSG','1731',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102586','NTF_Lambert_Zone_II',NULL,NULL,'EPSG','4400','EPSG','4275','ESRI','102582','EPSG','1734',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102587','NTF_Lambert_Zone_III',NULL,NULL,'EPSG','4400','EPSG','4275','ESRI','102583','EPSG','1733',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102588','NTF_Lambert_Zone_IV',NULL,NULL,'EPSG','4400','EPSG','4275','ESRI','102584','EPSG','1327',NULL,0);
INSERT INTO "area" VALUES('ESRI','54','USA - Contiguous US','USA - Contiguous US',20.0,50.0,-125.0,-65.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102589','Panhandle_Energy_Albers',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'ESRI','54','PROJCS["Panhandle_Energy_Albers",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-86.0],PARAMETER["Standard_Parallel_1",31.0],PARAMETER["Standard_Parallel_2",41.0],PARAMETER["Latitude_Of_Origin",25.0],UNIT["Foot_US",0.3048006096012192]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102590','Tananarive_1925_Laborde_Grid',NULL,NULL,NULL,NULL,'EPSG','4297',NULL,NULL,'EPSG','3273','PROJCS["Tananarive_1925_Laborde_Grid",GEOGCS["GCS_Tananarive_1925",DATUM["D_Tananarive_1925",SPHEROID["International_1924",6378388.0,297.0]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Laborde_Oblique_Mercator"],PARAMETER["False_Easting",400000.0],PARAMETER["False_Northing",800000.0],PARAMETER["Scale_Factor",0.9995],PARAMETER["Azimuth",18.9],PARAMETER["Longitude_Of_Center",46.43722916666667],PARAMETER["Latitude_Of_Center",-18.9],UNIT["Meter",1.0]]',0);
INSERT INTO "conversion" VALUES('ESRI','102591','unnamed',NULL,NULL,'EPSG','1026','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',36.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',2.7,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999625544,'EPSG','9201','EPSG','8806','False easting',500135.0,'EPSG','9001','EPSG','8807','False northing',300090.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102591','Nord_Algerie_Degree',NULL,NULL,'EPSG','4400','ESRI','104305','ESRI','102591','EPSG','1026',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102592','unnamed',NULL,NULL,'EPSG','1026','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',33.3,'EPSG','9102','EPSG','8802','Longitude of natural origin',2.7,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999625769,'EPSG','9201','EPSG','8806','False easting',500135.0,'EPSG','9001','EPSG','8807','False northing',300090.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102592','Sud_Algerie_Degree',NULL,NULL,'EPSG','4400','ESRI','104305','ESRI','102592','EPSG','1026',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102593','JGD_2011_UTM_Zone_51N',NULL,NULL,'EPSG','4400','EPSG','6668','EPSG','16051','EPSG','3959',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102594','JGD_2011_UTM_Zone_52N',NULL,NULL,'EPSG','4400','EPSG','6668','EPSG','16052','EPSG','3960',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102595','JGD_2011_UTM_Zone_53N',NULL,NULL,'EPSG','4400','EPSG','6668','EPSG','16053','EPSG','3961',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102596','JGD_2011_UTM_Zone_54N',NULL,NULL,'EPSG','4400','EPSG','6668','EPSG','16054','EPSG','3962',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102597','JGD_2011_UTM_Zone_55N',NULL,NULL,'EPSG','4400','EPSG','6668','EPSG','16055','EPSG','3963',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102598','JGD_2011_UTM_Zone_56N',NULL,NULL,'EPSG','4400','EPSG','6668','EPSG','16056','EPSG','1983',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102599','WGS_1984_California_Teale_Albers_FtUS',NULL,NULL,NULL,NULL,'EPSG','4326',NULL,NULL,'EPSG','1375','PROJCS["WGS_1984_California_Teale_Albers_FtUS",GEOGCS["GCS_WGS_1984",DATUM["D_WGS_1984",SPHEROID["WGS_1984",6378137.0,298.257223563]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",-4000000.0],PARAMETER["Central_Meridian",-120.0],PARAMETER["Standard_Parallel_1",34.0],PARAMETER["Standard_Parallel_2",40.5],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Foot_US",0.3048006096012192]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102600','NAD_1983_California_Teale_Albers_FtUS',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'EPSG','1375','PROJCS["NAD_1983_California_Teale_Albers_FtUS",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",-4000000.0],PARAMETER["Central_Meridian",-120.0],PARAMETER["Standard_Parallel_1",34.0],PARAMETER["Standard_Parallel_2",40.5],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Foot_US",0.3048006096012192]]',0);
INSERT INTO "projected_crs" VALUES('ESRI','102601','NAD_1983_Texas_Centric_Mapping_System_Albers',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'EPSG','1412','PROJCS["NAD_1983_Texas_Centric_Mapping_System_Albers",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",1500000.0],PARAMETER["False_Northing",6000000.0],PARAMETER["Central_Meridian",-100.0],PARAMETER["Standard_Parallel_1",27.5],PARAMETER["Standard_Parallel_2",35.0],PARAMETER["Latitude_Of_Origin",18.0],UNIT["Meter",1.0]]',1);
INSERT INTO "conversion" VALUES('ESRI','102602','unnamed',NULL,NULL,'EPSG','1412','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',18.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',27.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',35.0,'EPSG','9102','EPSG','8826','Easting at false origin',1500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102602','NAD_1983_Texas_Centric_Mapping_System_Lambert',NULL,NULL,'EPSG','4400','EPSG','4269','ESRI','102602','EPSG','1412',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102603','unnamed',NULL,NULL,'EPSG','1412','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.16666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',27.41666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',34.91666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102603','NAD_1983_Texas_Statewide_Mapping_System',NULL,NULL,'EPSG','4400','EPSG','4269','ESRI','102603','EPSG','1412',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102604','unnamed',NULL,NULL,'EPSG','1380','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',0.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-83.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',31.41666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',34.28333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',0.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102604','NAD_1983_Georgia_Statewide_Lambert',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102604','EPSG','1380',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102605','unnamed',NULL,NULL,'EPSG','1381','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-114.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9996,'EPSG','9201','EPSG','8806','False easting',2500000.0,'EPSG','9001','EPSG','8807','False northing',1200000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102605','NAD_1983_Idaho_TM',NULL,NULL,'EPSG','4400','EPSG','4269','ESRI','102605','EPSG','1381',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102606','NAD_1983_Maine_2000_East_Zone',NULL,NULL,'EPSG','4400','EPSG','4269','ESRI','102208','EPSG','2960',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102607','NAD_1983_Maine_2000_Central_Zone',NULL,NULL,'EPSG','4400','EPSG','4269','ESRI','102209','EPSG','2959',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102608','NAD_1983_Maine_2000_West_Zone',NULL,NULL,'EPSG','4400','EPSG','4269','ESRI','102210','EPSG','2958',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102609','NAD_1983_Mississippi_TM',NULL,NULL,'EPSG','4400','EPSG','4269','ESRI','102469','EPSG','1393',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102610','unnamed',NULL,NULL,'EPSG','1854','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',33.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',129.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102610','JGD_2011_Japan_Zone_1',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102610','EPSG','1854',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102611','unnamed',NULL,NULL,'EPSG','1855','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',33.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',131.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102611','JGD_2011_Japan_Zone_2',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102611','EPSG','1855',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102612','unnamed',NULL,NULL,'EPSG','1856','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',132.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102612','JGD_2011_Japan_Zone_3',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102612','EPSG','1856',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102613','unnamed',NULL,NULL,'EPSG','1857','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',33.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',133.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102613','JGD_2011_Japan_Zone_4',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102613','EPSG','1857',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102614','unnamed',NULL,NULL,'EPSG','1858','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',134.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102614','JGD_2011_Japan_Zone_5',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102614','EPSG','1858',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102615','unnamed',NULL,NULL,'EPSG','1859','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',136.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102615','JGD_2011_Japan_Zone_6',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102615','EPSG','1859',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102616','unnamed',NULL,NULL,'EPSG','1860','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',137.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102616','JGD_2011_Japan_Zone_7',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102616','EPSG','1860',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102617','unnamed',NULL,NULL,'EPSG','1861','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',138.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102617','JGD_2011_Japan_Zone_8',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102617','EPSG','1861',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102618','unnamed',NULL,NULL,'EPSG','1862','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',139.8333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102618','JGD_2011_Japan_Zone_9',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102618','EPSG','1862',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102619','unnamed',NULL,NULL,'EPSG','1863','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',140.8333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102619','JGD_2011_Japan_Zone_10',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102619','EPSG','1863',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102620','unnamed',NULL,NULL,'EPSG','1864','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',140.25,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102620','JGD_2011_Japan_Zone_11',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102620','EPSG','1864',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102621','unnamed',NULL,NULL,'EPSG','1865','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',142.25,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102621','JGD_2011_Japan_Zone_12',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102621','EPSG','1865',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102622','unnamed',NULL,NULL,'EPSG','1866','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',144.25,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102622','JGD_2011_Japan_Zone_13',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102622','EPSG','1866',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102623','unnamed',NULL,NULL,'EPSG','1867','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',26.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',142.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102623','JGD_2011_Japan_Zone_14',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102623','EPSG','1867',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102624','unnamed',NULL,NULL,'EPSG','1868','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',26.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',127.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102624','JGD_2011_Japan_Zone_15',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102624','EPSG','1868',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102625','unnamed',NULL,NULL,'EPSG','1869','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',26.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',124.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102625','JGD_2011_Japan_Zone_16',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102625','EPSG','1869',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102626','unnamed',NULL,NULL,'EPSG','1870','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',26.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',131.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102626','JGD_2011_Japan_Zone_17',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102626','EPSG','1870',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102627','unnamed',NULL,NULL,'EPSG','1871','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',20.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',136.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102627','JGD_2011_Japan_Zone_18',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102627','EPSG','1871',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102628','unnamed',NULL,NULL,'EPSG','1872','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',26.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',154.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',0.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102628','JGD_2011_Japan_Zone_19',NULL,NULL,'EPSG','4400','EPSG','6668','ESRI','102628','EPSG','1872',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102629','unnamed',NULL,NULL,'EPSG','2154','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-85.83333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99996,'EPSG','9201','EPSG','8806','False easting',656166.6666666665,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102629','NAD_1983_StatePlane_Alabama_East_FIPS_0101_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102629','EPSG','2154',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102630','unnamed',NULL,NULL,'EPSG','2155','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999333333333333,'EPSG','9201','EPSG','8806','False easting',1968500.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102630','NAD_1983_StatePlane_Alabama_West_FIPS_0102_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102630','EPSG','2155',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102631','NAD_1983_StatePlane_Alaska_1_FIPS_5001_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102445','EPSG','2156',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102632','NAD_1983_StatePlane_Alaska_2_FIPS_5002_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102446','EPSG','2158',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102633','NAD_1983_StatePlane_Alaska_3_FIPS_5003_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102447','EPSG','2159',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102634','NAD_1983_StatePlane_Alaska_4_FIPS_5004_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102392','EPSG','2160',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102635','NAD_1983_StatePlane_Alaska_5_FIPS_5005_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102393','EPSG','2161',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102636','NAD_1983_StatePlane_Alaska_6_FIPS_5006_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102394','EPSG','2162',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102637','NAD_1983_StatePlane_Alaska_7_FIPS_5007_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102395','EPSG','2163',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102638','NAD_1983_StatePlane_Alaska_8_FIPS_5008_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102396','EPSG','2164',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102639','NAD_1983_StatePlane_Alaska_9_FIPS_5009_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102397','EPSG','2165',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102640','NAD_1983_StatePlane_Alaska_10_FIPS_5010_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102398','EPSG','2157',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102641','unnamed',NULL,NULL,'EPSG','2175','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-122.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',6561666.666666666,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.666666667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102641','NAD_1983_StatePlane_California_I_FIPS_0401_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102641','EPSG','2175',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102642','unnamed',NULL,NULL,'EPSG','2176','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-122.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.83333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',6561666.666666666,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.666666667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102642','NAD_1983_StatePlane_California_II_FIPS_0402_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102642','EPSG','2176',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102643','unnamed',NULL,NULL,'EPSG','2177','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.06666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.43333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',6561666.666666666,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.666666667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102643','NAD_1983_StatePlane_California_III_FIPS_0403_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102643','EPSG','2177',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102644','unnamed',NULL,NULL,'EPSG','2178','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',35.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-119.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',36.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',37.25,'EPSG','9102','EPSG','8826','Easting at false origin',6561666.666666666,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.666666667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102644','NAD_1983_StatePlane_California_IV_FIPS_0404_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102644','EPSG','2178',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102645','unnamed',NULL,NULL,'EPSG','2182','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-118.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',35.46666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',6561666.666666666,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.666666667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102645','NAD_1983_StatePlane_California_V_FIPS_0405_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102645','EPSG','2182',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102646','unnamed',NULL,NULL,'EPSG','2180','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',32.16666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-116.25,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',32.78333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',33.88333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',6561666.666666666,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.666666667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102646','NAD_1983_StatePlane_California_VI_FIPS_0406_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102646','EPSG','2180',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102647','NAD_1983_NSRS2007_StatePlane_Puerto_Rico_Virgin_Isls_FIPS_5200',NULL,NULL,'EPSG','4400','EPSG','4759','ESRI','102361','EPSG','3634',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102648','unnamed',NULL,NULL,'EPSG','2167','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-110.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',699998.6,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102648','NAD_1983_StatePlane_Arizona_East_FIPS_0201_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102648','EPSG','2167',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102649','unnamed',NULL,NULL,'EPSG','2166','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-111.9166666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',699998.6,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102649','NAD_1983_StatePlane_Arizona_Central_FIPS_0202_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102649','EPSG','2166',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102650','unnamed',NULL,NULL,'EPSG','2168','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-113.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999333333333333,'EPSG','9201','EPSG','8806','False easting',699998.6,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102650','NAD_1983_StatePlane_Arizona_West_FIPS_0203_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102650','EPSG','2168',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102651','unnamed',NULL,NULL,'EPSG','2169','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.93333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.23333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1312333.333333333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102651','NAD_1983_StatePlane_Arkansas_North_FIPS_0301_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102651','EPSG','2169',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102652','unnamed',NULL,NULL,'EPSG','2170','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',32.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',33.3,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',34.76666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',1312333.333333333,'EPSG','9003','EPSG','8827','Northing at false origin',1312333.333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102652','NAD_1983_StatePlane_Arkansas_South_FIPS_0302_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102652','EPSG','2170',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102653','unnamed',NULL,NULL,'EPSG','2184','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-105.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',39.71666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',3000000.000316083,'EPSG','9003','EPSG','8827','Northing at false origin',999999.999996,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102653','NAD_1983_StatePlane_Colorado_North_FIPS_0501_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102653','EPSG','2184',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102654','unnamed',NULL,NULL,'EPSG','2183','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-105.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.45,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.75,'EPSG','9102','EPSG','8826','Easting at false origin',3000000.000316083,'EPSG','9003','EPSG','8827','Northing at false origin',999999.999996,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102654','NAD_1983_StatePlane_Colorado_Central_FIPS_0502_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102654','EPSG','2183',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102655','unnamed',NULL,NULL,'EPSG','2185','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-105.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.23333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.43333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',3000000.000316083,'EPSG','9003','EPSG','8827','Northing at false origin',999999.999996,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102655','NAD_1983_StatePlane_Colorado_South_FIPS_0503_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102655','EPSG','2185',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102656','unnamed',NULL,NULL,'EPSG','1377','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-72.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',41.2,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.86666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',999999.999996,'EPSG','9003','EPSG','8827','Northing at false origin',499999.999998,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102656','NAD_1983_StatePlane_Connecticut_FIPS_0600_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102656','EPSG','1377',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102657','unnamed',NULL,NULL,'EPSG','1378','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-75.41666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999995,'EPSG','9201','EPSG','8806','False easting',656166.6666666665,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102657','NAD_1983_StatePlane_Delaware_FIPS_0700_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102657','EPSG','1378',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102658','unnamed',NULL,NULL,'EPSG','2186','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',24.33333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-81.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999411764705882,'EPSG','9201','EPSG','8806','False easting',656166.6666666665,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102658','NAD_1983_StatePlane_Florida_East_FIPS_0901_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102658','EPSG','2186',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102659','unnamed',NULL,NULL,'EPSG','2188','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',24.33333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-82.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999411764705882,'EPSG','9201','EPSG','8806','False easting',656166.6666666665,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102659','NAD_1983_StatePlane_Florida_West_FIPS_0902_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102659','EPSG','2188',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102660','unnamed',NULL,NULL,'EPSG','2187','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',29.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',29.58333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',30.75,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102660','NAD_1983_StatePlane_Florida_North_FIPS_0903_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102660','EPSG','2187',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102661','NAD_1983_StatePlane_Hawaii_1_FIPS_5101_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102461','EPSG','1546',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102662','NAD_1983_StatePlane_Hawaii_2_FIPS_5102_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102462','EPSG','1547',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102663','NAD_1983_StatePlane_Hawaii_3_FIPS_5103_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102463','EPSG','1548',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102664','NAD_1983_StatePlane_Hawaii_4_FIPS_5104_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102464','EPSG','1549',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102665','NAD_1983_StatePlane_Hawaii_5_FIPS_5105_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102465','EPSG','1550',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102666','unnamed',NULL,NULL,'EPSG','2189','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-82.16666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',656166.6666666665,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102666','NAD_1983_StatePlane_Georgia_East_FIPS_1001_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102666','EPSG','2189',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102667','unnamed',NULL,NULL,'EPSG','2190','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-84.16666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',2296583.333333333,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102667','NAD_1983_StatePlane_Georgia_West_FIPS_1002_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102667','EPSG','2190',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102668','unnamed',NULL,NULL,'EPSG','2192','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-112.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999473684210526,'EPSG','9201','EPSG','8806','False easting',656166.6666666665,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102668','NAD_1983_StatePlane_Idaho_East_FIPS_1101_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102668','EPSG','2192',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102669','unnamed',NULL,NULL,'EPSG','2191','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-114.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999473684210526,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102669','NAD_1983_StatePlane_Idaho_Central_FIPS_1102_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102669','EPSG','2191',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102670','unnamed',NULL,NULL,'EPSG','2193','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-115.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999333333333333,'EPSG','9201','EPSG','8806','False easting',2624666.666666666,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102670','NAD_1983_StatePlane_Idaho_West_FIPS_1103_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102670','EPSG','2193',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102671','unnamed',NULL,NULL,'EPSG','2194','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.33333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999975,'EPSG','9201','EPSG','8806','False easting',984250.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102671','NAD_1983_StatePlane_Illinois_East_FIPS_1201_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102671','EPSG','2194',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102672','unnamed',NULL,NULL,'EPSG','2195','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.16666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999411764705882,'EPSG','9201','EPSG','8806','False easting',2296583.333333333,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102672','NAD_1983_StatePlane_Illinois_West_FIPS_1202_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102672','EPSG','2195',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102673','unnamed',NULL,NULL,'EPSG','2196','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-85.66666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',328083.3333333333,'EPSG','9003','EPSG','8807','False northing',820208.3333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102673','NAD_1983_StatePlane_Indiana_East_FIPS_1301_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102673','EPSG','2196',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102674','unnamed',NULL,NULL,'EPSG','2197','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.08333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',2952750.0,'EPSG','9003','EPSG','8807','False northing',820208.3333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102674','NAD_1983_StatePlane_Indiana_West_FIPS_1302_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102674','EPSG','2197',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102675','unnamed',NULL,NULL,'EPSG','2198','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.06666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.26666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',4921250.0,'EPSG','9003','EPSG','8827','Northing at false origin',3280833.333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102675','NAD_1983_StatePlane_Iowa_North_FIPS_1401_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102675','EPSG','2198',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102676','unnamed',NULL,NULL,'EPSG','2199','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.61666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102676','NAD_1983_StatePlane_Iowa_South_FIPS_1402_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102676','EPSG','2199',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102677','unnamed',NULL,NULL,'EPSG','2200','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.71666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1312333.333333333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102677','NAD_1983_StatePlane_Kansas_North_FIPS_1501_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102677','EPSG','2200',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102678','unnamed',NULL,NULL,'EPSG','2201','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.26666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.56666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',1312333.333333333,'EPSG','9003','EPSG','8827','Northing at false origin',1312333.333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102678','NAD_1983_StatePlane_Kansas_South_FIPS_1502_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102678','EPSG','2201',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102679','unnamed',NULL,NULL,'EPSG','2202','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.25,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.96666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.96666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102679','NAD_1983_StatePlane_Kentucky_North_FIPS_1601_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102679','EPSG','2202',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102680','unnamed',NULL,NULL,'EPSG','2203','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-85.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',36.73333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',37.93333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.666666667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102680','NAD_1983_StatePlane_Kentucky_South_FIPS_1602_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102680','EPSG','2203',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102681','unnamed',NULL,NULL,'EPSG','2204','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',30.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',31.16666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',32.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',3280833.333333333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102681','NAD_1983_StatePlane_Louisiana_North_FIPS_1701_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102681','EPSG','2204',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102682','unnamed',NULL,NULL,'EPSG','2529','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',28.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.33333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',29.3,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',30.7,'EPSG','9102','EPSG','8826','Easting at false origin',3280833.333333333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102682','NAD_1983_StatePlane_Louisiana_South_FIPS_1702_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102682','EPSG','2529',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102683','unnamed',NULL,NULL,'EPSG','2206','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-68.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',984250.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102683','NAD_1983_StatePlane_Maine_East_FIPS_1801_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102683','EPSG','2206',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102684','unnamed',NULL,NULL,'EPSG','2207','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-70.16666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',2952750.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102684','NAD_1983_StatePlane_Maine_West_FIPS_1802_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102684','EPSG','2207',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102685','unnamed',NULL,NULL,'EPSG','1389','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-77.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.3,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.45,'EPSG','9102','EPSG','8826','Easting at false origin',1312333.333333333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102685','NAD_1983_StatePlane_Maryland_FIPS_1900_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102685','EPSG','1389',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102686','unnamed',NULL,NULL,'EPSG','2209','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-71.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',41.71666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',42.68333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',656166.6666666665,'EPSG','9003','EPSG','8827','Northing at false origin',2460625.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102686','NAD_1983_StatePlane_Massachusetts_Mainland_FIPS_2001_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102686','EPSG','2209',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102687','unnamed',NULL,NULL,'EPSG','2208','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-70.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',41.28333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.48333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102687','NAD_1983_StatePlane_Massachusetts_Island_FIPS_2002_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102687','EPSG','2208',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102688','unnamed',NULL,NULL,'EPSG','1723','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.78333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-87.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.48333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.08333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',26246666.66666666,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102688','NAD_1983_StatePlane_Michigan_North_FIPS_2111_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102688','EPSG','1723',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102689','unnamed',NULL,NULL,'EPSG','1724','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.31666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.36666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.18333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.7,'EPSG','9102','EPSG','8826','Easting at false origin',19685000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102689','NAD_1983_StatePlane_Michigan_Central_FIPS_2112_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102689','EPSG','1724',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102690','unnamed',NULL,NULL,'EPSG','1725','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.36666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.1,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',13123333.33333333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102690','NAD_1983_StatePlane_Michigan_South_FIPS_2113_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102690','EPSG','1725',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102691','NAD_1983_StatePlane_Minnesota_North_FIPS_2201_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102466','EPSG','2214',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102692','NAD_1983_StatePlane_Minnesota_Central_FIPS_2202_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102467','EPSG','2213',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102693','NAD_1983_StatePlane_Minnesota_South_FIPS_2203_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102468','EPSG','2215',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102694','unnamed',NULL,NULL,'EPSG','2216','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',29.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.83333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',984250.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102694','NAD_1983_StatePlane_Mississippi_East_FIPS_2301_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102694','EPSG','2216',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102695','unnamed',NULL,NULL,'EPSG','2217','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',29.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.33333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',2296583.333333333,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102695','NAD_1983_StatePlane_Mississippi_West_FIPS_2302_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102695','EPSG','2217',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102696','unnamed',NULL,NULL,'EPSG','2219','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',35.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999333333333333,'EPSG','9201','EPSG','8806','False easting',820208.3333333333,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102696','NAD_1983_StatePlane_Missouri_East_FIPS_2401_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102696','EPSG','2219',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102697','unnamed',NULL,NULL,'EPSG','2218','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',35.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999333333333333,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102697','NAD_1983_StatePlane_Missouri_Central_FIPS_2402_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102697','EPSG','2218',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102698','unnamed',NULL,NULL,'EPSG','2220','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.16666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-94.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999411764705882,'EPSG','9201','EPSG','8806','False easting',2788708.333333333,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102698','NAD_1983_StatePlane_Missouri_West_FIPS_2403_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102698','EPSG','2220',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102699','unnamed',NULL,NULL,'EPSG','2179','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-118.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',35.46666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',408000.0,'EPSG','9003','EPSG','8827','Northing at false origin',-266000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102699','NAD_1927_StatePlane_California_V_Ventura',NULL,NULL,'ESRI','Foot_US','EPSG','4267','ESRI','102699','EPSG','2179',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102700','unnamed',NULL,NULL,'EPSG','1395','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.25,'EPSG','9102','EPSG','8822','Longitude of false origin',-109.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',49.0,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102700','NAD_1983_StatePlane_Montana_FIPS_2500_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102700','EPSG','1395',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102701','NAD_1983_PACP00_UTM_Zone_4N',NULL,NULL,'EPSG','4400','ESRI','104259','EPSG','16004','EPSG','3488',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102702','NAD_1983_PACP00_UTM_Zone_5N',NULL,NULL,'EPSG','4400','ESRI','104259','EPSG','16005','EPSG','3491',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102703','NAD_1983_PACP00_UTM_Zone_2S',NULL,NULL,'EPSG','4400','ESRI','104259','EPSG','16102','EPSG','3110',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102704','unnamed',NULL,NULL,'EPSG','1396','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.0,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102704','NAD_1983_StatePlane_Nebraska_FIPS_2600_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102704','EPSG','1396',NULL,1);
INSERT INTO "area" VALUES('ESRI','55','US - Nebraska - Lancaster County','US - Nebraska - Lancaster County',40.5,41.07,-96.93,-96.43,0);
INSERT INTO "conversion" VALUES('ESRI','102705','unnamed',NULL,NULL,'ESRI','55','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.25,'EPSG','9102','EPSG','8802','Longitude of natural origin',-96.68805555555556,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000054615,'EPSG','9201','EPSG','8806','False easting',164041.6666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102705','NAD_1983_Nebraska_Lancaster_County_FtUS',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102705','ESRI','55',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102706','unnamed',NULL,NULL,'EPSG','1356','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.73409694444445,'EPSG','9102','EPSG','8802','Longitude of natural origin',35.21208055555556,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',170251.555,'EPSG','9001','EPSG','8807','False northing',126867.909,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102706','Palestine_1923_Palestine_Grid_TM',NULL,NULL,'EPSG','4400','EPSG','4281','ESRI','102706','EPSG','1356',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102707','unnamed',NULL,NULL,'EPSG','2224','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-115.5833333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',656166.6666666665,'EPSG','9003','EPSG','8807','False northing',26246666.66666666,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102707','NAD_1983_StatePlane_Nevada_East_FIPS_2701_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102707','EPSG','2224',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102708','unnamed',NULL,NULL,'EPSG','2223','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-116.6666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',19685000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102708','NAD_1983_StatePlane_Nevada_Central_FIPS_2702_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102708','EPSG','2223',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102709','unnamed',NULL,NULL,'EPSG','2225','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-118.5833333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',2624666.666666666,'EPSG','9003','EPSG','8807','False northing',13123333.33333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102709','NAD_1983_StatePlane_Nevada_West_FIPS_2703_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102709','EPSG','2225',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102710','unnamed',NULL,NULL,'EPSG','1398','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-71.66666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',984250.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102710','NAD_1983_StatePlane_New_Hampshire_FIPS_2800_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102710','EPSG','1398',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102711','unnamed',NULL,NULL,'EPSG','1399','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-74.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',492125.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102711','NAD_1983_StatePlane_New_Jersey_FIPS_2900_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102711','EPSG','1399',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102712','unnamed',NULL,NULL,'EPSG','2228','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-104.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999090909090909,'EPSG','9201','EPSG','8806','False easting',541337.5,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102712','NAD_1983_StatePlane_New_Mexico_East_FIPS_3001_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102712','EPSG','2228',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102713','unnamed',NULL,NULL,'EPSG','2231','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-106.25,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102713','NAD_1983_StatePlane_New_Mexico_Central_FIPS_3002_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102713','EPSG','2231',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102714','unnamed',NULL,NULL,'EPSG','2232','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-107.8333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999166666666667,'EPSG','9201','EPSG','8806','False easting',2723091.666666666,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102714','NAD_1983_StatePlane_New_Mexico_West_FIPS_3003_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102714','EPSG','2232',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102715','unnamed',NULL,NULL,'EPSG','2234','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-74.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',492125.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102715','NAD_1983_StatePlane_New_York_East_FIPS_3101_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102715','EPSG','2234',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102716','unnamed',NULL,NULL,'EPSG','2233','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-76.58333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',820208.3333333333,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102716','NAD_1983_StatePlane_New_York_Central_FIPS_3102_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102716','EPSG','2233',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102717','unnamed',NULL,NULL,'EPSG','2236','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-78.58333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',1148291.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102717','NAD_1983_StatePlane_New_York_West_FIPS_3103_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102717','EPSG','2236',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102718','unnamed',NULL,NULL,'EPSG','2235','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.16666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-74.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.66666666666666,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.03333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',984250.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102718','NAD_1983_StatePlane_New_York_Long_Island_FIPS_3104_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102718','EPSG','2235',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102719','unnamed',NULL,NULL,'EPSG','1402','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.75,'EPSG','9102','EPSG','8822','Longitude of false origin',-79.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.16666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.002616666,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102719','NAD_1983_StatePlane_North_Carolina_FIPS_3200_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102719','EPSG','1402',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102720','unnamed',NULL,NULL,'EPSG','2237','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.43333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.73333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102720','NAD_1983_StatePlane_North_Dakota_North_FIPS_3301_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102720','EPSG','2237',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102721','unnamed',NULL,NULL,'EPSG','2238','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.18333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.48333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102721','NAD_1983_StatePlane_North_Dakota_South_FIPS_3302_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102721','EPSG','2238',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102722','unnamed',NULL,NULL,'EPSG','2239','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-82.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.43333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.7,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102722','NAD_1983_StatePlane_Ohio_North_FIPS_3401_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102722','EPSG','2239',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102723','unnamed',NULL,NULL,'EPSG','2240','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-82.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.73333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.03333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102723','NAD_1983_StatePlane_Ohio_South_FIPS_3402_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102723','EPSG','2240',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102724','unnamed',NULL,NULL,'EPSG','2241','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',35.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',35.56666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.76666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102724','NAD_1983_StatePlane_Oklahoma_North_FIPS_3501_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102724','EPSG','2241',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102725','unnamed',NULL,NULL,'EPSG','2242','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',33.93333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',35.23333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102725','NAD_1983_StatePlane_Oklahoma_South_FIPS_3502_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102725','EPSG','2242',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102726','unnamed',NULL,NULL,'EPSG','2243','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.0,'EPSG','9102','EPSG','8826','Easting at false origin',8202083.333333332,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102726','NAD_1983_StatePlane_Oregon_North_FIPS_3601_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102726','EPSG','2243',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102727','unnamed',NULL,NULL,'EPSG','2244','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.0,'EPSG','9102','EPSG','8826','Easting at false origin',4921250.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102727','NAD_1983_StatePlane_Oregon_South_FIPS_3602_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102727','EPSG','2244',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102728','unnamed',NULL,NULL,'EPSG','2245','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.16666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-77.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.88333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.95,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102728','NAD_1983_StatePlane_Pennsylvania_North_FIPS_3701_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102728','EPSG','2245',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102729','unnamed',NULL,NULL,'EPSG','2246','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-77.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',39.93333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.96666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102729','NAD_1983_StatePlane_Pennsylvania_South_FIPS_3702_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102729','EPSG','2246',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102730','unnamed',NULL,NULL,'EPSG','1408','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.08333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-71.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99999375,'EPSG','9201','EPSG','8806','False easting',328083.3333333333,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102730','NAD_1983_StatePlane_Rhode_Island_FIPS_3800_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102730','EPSG','1408',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102733','unnamed',NULL,NULL,'EPSG','1409','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.83333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',32.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',34.83333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',1999996.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102733','NAD_1983_StatePlane_South_Carolina_FIPS_3900_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102733','EPSG','1409',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102734','unnamed',NULL,NULL,'EPSG','2249','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.41666666666666,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.68333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102734','NAD_1983_StatePlane_South_Dakota_North_FIPS_4001_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102734','EPSG','2249',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102735','unnamed',NULL,NULL,'EPSG','2250','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.3333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.83333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.4,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102735','NAD_1983_StatePlane_South_Dakota_South_FIPS_4002_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102735','EPSG','2250',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102736','unnamed',NULL,NULL,'EPSG','1411','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-86.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',35.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.41666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102736','NAD_1983_StatePlane_Tennessee_FIPS_4100_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102736','EPSG','1411',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102737','unnamed',NULL,NULL,'EPSG','2253','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-101.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.65,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.18333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',656166.6666666665,'EPSG','9003','EPSG','8827','Northing at false origin',3280833.333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102737','NAD_1983_StatePlane_Texas_North_FIPS_4201_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102737','EPSG','2253',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102738','unnamed',NULL,NULL,'EPSG','2254','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.66666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',32.13333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',33.96666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',6561666.666666666,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102738','NAD_1983_StatePlane_Texas_North_Central_FIPS_4202_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102738','EPSG','2254',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102739','unnamed',NULL,NULL,'EPSG','2252','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',29.66666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.3333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',30.11666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',31.88333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',2296583.333333333,'EPSG','9003','EPSG','8827','Northing at false origin',9842500.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102739','NAD_1983_StatePlane_Texas_Central_FIPS_4203_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102739','EPSG','2252',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102740','unnamed',NULL,NULL,'EPSG','2527','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',27.83333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-99.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',28.38333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',30.28333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',13123333.33333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102740','NAD_1983_StatePlane_Texas_South_Central_FIPS_4204_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102740','EPSG','2527',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102741','unnamed',NULL,NULL,'EPSG','2528','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',25.66666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',26.16666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',27.83333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',984250.0,'EPSG','9003','EPSG','8827','Northing at false origin',16404166.66666666,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102741','NAD_1983_StatePlane_Texas_South_FIPS_4205_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102741','EPSG','2528',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102742','unnamed',NULL,NULL,'EPSG','2258','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-111.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.71666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',3280833.333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102742','NAD_1983_StatePlane_Utah_North_FIPS_4301_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102742','EPSG','2258',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102743','unnamed',NULL,NULL,'EPSG','2257','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-111.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',39.01666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.65,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',6561666.666666666,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102743','NAD_1983_StatePlane_Utah_Central_FIPS_4302_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102743','EPSG','2257',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102744','unnamed',NULL,NULL,'EPSG','2259','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-111.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.21666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.35,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',9842500.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102744','NAD_1983_StatePlane_Utah_South_FIPS_4303_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102744','EPSG','2259',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102745','unnamed',NULL,NULL,'EPSG','1414','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-72.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999642857142857,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102745','NAD_1983_StatePlane_Vermont_FIPS_4400_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102745','EPSG','1414',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102746','unnamed',NULL,NULL,'EPSG','2260','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-78.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.2,'EPSG','9102','EPSG','8826','Easting at false origin',11482916.66666666,'EPSG','9003','EPSG','8827','Northing at false origin',6561666.666666666,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102746','NAD_1983_StatePlane_Virginia_North_FIPS_4501_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102746','EPSG','2260',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102747','unnamed',NULL,NULL,'EPSG','2261','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-78.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',36.76666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',37.96666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',11482916.66666666,'EPSG','9003','EPSG','8827','Northing at false origin',3280833.333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102747','NAD_1983_StatePlane_Virginia_South_FIPS_4502_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102747','EPSG','2261',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102748','unnamed',NULL,NULL,'EPSG','2273','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.8333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.73333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102748','NAD_1983_StatePlane_Washington_North_FIPS_4601_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102748','EPSG','2273',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102749','unnamed',NULL,NULL,'EPSG','2274','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.83333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.33333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102749','NAD_1983_StatePlane_Washington_South_FIPS_4602_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102749','EPSG','2274',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102750','unnamed',NULL,NULL,'EPSG','2264','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-79.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',39.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.25,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102750','NAD_1983_StatePlane_West_Virginia_North_FIPS_4701_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102750','EPSG','2264',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102751','unnamed',NULL,NULL,'EPSG','2265','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.48333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.88333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102751','NAD_1983_StatePlane_West_Virginia_South_FIPS_4702_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102751','EPSG','2265',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102752','unnamed',NULL,NULL,'EPSG','2267','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.16666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.56666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.76666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102752','NAD_1983_StatePlane_Wisconsin_North_FIPS_4801_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102752','EPSG','2267',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102753','unnamed',NULL,NULL,'EPSG','2266','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.5,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102753','NAD_1983_StatePlane_Wisconsin_Central_FIPS_4802_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102753','EPSG','2266',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102754','unnamed',NULL,NULL,'EPSG','2268','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.73333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.06666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102754','NAD_1983_StatePlane_Wisconsin_South_FIPS_4803_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102754','EPSG','2268',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102755','unnamed',NULL,NULL,'EPSG','2269','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-105.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',656166.6666666665,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102755','NAD_1983_StatePlane_Wyoming_East_FIPS_4901_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102755','EPSG','2269',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102756','unnamed',NULL,NULL,'EPSG','2270','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-107.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',1312333.333333333,'EPSG','9003','EPSG','8807','False northing',328083.3333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102756','NAD_1983_StatePlane_Wyoming_East_Central_FIPS_4902_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102756','EPSG','2270',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102757','unnamed',NULL,NULL,'EPSG','2272','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-108.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',1968500.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102757','NAD_1983_StatePlane_Wyoming_West_Central_FIPS_4903_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102757','EPSG','2272',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102758','unnamed',NULL,NULL,'EPSG','2271','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-110.0833333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',2624666.666666666,'EPSG','9003','EPSG','8807','False northing',328083.3333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102758','NAD_1983_StatePlane_Wyoming_West_FIPS_4904_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102758','EPSG','2271',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102761','unnamed',NULL,NULL,'EPSG','2251','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',17.83333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-66.43333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',18.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',18.43333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',656166.6666666665,'EPSG','9003','EPSG','8827','Northing at false origin',656166.6666666665,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102761','NAD_1983_StatePlane_Puerto_Rico_Virgin_Islands_FIPS_5200_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102761','EPSG','2251',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102762','unnamed',NULL,NULL,'EPSG','3147','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',-9.0,'EPSG','9102','EPSG','8822','Longitude of false origin',26.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',-6.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',-11.5,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102762','Katanga_1955_Katanga_Lambert',NULL,NULL,'EPSG','4400','EPSG','4695','ESRI','102762','EPSG','3147',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102763','unnamed',NULL,NULL,'EPSG','1386','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-85.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.08333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',4921250.0,'EPSG','9003','EPSG','8827','Northing at false origin',3280833.333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102763','NAD_1983_StatePlane_Kentucky_FIPS_1600_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4269','ESRI','102763','EPSG','1386',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102764','Pulkovo_1942_Adj_1983_3_Degree_GK_Zone_7',NULL,NULL,'EPSG','4400','EPSG','4178','EPSG','16267','EPSG','3584',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102765','Pulkovo_1942_Adj_1983_3_Degree_GK_Zone_8',NULL,NULL,'EPSG','4400','EPSG','4178','EPSG','16268','EPSG','3586',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102766','NAD_1983_StatePlane_Guam_FIPS_5400_Feet',NULL,NULL,NULL,NULL,'EPSG','4269',NULL,NULL,'EPSG','1110','PROJCS["NAD_1983_StatePlane_Guam_FIPS_5400_Feet",GEOGCS["GCS_North_American_1983",DATUM["D_North_American_1983",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Polyconic"],PARAMETER["False_Easting",164041.6666666666],PARAMETER["False_Northing",164041.6666666666],PARAMETER["Central_Meridian",144.7487507055556],PARAMETER["Latitude_Of_Origin",13.47246635277778],UNIT["Foot_US",0.3048006096012192]]',0);
INSERT INTO "area" VALUES('ESRI','56','Colombia - Leticia - Amazonas','Colombia - Leticia - Amazonas',-4.7,-3.683333333333334,-70.45,-69.43333333333334,0);
INSERT INTO "projected_crs" VALUES('ESRI','102767','MAGNA_Leticia_Amazonas_1994',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','56','PROJCS["MAGNA_Leticia_Amazonas_1994",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",25978.217],PARAMETER["False_Northing",27501.365],PARAMETER["Longitude_Of_Center",-69.94281105833333],PARAMETER["Latitude_Of_Center",-4.197684047222222],PARAMETER["Height",89.7],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','57','Colombia - Medellin - Antioquia','Colombia - Medellin - Antioquia',5.716666666666667,6.733333333333333,-76.06666666666666,-75.05,0);
INSERT INTO "projected_crs" VALUES('ESRI','102768','MAGNA_Medellin_Antioquia_2010',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','57','PROJCS["MAGNA_Medellin_Antioquia_2010",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",835378.647],PARAMETER["False_Northing",1180816.875],PARAMETER["Longitude_Of_Center",-75.56488694444444],PARAMETER["Latitude_Of_Center",6.229208888888889],PARAMETER["Height",1510.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','58','Colombia - Arauca - Arauca','Colombia - Arauca - Arauca',6.583333333333333,7.6,-71.26666666666667,-70.25,0);
INSERT INTO "projected_crs" VALUES('ESRI','102769','MAGNA_Arauca_2007',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','58','PROJCS["MAGNA_Arauca_2007",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1035263.443],PARAMETER["False_Northing",1275526.621],PARAMETER["Longitude_Of_Center",-70.75830965555555],PARAMETER["Latitude_Of_Center",7.087606391666666],PARAMETER["Height",100.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','59','Colombia - Barranquilla - Atlantico','Colombia - Barranquilla - Atlantico',10.41666666666667,11.43333333333333,-75.35,-74.33333333333333,0);
INSERT INTO "projected_crs" VALUES('ESRI','102770','MAGNA_Barranquilla_Atlantico_1997',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','59','PROJCS["MAGNA_Barranquilla_Atlantico_1997",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",917264.406],PARAMETER["False_Northing",1699839.935],PARAMETER["Longitude_Of_Center",-74.83433133333332],PARAMETER["Latitude_Of_Center",10.92318308333333],PARAMETER["Height",100.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','60','Colombia - Bogota D.C. - Bogota D.C.','Colombia - Bogota D.C. - Bogota D.C.',4.166666666666667,5.183333333333334,-74.65,-73.63333333333334,0);
INSERT INTO "projected_crs" VALUES('ESRI','102771','MAGNA_Bogota_DC_2005',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','60','PROJCS["MAGNA_Bogota_DC_2005",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",92334.879],PARAMETER["False_Northing",109320.965],PARAMETER["Longitude_Of_Center",-74.14659166666668],PARAMETER["Latitude_Of_Center",4.680486111111112],PARAMETER["Height",2550.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','61','Colombia - Cartagena_Bolivar','Colombia - Cartagena_Bolivar',9.883333333333333,10.9,-76.01666666666667,-75.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102772','MAGNA_Cartagena_Bolivar_2005',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','61','PROJCS["MAGNA_Cartagena_Bolivar_2005",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",842981.41],PARAMETER["False_Northing",1641887.09],PARAMETER["Longitude_Of_Center",-75.51120694444444],PARAMETER["Latitude_Of_Center",10.3970475],PARAMETER["Height",0.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','62','Colombia - Tunja - Boyaca','Colombia - Tunja - Boyaca',5.033333333333333,6.05,-73.86666666666666,-72.85,0);
INSERT INTO "projected_crs" VALUES('ESRI','102773','MAGNA_Tunja_Boyaca_1997',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','62','PROJCS["MAGNA_Tunja_Boyaca_1997",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1080514.91],PARAMETER["False_Northing",1103772.028],PARAMETER["Longitude_Of_Center",-73.3519389],PARAMETER["Latitude_Of_Center",5.534194738888889],PARAMETER["Height",2800.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','63','Colombia - Manizales - Caldas','Colombia - Manizales - Caldas',4.566666666666666,5.583333333333333,-76.01666666666667,-75.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102774','MAGNA_Manizales_Caldas_2011',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','63','PROJCS["MAGNA_Manizales_Caldas_2011",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1173727.04],PARAMETER["False_Northing",1052391.13],PARAMETER["Longitude_Of_Center",-75.51109472222223],PARAMETER["Latitude_Of_Center",5.068153888888888],PARAMETER["Height",2100.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','64','Colombia - Florencia - Caqueta','Colombia - Florencia - Caqueta',1.116666666666667,2.133333333333333,-76.13333333333334,-75.11666666666666,0);
INSERT INTO "projected_crs" VALUES('ESRI','102775','MAGNA_Florencia_Caqueta_2007',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','64','PROJCS["MAGNA_Florencia_Caqueta_2007",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1162300.348],PARAMETER["False_Northing",671068.716],PARAMETER["Longitude_Of_Center",-75.61911760277778],PARAMETER["Latitude_Of_Center",1.621012294444445],PARAMETER["Height",300.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','65','Colombia - Yopal - Casanare','Colombia - Yopal - Casanare',4.85,5.866666666666667,-72.93333333333334,-71.91666666666667,0);
INSERT INTO "projected_crs" VALUES('ESRI','102776','MAGNA_Yopal_Casanare_2006',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','65','PROJCS["MAGNA_Yopal_Casanare_2006",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",851184.177],PARAMETER["False_Northing",1083954.137],PARAMETER["Longitude_Of_Center",-72.42004027777779],PARAMETER["Latitude_Of_Center",5.353927222222222],PARAMETER["Height",300.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','66','Colombia - Popayan - Cauca','Colombia - Popayan - Cauca',2.95,2.966666666666667,-77.11666666666666,-76.1,0);
INSERT INTO "projected_crs" VALUES('ESRI','102777','MAGNA_Popayan_Cauca_2006',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','66','PROJCS["MAGNA_Popayan_Cauca_2006",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1052430.525],PARAMETER["False_Northing",763366.548],PARAMETER["Longitude_Of_Center",-76.6060916361111],PARAMETER["Latitude_Of_Center",2.456159883333334],PARAMETER["Height",1740.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','67','Colombia - Valledupar - Cesar','Colombia - Valledupar - Cesar',9.933333333333334,10.95,-73.58333333333333,-73.56666666666666,0);
INSERT INTO "projected_crs" VALUES('ESRI','102778','MAGNA_Valledupar_Cesar_2011',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','67','PROJCS["MAGNA_Valledupar_Cesar_2011",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1090979.66],PARAMETER["False_Northing",1647208.93],PARAMETER["Longitude_Of_Center",-73.2465713888889],PARAMETER["Latitude_Of_Center",10.44726111111111],PARAMETER["Height",200.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','68','Colombia - Quibdo - Choco','Colombia - Quibdo - Choco',5.183333333333334,6.2,-77.16666666666667,-76.15,0);
INSERT INTO "projected_crs" VALUES('ESRI','102779','MAGNA_Quibdo_Choco_2011',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','68','PROJCS["MAGNA_Quibdo_Choco_2011",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1047273.617],PARAMETER["False_Northing",1121443.09],PARAMETER["Longitude_Of_Center",-76.65075385833335],PARAMETER["Latitude_Of_Center",5.694247661111111],PARAMETER["Height",44.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','69','Colombia - Monteria - Cordoba','Colombia - Monteria - Cordoba',8.266666666666667,9.283333333333333,-76.38333333333334,-75.36666666666666,0);
INSERT INTO "projected_crs" VALUES('ESRI','102780','MAGNA_Monteria_Cordoba_2006',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','69','PROJCS["MAGNA_Monteria_Cordoba_2006",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1131814.934],PARAMETER["False_Northing",1462131.119],PARAMETER["Longitude_Of_Center",-75.87955333055555],PARAMETER["Latitude_Of_Center",8.773085755555556],PARAMETER["Height",15.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','70','Colombia - Inirida - Guainia','Colombia - Inirida - Guainia',3.333333333333333,4.35,-68.41666666666667,-67.4,0);
INSERT INTO "projected_crs" VALUES('ESRI','102781','MAGNA_Inirida_Guainia_2008',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','70','PROJCS["MAGNA_Inirida_Guainia_2008",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1019177.687],PARAMETER["False_Northing",491791.326],PARAMETER["Longitude_Of_Center",-67.90523208888889],PARAMETER["Latitude_Of_Center",3.845438183333334],PARAMETER["Height",96.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','71','Colombia - San Jose del Guaviare - Guaviare','Colombia - San Jose del Guaviare - Guaviare',2.05,3.066666666666667,-73.15,-72.13333333333334,0);
INSERT INTO "projected_crs" VALUES('ESRI','102782','MAGNA_San_Jose_del_Guaviare_2011',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','71','PROJCS["MAGNA_San_Jose_del_Guaviare_2011",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1159876.62],PARAMETER["False_Northing",775380.342],PARAMETER["Longitude_Of_Center",-72.640033325],PARAMETER["Latitude_Of_Center",2.564078941666666],PARAMETER["Height",185.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','72','Colombia - Neiva - Huila','Colombia - Neiva - Huila',2.433333333333334,3.45,-75.8,-74.78333333333333,0);
INSERT INTO "projected_crs" VALUES('ESRI','102783','MAGNA_Neiva_Huila_2006',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','72','PROJCS["MAGNA_Neiva_Huila_2006",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",864476.923],PARAMETER["False_Northing",817199.827],PARAMETER["Longitude_Of_Center",-75.29643672222223],PARAMETER["Latitude_Of_Center",2.942415055555556],PARAMETER["Height",430.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','73','Colombia - Riohacha - La Guajira','Colombia - Riohacha - La Guajira',11.03333333333333,12.05,-73.41666666666667,-72.4,0);
INSERT INTO "projected_crs" VALUES('ESRI','102784','MAGNA_Riohacha_La_Guajira_2006',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','73','PROJCS["MAGNA_Riohacha_La_Guajira_2006",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1128154.73],PARAMETER["False_Northing",1767887.914],PARAMETER["Longitude_Of_Center",-72.90276886944444],PARAMETER["Latitude_Of_Center",11.53691332777778],PARAMETER["Height",6.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','74','Colombia - Santa Marta - Magdalena','Colombia - Santa Marta - Magdalena',10.71666666666667,11.73333333333333,-74.73333333333333,-73.71666666666667,0);
INSERT INTO "projected_crs" VALUES('ESRI','102785','MAGNA_Santa_Marta_Magdalena_2007',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','74','PROJCS["MAGNA_Santa_Marta_Magdalena_2007",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",983892.409],PARAMETER["False_Northing",1732533.518],PARAMETER["Longitude_Of_Center",-74.22500527777778],PARAMETER["Latitude_Of_Center",11.21964305555556],PARAMETER["Height",29.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','75','Colombia - Villavicencio - Meta','Colombia - Villavicencio - Meta',3.65,4.666666666666667,-74.13333333333334,-73.11666666666666,0);
INSERT INTO "projected_crs" VALUES('ESRI','102786','MAGNA_Villavicencio_Meta_2011',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','75','PROJCS["MAGNA_Villavicencio_Meta_2011",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1050678.757],PARAMETER["False_Northing",950952.124],PARAMETER["Longitude_Of_Center",-73.62448598611111],PARAMETER["Latitude_Of_Center",4.1553751],PARAMETER["Height",427.19],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','76','Colombia - Pasto - Narino','Colombia - Pasto - Narino',0.7,1.716666666666667,-77.76666666666667,-76.75,0);
INSERT INTO "projected_crs" VALUES('ESRI','102787','MAGNA_Pasto_Narino_2008',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','76','PROJCS["MAGNA_Pasto_Narino_2008",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",980469.695],PARAMETER["False_Northing",624555.332],PARAMETER["Longitude_Of_Center",-77.25312563333334],PARAMETER["Latitude_Of_Center",1.200989513888889],PARAMETER["Height",2530.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','77','Colombia - Cucuta - Norte de Santander','Colombia - Cucuta - Norte de Santander',7.383333333333334,8.4,-73.01666666666667,-72.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102788','MAGNA_Cucuta_Norte_de_Santander_2011',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','77','PROJCS["MAGNA_Cucuta_Norte_de_Santander_2011",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",842805.406],PARAMETER["False_Northing",1364404.57],PARAMETER["Longitude_Of_Center",-72.50287095],PARAMETER["Latitude_Of_Center",7.888936736111111],PARAMETER["Height",308.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','78','Colombia - Mocoa - Putumayo','Colombia - Mocoa - Putumayo',0.6333333333333333,1.65,-77.16666666666667,-76.15,0);
INSERT INTO "projected_crs" VALUES('ESRI','102789','MAGNA_Mocoa_Putumayo_2011',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','78','PROJCS["MAGNA_Mocoa_Putumayo_2011",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1047467.388],PARAMETER["False_Northing",617828.474],PARAMETER["Longitude_Of_Center",-76.65102121944444],PARAMETER["Latitude_Of_Center",1.140023358333333],PARAMETER["Height",655.2],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','79','Colombia - Armenia - Quindio','Colombia - Armenia - Quindio',4.016666666666667,5.033333333333333,-76.18333333333334,-75.16666666666667,0);
INSERT INTO "projected_crs" VALUES('ESRI','102790','MAGNA_Armenia_Quindio_2006',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','79','PROJCS["MAGNA_Armenia_Quindio_2006",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1155824.666],PARAMETER["False_Northing",993087.465],PARAMETER["Longitude_Of_Center",-75.67348916666667],PARAMETER["Latitude_Of_Center",4.532325],PARAMETER["Height",1470.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','80','Colombia - Pereira - Risaralda','Colombia - Pereira - Risaralda',4.3,5.316666666666666,-76.2,-75.18333333333334,0);
INSERT INTO "projected_crs" VALUES('ESRI','102791','MAGNA_Pereira_Risaralda_2007',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','80','PROJCS["MAGNA_Pereira_Risaralda_2007",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1153492.012],PARAMETER["False_Northing",1024195.255],PARAMETER["Longitude_Of_Center",-75.69395138888889],PARAMETER["Latitude_Of_Center",4.813593611111111],PARAMETER["Height",1500.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','81','Colombia - San_Andres - San_Andres','Colombia - San_Andres - San_Andres',12.01666666666667,13.03333333333333,-82.23333333333333,-81.21666666666667,0);
INSERT INTO "projected_crs" VALUES('ESRI','102792','MAGNA_San_Andres_2007',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','81','PROJCS["MAGNA_San_Andres_2007",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",820439.298],PARAMETER["False_Northing",1877357.828],PARAMETER["Longitude_Of_Center",-81.72937595],PARAMETER["Latitude_Of_Center",12.523794325],PARAMETER["Height",6.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','82','Colombia - Bucaramanga - Santander','Colombia - Bucaramanga - Santander',6.566666666666666,7.583333333333333,-73.7,-72.68333333333334,0);
INSERT INTO "projected_crs" VALUES('ESRI','102793','MAGNA_Bucaramanga_Santander_2008',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','82','PROJCS["MAGNA_Bucaramanga_Santander_2008",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1097241.305],PARAMETER["False_Northing",1274642.278],PARAMETER["Longitude_Of_Center",-73.19734322222223],PARAMETER["Latitude_Of_Center",7.078887141666667],PARAMETER["Height",931.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','83','Colombia - Sucre - Sucre','Colombia - Sucre - Sucre',8.3,9.316666666666666,-75.23333333333333,-74.21666666666667,0);
INSERT INTO "projected_crs" VALUES('ESRI','102794','MAGNA_Sucre_2006',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','83','PROJCS["MAGNA_Sucre_2006",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",929043.607],PARAMETER["False_Northing",1466125.658],PARAMETER["Longitude_Of_Center",-74.722466825],PARAMETER["Latitude_Of_Center",8.810550366666668],PARAMETER["Height",20.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','84','Colombia - Ibague - Tolima','Colombia - Ibague - Tolima',3.916666666666667,4.933333333333334,-75.68333333333334,-74.66666666666667,0);
INSERT INTO "projected_crs" VALUES('ESRI','102795','MAGNA_Ibague_Tolima_2007',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','84','PROJCS["MAGNA_Ibague_Tolima_2007",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",877634.33],PARAMETER["False_Northing",980541.348],PARAMETER["Longitude_Of_Center",-75.17992593333334],PARAMETER["Latitude_Of_Center",4.419412827777778],PARAMETER["Height",1100.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','85','Colombia - Cali - Valle del Cauca','Colombia - Cali - Valle del Cauca',2.933333333333334,3.95,-77.03333333333333,-76.01666666666667,0);
INSERT INTO "projected_crs" VALUES('ESRI','102796','MAGNA_Cali_Valle_del_Cauca_2009',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','85','PROJCS["MAGNA_Cali_Valle_del_Cauca_2009",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1061900.18],PARAMETER["False_Northing",872364.63],PARAMETER["Longitude_Of_Center",-76.5205625],PARAMETER["Latitude_Of_Center",3.441883333333334],PARAMETER["Height",1000.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','86','Colombia - Mitu - Vaupes','Colombia - Mitu - Vaupes',0.7333333333333333,1.75,-70.75,-69.73333333333333,0);
INSERT INTO "projected_crs" VALUES('ESRI','102797','MAGNA_Mitu_Vaupes_2011',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','86','PROJCS["MAGNA_Mitu_Vaupes_2011",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1093717.398],PARAMETER["False_Northing",629997.236],PARAMETER["Longitude_Of_Center",-70.23546165555555],PARAMETER["Latitude_Of_Center",1.249969366666667],PARAMETER["Height",170.0],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','87','Colombia - Puerto - Carreno - Vichada','Colombia - Puerto - Carreno - Vichada',5.666666666666667,6.683333333333334,-68.01666666666667,-67.0,0);
INSERT INTO "projected_crs" VALUES('ESRI','102798','MAGNA_Puerto_Carreno_Vichada_2011',NULL,NULL,NULL,NULL,'EPSG','4686',NULL,NULL,'ESRI','87','PROJCS["MAGNA_Puerto_Carreno_Vichada_2011",GEOGCS["GCS_MAGNA",DATUM["D_MAGNA",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["IGAC_Plano_Cartesiano"],PARAMETER["False_Easting",1063834.703],PARAMETER["False_Northing",1175257.481],PARAMETER["Longitude_Of_Center",-67.50075024722223],PARAMETER["Latitude_Of_Center",6.18072141388889],PARAMETER["Height",51.58],UNIT["Meter",1.0]]',1);
INSERT INTO "area" VALUES('ESRI','88','UK - Highways England - A1','UK - Highways England - A1',50.1068,50.4249,-5.5482,-5.3991,0);
INSERT INTO "conversion" VALUES('ESRI','102799','unnamed',NULL,NULL,'ESRI','88','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99926,'EPSG','9201','EPSG','8806','False easting',261910.5587,'EPSG','9001','EPSG','8807','False northing',70975.76209,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102799','OSGB36_Highways_England_A1H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102799','ESRI','88',NULL,0);
INSERT INTO "area" VALUES('ESRI','89','UK - Highways England - A2','UK - Highways England - A2',50.1106,50.4286,-5.4217,-5.2734,0);
INSERT INTO "conversion" VALUES('ESRI','102800','unnamed',NULL,NULL,'ESRI','89','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999314,'EPSG','9201','EPSG','8806','False easting',252927.2844,'EPSG','9001','EPSG','8807','False northing',70979.59363,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102800','OSGB36_Highways_England_A2H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102800','ESRI','89',NULL,0);
INSERT INTO "area" VALUES('ESRI','90','UK - Highways England - A3','UK - Highways England - A3',50.1142,50.4321,-5.2952,-5.1477,0);
INSERT INTO "conversion" VALUES('ESRI','102801','unnamed',NULL,NULL,'ESRI','90','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999365,'EPSG','9201','EPSG','8806','False easting',243942.3084,'EPSG','9001','EPSG','8807','False northing',70983.21269,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102801','OSGB36_Highways_England_A3H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102801','ESRI','90',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102802','unnamed',NULL,NULL,'ESRI','90','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99939,'EPSG','9201','EPSG','8806','False easting',243948.4072,'EPSG','9001','EPSG','8807','False northing',70984.98734,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102802','OSGB36_Highways_England_A3H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102802','ESRI','90',NULL,0);
INSERT INTO "area" VALUES('ESRI','91','UK - Highways England - A4','UK - Highways England - A4',50.2075,50.5253,-5.1747,-5.0277,0);
INSERT INTO "conversion" VALUES('ESRI','102803','unnamed',NULL,NULL,'ESRI','91','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999415,'EPSG','9201','EPSG','8806','False easting',234956.1813,'EPSG','9001','EPSG','8807','False northing',70986.76115,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102803','OSGB36_Highways_England_A4H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102803','ESRI','91',NULL,0);
INSERT INTO "area" VALUES('ESRI','92','UK - Highways England - A5','UK - Highways England - A5',50.2109,50.5289,-5.0479,-4.8877,0);
INSERT INTO "conversion" VALUES('ESRI','102804','unnamed',NULL,NULL,'ESRI','92','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999465,'EPSG','9201','EPSG','8806','False easting',225969.1556,'EPSG','9001','EPSG','8807','False northing',70990.30995,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102804','OSGB36_Highways_England_A5H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102804','ESRI','92',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102805','unnamed',NULL,NULL,'ESRI','92','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99949,'EPSG','9201','EPSG','8806','False easting',225974.8051,'EPSG','9001','EPSG','8807','False northing',70992.08478,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102805','OSGB36_Highways_England_A5H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102805','ESRI','92',NULL,0);
INSERT INTO "area" VALUES('ESRI','93','UK - Highways England - A6','UK - Highways England - A6',50.2144,50.5323,-4.907,-4.7477,0);
INSERT INTO "conversion" VALUES('ESRI','102806','unnamed',NULL,NULL,'ESRI','93','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999516,'EPSG','9201','EPSG','8806','False easting',215981.5338,'EPSG','9001','EPSG','8807','False northing',70993.93011,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102806','OSGB36_Highways_England_A6H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102806','ESRI','93',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102807','unnamed',NULL,NULL,'ESRI','93','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999541,'EPSG','9201','EPSG','8806','False easting',215986.9336,'EPSG','9001','EPSG','8807','False northing',70995.70502,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102807','OSGB36_Highways_England_A6H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102807','ESRI','93',NULL,0);
INSERT INTO "area" VALUES('ESRI','94','UK - Highways England - A7','UK - Highways England - A7',50.3975,50.5356,-4.766,-4.6175,0);
INSERT INTO "conversion" VALUES('ESRI','102808','unnamed',NULL,NULL,'ESRI','94','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999564,'EPSG','9201','EPSG','8806','False easting',205992.2754,'EPSG','9001','EPSG','8807','False northing',70997.33764,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102808','OSGB36_Highways_England_A7H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102808','ESRI','94',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102809','unnamed',NULL,NULL,'ESRI','94','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999589,'EPSG','9201','EPSG','8806','False easting',205997.4254,'EPSG','9001','EPSG','8807','False northing',70999.11264,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102809','OSGB36_Highways_England_A7H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102809','ESRI','94',NULL,0);
INSERT INTO "area" VALUES('ESRI','95','UK - Highways England - A8','UK - Highways England - A8',50.221,50.7996,-4.6397,-4.4536,0);
INSERT INTO "conversion" VALUES('ESRI','102810','unnamed',NULL,NULL,'ESRI','95','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999613,'EPSG','9201','EPSG','8806','False easting',196002.254,'EPSG','9001','EPSG','8807','False northing',71000.81651,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102810','OSGB36_Highways_England_A8H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102810','ESRI','95',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102811','unnamed',NULL,NULL,'ESRI','95','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999638,'EPSG','9201','EPSG','8806','False easting',196007.1543,'EPSG','9001','EPSG','8807','False northing',71002.5916,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102811','OSGB36_Highways_England_A8H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102811','ESRI','95',NULL,0);
INSERT INTO "area" VALUES('ESRI','96','UK - Highways England - A9','UK - Highways England - A9',50.2244,50.8031,-4.4837,-4.2855,0);
INSERT INTO "conversion" VALUES('ESRI','102812','unnamed',NULL,NULL,'ESRI','96','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999662,'EPSG','9201','EPSG','8806','False easting',185011.1931,'EPSG','9001','EPSG','8807','False northing',71004.29572,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102812','OSGB36_Highways_England_A9H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102812','ESRI','96',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102813','unnamed',NULL,NULL,'ESRI','96','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999687,'EPSG','9201','EPSG','8806','False easting',185015.8185,'EPSG','9001','EPSG','8807','False northing',71006.07089,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102813','OSGB36_Highways_England_A9H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102813','ESRI','96',NULL,0);
INSERT INTO "area" VALUES('ESRI','97','UK - Highways England - A10','UK - Highways England - A10',50.2278,50.8069,-4.3136,-4.0893,0);
INSERT INTO "conversion" VALUES('ESRI','102814','unnamed',NULL,NULL,'ESRI','97','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999713,'EPSG','9201','EPSG','8806','False easting',173019.2914,'EPSG','9001','EPSG','8807','False northing',71007.91729,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102814','OSGB36_Highways_England_A10H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102814','ESRI','97',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102815','unnamed',NULL,NULL,'ESRI','97','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999738,'EPSG','9201','EPSG','8806','False easting',173023.6171,'EPSG','9001','EPSG','8807','False northing',71009.69256,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102815','OSGB36_Highways_England_A10H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102815','ESRI','97',NULL,0);
INSERT INTO "area" VALUES('ESRI','98','UK - Highways England - A11','UK - Highways England - A11',50.2315,50.8105,-4.115,-3.8791,0);
INSERT INTO "conversion" VALUES('ESRI','102816','unnamed',NULL,NULL,'ESRI','98','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999767,'EPSG','9201','EPSG','8806','False easting',159026.3186,'EPSG','9001','EPSG','8807','False northing',71011.75231,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102816','OSGB36_Highways_England_A11H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102816','ESRI','98',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102817','unnamed',NULL,NULL,'ESRI','98','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999792,'EPSG','9201','EPSG','8806','False easting',159030.2944,'EPSG','9001','EPSG','8807','False northing',71013.52767,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102817','OSGB36_Highways_England_A11H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102817','ESRI','98',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102818','unnamed',NULL,NULL,'ESRI','98','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999817,'EPSG','9201','EPSG','8806','False easting',159034.2704,'EPSG','9001','EPSG','8807','False northing',71015.30312,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102818','OSGB36_Highways_England_A11H3',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102818','ESRI','98',NULL,0);
INSERT INTO "area" VALUES('ESRI','99','UK - Highways England - A12','UK - Highways England - A12',50.2351,50.814,-3.9022,-3.6549,0);
INSERT INTO "conversion" VALUES('ESRI','102819','unnamed',NULL,NULL,'ESRI','99','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999817,'EPSG','9201','EPSG','8806','False easting',144031.0383,'EPSG','9001','EPSG','8807','False northing',71015.30362,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102819','OSGB36_Highways_England_A12H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102819','ESRI','99',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102820','unnamed',NULL,NULL,'ESRI','99','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999842,'EPSG','9201','EPSG','8806','False easting',144034.6392,'EPSG','9001','EPSG','8807','False northing',71017.07907,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102820','OSGB36_Highways_England_A12H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102820','ESRI','99',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102821','unnamed',NULL,NULL,'ESRI','99','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999867,'EPSG','9201','EPSG','8806','False easting',144038.2403,'EPSG','9001','EPSG','8807','False northing',71018.8546,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102821','OSGB36_Highways_England_A12H3',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102821','ESRI','99',NULL,0);
INSERT INTO "area" VALUES('ESRI','100','UK - Highways England - A13','UK - Highways England - A13',50.4183,50.8981,-3.6781,-3.4219,0);
INSERT INTO "conversion" VALUES('ESRI','102822','unnamed',NULL,NULL,'ESRI','100','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999865,'EPSG','9201','EPSG','8806','False easting',128033.7365,'EPSG','9001','EPSG','8807','False northing',71018.71321,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102822','OSGB36_Highways_England_A13H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102822','ESRI','100',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102823','unnamed',NULL,NULL,'ESRI','100','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99989,'EPSG','9201','EPSG','8806','False easting',128036.9375,'EPSG','9001','EPSG','8807','False northing',71020.48874,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102823','OSGB36_Highways_England_A13H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102823','ESRI','100',NULL,0);
INSERT INTO "area" VALUES('ESRI','101','UK - Highways England - A14','UK - Highways England - A14',50.585,51.1984,-4.4468,-3.1023,0);
INSERT INTO "conversion" VALUES('ESRI','102824','unnamed',NULL,NULL,'ESRI','101','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999914,'EPSG','9201','EPSG','8806','False easting',111034.6979,'EPSG','9001','EPSG','8807','False northing',71022.19417,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102824','OSGB36_Highways_England_A14H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102824','ESRI','101',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102825','unnamed',NULL,NULL,'ESRI','101','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999939,'EPSG','9201','EPSG','8806','False easting',111037.4739,'EPSG','9001','EPSG','8807','False northing',71023.96979,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102825','OSGB36_Highways_England_A14H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102825','ESRI','101',NULL,0);
INSERT INTO "area" VALUES('ESRI','102','UK - Highways England - A15','UK - Highways England - A15',50.6049,52.0473,-3.1375,-2.6218,0);
INSERT INTO "conversion" VALUES('ESRI','102826','unnamed',NULL,NULL,'ESRI','102','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999967,'EPSG','9201','EPSG','8806','False easting',88032.17537,'EPSG','9001','EPSG','8807','False northing',71025.95967,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102826','OSGB36_Highways_England_A15H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102826','ESRI','102',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102827','unnamed',NULL,NULL,'ESRI','102','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999992,'EPSG','9201','EPSG','8806','False easting',88034.37626,'EPSG','9001','EPSG','8807','False northing',71027.73539,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102827','OSGB36_Highways_England_A15H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102827','ESRI','102',NULL,0);
INSERT INTO "area" VALUES('ESRI','103','UK - Highways England - A16','UK - Highways England - A16',50.6084,52.048,-2.6417,-1.5041,0);
INSERT INTO "conversion" VALUES('ESRI','102828','unnamed',NULL,NULL,'ESRI','103','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000012,'EPSG','9201','EPSG','8806','False easting',54022.17583,'EPSG','9001','EPSG','8807','False northing',71029.15712,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102828','OSGB36_Highways_England_A16H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102828','ESRI','103',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102829','unnamed',NULL,NULL,'ESRI','103','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000037,'EPSG','9201','EPSG','8806','False easting',54023.52644,'EPSG','9001','EPSG','8807','False northing',71030.93291,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102829','OSGB36_Highways_England_A16H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102829','ESRI','103',NULL,0);
INSERT INTO "area" VALUES('ESRI','104','UK - Highways England - A17','UK - Highways England - A17',50.777,52.048,-1.5177,-1.0083,0);
INSERT INTO "conversion" VALUES('ESRI','102830','unnamed',NULL,NULL,'ESRI','104','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999981,'EPSG','9201','EPSG','8806','False easting',-24009.11135,'EPSG','9001','EPSG','8807','False northing',71026.9544,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102830','OSGB36_Highways_England_A17H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102830','ESRI','104',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102831','unnamed',NULL,NULL,'ESRI','104','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000006,'EPSG','9201','EPSG','8806','False easting',-24009.7116,'EPSG','9001','EPSG','8807','False northing',71028.73014,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102831','OSGB36_Highways_England_A17H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102831','ESRI','104',NULL,0);
INSERT INTO "area" VALUES('ESRI','105','UK - Highways England - A18','UK - Highways England - A18',50.7727,52.0448,-1.0355,-0.571,0);
INSERT INTO "conversion" VALUES('ESRI','102832','unnamed',NULL,NULL,'ESRI','105','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999928,'EPSG','9201','EPSG','8806','False easting',-58018.94296,'EPSG','9001','EPSG','8807','False northing',71023.18879,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102832','OSGB36_Highways_England_A18H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102832','ESRI','105',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102833','unnamed',NULL,NULL,'ESRI','105','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999953,'EPSG','9201','EPSG','8806','False easting',-58020.39349,'EPSG','9001','EPSG','8807','False northing',71024.96444,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102833','OSGB36_Highways_England_A18H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102833','ESRI','105',NULL,0);
INSERT INTO "area" VALUES('ESRI','106','UK - Highways England - A19','UK - Highways England - A19',50.7696,52.0404,-0.6101,-0.3232,0);
INSERT INTO "conversion" VALUES('ESRI','102834','unnamed',NULL,NULL,'ESRI','106','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999874,'EPSG','9201','EPSG','8806','False easting',-88023.98625,'EPSG','9001','EPSG','8807','False northing',71019.35254,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102834','OSGB36_Highways_England_A19H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102834','ESRI','106',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102835','unnamed',NULL,NULL,'ESRI','106','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999899,'EPSG','9201','EPSG','8806','False easting',-88026.18693,'EPSG','9001','EPSG','8807','False northing',71021.12809,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102835','OSGB36_Highways_England_A19H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102835','ESRI','106',NULL,0);
INSERT INTO "area" VALUES('ESRI','107','UK - Highways England - A20','UK - Highways England - A20',50.7659,52.0371,-0.369,-0.0755,0);
INSERT INTO "conversion" VALUES('ESRI','102836','unnamed',NULL,NULL,'ESRI','107','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999826,'EPSG','9201','EPSG','8806','False easting',-105023.5775,'EPSG','9001','EPSG','8807','False northing',71015.94289,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102836','OSGB36_Highways_England_A20H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102836','ESRI','107',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102837','unnamed',NULL,NULL,'ESRI','107','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999851,'EPSG','9201','EPSG','8806','False easting',-105026.2032,'EPSG','9001','EPSG','8807','False northing',71017.71836,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102837','OSGB36_Highways_England_A20H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102837','ESRI','107',NULL,0);
INSERT INTO "area" VALUES('ESRI','108','UK - Highways England - A21','UK - Highways England - A21',50.7618,52.0333,-0.128,0.1722,0);
INSERT INTO "conversion" VALUES('ESRI','102838','unnamed',NULL,NULL,'ESRI','108','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999771,'EPSG','9201','EPSG','8806','False easting',-122020.6823,'EPSG','9001','EPSG','8807','False northing',71012.0364,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102838','OSGB36_Highways_England_A21H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102838','ESRI','108',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102839','unnamed',NULL,NULL,'ESRI','108','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999796,'EPSG','9201','EPSG','8806','False easting',-122023.7329,'EPSG','9001','EPSG','8807','False northing',71013.81177,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102839','OSGB36_Highways_England_A21H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102839','ESRI','108',NULL,0);
INSERT INTO "area" VALUES('ESRI','109','UK - Highways England - A22','UK - Highways England - A22',50.7572,52.029,0.1129,0.4198,0);
INSERT INTO "conversion" VALUES('ESRI','102840','unnamed',NULL,NULL,'ESRI','109','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999708,'EPSG','9201','EPSG','8806','False easting',-139014.8049,'EPSG','9001','EPSG','8807','False northing',71007.56222,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102840','OSGB36_Highways_England_A22H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102840','ESRI','109',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102841','unnamed',NULL,NULL,'ESRI','109','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999733,'EPSG','9201','EPSG','8806','False easting',-139018.2804,'EPSG','9001','EPSG','8807','False northing',71009.33748,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102841','OSGB36_Highways_England_A22H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102841','ESRI','109',NULL,0);
INSERT INTO "area" VALUES('ESRI','110','UK - Highways England - A23','UK - Highways England - A23',50.7546,52.0242,0.3537,0.5509,0);
INSERT INTO "conversion" VALUES('ESRI','102842','unnamed',NULL,NULL,'ESRI','110','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999656,'EPSG','9201','EPSG','8806','False easting',-156008.5024,'EPSG','9001','EPSG','8807','False northing',71003.86967,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102842','OSGB36_Highways_England_A23H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102842','ESRI','110',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102843','unnamed',NULL,NULL,'ESRI','110','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999681,'EPSG','9201','EPSG','8806','False easting',-156012.4027,'EPSG','9001','EPSG','8807','False northing',71005.64484,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102843','OSGB36_Highways_England_A23H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102843','ESRI','110',NULL,0);
INSERT INTO "area" VALUES('ESRI','111','UK - Highways England - A24','UK - Highways England - A24',50.7511,52.0214,0.4812,0.711,0);
INSERT INTO "conversion" VALUES('ESRI','102844','unnamed',NULL,NULL,'ESRI','111','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999613,'EPSG','9201','EPSG','8806','False easting',-165001.8975,'EPSG','9001','EPSG','8807','False northing',71000.81651,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102844','OSGB36_Highways_England_A24H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102844','ESRI','111',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102845','unnamed',NULL,NULL,'ESRI','111','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999638,'EPSG','9201','EPSG','8806','False easting',-165006.0227,'EPSG','9001','EPSG','8807','False northing',71002.5916,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102845','OSGB36_Highways_England_A24H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102845','ESRI','111',NULL,0);
INSERT INTO "area" VALUES('ESRI','112','UK - Highways England - A25','UK - Highways England - A25',50.7478,52.0178,0.637,0.8566,0);
INSERT INTO "conversion" VALUES('ESRI','102846','unnamed',NULL,NULL,'ESRI','112','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999565,'EPSG','9201','EPSG','8806','False easting',-175993.5763,'EPSG','9001','EPSG','8807','False northing',70997.40864,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102846','OSGB36_Highways_England_A25H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102846','ESRI','112',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102847','unnamed',NULL,NULL,'ESRI','112','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99959,'EPSG','9201','EPSG','8806','False easting',-175997.9763,'EPSG','9001','EPSG','8807','False northing',70999.18364,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102847','OSGB36_Highways_England_A25H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102847','ESRI','112',NULL,0);
INSERT INTO "area" VALUES('ESRI','113','UK - Highways England - A26','UK - Highways England - A26',50.7444,52.0144,0.7786,1.0021,0);
INSERT INTO "conversion" VALUES('ESRI','102848','unnamed',NULL,NULL,'ESRI','113','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999517,'EPSG','9201','EPSG','8806','False easting',-185984.2846,'EPSG','9001','EPSG','8807','False northing',70994.00109,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102848','OSGB36_Highways_England_A26H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102848','ESRI','113',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102849','unnamed',NULL,NULL,'ESRI','113','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999542,'EPSG','9201','EPSG','8806','False easting',-185988.9343,'EPSG','9001','EPSG','8807','False northing',70995.77601,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102849','OSGB36_Highways_England_A26H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102849','ESRI','113',NULL,0);
INSERT INTO "area" VALUES('ESRI','114','UK - Highways England - A27','UK - Highways England - A27',50.9293,52.0108,0.932,1.1476,0);
INSERT INTO "conversion" VALUES('ESRI','102850','unnamed',NULL,NULL,'ESRI','114','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999467,'EPSG','9201','EPSG','8806','False easting',-195973.6419,'EPSG','9001','EPSG','8807','False northing',70990.45191,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102850','OSGB36_Highways_England_A27H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102850','ESRI','114',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102851','unnamed',NULL,NULL,'ESRI','114','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999492,'EPSG','9201','EPSG','8806','False easting',-195978.5414,'EPSG','9001','EPSG','8807','False northing',70992.22674,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102851','OSGB36_Highways_England_A27H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102851','ESRI','114',NULL,0);
INSERT INTO "area" VALUES('ESRI','115','UK - Highways England - A28','UK - Highways England - A28',50.9259,52.007,1.0741,1.2785,0);
INSERT INTO "conversion" VALUES('ESRI','102852','unnamed',NULL,NULL,'ESRI','115','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999416,'EPSG','9201','EPSG','8806','False easting',-205961.7946,'EPSG','9001','EPSG','8807','False northing',70986.83212,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102852','OSGB36_Highways_England_A28H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102852','ESRI','115',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102853','unnamed',NULL,NULL,'ESRI','115','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999441,'EPSG','9201','EPSG','8806','False easting',-205966.9438,'EPSG','9001','EPSG','8807','False northing',70988.60686,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102853','OSGB36_Highways_England_A28H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102853','ESRI','115',NULL,0);
INSERT INTO "area" VALUES('ESRI','116','UK - Highways England - A29','UK - Highways England - A29',50.9223,52.0034,1.202,1.4094,0);
INSERT INTO "conversion" VALUES('ESRI','102854','unnamed',NULL,NULL,'ESRI','116','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999366,'EPSG','9201','EPSG','8806','False easting',-214949.3801,'EPSG','9001','EPSG','8807','False northing',70983.28366,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102854','OSGB36_Highways_England_A29H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102854','ESRI','116',NULL,0);
INSERT INTO "area" VALUES('ESRI','117','UK - Highways England - A30','UK - Highways England - A30',50.9186,51.9997,1.3299,1.5403,0);
INSERT INTO "conversion" VALUES('ESRI','102855','unnamed',NULL,NULL,'ESRI','117','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999314,'EPSG','9201','EPSG','8806','False easting',-223935.6193,'EPSG','9001','EPSG','8807','False northing',70979.59363,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102855','OSGB36_Highways_England_A30H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102855','ESRI','117',NULL,0);
INSERT INTO "area" VALUES('ESRI','118','UK - Highways England - B15','UK - Highways England - B15',52.0434,53.9351,-3.1882,-2.6416,0);
INSERT INTO "conversion" VALUES('ESRI','102856','unnamed',NULL,NULL,'ESRI','118','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999967,'EPSG','9201','EPSG','8806','False easting',88032.17537,'EPSG','9001','EPSG','8807','False northing',111040.5848,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102856','OSGB36_Highways_England_B15H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102856','ESRI','118',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102857','unnamed',NULL,NULL,'ESRI','118','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999992,'EPSG','9201','EPSG','8806','False easting',88034.37626,'EPSG','9001','EPSG','8807','False northing',111043.361,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102857','OSGB36_Highways_England_B15H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102857','ESRI','118',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102858','unnamed',NULL,NULL,'ESRI','118','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000017,'EPSG','9201','EPSG','8806','False easting',88036.57726,'EPSG','9001','EPSG','8807','False northing',111046.1372,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102858','OSGB36_Highways_England_B15H3',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102858','ESRI','118',NULL,0);
INSERT INTO "area" VALUES('ESRI','119','UK - Highways England - B16','UK - Highways England - B16',52.0472,53.9359,-2.6703,-1.482,0);
INSERT INTO "conversion" VALUES('ESRI','102859','unnamed',NULL,NULL,'ESRI','119','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000012,'EPSG','9201','EPSG','8806','False easting',54022.17583,'EPSG','9001','EPSG','8807','False northing',111045.5837,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102859','OSGB36_Highways_England_B16H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102859','ESRI','119',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102860','unnamed',NULL,NULL,'ESRI','119','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000037,'EPSG','9201','EPSG','8806','False easting',54023.52644,'EPSG','9001','EPSG','8807','False northing',111048.3599,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102860','OSGB36_Highways_England_B16H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102860','ESRI','119',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102861','unnamed',NULL,NULL,'ESRI','119','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000062,'EPSG','9201','EPSG','8806','False easting',54024.87711,'EPSG','9001','EPSG','8807','False northing',111051.1363,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102861','OSGB36_Highways_England_B16H3',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102861','ESRI','119',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102862','unnamed',NULL,NULL,'ESRI','119','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000087,'EPSG','9201','EPSG','8806','False easting',54026.22785,'EPSG','9001','EPSG','8807','False northing',111053.9128,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102862','OSGB36_Highways_England_B16H4',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102862','ESRI','119',NULL,0);
INSERT INTO "area" VALUES('ESRI','120','UK - Highways England - B17','UK - Highways England - B17',52.0447,53.9359,-1.5042,-0.9641,0);
INSERT INTO "conversion" VALUES('ESRI','102863','unnamed',NULL,NULL,'ESRI','120','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999981,'EPSG','9201','EPSG','8806','False easting',-24009.11135,'EPSG','9001','EPSG','8807','False northing',111042.14,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102863','OSGB36_Highways_England_B17H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102863','ESRI','120',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102864','unnamed',NULL,NULL,'ESRI','120','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000006,'EPSG','9201','EPSG','8806','False easting',-24009.7116,'EPSG','9001','EPSG','8807','False northing',111044.9161,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102864','OSGB36_Highways_England_B17H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102864','ESRI','120',NULL,0);
INSERT INTO "area" VALUES('ESRI','121','UK - Highways England - B18','UK - Highways England - B18',52.0403,53.9325,-1.0084,-0.5073,0);
INSERT INTO "conversion" VALUES('ESRI','102865','unnamed',NULL,NULL,'ESRI','121','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999928,'EPSG','9201','EPSG','8806','False easting',-58018.94296,'EPSG','9001','EPSG','8807','False northing',111036.2529,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102865','OSGB36_Highways_England_B18H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102865','ESRI','121',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102866','unnamed',NULL,NULL,'ESRI','121','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999953,'EPSG','9201','EPSG','8806','False easting',-58020.39349,'EPSG','9001','EPSG','8807','False northing',111039.0289,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102866','OSGB36_Highways_England_B18H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102866','ESRI','121',NULL,0);
INSERT INTO "area" VALUES('ESRI','122','UK - Highways England - B19','UK - Highways England - B19',52.037,53.9277,-0.5711,-0.2485,0);
INSERT INTO "conversion" VALUES('ESRI','102867','unnamed',NULL,NULL,'ESRI','122','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999874,'EPSG','9201','EPSG','8806','False easting',-88023.98625,'EPSG','9001','EPSG','8807','False northing',111030.2554,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102867','OSGB36_Highways_England_B19H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102867','ESRI','122',NULL,0);
INSERT INTO "area" VALUES('ESRI','123','UK - Highways England - B20','UK - Highways England - B20',52.0332,53.9242,-0.3233,0.0103,0);
INSERT INTO "conversion" VALUES('ESRI','102868','unnamed',NULL,NULL,'ESRI','123','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999826,'EPSG','9201','EPSG','8806','False easting',-105023.5775,'EPSG','9001','EPSG','8807','False northing',111024.9248,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102868','OSGB36_Highways_England_B20H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102868','ESRI','123',NULL,0);
INSERT INTO "area" VALUES('ESRI','124','UK - Highways England - B21','UK - Highways England - B21',52.0289,52.8061,-0.0756,0.2105,0);
INSERT INTO "conversion" VALUES('ESRI','102869','unnamed',NULL,NULL,'ESRI','124','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999771,'EPSG','9201','EPSG','8806','False easting',-122020.6823,'EPSG','9001','EPSG','8807','False northing',111018.8175,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102869','OSGB36_Highways_England_B21H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102869','ESRI','124',NULL,0);
INSERT INTO "area" VALUES('ESRI','125','UK - Highways England - B22','UK - Highways England - B22',52.0241,52.8017,0.1721,0.4625,0);
INSERT INTO "conversion" VALUES('ESRI','102870','unnamed',NULL,NULL,'ESRI','125','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999709,'EPSG','9201','EPSG','8806','False easting',-139014.9439,'EPSG','9001','EPSG','8807','False northing',111011.9337,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102870','OSGB36_Highways_England_B22H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102870','ESRI','125',NULL,0);
INSERT INTO "area" VALUES('ESRI','126','UK - Highways England - B23','UK - Highways England - B23',52.0213,52.7967,0.4197,0.5958,0);
INSERT INTO "conversion" VALUES('ESRI','102871','unnamed',NULL,NULL,'ESRI','126','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999656,'EPSG','9201','EPSG','8806','False easting',-156008.5024,'EPSG','9001','EPSG','8807','False northing',111006.0498,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102871','OSGB36_Highways_England_B23H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102871','ESRI','126',NULL,0);
INSERT INTO "area" VALUES('ESRI','127','UK - Highways England - B24','UK - Highways England - B24',52.0177,52.7939,0.5508,0.7588,0);
INSERT INTO "conversion" VALUES('ESRI','102872','unnamed',NULL,NULL,'ESRI','127','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999614,'EPSG','9201','EPSG','8806','False easting',-165002.0625,'EPSG','9001','EPSG','8807','False northing',111001.3875,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102872','OSGB36_Highways_England_B24H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102872','ESRI','127',NULL,0);
INSERT INTO "area" VALUES('ESRI','128','UK - Highways England - B25','UK - Highways England - B25',52.0143,52.7902,0.7109,0.9069,0);
INSERT INTO "conversion" VALUES('ESRI','102873','unnamed',NULL,NULL,'ESRI','128','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999565,'EPSG','9201','EPSG','8806','False easting',-175993.5763,'EPSG','9001','EPSG','8807','False northing',110995.9487,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102873','OSGB36_Highways_England_B25H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102873','ESRI','128',NULL,0);
INSERT INTO "area" VALUES('ESRI','129','UK - Highways England - B26','UK - Highways England - B26',52.0107,52.7866,0.8565,1.055,0);
INSERT INTO "conversion" VALUES('ESRI','102874','unnamed',NULL,NULL,'ESRI','129','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999517,'EPSG','9201','EPSG','8806','False easting',-185984.2846,'EPSG','9001','EPSG','8807','False northing',110990.6214,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102874','OSGB36_Highways_England_B26H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102874','ESRI','129',NULL,0);
INSERT INTO "area" VALUES('ESRI','130','UK - Highways England - B27','UK - Highways England - B27',52.0069,52.7829,1.002,1.2031,0);
INSERT INTO "conversion" VALUES('ESRI','102875','unnamed',NULL,NULL,'ESRI','130','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999467,'EPSG','9201','EPSG','8806','False easting',-195973.6419,'EPSG','9001','EPSG','8807','False northing',110985.0727,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102875','OSGB36_Highways_England_B27H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102875','ESRI','130',NULL,0);
INSERT INTO "area" VALUES('ESRI','131','UK - Highways England - B28','UK - Highways England - B28',52.0033,52.779,1.1475,1.3363,0);
INSERT INTO "conversion" VALUES('ESRI','102876','unnamed',NULL,NULL,'ESRI','131','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999416,'EPSG','9201','EPSG','8806','False easting',-205961.7946,'EPSG','9001','EPSG','8807','False northing',110979.4136,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102876','OSGB36_Highways_England_B28H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102876','ESRI','131',NULL,0);
INSERT INTO "area" VALUES('ESRI','132','UK - Highways England - B29','UK - Highways England - B29',51.9996,52.7753,1.2784,1.4695,0);
INSERT INTO "conversion" VALUES('ESRI','102877','unnamed',NULL,NULL,'ESRI','132','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999367,'EPSG','9201','EPSG','8806','False easting',-214949.595,'EPSG','9001','EPSG','8807','False northing',110973.9769,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102877','OSGB36_Highways_England_B29H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102877','ESRI','132',NULL,0);
INSERT INTO "area" VALUES('ESRI','133','UK - Highways England - B30','UK - Highways England - B30',51.9957,52.7715,1.4093,1.6026,0);
INSERT INTO "conversion" VALUES('ESRI','102878','unnamed',NULL,NULL,'ESRI','133','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999315,'EPSG','9201','EPSG','8806','False easting',-223935.8432,'EPSG','9001','EPSG','8807','False northing',110968.208,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102878','OSGB36_Highways_England_B30H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102878','ESRI','133',NULL,0);
INSERT INTO "area" VALUES('ESRI','134','UK - Highways England - B31','UK - Highways England - B31',52.3416,52.7675,1.5681,1.7357,0);
INSERT INTO "conversion" VALUES('ESRI','102879','unnamed',NULL,NULL,'ESRI','134','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999261,'EPSG','9201','EPSG','8806','False easting',-232920.6915,'EPSG','9001','EPSG','8807','False northing',110962.2179,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102879','OSGB36_Highways_England_B31H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102879','ESRI','134',NULL,0);
INSERT INTO "area" VALUES('ESRI','135','UK - Highways England - B32','UK - Highways England - B32',52.3374,52.7634,1.6999,1.8688,0);
INSERT INTO "conversion" VALUES('ESRI','102880','unnamed',NULL,NULL,'ESRI','135','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999206,'EPSG','9201','EPSG','8806','False easting',-241904.3281,'EPSG','9001','EPSG','8807','False northing',110956.1174,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102880','OSGB36_Highways_England_B32H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102880','ESRI','135',NULL,0);
INSERT INTO "area" VALUES('ESRI','136','UK - Highways England - C13','UK - Highways England - C13',54.3636,54.7717,-3.8344,-3.5547,0);
INSERT INTO "conversion" VALUES('ESRI','102881','unnamed',NULL,NULL,'ESRI','136','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999866,'EPSG','9201','EPSG','8806','False easting',128033.8646,'EPSG','9001','EPSG','8807','False northing',126033.3354,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102881','OSGB36_Highways_England_C13H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102881','ESRI','136',NULL,0);
INSERT INTO "area" VALUES('ESRI','137','UK - Highways England - C14','UK - Highways England - C14',54.0079,54.7758,-3.5703,-3.1904,0);
INSERT INTO "conversion" VALUES('ESRI','102882','unnamed',NULL,NULL,'ESRI','137','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999914,'EPSG','9201','EPSG','8806','False easting',111034.6979,'EPSG','9001','EPSG','8807','False northing',126039.3868,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102882','OSGB36_Highways_England_C14H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102882','ESRI','137',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102883','unnamed',NULL,NULL,'ESRI','137','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999939,'EPSG','9201','EPSG','8806','False easting',111037.4739,'EPSG','9001','EPSG','8807','False northing',126042.5379,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102883','OSGB36_Highways_England_C14H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102883','ESRI','137',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102884','unnamed',NULL,NULL,'ESRI','137','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999964,'EPSG','9201','EPSG','8806','False easting',111040.25,'EPSG','9001','EPSG','8807','False northing',126045.6892,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102884','OSGB36_Highways_England_C14H3',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102884','ESRI','137',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102885','unnamed',NULL,NULL,'ESRI','137','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999989,'EPSG','9201','EPSG','8806','False easting',111043.0263,'EPSG','9001','EPSG','8807','False northing',126048.8406,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102885','OSGB36_Highways_England_C14H4',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102885','ESRI','137',NULL,0);
INSERT INTO "area" VALUES('ESRI','138','UK - Highways England - C15','UK - Highways England - C15',53.931,55.1394,-3.2237,-2.6702,0);
INSERT INTO "conversion" VALUES('ESRI','102886','unnamed',NULL,NULL,'ESRI','138','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999967,'EPSG','9201','EPSG','8806','False easting',88032.17537,'EPSG','9001','EPSG','8807','False northing',126046.0693,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102886','OSGB36_Highways_England_C15H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102886','ESRI','138',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102887','unnamed',NULL,NULL,'ESRI','138','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999992,'EPSG','9201','EPSG','8806','False easting',88034.37626,'EPSG','9001','EPSG','8807','False northing',126049.2206,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102887','OSGB36_Highways_England_C15H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102887','ESRI','138',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102888','unnamed',NULL,NULL,'ESRI','138','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000017,'EPSG','9201','EPSG','8806','False easting',88036.57726,'EPSG','9001','EPSG','8807','False northing',126052.372,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102888','OSGB36_Highways_England_C15H3',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102888','ESRI','138',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102889','unnamed',NULL,NULL,'ESRI','138','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000042,'EPSG','9201','EPSG','8806','False easting',88038.77836,'EPSG','9001','EPSG','8807','False northing',126055.5236,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102889','OSGB36_Highways_England_C15H4',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102889','ESRI','138',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102890','unnamed',NULL,NULL,'ESRI','138','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000067,'EPSG','9201','EPSG','8806','False easting',88040.97958,'EPSG','9001','EPSG','8807','False northing',126058.6753,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102890','OSGB36_Highways_England_C15H5',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102890','ESRI','138',NULL,0);
INSERT INTO "area" VALUES('ESRI','139','UK - Highways England - C16','UK - Highways England - C16',53.935,55.8321,-2.7026,-1.4571,0);
INSERT INTO "conversion" VALUES('ESRI','102891','unnamed',NULL,NULL,'ESRI','139','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000012,'EPSG','9201','EPSG','8806','False easting',54022.17583,'EPSG','9001','EPSG','8807','False northing',126051.7436,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102891','OSGB36_Highways_England_C16H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102891','ESRI','139',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102892','unnamed',NULL,NULL,'ESRI','139','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000037,'EPSG','9201','EPSG','8806','False easting',54023.52644,'EPSG','9001','EPSG','8807','False northing',126054.895,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102892','OSGB36_Highways_England_C16H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102892','ESRI','139',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102893','unnamed',NULL,NULL,'ESRI','139','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000062,'EPSG','9201','EPSG','8806','False easting',54024.87711,'EPSG','9001','EPSG','8807','False northing',126058.0466,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102893','OSGB36_Highways_England_C16H3',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102893','ESRI','139',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102894','unnamed',NULL,NULL,'ESRI','139','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000087,'EPSG','9201','EPSG','8806','False easting',54026.22785,'EPSG','9001','EPSG','8807','False northing',126061.1983,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102894','OSGB36_Highways_England_C16H4',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102894','ESRI','139',NULL,0);
INSERT INTO "area" VALUES('ESRI','140','UK - Highways England - C17','UK - Highways England - C17',53.9324,55.5176,-1.4821,-0.923,0);
INSERT INTO "conversion" VALUES('ESRI','102895','unnamed',NULL,NULL,'ESRI','140','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999981,'EPSG','9201','EPSG','8806','False easting',-24009.11135,'EPSG','9001','EPSG','8807','False northing',126047.8346,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102895','OSGB36_Highways_England_C17H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102895','ESRI','140',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102896','unnamed',NULL,NULL,'ESRI','140','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000006,'EPSG','9201','EPSG','8806','False easting',-24009.7116,'EPSG','9001','EPSG','8807','False northing',126050.9859,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102896','OSGB36_Highways_England_C17H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102896','ESRI','140',NULL,0);
INSERT INTO "area" VALUES('ESRI','141','UK - Highways England - C18','UK - Highways England - C18',53.9276,54.3908,-0.9642,-0.4907,0);
INSERT INTO "conversion" VALUES('ESRI','102897','unnamed',NULL,NULL,'ESRI','141','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999928,'EPSG','9201','EPSG','8806','False easting',-58018.94296,'EPSG','9001','EPSG','8807','False northing',126041.1519,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102897','OSGB36_Highways_England_C18H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102897','ESRI','141',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102898','unnamed',NULL,NULL,'ESRI','141','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999953,'EPSG','9201','EPSG','8806','False easting',-58020.39349,'EPSG','9001','EPSG','8807','False northing',126044.3031,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102898','OSGB36_Highways_England_C18H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102898','ESRI','141',NULL,0);
INSERT INTO "area" VALUES('ESRI','142','UK - Highways England - C19','UK - Highways England - C19',53.9241,54.3859,-0.5074,-0.229,0);
INSERT INTO "conversion" VALUES('ESRI','102899','unnamed',NULL,NULL,'ESRI','142','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999874,'EPSG','9201','EPSG','8806','False easting',-88023.98625,'EPSG','9001','EPSG','8807','False northing',126034.3439,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102899','OSGB36_Highways_England_C19H1',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102899','ESRI','142',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','102900','unnamed',NULL,NULL,'ESRI','142','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',49.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-2.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999899,'EPSG','9201','EPSG','8806','False easting',-88026.18693,'EPSG','9001','EPSG','8807','False northing',126037.4949,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102900','OSGB36_Highways_England_C19H2',NULL,NULL,'EPSG','4400','EPSG','4277','ESRI','102900','ESRI','142',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102962','NAD_1983_2011_California_Teale_Albers',NULL,NULL,NULL,NULL,'EPSG','6318',NULL,NULL,'EPSG','1375','PROJCS["NAD_1983_2011_California_Teale_Albers",GEOGCS["GCS_NAD_1983_2011",DATUM["D_NAD_1983_2011",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",-4000000.0],PARAMETER["Central_Meridian",-120.0],PARAMETER["Standard_Parallel_1",34.0],PARAMETER["Standard_Parallel_2",40.5],PARAMETER["Latitude_Of_Origin",0.0],UNIT["Meter",1.0]]',1);
INSERT INTO "projected_crs" VALUES('ESRI','102963','NAD_1983_2011_Mississippi_TM',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102469','EPSG','1393',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102965','NAD_1983_2011_Contiguous_USA_Albers',NULL,NULL,NULL,NULL,'EPSG','6318',NULL,NULL,'EPSG','1323','PROJCS["NAD_1983_2011_Contiguous_USA_Albers",GEOGCS["GCS_NAD_1983_2011",DATUM["D_NAD_1983_2011",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-96.0],PARAMETER["Standard_Parallel_1",29.5],PARAMETER["Standard_Parallel_2",45.5],PARAMETER["Latitude_Of_Origin",23.0],UNIT["Meter",1.0]]',1);
INSERT INTO "projected_crs" VALUES('ESRI','102966','NAD_1983_2011_Alaska_Albers',NULL,NULL,NULL,NULL,'EPSG','6318',NULL,NULL,'EPSG','1330','PROJCS["NAD_1983_2011_Alaska_Albers",GEOGCS["GCS_NAD_1983_2011",DATUM["D_NAD_1983_2011",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",0.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-154.0],PARAMETER["Standard_Parallel_1",55.0],PARAMETER["Standard_Parallel_2",65.0],PARAMETER["Latitude_Of_Origin",50.0],UNIT["Meter",1.0]]',1);
INSERT INTO "projected_crs" VALUES('ESRI','102967','NAD_1983_2011_Florida_GDL_Albers',NULL,NULL,NULL,NULL,'EPSG','6318',NULL,NULL,'EPSG','1379','PROJCS["NAD_1983_2011_Florida_GDL_Albers",GEOGCS["GCS_NAD_1983_2011",DATUM["D_NAD_1983_2011",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",400000.0],PARAMETER["False_Northing",0.0],PARAMETER["Central_Meridian",-84.0],PARAMETER["Standard_Parallel_1",24.0],PARAMETER["Standard_Parallel_2",31.5],PARAMETER["Latitude_Of_Origin",24.0],UNIT["Meter",1.0]]',1);
INSERT INTO "projected_crs" VALUES('ESRI','102968','NAD_1983_2011_Michigan_GeoRef_Meters',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102123','EPSG','1391',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102969','NAD_1983_2011_Oregon_Statewide_Lambert',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102380','EPSG','1406',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102970','NAD_1983_2011_Oregon_Statewide_Lambert_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6318','ESRI','102381','EPSG','1406',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102971','NAD_1983_2011_Texas_Centric_Mapping_System_Albers',NULL,NULL,NULL,NULL,'EPSG','6318',NULL,NULL,'EPSG','1412','PROJCS["NAD_1983_2011_Texas_Centric_Mapping_System_Albers",GEOGCS["GCS_NAD_1983_2011",DATUM["D_NAD_1983_2011",SPHEROID["GRS_1980",6378137.0,298.257222101]],PRIMEM["Greenwich",0.0],UNIT["Degree",0.0174532925199433]],PROJECTION["Albers"],PARAMETER["False_Easting",1500000.0],PARAMETER["False_Northing",6000000.0],PARAMETER["Central_Meridian",-100.0],PARAMETER["Standard_Parallel_1",27.5],PARAMETER["Standard_Parallel_2",35.0],PARAMETER["Latitude_Of_Origin",18.0],UNIT["Meter",1.0]]',1);
INSERT INTO "projected_crs" VALUES('ESRI','102972','NAD_1983_2011_Texas_Centric_Mapping_System_Lambert',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102602','EPSG','1412',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102973','NAD_1983_2011_Wisconsin_TM',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','14841','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102974','NAD_1983_2011_Wisconsin_TM_US_Ft',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102217','EPSG','1418',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','102975','NAD_1983_2011_StatePlane_Alabama_East_FIPS_0101',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102229','EPSG','2154',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102976','NAD_1983_2011_StatePlane_Alabama_West_FIPS_0102',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102230','EPSG','2155',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102977','unnamed',NULL,NULL,'EPSG','2156','EPSG','9812','Hotine Oblique Mercator (variant A)','EPSG','8811','Latitude of projection centre',57.0,'EPSG','9102','EPSG','8812','Longitude of projection centre',-133.6666666666667,'EPSG','9102','EPSG','8813','Azimuth of initial line',-36.86989764583333,'EPSG','9102','EPSG','8814','Angle from Rectified to Skew Grid',-36.86989764583333,'EPSG','9102','EPSG','8815','Scale factor on initial line',0.9999,'EPSG','9201','EPSG','8806','False easting',5000000.0,'EPSG','9001','EPSG','8807','False northing',-5000000.0,'EPSG','9001',1);
INSERT INTO "projected_crs" VALUES('ESRI','102977','NAD_1983_2011_StatePlane_Alaska_1_FIPS_5001',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102977','EPSG','2156',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102978','NAD_1983_2011_StatePlane_Alaska_2_FIPS_5002',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','15032','EPSG','2158',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102979','NAD_1983_2011_StatePlane_Alaska_3_FIPS_5003',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','15033','EPSG','2159',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102980','NAD_1983_2011_StatePlane_Alaska_4_FIPS_5004',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','15034','EPSG','2160',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102981','NAD_1983_2011_StatePlane_Alaska_5_FIPS_5005',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','15035','EPSG','2161',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102982','NAD_1983_2011_StatePlane_Alaska_6_FIPS_5006',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','15036','EPSG','2162',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102983','NAD_1983_2011_StatePlane_Alaska_7_FIPS_5007',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','15037','EPSG','2163',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102984','NAD_1983_2011_StatePlane_Alaska_8_FIPS_5008',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','15038','EPSG','2164',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102985','NAD_1983_2011_StatePlane_Alaska_9_FIPS_5009',NULL,NULL,'EPSG','4400','EPSG','6318','EPSG','15039','EPSG','2165',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102986','unnamed',NULL,NULL,'EPSG','2157','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',51.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-176.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',51.83333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',53.83333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102986','NAD_1983_2011_StatePlane_Alaska_10_FIPS_5010',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102986','EPSG','2157',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102987','NAD_1983_2011_StatePlane_Arizona_East_FIPS_0201',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102248','EPSG','2167',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102988','NAD_1983_2011_StatePlane_Arizona_Central_FIPS_0202',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102249','EPSG','2166',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102989','NAD_1983_2011_StatePlane_Arizona_West_FIPS_0203',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102250','EPSG','2168',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102990','unnamed',NULL,NULL,'EPSG','2167','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-110.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102990','NAD_1983_2011_StatePlane_Arizona_East_FIPS_0201_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6318','ESRI','102990','EPSG','2167',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102991','unnamed',NULL,NULL,'EPSG','2166','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-111.9166666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102991','NAD_1983_2011_StatePlane_Arizona_Central_FIPS_0202_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6318','ESRI','102991','EPSG','2166',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','102992','unnamed',NULL,NULL,'EPSG','2168','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-113.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999333333333333,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102992','NAD_1983_2011_StatePlane_Arizona_West_FIPS_0203_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6318','ESRI','102992','EPSG','2168',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102993','NAD_1983_2011_StatePlane_Arkansas_North_FIPS_0301',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102251','EPSG','2169',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102994','NAD_1983_2011_StatePlane_Arkansas_South_FIPS_0302',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102252','EPSG','2170',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102995','NAD_1983_2011_StatePlane_Arkansas_North_FIPS_0301_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102651','EPSG','2169',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102996','NAD_1983_2011_StatePlane_Arkansas_South_FIPS_0302_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102652','EPSG','2170',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102997','NAD_1983_2011_StatePlane_California_I_FIPS_0401',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102241','EPSG','2175',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102998','NAD_1983_2011_StatePlane_California_II_FIPS_0402',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102242','EPSG','2176',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','102999','NAD_1983_2011_StatePlane_California_III_FIPS_0403',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102243','EPSG','2177',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103000','NAD_1983_2011_StatePlane_California_IV_FIPS_0404',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102244','EPSG','2178',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103001','NAD_1983_2011_StatePlane_California_V_FIPS_0405',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102245','EPSG','2182',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103002','NAD_1983_2011_StatePlane_California_VI_FIPS_0406',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102246','EPSG','2180',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103003','NAD_1983_2011_StatePlane_California_I_FIPS_0401_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102641','EPSG','2175',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103004','NAD_1983_2011_StatePlane_California_II_FIPS_0402_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102642','EPSG','2176',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103005','NAD_1983_2011_StatePlane_California_III_FIPS_0403_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102643','EPSG','2177',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103006','NAD_1983_2011_StatePlane_California_IV_FIPS_0404_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102644','EPSG','2178',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103007','NAD_1983_2011_StatePlane_California_V_FIPS_0405_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102645','EPSG','2182',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103008','NAD_1983_2011_StatePlane_California_VI_FIPS_0406_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102646','EPSG','2180',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103009','NAD_1983_2011_StatePlane_Colorado_North_FIPS_0501',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102253','EPSG','2184',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103010','NAD_1983_2011_StatePlane_Colorado_Central_FIPS_0502',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102254','EPSG','2183',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103011','NAD_1983_2011_StatePlane_Colorado_South_FIPS_0503',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102255','EPSG','2185',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103012','NAD_1983_2011_StatePlane_Colorado_North_FIPS_0501_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102653','EPSG','2184',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103013','NAD_1983_2011_StatePlane_Colorado_Central_FIPS_0502_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102654','EPSG','2183',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103014','NAD_1983_2011_StatePlane_Colorado_South_FIPS_0503_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102655','EPSG','2185',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103015','NAD_1983_2011_StatePlane_Connecticut_FIPS_0600',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102256','EPSG','1377',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103016','NAD_1983_2011_StatePlane_Connecticut_FIPS_0600_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102656','EPSG','1377',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103017','NAD_1983_2011_StatePlane_Delaware_FIPS_0700',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102257','EPSG','1378',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103018','NAD_1983_2011_StatePlane_Delaware_FIPS_0700_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102657','EPSG','1378',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103019','NAD_1983_2011_StatePlane_Florida_East_FIPS_0901',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102258','EPSG','2186',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103020','NAD_1983_2011_StatePlane_Florida_West_FIPS_0902',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102259','EPSG','2188',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103021','NAD_1983_2011_StatePlane_Florida_North_FIPS_0903',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102260','EPSG','2187',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103022','NAD_1983_2011_StatePlane_Florida_East_FIPS_0901_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102658','EPSG','2186',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103023','NAD_1983_2011_StatePlane_Florida_West_FIPS_0902_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102659','EPSG','2188',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103024','NAD_1983_2011_StatePlane_Florida_North_FIPS_0903_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102660','EPSG','2187',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103025','NAD_1983_2011_StatePlane_Georgia_East_FIPS_1001',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102266','EPSG','2189',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103026','NAD_1983_2011_StatePlane_Georgia_West_FIPS_1002',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102267','EPSG','2190',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103027','NAD_1983_2011_StatePlane_Georgia_East_FIPS_1001_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102666','EPSG','2189',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103028','NAD_1983_2011_StatePlane_Georgia_West_FIPS_1002_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102667','EPSG','2190',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103029','NAD_1983_2011_StatePlane_Idaho_East_FIPS_1101',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102268','EPSG','2192',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103030','NAD_1983_2011_StatePlane_Idaho_Central_FIPS_1102',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102269','EPSG','2191',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103031','NAD_1983_2011_StatePlane_Idaho_West_FIPS_1103',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102270','EPSG','2193',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103032','NAD_1983_2011_StatePlane_Idaho_East_FIPS_1101_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102668','EPSG','2192',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103033','NAD_1983_2011_StatePlane_Idaho_Central_FIPS_1102_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102669','EPSG','2191',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103034','NAD_1983_2011_StatePlane_Idaho_West_FIPS_1103_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102670','EPSG','2193',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103035','NAD_1983_2011_StatePlane_Illinois_East_FIPS_1201',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102271','EPSG','2194',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103036','NAD_1983_2011_StatePlane_Illinois_West_FIPS_1202',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102272','EPSG','2195',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103037','NAD_1983_2011_StatePlane_Illinois_East_FIPS_1201_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102671','EPSG','2194',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103038','NAD_1983_2011_StatePlane_Illinois_West_FIPS_1202_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102672','EPSG','2195',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103039','NAD_1983_2011_StatePlane_Indiana_East_FIPS_1301',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102273','EPSG','2196',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103040','NAD_1983_2011_StatePlane_Indiana_West_FIPS_1302',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102274','EPSG','2197',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103041','NAD_1983_2011_StatePlane_Indiana_East_FIPS_1301_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102673','EPSG','2196',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103042','NAD_1983_2011_StatePlane_Indiana_West_FIPS_1302_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102674','EPSG','2197',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103043','NAD_1983_2011_StatePlane_Iowa_North_FIPS_1401',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102275','EPSG','2198',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103044','NAD_1983_2011_StatePlane_Iowa_South_FIPS_1402',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102276','EPSG','2199',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103045','NAD_1983_2011_StatePlane_Iowa_North_FIPS_1401_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102675','EPSG','2198',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103046','NAD_1983_2011_StatePlane_Iowa_South_FIPS_1402_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102676','EPSG','2199',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103047','NAD_1983_2011_StatePlane_Kansas_North_FIPS_1501',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102277','EPSG','2200',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103048','NAD_1983_2011_StatePlane_Kansas_South_FIPS_1502',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102278','EPSG','2201',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103049','NAD_1983_2011_StatePlane_Kansas_North_FIPS_1501_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102677','EPSG','2200',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103050','NAD_1983_2011_StatePlane_Kansas_South_FIPS_1502_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102678','EPSG','2201',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103051','NAD_1983_2011_StatePlane_Kentucky_North_FIPS_1601',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102279','EPSG','2202',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103052','NAD_1983_2011_StatePlane_Kentucky_North_FIPS_1601_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102679','EPSG','2202',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103053','NAD_1983_2011_StatePlane_Kentucky_FIPS_1600',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','65163','EPSG','1386',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103054','NAD_1983_2011_StatePlane_Kentucky_FIPS_1600_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102763','EPSG','1386',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103055','NAD_1983_2011_StatePlane_Kentucky_South_FIPS_1602',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102280','EPSG','2203',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103056','NAD_1983_2011_StatePlane_Kentucky_South_FIPS_1602_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102680','EPSG','2203',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103057','NAD_1983_2011_StatePlane_Louisiana_North_FIPS_1701',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102281','EPSG','2204',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103058','NAD_1983_2011_StatePlane_Louisiana_South_FIPS_1702',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102282','EPSG','2529',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103059','NAD_1983_2011_StatePlane_Louisiana_North_FIPS_1701_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102681','EPSG','2204',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103060','NAD_1983_2011_StatePlane_Louisiana_South_FIPS_1702_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102682','EPSG','2529',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103061','NAD_1983_2011_StatePlane_Maine_East_FIPS_1801',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102283','EPSG','2206',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103062','NAD_1983_2011_StatePlane_Maine_West_FIPS_1802',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102284','EPSG','2207',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103063','NAD_1983_2011_StatePlane_Maine_East_FIPS_1801_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102683','EPSG','2206',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103064','NAD_1983_2011_StatePlane_Maine_West_FIPS_1802_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102684','EPSG','2207',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103065','NAD_1983_2011_Maine_2000_East_Zone',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102208','EPSG','2960',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103066','NAD_1983_2011_Maine_2000_Central_Zone',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102209','EPSG','2959',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103067','NAD_1983_2011_Maine_2000_West_Zone',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102210','EPSG','2958',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103068','NAD_1983_2011_StatePlane_Maryland_FIPS_1900',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102285','EPSG','1389',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103069','NAD_1983_2011_StatePlane_Maryland_FIPS_1900_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102685','EPSG','1389',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103070','NAD_1983_2011_StatePlane_Massachusetts_Mainland_FIPS_2001',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102286','EPSG','2209',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103071','NAD_1983_2011_StatePlane_Massachusetts_Island_FIPS_2002',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102287','EPSG','2208',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103072','NAD_1983_2011_StatePlane_Massachusetts_Mnld_FIPS_2001_FtUS',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102686','EPSG','2209',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103073','NAD_1983_2011_StatePlane_Massachusetts_Isl_FIPS_2002_FtUS',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102687','EPSG','2208',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103074','NAD_1983_2011_StatePlane_Michigan_North_FIPS_2111',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102288','EPSG','1723',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103075','NAD_1983_2011_StatePlane_Michigan_Central_FIPS_2112',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102289','EPSG','1724',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103076','NAD_1983_2011_StatePlane_Michigan_South_FIPS_2113',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102290','EPSG','1725',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103077','unnamed',NULL,NULL,'EPSG','1723','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.78333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-87.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.48333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.08333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',26246719.16010498,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103077','NAD_1983_2011_StatePlane_Michigan_North_FIPS_2111_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6318','ESRI','103077','EPSG','1723',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103078','unnamed',NULL,NULL,'EPSG','1724','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.31666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.36666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.18333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.7,'EPSG','9102','EPSG','8826','Easting at false origin',19685039.37007874,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103078','NAD_1983_2011_StatePlane_Michigan_Central_FIPS_2112_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6318','ESRI','103078','EPSG','1724',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103079','unnamed',NULL,NULL,'EPSG','1725','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.36666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.1,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',13123359.58005249,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103079','NAD_1983_2011_StatePlane_Michigan_South_FIPS_2113_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6318','ESRI','103079','EPSG','1725',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103080','NAD_1983_2011_StatePlane_Minnesota_North_FIPS_2201',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102291','EPSG','2214',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103081','NAD_1983_2011_StatePlane_Minnesota_Central_FIPS_2202',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102292','EPSG','2213',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103082','NAD_1983_2011_StatePlane_Minnesota_South_FIPS_2203',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102293','EPSG','2215',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103083','NAD_1983_2011_StatePlane_Minnesota_North_FIPS_2201_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102466','EPSG','2214',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103084','NAD_1983_2011_StatePlane_Minnesota_Central_FIPS_2202_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102467','EPSG','2213',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103085','NAD_1983_2011_StatePlane_Minnesota_South_FIPS_2203_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102468','EPSG','2215',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103086','NAD_1983_2011_StatePlane_Mississippi_East_FIPS_2301',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102294','EPSG','2216',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103087','NAD_1983_2011_StatePlane_Mississippi_West_FIPS_2302',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102295','EPSG','2217',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103088','NAD_1983_2011_StatePlane_Mississippi_East_FIPS_2301_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102694','EPSG','2216',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103089','NAD_1983_2011_StatePlane_Mississippi_West_FIPS_2302_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102695','EPSG','2217',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103090','NAD_1983_2011_StatePlane_Missouri_East_FIPS_2401',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102296','EPSG','2219',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103091','NAD_1983_2011_StatePlane_Missouri_Central_FIPS_2402',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102297','EPSG','2218',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103092','NAD_1983_2011_StatePlane_Missouri_West_FIPS_2403',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102298','EPSG','2220',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103093','NAD_1983_2011_StatePlane_Montana_FIPS_2500',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102300','EPSG','1395',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103094','unnamed',NULL,NULL,'EPSG','1395','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.25,'EPSG','9102','EPSG','8822','Longitude of false origin',-109.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',49.0,'EPSG','9102','EPSG','8826','Easting at false origin',1968503.937007874,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103094','NAD_1983_2011_StatePlane_Montana_FIPS_2500_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6318','ESRI','103094','EPSG','1395',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103095','NAD_1983_2011_StatePlane_Nebraska_FIPS_2600',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102304','EPSG','1396',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103096','NAD_1983_2011_StatePlane_Nebraska_FIPS_2600_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102704','EPSG','1396',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103097','NAD_1983_2011_StatePlane_Nevada_East_FIPS_2701',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102307','EPSG','2224',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103098','NAD_1983_2011_StatePlane_Nevada_Central_FIPS_2702',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102308','EPSG','2223',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103099','NAD_1983_2011_StatePlane_Nevada_West_FIPS_2703',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102309','EPSG','2225',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103100','NAD_1983_2011_StatePlane_Nevada_East_FIPS_2701_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102707','EPSG','2224',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103101','NAD_1983_2011_StatePlane_Nevada_Central_FIPS_2702_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102708','EPSG','2223',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103102','NAD_1983_2011_StatePlane_Nevada_West_FIPS_2703_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102709','EPSG','2225',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103103','NAD_1983_2011_StatePlane_New_Hampshire_FIPS_2800',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102310','EPSG','1398',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103104','NAD_1983_2011_StatePlane_New_Hampshire_FIPS_2800_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102710','EPSG','1398',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103105','NAD_1983_2011_StatePlane_New_Jersey_FIPS_2900',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102311','EPSG','1399',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103106','NAD_1983_2011_StatePlane_New_Jersey_FIPS_2900_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102711','EPSG','1399',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103107','NAD_1983_2011_StatePlane_New_Mexico_East_FIPS_3001',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102312','EPSG','2228',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103108','NAD_1983_2011_StatePlane_New_Mexico_Central_FIPS_3002',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102313','EPSG','2231',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103109','NAD_1983_2011_StatePlane_New_Mexico_West_FIPS_3003',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102314','EPSG','2232',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103110','NAD_1983_2011_StatePlane_New_Mexico_East_FIPS_3001_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102712','EPSG','2228',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103111','NAD_1983_2011_StatePlane_New_Mexico_Central_FIPS_3002_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102713','EPSG','2231',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103112','NAD_1983_2011_StatePlane_New_Mexico_West_FIPS_3003_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102714','EPSG','2232',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103113','NAD_1983_2011_StatePlane_New_York_East_FIPS_3101',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102315','EPSG','2234',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103114','NAD_1983_2011_StatePlane_New_York_Central_FIPS_3102',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102316','EPSG','2233',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103115','NAD_1983_2011_StatePlane_New_York_West_FIPS_3103',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102317','EPSG','2236',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103116','NAD_1983_2011_StatePlane_New_York_Long_Island_FIPS_3104',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102318','EPSG','2235',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103117','NAD_1983_2011_StatePlane_New_York_East_FIPS_3101_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102715','EPSG','2234',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103118','NAD_1983_2011_StatePlane_New_York_Central_FIPS_3102_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102716','EPSG','2233',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103119','NAD_1983_2011_StatePlane_New_York_West_FIPS_3103_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102717','EPSG','2236',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103120','NAD_1983_2011_StatePlane_New_York_Long_Isl_FIPS_3104_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102718','EPSG','2235',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103121','unnamed',NULL,NULL,'EPSG','1402','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.75,'EPSG','9102','EPSG','8822','Longitude of false origin',-79.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.16666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',609601.2192024384,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103121','NAD_1983_2011_StatePlane_North_Carolina_FIPS_3200',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','103121','EPSG','1402',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103122','unnamed',NULL,NULL,'EPSG','1402','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.75,'EPSG','9102','EPSG','8822','Longitude of false origin',-79.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.16666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103122','NAD_1983_2011_StatePlane_North_Carolina_FIPS_3200_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','103122','EPSG','1402',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103123','NAD_1983_2011_StatePlane_North_Dakota_North_FIPS_3301',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102320','EPSG','2237',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103124','NAD_1983_2011_StatePlane_North_Dakota_South_FIPS_3302',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102321','EPSG','2238',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103125','unnamed',NULL,NULL,'EPSG','2237','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.43333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.73333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1968503.937007874,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103125','NAD_1983_2011_StatePlane_North_Dakota_North_FIPS_3301_FtI',NULL,NULL,'ESRI','Foot','EPSG','6318','ESRI','103125','EPSG','2237',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103126','unnamed',NULL,NULL,'EPSG','2238','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.18333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.48333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1968503.937007874,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103126','NAD_1983_2011_StatePlane_North_Dakota_South_FIPS_3302_FtI',NULL,NULL,'ESRI','Foot','EPSG','6318','ESRI','103126','EPSG','2238',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103127','NAD_1983_2011_StatePlane_Ohio_North_FIPS_3401',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102322','EPSG','2239',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103128','NAD_1983_2011_StatePlane_Ohio_South_FIPS_3402',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102323','EPSG','2240',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103129','NAD_1983_2011_StatePlane_Ohio_North_FIPS_3401_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102722','EPSG','2239',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103130','NAD_1983_2011_StatePlane_Ohio_South_FIPS_3402_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102723','EPSG','2240',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103131','NAD_1983_2011_StatePlane_Oklahoma_North_FIPS_3501',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102324','EPSG','2241',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103132','NAD_1983_2011_StatePlane_Oklahoma_South_FIPS_3502',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102325','EPSG','2242',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103133','NAD_1983_2011_StatePlane_Oklahoma_North_FIPS_3501_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102724','EPSG','2241',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103134','NAD_1983_2011_StatePlane_Oklahoma_South_FIPS_3502_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102725','EPSG','2242',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103135','NAD_1983_2011_StatePlane_Oregon_North_FIPS_3601',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102326','EPSG','2243',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103136','NAD_1983_2011_StatePlane_Oregon_South_FIPS_3602',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102327','EPSG','2244',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103137','NAD_1983_2011_StatePlane_Oregon_North_FIPS_3601_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6318','ESRI','102378','EPSG','2243',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103138','NAD_1983_2011_StatePlane_Oregon_South_FIPS_3602_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6318','ESRI','102379','EPSG','2244',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103139','unnamed',NULL,NULL,'EPSG','2245','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.16666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-77.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.88333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.95,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103139','NAD_1983_2011_StatePlane_Pennsylvania_North_FIPS_3701',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','103139','EPSG','2245',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103140','NAD_1983_2011_StatePlane_Pennsylvania_North_FIPS_3701_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102728','EPSG','2245',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103141','unnamed',NULL,NULL,'EPSG','2246','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-77.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',39.93333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.96666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103141','NAD_1983_2011_StatePlane_Pennsylvania_South_FIPS_3702',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','103141','EPSG','2246',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103142','NAD_1983_2011_StatePlane_Pennsylvania_South_FIPS_3702_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102729','EPSG','2246',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103143','NAD_1983_2011_StatePlane_Rhode_Island_FIPS_3800',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102330','EPSG','1408',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103144','NAD_1983_2011_StatePlane_Rhode_Island_FIPS_3800_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102730','EPSG','1408',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103145','unnamed',NULL,NULL,'EPSG','1409','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.83333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',32.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',34.83333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',609600.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103145','NAD_1983_2011_StatePlane_South_Carolina_FIPS_3900',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','103145','EPSG','1409',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103146','unnamed',NULL,NULL,'EPSG','1409','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.83333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',32.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',34.83333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103146','NAD_1983_2011_StatePlane_South_Carolina_FIPS_3900_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6318','ESRI','103146','EPSG','1409',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103147','NAD_1983_2011_StatePlane_South_Dakota_North_FIPS_4001',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102334','EPSG','2249',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103148','NAD_1983_2011_StatePlane_South_Dakota_South_FIPS_4002',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102335','EPSG','2250',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103149','NAD_1983_2011_StatePlane_South_Dakota_North_FIPS_4001_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102734','EPSG','2249',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103150','NAD_1983_2011_StatePlane_South_Dakota_South_FIPS_4002_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102735','EPSG','2250',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103151','NAD_1983_2011_StatePlane_Tennessee_FIPS_4100',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102336','EPSG','1411',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103152','NAD_1983_2011_StatePlane_Tennessee_FIPS_4100_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102736','EPSG','1411',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103153','NAD_1983_2011_StatePlane_Texas_North_FIPS_4201',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102337','EPSG','2253',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103154','NAD_1983_2011_StatePlane_Texas_North_Central_FIPS_4202',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102338','EPSG','2254',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103155','NAD_1983_2011_StatePlane_Texas_Central_FIPS_4203',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102339','EPSG','2252',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103156','NAD_1983_2011_StatePlane_Texas_South_Central_FIPS_4204',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102340','EPSG','2527',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103157','NAD_1983_2011_StatePlane_Texas_South_FIPS_4205',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102341','EPSG','2528',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103158','NAD_1983_2011_StatePlane_Texas_North_FIPS_4201_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102737','EPSG','2253',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103159','NAD_1983_2011_StatePlane_Texas_North_Central_FIPS_4202_FtUS',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102738','EPSG','2254',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103160','NAD_1983_2011_StatePlane_Texas_Central_FIPS_4203_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102739','EPSG','2252',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103161','NAD_1983_2011_StatePlane_Texas_South_Central_FIPS_4204_FtUS',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102740','EPSG','2527',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103162','NAD_1983_2011_StatePlane_Texas_South_FIPS_4205_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102741','EPSG','2528',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103163','NAD_1983_2011_StatePlane_Utah_North_FIPS_4301',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102342','EPSG','2258',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103164','NAD_1983_2011_StatePlane_Utah_Central_FIPS_4302',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102343','EPSG','2257',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103165','NAD_1983_2011_StatePlane_Utah_South_FIPS_4303',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102344','EPSG','2259',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103166','unnamed',NULL,NULL,'EPSG','2258','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-111.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.71666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1640419.947506561,'EPSG','9002','EPSG','8827','Northing at false origin',3280839.895013123,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103166','NAD_1983_2011_StatePlane_Utah_North_FIPS_4301_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6318','ESRI','103166','EPSG','2258',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103167','unnamed',NULL,NULL,'EPSG','2257','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-111.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',39.01666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.65,'EPSG','9102','EPSG','8826','Easting at false origin',1640419.947506561,'EPSG','9002','EPSG','8827','Northing at false origin',6561679.790026246,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103167','NAD_1983_2011_StatePlane_Utah_Central_FIPS_4302_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6318','ESRI','103167','EPSG','2257',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103168','unnamed',NULL,NULL,'EPSG','2259','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-111.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.21666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.35,'EPSG','9102','EPSG','8826','Easting at false origin',1640419.947506561,'EPSG','9002','EPSG','8827','Northing at false origin',9842519.685039369,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103168','NAD_1983_2011_StatePlane_Utah_South_FIPS_4303_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6318','ESRI','103168','EPSG','2259',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103169','NAD_1983_2011_StatePlane_Utah_North_FIPS_4301_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102742','EPSG','2258',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103170','NAD_1983_2011_StatePlane_Utah_Central_FIPS_4302_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102743','EPSG','2257',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103171','NAD_1983_2011_StatePlane_Utah_South_FIPS_4303_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102744','EPSG','2259',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103172','NAD_1983_2011_StatePlane_Vermont_FIPS_4400',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102345','EPSG','1414',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103173','NAD_1983_2011_StatePlane_Vermont_FIPS_4400_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102745','EPSG','1414',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103174','NAD_1983_2011_StatePlane_Virginia_North_FIPS_4501',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102346','EPSG','2260',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103175','NAD_1983_2011_StatePlane_Virginia_South_FIPS_4502',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102347','EPSG','2261',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103176','NAD_1983_2011_StatePlane_Virginia_North_FIPS_4501_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102746','EPSG','2260',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103177','NAD_1983_2011_StatePlane_Virginia_South_FIPS_4502_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102747','EPSG','2261',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103178','NAD_1983_2011_StatePlane_Washington_North_FIPS_4601',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102348','EPSG','2273',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103179','NAD_1983_2011_StatePlane_Washington_South_FIPS_4602',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102349','EPSG','2274',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103180','NAD_1983_2011_StatePlane_Washington_North_FIPS_4601_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102748','EPSG','2273',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103181','NAD_1983_2011_StatePlane_Washington_South_FIPS_4602_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102749','EPSG','2274',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103182','NAD_1983_2011_StatePlane_West_Virginia_North_FIPS_4701',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102350','EPSG','2264',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103183','NAD_1983_2011_StatePlane_West_Virginia_South_FIPS_4702',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102351','EPSG','2265',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103184','NAD_1983_2011_StatePlane_West_Virginia_North_FIPS_4701_FtUS',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102750','EPSG','2264',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103185','NAD_1983_2011_StatePlane_West_Virginia_South_FIPS_4702_FtUS',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102751','EPSG','2265',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103186','NAD_1983_2011_StatePlane_Wisconsin_North_FIPS_4801',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102352','EPSG','2267',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103187','NAD_1983_2011_StatePlane_Wisconsin_Central_FIPS_4802',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102353','EPSG','2266',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103188','NAD_1983_2011_StatePlane_Wisconsin_South_FIPS_4803',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102354','EPSG','2268',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103189','NAD_1983_2011_StatePlane_Wisconsin_North_FIPS_4801_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102752','EPSG','2267',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103190','NAD_1983_2011_StatePlane_Wisconsin_Central_FIPS_4802_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102753','EPSG','2266',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103191','NAD_1983_2011_StatePlane_Wisconsin_South_FIPS_4803_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102754','EPSG','2268',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103192','NAD_1983_2011_StatePlane_Wyoming_East_FIPS_4901',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102355','EPSG','2269',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103193','NAD_1983_2011_StatePlane_Wyoming_East_Central_FIPS_4902',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102356','EPSG','2270',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103194','NAD_1983_2011_StatePlane_Wyoming_West_Central_FIPS_4903',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102357','EPSG','2272',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103195','NAD_1983_2011_StatePlane_Wyoming_West_FIPS_4904',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102358','EPSG','2271',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103196','NAD_1983_2011_StatePlane_Wyoming_East_FIPS_4901_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102755','EPSG','2269',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103197','NAD_1983_2011_StatePlane_Wyoming_E_Central_FIPS_4902_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102756','EPSG','2270',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103198','NAD_1983_2011_StatePlane_Wyoming_W_Central_FIPS_4903_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102757','EPSG','2272',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103199','NAD_1983_2011_StatePlane_Wyoming_West_FIPS_4904_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6318','ESRI','102758','EPSG','2271',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103200','NAD_1983_2011_StatePlane_Puerto_Rico_Virgin_Isls_FIPS_5200',NULL,NULL,'EPSG','4400','EPSG','6318','ESRI','102361','EPSG','3634',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103201','RGRDC_2005_Congo_TM_Zone_12',NULL,NULL,'EPSG','4400','EPSG','4046','EPSG','17412','EPSG','3937',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103202','RGRDC_2005_Congo_TM_Zone_14',NULL,NULL,'EPSG','4400','EPSG','4046','EPSG','17414','EPSG','3151',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103203','RGRDC_2005_Congo_TM_Zone_16',NULL,NULL,'EPSG','4400','EPSG','4046','EPSG','17416','EPSG','3617',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103204','RGRDC_2005_Congo_TM_Zone_18',NULL,NULL,'EPSG','4400','EPSG','4046','EPSG','17418','EPSG','3618',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103205','RGRDC_2005_Congo_TM_Zone_20',NULL,NULL,'EPSG','4400','EPSG','4046','EPSG','17420','EPSG','3620',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103206','RGRDC_2005_Congo_TM_Zone_22',NULL,NULL,'EPSG','4400','EPSG','4046','EPSG','17422','EPSG','3621',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103207','RGRDC_2005_Congo_TM_Zone_24',NULL,NULL,'EPSG','4400','EPSG','4046','EPSG','17424','EPSG','3622',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103208','RGRDC_2005_Congo_TM_Zone_26',NULL,NULL,'EPSG','4400','EPSG','4046','EPSG','17426','EPSG','3623',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103209','RGRDC_2005_Congo_TM_Zone_28',NULL,NULL,'EPSG','4400','EPSG','4046','EPSG','17428','EPSG','3624',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103210','RGRDC_2005_UTM_Zone_33S',NULL,NULL,'EPSG','4400','EPSG','4046','EPSG','16133','EPSG','3626',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103211','RGRDC_2005_UTM_Zone_34S',NULL,NULL,'EPSG','4400','EPSG','4046','EPSG','16134','EPSG','3627',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103212','RGRDC_2005_UTM_Zone_35S',NULL,NULL,'EPSG','4400','EPSG','4046','EPSG','16135','EPSG','3628',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103213','Chua_UTM_Zone_23S',NULL,NULL,'EPSG','4400','EPSG','4224','EPSG','16123','EPSG','3619',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103214','REGCAN95_UTM_Zone_27N',NULL,NULL,'EPSG','4400','EPSG','4081','EPSG','16027','EPSG','3629',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103215','REGCAN95_UTM_Zone_28N',NULL,NULL,'EPSG','4400','EPSG','4081','EPSG','16028','EPSG','3630',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103216','ETRS_1989_DKTM1',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','4089','EPSG','3631',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103217','ETRS_1989_DKTM2',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','4090','EPSG','3632',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103218','ETRS_1989_DKTM3',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','4091','EPSG','2532',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103219','ETRS_1989_DKTM4',NULL,NULL,'EPSG','4400','EPSG','4258','EPSG','4092','EPSG','2533',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103220','unnamed',NULL,NULL,'EPSG','2154','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-85.83333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99996,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103220','NAD_1983_CORS96_StatePlane_Alabama_East_FIPS_0101',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103220','EPSG','2154',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103221','unnamed',NULL,NULL,'EPSG','2155','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999333333333333,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103221','NAD_1983_CORS96_StatePlane_Alabama_West_FIPS_0102',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103221','EPSG','2155',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103222','unnamed',NULL,NULL,'EPSG','2167','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-110.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',213360.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103222','NAD_1983_CORS96_StatePlane_Arizona_East_FIPS_0201',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103222','EPSG','2167',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103223','unnamed',NULL,NULL,'EPSG','2166','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-111.9166666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',213360.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103223','NAD_1983_CORS96_StatePlane_Arizona_Central_FIPS_0202',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103223','EPSG','2166',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103224','unnamed',NULL,NULL,'EPSG','2168','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-113.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999333333333333,'EPSG','9201','EPSG','8806','False easting',213360.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103224','NAD_1983_CORS96_StatePlane_Arizona_West_FIPS_0203',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103224','EPSG','2168',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103225','unnamed',NULL,NULL,'EPSG','2167','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-110.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103225','NAD_1983_CORS96_StatePlane_Arizona_East_FIPS_0201_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','103225','EPSG','2167',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103226','unnamed',NULL,NULL,'EPSG','2166','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-111.9166666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103226','NAD_1983_CORS96_StatePlane_Arizona_Central_FIPS_0202_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','103226','EPSG','2166',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103227','unnamed',NULL,NULL,'EPSG','2168','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-113.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999333333333333,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9002','EPSG','8807','False northing',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103227','NAD_1983_CORS96_StatePlane_Arizona_West_FIPS_0203_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','103227','EPSG','2168',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103228','unnamed',NULL,NULL,'EPSG','2169','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.93333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.23333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103228','NAD_1983_CORS96_StatePlane_Arkansas_North_FIPS_0301',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103228','EPSG','2169',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103229','unnamed',NULL,NULL,'EPSG','2170','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',32.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',33.3,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',34.76666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',400000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103229','NAD_1983_CORS96_StatePlane_Arkansas_South_FIPS_0302',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103229','EPSG','2170',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103230','unnamed',NULL,NULL,'EPSG','2169','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.93333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.23333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1312333.333333333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103230','NAD_1983_CORS96_StatePlane_Arkansas_North_FIPS_0301_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103230','EPSG','2169',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103231','unnamed',NULL,NULL,'EPSG','2170','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',32.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',33.3,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',34.76666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',1312333.333333333,'EPSG','9003','EPSG','8827','Northing at false origin',1312333.333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103231','NAD_1983_CORS96_StatePlane_Arkansas_South_FIPS_0302_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103231','EPSG','2170',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103232','unnamed',NULL,NULL,'EPSG','2175','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-122.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103232','NAD_1983_CORS96_StatePlane_California_I_FIPS_0401',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103232','EPSG','2175',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103233','unnamed',NULL,NULL,'EPSG','2176','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-122.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.83333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103233','NAD_1983_CORS96_StatePlane_California_II_FIPS_0402',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103233','EPSG','2176',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103234','unnamed',NULL,NULL,'EPSG','2177','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.06666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.43333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103234','NAD_1983_CORS96_StatePlane_California_III_FIPS_0403',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103234','EPSG','2177',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103235','unnamed',NULL,NULL,'EPSG','2178','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',35.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-119.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',36.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',37.25,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103235','NAD_1983_CORS96_StatePlane_California_IV_FIPS_0404',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103235','EPSG','2178',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103236','unnamed',NULL,NULL,'EPSG','2182','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-118.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',35.46666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103236','NAD_1983_CORS96_StatePlane_California_V_FIPS_0405',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103236','EPSG','2182',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103237','unnamed',NULL,NULL,'EPSG','2180','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',32.16666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-116.25,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',32.78333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',33.88333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103237','NAD_1983_CORS96_StatePlane_California_VI_FIPS_0406',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103237','EPSG','2180',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103238','unnamed',NULL,NULL,'EPSG','2175','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-122.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',6561666.666666666,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.666666667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103238','NAD_1983_CORS96_StatePlane_California_I_FIPS_0401_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103238','EPSG','2175',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103239','unnamed',NULL,NULL,'EPSG','2176','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-122.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.83333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',6561666.666666666,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.666666667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103239','NAD_1983_CORS96_StatePlane_California_II_FIPS_0402_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103239','EPSG','2176',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103240','unnamed',NULL,NULL,'EPSG','2177','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.06666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.43333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',6561666.666666666,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.666666667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103240','NAD_1983_CORS96_StatePlane_California_III_FIPS_0403_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103240','EPSG','2177',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103241','unnamed',NULL,NULL,'EPSG','2178','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',35.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-119.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',36.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',37.25,'EPSG','9102','EPSG','8826','Easting at false origin',6561666.666666666,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.666666667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103241','NAD_1983_CORS96_StatePlane_California_IV_FIPS_0404_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103241','EPSG','2178',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103242','unnamed',NULL,NULL,'EPSG','2182','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-118.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',35.46666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',6561666.666666666,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.666666667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103242','NAD_1983_CORS96_StatePlane_California_V_FIPS_0405_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103242','EPSG','2182',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103243','unnamed',NULL,NULL,'EPSG','2180','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',32.16666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-116.25,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',32.78333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',33.88333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',6561666.666666666,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.666666667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103243','NAD_1983_CORS96_StatePlane_California_VI_FIPS_0406_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103243','EPSG','2180',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103244','unnamed',NULL,NULL,'EPSG','2184','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-105.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',39.71666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',914401.8289,'EPSG','9001','EPSG','8827','Northing at false origin',304800.6096,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103244','NAD_1983_CORS96_StatePlane_Colorado_North_FIPS_0501',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103244','EPSG','2184',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103245','unnamed',NULL,NULL,'EPSG','2183','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-105.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.45,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.75,'EPSG','9102','EPSG','8826','Easting at false origin',914401.8289,'EPSG','9001','EPSG','8827','Northing at false origin',304800.6096,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103245','NAD_1983_CORS96_StatePlane_Colorado_Central_FIPS_0502',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103245','EPSG','2183',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103246','unnamed',NULL,NULL,'EPSG','2185','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-105.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.23333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.43333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',914401.8289,'EPSG','9001','EPSG','8827','Northing at false origin',304800.6096,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103246','NAD_1983_CORS96_StatePlane_Colorado_South_FIPS_0503',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103246','EPSG','2185',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103247','unnamed',NULL,NULL,'EPSG','2184','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-105.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',39.71666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',3000000.000316083,'EPSG','9003','EPSG','8827','Northing at false origin',999999.999996,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103247','NAD_1983_CORS96_StatePlane_Colorado_North_FIPS_0501_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103247','EPSG','2184',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103248','unnamed',NULL,NULL,'EPSG','2183','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-105.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.45,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.75,'EPSG','9102','EPSG','8826','Easting at false origin',3000000.000316083,'EPSG','9003','EPSG','8827','Northing at false origin',999999.999996,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103248','NAD_1983_CORS96_StatePlane_Colorado_Central_FIPS_0502_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103248','EPSG','2183',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103249','unnamed',NULL,NULL,'EPSG','2185','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-105.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.23333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.43333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',3000000.000316083,'EPSG','9003','EPSG','8827','Northing at false origin',999999.999996,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103249','NAD_1983_CORS96_StatePlane_Colorado_South_FIPS_0503_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103249','EPSG','2185',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103250','unnamed',NULL,NULL,'EPSG','1377','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-72.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',41.2,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.86666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',304800.6096,'EPSG','9001','EPSG','8827','Northing at false origin',152400.3048,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103250','NAD_1983_CORS96_StatePlane_Connecticut_FIPS_0600',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103250','EPSG','1377',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103251','unnamed',NULL,NULL,'EPSG','1377','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-72.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',41.2,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.86666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',999999.999996,'EPSG','9003','EPSG','8827','Northing at false origin',499999.999998,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103251','NAD_1983_CORS96_StatePlane_Connecticut_FIPS_0600_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103251','EPSG','1377',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103252','unnamed',NULL,NULL,'EPSG','1378','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-75.41666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999995,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103252','NAD_1983_CORS96_StatePlane_Delaware_FIPS_0700',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103252','EPSG','1378',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103253','unnamed',NULL,NULL,'EPSG','1378','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-75.41666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999995,'EPSG','9201','EPSG','8806','False easting',656166.6666666665,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103253','NAD_1983_CORS96_StatePlane_Delaware_FIPS_0700_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103253','EPSG','1378',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103254','unnamed',NULL,NULL,'EPSG','2186','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',24.33333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-81.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999411764705882,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103254','NAD_1983_CORS96_StatePlane_Florida_East_FIPS_0901',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103254','EPSG','2186',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103255','unnamed',NULL,NULL,'EPSG','2188','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',24.33333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-82.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999411764705882,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103255','NAD_1983_CORS96_StatePlane_Florida_West_FIPS_0902',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103255','EPSG','2188',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103256','unnamed',NULL,NULL,'EPSG','2187','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',29.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',29.58333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',30.75,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103256','NAD_1983_CORS96_StatePlane_Florida_North_FIPS_0903',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103256','EPSG','2187',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103257','unnamed',NULL,NULL,'EPSG','2186','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',24.33333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-81.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999411764705882,'EPSG','9201','EPSG','8806','False easting',656166.6666666665,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103257','NAD_1983_CORS96_StatePlane_Florida_East_FIPS_0901_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103257','EPSG','2186',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103258','unnamed',NULL,NULL,'EPSG','2188','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',24.33333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-82.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999411764705882,'EPSG','9201','EPSG','8806','False easting',656166.6666666665,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103258','NAD_1983_CORS96_StatePlane_Florida_West_FIPS_0902_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103258','EPSG','2188',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103259','unnamed',NULL,NULL,'EPSG','2187','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',29.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',29.58333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',30.75,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103259','NAD_1983_CORS96_StatePlane_Florida_North_FIPS_0903_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103259','EPSG','2187',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103260','unnamed',NULL,NULL,'EPSG','2189','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-82.16666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103260','NAD_1983_CORS96_StatePlane_Georgia_East_FIPS_1001',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103260','EPSG','2189',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103261','unnamed',NULL,NULL,'EPSG','2190','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-84.16666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103261','NAD_1983_CORS96_StatePlane_Georgia_West_FIPS_1002',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103261','EPSG','2190',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103262','unnamed',NULL,NULL,'EPSG','2189','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-82.16666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',656166.6666666665,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103262','NAD_1983_CORS96_StatePlane_Georgia_East_FIPS_1001_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103262','EPSG','2189',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103263','unnamed',NULL,NULL,'EPSG','2190','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',30.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-84.16666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',2296583.333333333,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103263','NAD_1983_CORS96_StatePlane_Georgia_West_FIPS_1002_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103263','EPSG','2190',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103264','unnamed',NULL,NULL,'EPSG','2192','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-112.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999473684210526,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103264','NAD_1983_CORS96_StatePlane_Idaho_East_FIPS_1101',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103264','EPSG','2192',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103265','unnamed',NULL,NULL,'EPSG','2191','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-114.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999473684210526,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103265','NAD_1983_CORS96_StatePlane_Idaho_Central_FIPS_1102',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103265','EPSG','2191',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103266','unnamed',NULL,NULL,'EPSG','2193','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-115.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999333333333333,'EPSG','9201','EPSG','8806','False easting',800000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103266','NAD_1983_CORS96_StatePlane_Idaho_West_FIPS_1103',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103266','EPSG','2193',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103267','unnamed',NULL,NULL,'EPSG','2192','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-112.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999473684210526,'EPSG','9201','EPSG','8806','False easting',656166.6666666665,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103267','NAD_1983_CORS96_StatePlane_Idaho_East_FIPS_1101_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103267','EPSG','2192',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103268','unnamed',NULL,NULL,'EPSG','2191','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-114.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999473684210526,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103268','NAD_1983_CORS96_StatePlane_Idaho_Central_FIPS_1102_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103268','EPSG','2191',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103269','unnamed',NULL,NULL,'EPSG','2193','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-115.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999333333333333,'EPSG','9201','EPSG','8806','False easting',2624666.666666666,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103269','NAD_1983_CORS96_StatePlane_Idaho_West_FIPS_1103_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103269','EPSG','2193',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103270','unnamed',NULL,NULL,'EPSG','2194','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.33333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999975,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103270','NAD_1983_CORS96_StatePlane_Illinois_East_FIPS_1201',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103270','EPSG','2194',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103271','unnamed',NULL,NULL,'EPSG','2195','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.16666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999411764705882,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103271','NAD_1983_CORS96_StatePlane_Illinois_West_FIPS_1202',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103271','EPSG','2195',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103272','unnamed',NULL,NULL,'EPSG','2194','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.33333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999975,'EPSG','9201','EPSG','8806','False easting',984250.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103272','NAD_1983_CORS96_StatePlane_Illinois_East_FIPS_1201_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103272','EPSG','2194',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103273','unnamed',NULL,NULL,'EPSG','2195','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.16666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999411764705882,'EPSG','9201','EPSG','8806','False easting',2296583.333333333,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103273','NAD_1983_CORS96_StatePlane_Illinois_West_FIPS_1202_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103273','EPSG','2195',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103274','unnamed',NULL,NULL,'EPSG','2196','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-85.66666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',250000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103274','NAD_1983_CORS96_StatePlane_Indiana_East_FIPS_1301',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103274','EPSG','2196',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103275','unnamed',NULL,NULL,'EPSG','2197','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.08333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',900000.0,'EPSG','9001','EPSG','8807','False northing',250000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103275','NAD_1983_CORS96_StatePlane_Indiana_West_FIPS_1302',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103275','EPSG','2197',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103276','unnamed',NULL,NULL,'EPSG','2196','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-85.66666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',328083.3333333333,'EPSG','9003','EPSG','8807','False northing',820208.3333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103276','NAD_1983_CORS96_StatePlane_Indiana_East_FIPS_1301_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103276','EPSG','2196',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103277','unnamed',NULL,NULL,'EPSG','2197','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',37.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.08333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',2952750.0,'EPSG','9003','EPSG','8807','False northing',820208.3333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103277','NAD_1983_CORS96_StatePlane_Indiana_West_FIPS_1302_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103277','EPSG','2197',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103278','unnamed',NULL,NULL,'EPSG','2198','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.06666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.26666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',1500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103278','NAD_1983_CORS96_StatePlane_Iowa_North_FIPS_1401',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103278','EPSG','2198',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103279','unnamed',NULL,NULL,'EPSG','2199','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.61666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103279','NAD_1983_CORS96_StatePlane_Iowa_South_FIPS_1402',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103279','EPSG','2199',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103280','unnamed',NULL,NULL,'EPSG','2198','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.06666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.26666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',4921250.0,'EPSG','9003','EPSG','8827','Northing at false origin',3280833.333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103280','NAD_1983_CORS96_StatePlane_Iowa_North_FIPS_1401_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103280','EPSG','2198',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103281','unnamed',NULL,NULL,'EPSG','2199','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.61666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103281','NAD_1983_CORS96_StatePlane_Iowa_South_FIPS_1402_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103281','EPSG','2199',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103282','unnamed',NULL,NULL,'EPSG','2200','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.71666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103282','NAD_1983_CORS96_StatePlane_Kansas_North_FIPS_1501',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103282','EPSG','2200',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103283','unnamed',NULL,NULL,'EPSG','2201','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.26666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.56666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',400000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103283','NAD_1983_CORS96_StatePlane_Kansas_South_FIPS_1502',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103283','EPSG','2201',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103284','unnamed',NULL,NULL,'EPSG','2200','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.71666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1312333.333333333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103284','NAD_1983_CORS96_StatePlane_Kansas_North_FIPS_1501_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103284','EPSG','2200',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103285','unnamed',NULL,NULL,'EPSG','2201','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.26666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.56666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',1312333.333333333,'EPSG','9003','EPSG','8827','Northing at false origin',1312333.333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103285','NAD_1983_CORS96_StatePlane_Kansas_South_FIPS_1502_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103285','EPSG','2201',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103286','unnamed',NULL,NULL,'EPSG','2202','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.25,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.96666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.96666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103286','NAD_1983_CORS96_StatePlane_Kentucky_North_FIPS_1601',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103286','EPSG','2202',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103287','unnamed',NULL,NULL,'EPSG','2202','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.25,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.96666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.96666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103287','NAD_1983_CORS96_StatePlane_Kentucky_North_FIPS_1601_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103287','EPSG','2202',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103288','unnamed',NULL,NULL,'EPSG','1386','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-85.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.08333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',1500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103288','NAD_1983_CORS96_StatePlane_Kentucky_FIPS_1600',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103288','EPSG','1386',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103289','unnamed',NULL,NULL,'EPSG','1386','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-85.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.08333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',4921250.0,'EPSG','9003','EPSG','8827','Northing at false origin',3280833.333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103289','NAD_1983_CORS96_StatePlane_Kentucky_FIPS_1600_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103289','EPSG','1386',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103290','unnamed',NULL,NULL,'EPSG','2203','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-85.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',36.73333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',37.93333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',500000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103290','NAD_1983_CORS96_StatePlane_Kentucky_South_FIPS_1602',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103290','EPSG','2203',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103291','unnamed',NULL,NULL,'EPSG','2203','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-85.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',36.73333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',37.93333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',1640416.666666667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103291','NAD_1983_CORS96_StatePlane_Kentucky_South_FIPS_1602_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103291','EPSG','2203',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103292','unnamed',NULL,NULL,'EPSG','2204','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',30.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',31.16666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',32.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103292','NAD_1983_CORS96_StatePlane_Louisiana_North_FIPS_1701',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103292','EPSG','2204',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103293','unnamed',NULL,NULL,'EPSG','2529','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',28.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.33333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',29.3,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',30.7,'EPSG','9102','EPSG','8826','Easting at false origin',1000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103293','NAD_1983_CORS96_StatePlane_Louisiana_South_FIPS_1702',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103293','EPSG','2529',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103294','unnamed',NULL,NULL,'EPSG','2204','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',30.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',31.16666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',32.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',3280833.333333333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103294','NAD_1983_CORS96_StatePlane_Louisiana_North_FIPS_1701_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103294','EPSG','2204',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103295','unnamed',NULL,NULL,'EPSG','2529','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',28.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.33333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',29.3,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',30.7,'EPSG','9102','EPSG','8826','Easting at false origin',3280833.333333333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103295','NAD_1983_CORS96_StatePlane_Louisiana_South_FIPS_1702_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103295','EPSG','2529',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103296','unnamed',NULL,NULL,'EPSG','2206','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-68.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103296','NAD_1983_CORS96_StatePlane_Maine_East_FIPS_1801',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103296','EPSG','2206',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103297','unnamed',NULL,NULL,'EPSG','2207','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-70.16666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',900000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103297','NAD_1983_CORS96_StatePlane_Maine_West_FIPS_1802',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103297','EPSG','2207',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103298','unnamed',NULL,NULL,'EPSG','2206','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.66666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-68.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',984250.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103298','NAD_1983_CORS96_StatePlane_Maine_East_FIPS_1801_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103298','EPSG','2206',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103299','unnamed',NULL,NULL,'EPSG','2207','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-70.16666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',2952750.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103299','NAD_1983_CORS96_StatePlane_Maine_West_FIPS_1802_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103299','EPSG','2207',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103300','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.36666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000365285,'EPSG','9201','EPSG','8806','False easting',147218.6942,'EPSG','9001','EPSG','8807','False northing',0.0037,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103300','NAD_1983_HARN_WISCRS_Adams_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103300','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103301','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.70611111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.62222222222222,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000495683,'EPSG','9201','EPSG','8806','False easting',172821.9461,'EPSG','9001','EPSG','8807','False northing',0.0017,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103301','NAD_1983_HARN_WISCRS_Ashland_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103301','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103302','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.13333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.85,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000486665,'EPSG','9201','EPSG','8806','False easting',93150.0,'EPSG','9001','EPSG','8807','False northing',0.0029,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103302','NAD_1983_HARN_WISCRS_Barron_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103302','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103303','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.66964837722222,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.15277777777779,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000331195,'EPSG','9201','EPSG','8806','False easting',228600.4575,'EPSG','9001','EPSG','8807','False northing',148551.4837,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103303','NAD_1983_HARN_WISCRS_Bayfield_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103303','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103304','NAD_1983_HARN_WISCRS_Brown_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','EPSG','7428','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103305','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.48138888888889,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.79722222222222,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000382778,'EPSG','9201','EPSG','8806','False easting',175260.3502,'EPSG','9001','EPSG','8807','False northing',0.0048,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103305','NAD_1983_HARN_WISCRS_Buffalo_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103305','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103306','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.89871486583333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.45777777777778,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000383841,'EPSG','9201','EPSG','8806','False easting',64008.1276,'EPSG','9001','EPSG','8807','False northing',59445.9043,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103306','NAD_1983_HARN_WISCRS_Burnett_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103306','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103307','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.71944444444445,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000286569,'EPSG','9201','EPSG','8806','False easting',244754.8893,'EPSG','9001','EPSG','8807','False northing',0.0049,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103307','NAD_1983_HARN_WISCRS_Calumet_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103307','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103308','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.97785689861112,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.29444444444444,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000391127,'EPSG','9201','EPSG','8806','False easting',60045.72,'EPSG','9001','EPSG','8807','False northing',44091.4346,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103308','NAD_1983_HARN_WISCRS_Chippewa_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103308','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103309','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.6,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.70833333333334,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000463003,'EPSG','9201','EPSG','8806','False easting',199949.1989,'EPSG','9001','EPSG','8807','False northing',0.0086,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103309','NAD_1983_HARN_WISCRS_Clark_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103309','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103310','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.46254664583333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.39444444444445,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00003498,'EPSG','9201','EPSG','8806','False easting',169164.3381,'EPSG','9001','EPSG','8807','False northing',111569.6134,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103310','NAD_1983_HARN_WISCRS_Columbia_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103310','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103311','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.200055605,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.9388888888889,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000349151,'EPSG','9201','EPSG','8806','False easting',113690.6274,'EPSG','9001','EPSG','8807','False northing',53703.1201,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103311','NAD_1983_HARN_WISCRS_Crawford_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103311','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103312','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.0695160375,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.42222222222223,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000384786,'EPSG','9201','EPSG','8806','False easting',247193.2944,'EPSG','9001','EPSG','8807','False northing',146591.9896,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103312','NAD_1983_HARN_WISCRS_Dane_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103312','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103313','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.47222222222222,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.775,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000346418,'EPSG','9201','EPSG','8806','False easting',263347.7263,'EPSG','9001','EPSG','8807','False northing',0.0076,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103313','NAD_1983_HARN_WISCRS_Dodge_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103313','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103314','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.4,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.27222222222223,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000187521,'EPSG','9201','EPSG','8806','False easting',158801.1176,'EPSG','9001','EPSG','8807','False northing',0.0023,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103314','NAD_1983_HARN_WISCRS_Door_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103314','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103315','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.88333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.91666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000385418,'EPSG','9201','EPSG','8806','False easting',59131.3183,'EPSG','9001','EPSG','8807','False northing',0.0041,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103315','NAD_1983_HARN_WISCRS_Douglas_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103315','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103316','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.40833333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.89444444444445,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000410324,'EPSG','9201','EPSG','8806','False easting',51816.104,'EPSG','9001','EPSG','8807','False northing',0.003,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103316','NAD_1983_HARN_WISCRS_Dunn_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103316','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103317','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.87228112638889,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.28888888888889,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000035079,'EPSG','9201','EPSG','8806','False easting',120091.4402,'EPSG','9001','EPSG','8807','False northing',91687.9239,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103317','NAD_1983_HARN_WISCRS_EauClaire_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103317','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103318','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.43888888888888,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.14166666666668,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000552095,'EPSG','9201','EPSG','8806','False easting',133502.6683,'EPSG','9001','EPSG','8807','False northing',0.0063,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103318','NAD_1983_HARN_WISCRS_Florence_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103318','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103319','NAD_1983_HARN_WISCRS_Fond_du_Lac_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103307','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103320','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.00555555555555,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.63333333333334,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000673004,'EPSG','9201','EPSG','8806','False easting',275844.5533,'EPSG','9001','EPSG','8807','False northing',0.0157,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103320','NAD_1983_HARN_WISCRS_Forest_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103320','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103321','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.41111111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.8,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000349452,'EPSG','9201','EPSG','8806','False easting',242316.4841,'EPSG','9001','EPSG','8807','False northing',0.01,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103321','NAD_1983_HARN_WISCRS_Grant_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103321','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103322','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',42.63756227694444,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.83888888888889,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000390487,'EPSG','9201','EPSG','8806','False easting',170078.7403,'EPSG','9001','EPSG','8807','False northing',45830.2947,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103322','NAD_1983_HARN_WISCRS_Green_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103322','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103323','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.80700011777778,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.24166666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000344057,'EPSG','9201','EPSG','8806','False easting',150876.3018,'EPSG','9001','EPSG','8807','False northing',79170.7795,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103323','NAD_1983_HARN_WISCRS_GreenLake_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103323','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103324','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.53888888888888,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.16111111111111,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000394961,'EPSG','9201','EPSG','8806','False easting',113081.0261,'EPSG','9001','EPSG','8807','False northing',0.0045,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103324','NAD_1983_HARN_WISCRS_Iowa_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103324','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103325','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.43333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.25555555555556,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000677153,'EPSG','9201','EPSG','8806','False easting',220980.4419,'EPSG','9001','EPSG','8807','False northing',0.0085,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103325','NAD_1983_HARN_WISCRS_Iron_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103325','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103326','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.25333512777778,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.84429651944444,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000353,'EPSG','9201','EPSG','8806','False easting',27000.0,'EPSG','9001','EPSG','8807','False northing',25000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103326','NAD_1983_HARN_WISCRS_Jackson_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103326','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103327','NAD_1983_HARN_WISCRS_Jefferson_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103313','EPSG','1418',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103328','NAD_1983_HARN_WISCRS_Juneau_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103300','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103329','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.21666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.89444444444445,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000260649,'EPSG','9201','EPSG','8806','False easting',185928.3728,'EPSG','9001','EPSG','8807','False northing',0.0009,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103329','NAD_1983_HARN_WISCRS_Kenosha_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103329','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103330','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.26666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.55,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000233704,'EPSG','9201','EPSG','8806','False easting',79857.7614,'EPSG','9001','EPSG','8807','False northing',0.0012,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103330','NAD_1983_HARN_WISCRS_Kewaunee_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103330','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103331','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.45111111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.31666666666666,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000319985,'EPSG','9201','EPSG','8806','False easting',130454.6598,'EPSG','9001','EPSG','8807','False northing',0.0033,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103331','NAD_1983_HARN_WISCRS_LaCrosse_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103331','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103332','NAD_1983_HARN_WISCRS_Lafayette_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103322','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103333','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.15423710527778,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.03333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000627024,'EPSG','9201','EPSG','8806','False easting',198425.197,'EPSG','9001','EPSG','8807','False northing',105279.7829,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103333','NAD_1983_HARN_WISCRS_Langlade_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103333','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103334','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.84444444444445,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.73333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000599003,'EPSG','9201','EPSG','8806','False easting',116129.0323,'EPSG','9001','EPSG','8807','False northing',0.0058,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103334','NAD_1983_HARN_WISCRS_Lincoln_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103334','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103335','NAD_1983_HARN_WISCRS_Manitowoc_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103330','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103336','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.90090442361111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.77,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000053289,'EPSG','9201','EPSG','8806','False easting',74676.1493,'EPSG','9001','EPSG','8807','False northing',55049.2669,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103336','NAD_1983_HARN_WISCRS_Marathon_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103336','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103337','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.69166666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.71111111111111,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000234982,'EPSG','9201','EPSG','8806','False easting',238658.8794,'EPSG','9001','EPSG','8807','False northing',0.0032,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103337','NAD_1983_HARN_WISCRS_Marinette_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103337','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103338','NAD_1983_HARN_WISCRS_Marquette_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103323','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103339','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.71666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.41666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000362499,'EPSG','9201','EPSG','8806','False easting',105461.0121,'EPSG','9001','EPSG','8807','False northing',0.0029,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103339','NAD_1983_HARN_WISCRS_Menominee_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103339','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103340','NAD_1983_HARN_WISCRS_Milwaukee_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103329','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103341','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.00007392861111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.64166666666668,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000434122,'EPSG','9201','EPSG','8806','False easting',204521.209,'EPSG','9001','EPSG','8807','False northing',121923.9861,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103341','NAD_1983_HARN_WISCRS_Monroe_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103341','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103342','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.39722222222222,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.90833333333335,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000236869,'EPSG','9201','EPSG','8806','False easting',182880.3676,'EPSG','9001','EPSG','8807','False northing',0.0033,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103342','NAD_1983_HARN_WISCRS_Oconto_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103342','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103343','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.70422377027778,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.54444444444444,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000686968,'EPSG','9201','EPSG','8806','False easting',70104.1401,'EPSG','9001','EPSG','8807','False northing',57588.0346,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103343','NAD_1983_HARN_WISCRS_Oneida_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103343','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103344','NAD_1983_HARN_WISCRS_Outagamie_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103307','EPSG','1418',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103345','NAD_1983_HARN_WISCRS_Ozaukee_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103329','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103346','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.63614887194444,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.22777777777777,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000362977,'EPSG','9201','EPSG','8806','False easting',167640.3354,'EPSG','9001','EPSG','8807','False northing',86033.0876,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103346','NAD_1983_HARN_WISCRS_Pepin_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103346','EPSG','1418',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103347','NAD_1983_HARN_WISCRS_Pierce_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103346','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103348','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.66111111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.63333333333334,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000433849,'EPSG','9201','EPSG','8806','False easting',141732.2823,'EPSG','9001','EPSG','8807','False northing',0.0059,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103348','NAD_1983_HARN_WISCRS_Polk_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103348','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103349','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.41682397527777,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000039936,'EPSG','9201','EPSG','8806','False easting',56388.1128,'EPSG','9001','EPSG','8807','False northing',50022.1874,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103349','NAD_1983_HARN_WISCRS_Portage_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103349','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103350','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.55555555555555,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.48888888888889,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000649554,'EPSG','9201','EPSG','8806','False easting',227990.8546,'EPSG','9001','EPSG','8807','False northing',0.0109,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103350','NAD_1983_HARN_WISCRS_Price_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103350','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103351','NAD_1983_HARN_WISCRS_Racine_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103329','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103352','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.3223129275,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.43055555555556,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000375653,'EPSG','9201','EPSG','8806','False easting',202387.6048,'EPSG','9001','EPSG','8807','False northing',134255.4253,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103352','NAD_1983_HARN_WISCRS_Richland_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103352','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103353','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.94444444444444,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.07222222222222,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000337311,'EPSG','9201','EPSG','8806','False easting',146304.2926,'EPSG','9001','EPSG','8807','False northing',0.0068,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103353','NAD_1983_HARN_WISCRS_Rock_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103353','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103354','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.91944444444444,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.06666666666666,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000495976,'EPSG','9201','EPSG','8806','False easting',250546.1013,'EPSG','9001','EPSG','8807','False northing',0.0234,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103354','NAD_1983_HARN_WISCRS_Rusk_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103354','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103355','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.81944444444445,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.9,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000373868,'EPSG','9201','EPSG','8806','False easting',185623.5716,'EPSG','9001','EPSG','8807','False northing',0.0051,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103355','NAD_1983_HARN_WISCRS_Sauk_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103355','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103356','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.90009913138888,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.11666666666666,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000573461,'EPSG','9201','EPSG','8806','False easting',216713.2336,'EPSG','9001','EPSG','8807','False northing',120734.1631,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103356','NAD_1983_HARN_WISCRS_Sawyer_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103356','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103357','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.03611111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.60555555555555,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000032144,'EPSG','9201','EPSG','8806','False easting',262433.3253,'EPSG','9001','EPSG','8807','False northing',0.0096,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103357','NAD_1983_HARN_WISCRS_Shawano_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103357','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103358','NAD_1983_HARN_WISCRS_Sheboygan_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103330','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103359','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.03611111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.63333333333334,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000381803,'EPSG','9201','EPSG','8806','False easting',165506.7302,'EPSG','9001','EPSG','8807','False northing',0.0103,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103359','NAD_1983_HARN_WISCRS_St_Croix_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103359','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103360','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.17782208583333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.48333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000597566,'EPSG','9201','EPSG','8806','False easting',187147.5744,'EPSG','9001','EPSG','8807','False northing',107746.7522,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103360','NAD_1983_HARN_WISCRS_Taylor_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103360','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103361','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.16111111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.36666666666666,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000361538,'EPSG','9201','EPSG','8806','False easting',256946.9138,'EPSG','9001','EPSG','8807','False northing',0.0041,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103361','NAD_1983_HARN_WISCRS_Trempealeau_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103361','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103362','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.57503293972223,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.78333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000408158,'EPSG','9201','EPSG','8806','False easting',222504.4451,'EPSG','9001','EPSG','8807','False northing',47532.0602,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103362','NAD_1983_HARN_WISCRS_Vernon_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103362','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103363','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.07784409055556,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.48888888888889,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000730142,'EPSG','9201','EPSG','8806','False easting',134417.0689,'EPSG','9001','EPSG','8807','False northing',50337.1092,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103363','NAD_1983_HARN_WISCRS_Vilas_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103363','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103364','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',42.66946209694444,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.54166666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000367192,'EPSG','9201','EPSG','8806','False easting',232562.8651,'EPSG','9001','EPSG','8807','False northing',111088.2224,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103364','NAD_1983_HARN_WISCRS_Walworth_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103364','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103365','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.96121983333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.78333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000475376,'EPSG','9201','EPSG','8806','False easting',234086.8682,'EPSG','9001','EPSG','8807','False northing',188358.6058,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103365','NAD_1983_HARN_WISCRS_Washburn_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103365','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103366','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.91805555555555,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.06388888888888,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00003738,'EPSG','9201','EPSG','8806','False easting',120091.4415,'EPSG','9001','EPSG','8807','False northing',0.003,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103366','NAD_1983_HARN_WISCRS_Washington_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103366','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103367','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.56944444444445,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.225,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000346179,'EPSG','9201','EPSG','8806','False easting',208788.418,'EPSG','9001','EPSG','8807','False northing',0.0034,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103367','NAD_1983_HARN_WISCRS_Waukesha_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103367','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103368','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.42027777777778,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.81666666666666,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000333645,'EPSG','9201','EPSG','8806','False easting',185013.9709,'EPSG','9001','EPSG','8807','False northing',0.007,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103368','NAD_1983_HARN_WISCRS_Waupaca_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103368','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103369','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.11394404583334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.24166666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000392096,'EPSG','9201','EPSG','8806','False easting',120091.4402,'EPSG','9001','EPSG','8807','False northing',45069.7587,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103369','NAD_1983_HARN_WISCRS_Waushara_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103369','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103370','NAD_1983_HARN_WISCRS_Winnebago_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103307','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103371','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.36259546944444,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000421209,'EPSG','9201','EPSG','8806','False easting',208483.6173,'EPSG','9001','EPSG','8807','False northing',134589.754,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103371','NAD_1983_HARN_WISCRS_Wood_County_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103371','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103372','unnamed',NULL,NULL,'EPSG','2960','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-67.875,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99998,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103372','NAD_1983_CORS96_Maine_2000_East_Zone',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103372','EPSG','2960',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103373','unnamed',NULL,NULL,'EPSG','2959','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-69.125,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99998,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103373','NAD_1983_CORS96_Maine_2000_Central_Zone',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103373','EPSG','2959',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103374','unnamed',NULL,NULL,'EPSG','2958','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-70.375,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99998,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103374','NAD_1983_CORS96_Maine_2000_West_Zone',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103374','EPSG','2958',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103375','unnamed',NULL,NULL,'EPSG','1389','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-77.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.3,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.45,'EPSG','9102','EPSG','8826','Easting at false origin',400000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103375','NAD_1983_CORS96_StatePlane_Maryland_FIPS_1900',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103375','EPSG','1389',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103376','unnamed',NULL,NULL,'EPSG','1389','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-77.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.3,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.45,'EPSG','9102','EPSG','8826','Easting at false origin',1312333.333333333,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103376','NAD_1983_CORS96_StatePlane_Maryland_FIPS_1900_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103376','EPSG','1389',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103377','unnamed',NULL,NULL,'EPSG','2209','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-71.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',41.71666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',42.68333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',200000.0,'EPSG','9001','EPSG','8827','Northing at false origin',750000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103377','NAD_1983_CORS96_StatePlane_Massachusetts_Mainland_FIPS_2001',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103377','EPSG','2209',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103378','unnamed',NULL,NULL,'EPSG','2208','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-70.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',41.28333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.48333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103378','NAD_1983_CORS96_StatePlane_Massachusetts_Island_FIPS_2002',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103378','EPSG','2208',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103379','unnamed',NULL,NULL,'EPSG','2209','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-71.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',41.71666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',42.68333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',656166.6666666665,'EPSG','9003','EPSG','8827','Northing at false origin',2460625.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103379','NAD_1983_CORS96_StatePlane_Massachusetts_Mnld_FIPS_2001_FtUS',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103379','EPSG','2209',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103380','unnamed',NULL,NULL,'EPSG','2208','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-70.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',41.28333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.48333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103380','NAD_1983_CORS96_StatePlane_Massachusetts_Isl_FIPS_2002_FtUS',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103380','EPSG','2208',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103381','unnamed',NULL,NULL,'EPSG','1723','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.78333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-87.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.48333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.08333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',8000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103381','NAD_1983_CORS96_StatePlane_Michigan_North_FIPS_2111',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103381','EPSG','1723',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103382','unnamed',NULL,NULL,'EPSG','1724','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.31666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.36666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.18333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.7,'EPSG','9102','EPSG','8826','Easting at false origin',6000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103382','NAD_1983_CORS96_StatePlane_Michigan_Central_FIPS_2112',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103382','EPSG','1724',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103383','unnamed',NULL,NULL,'EPSG','1725','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.36666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.1,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',4000000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103383','NAD_1983_CORS96_StatePlane_Michigan_South_FIPS_2113',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103383','EPSG','1725',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103384','unnamed',NULL,NULL,'EPSG','1723','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.78333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-87.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.48333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.08333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',26246719.16010498,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103384','NAD_1983_CORS96_StatePlane_Michigan_North_FIPS_2111_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','103384','EPSG','1723',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103385','unnamed',NULL,NULL,'EPSG','1724','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.31666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.36666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.18333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.7,'EPSG','9102','EPSG','8826','Easting at false origin',19685039.37007874,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103385','NAD_1983_CORS96_StatePlane_Michigan_Central_FIPS_2112_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','103385','EPSG','1724',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103386','unnamed',NULL,NULL,'EPSG','1725','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-84.36666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.1,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',13123359.58005249,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103386','NAD_1983_CORS96_StatePlane_Michigan_South_FIPS_2113_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','103386','EPSG','1725',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103387','unnamed',NULL,NULL,'EPSG','2214','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.1,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.63333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',800000.0,'EPSG','9001','EPSG','8827','Northing at false origin',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103387','NAD_1983_CORS96_StatePlane_Minnesota_North_FIPS_2201',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103387','EPSG','2214',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103388','unnamed',NULL,NULL,'EPSG','2213','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.25,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.61666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.05,'EPSG','9102','EPSG','8826','Easting at false origin',800000.0,'EPSG','9001','EPSG','8827','Northing at false origin',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103388','NAD_1983_CORS96_StatePlane_Minnesota_Central_FIPS_2202',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103388','EPSG','2213',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103389','unnamed',NULL,NULL,'EPSG','2215','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.78333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.21666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',800000.0,'EPSG','9001','EPSG','8827','Northing at false origin',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103389','NAD_1983_CORS96_StatePlane_Minnesota_South_FIPS_2203',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103389','EPSG','2215',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103390','unnamed',NULL,NULL,'EPSG','2214','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.1,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.63333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',2624666.666666666,'EPSG','9003','EPSG','8827','Northing at false origin',328083.3333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103390','NAD_1983_CORS96_StatePlane_Minnesota_North_FIPS_2201_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103390','EPSG','2214',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103391','unnamed',NULL,NULL,'EPSG','2213','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.25,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.61666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.05,'EPSG','9102','EPSG','8826','Easting at false origin',2624666.666666666,'EPSG','9003','EPSG','8827','Northing at false origin',328083.3333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103391','NAD_1983_CORS96_StatePlane_Minnesota_Central_FIPS_2202_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103391','EPSG','2213',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103392','unnamed',NULL,NULL,'EPSG','2215','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.78333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.21666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',2624666.666666666,'EPSG','9003','EPSG','8827','Northing at false origin',328083.3333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103392','NAD_1983_CORS96_StatePlane_Minnesota_South_FIPS_2203_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103392','EPSG','2215',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103393','unnamed',NULL,NULL,'EPSG','2216','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',29.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.83333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103393','NAD_1983_CORS96_StatePlane_Mississippi_East_FIPS_2301',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103393','EPSG','2216',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103394','unnamed',NULL,NULL,'EPSG','2217','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',29.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.33333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',700000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103394','NAD_1983_CORS96_StatePlane_Mississippi_West_FIPS_2302',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103394','EPSG','2217',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103395','unnamed',NULL,NULL,'EPSG','2216','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',29.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.83333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',984250.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103395','NAD_1983_CORS96_StatePlane_Mississippi_East_FIPS_2301_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103395','EPSG','2216',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103396','unnamed',NULL,NULL,'EPSG','2217','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',29.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.33333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99995,'EPSG','9201','EPSG','8806','False easting',2296583.333333333,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103396','NAD_1983_CORS96_StatePlane_Mississippi_West_FIPS_2302_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103396','EPSG','2217',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103397','unnamed',NULL,NULL,'EPSG','2219','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',35.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999333333333333,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103397','NAD_1983_CORS96_StatePlane_Missouri_East_FIPS_2401',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103397','EPSG','2219',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103398','unnamed',NULL,NULL,'EPSG','2218','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',35.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999333333333333,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103398','NAD_1983_CORS96_StatePlane_Missouri_Central_FIPS_2402',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103398','EPSG','2218',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103399','unnamed',NULL,NULL,'EPSG','2220','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',36.16666666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-94.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999411764705882,'EPSG','9201','EPSG','8806','False easting',850000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103399','NAD_1983_CORS96_StatePlane_Missouri_West_FIPS_2403',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103399','EPSG','2220',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103400','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.36666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000365285,'EPSG','9201','EPSG','8806','False easting',482999.999,'EPSG','9003','EPSG','8807','False northing',0.012,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103400','NAD_1983_HARN_WISCRS_Adams_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103400','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103401','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.70611111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.62222222222222,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000495683,'EPSG','9201','EPSG','8806','False easting',567000.001,'EPSG','9003','EPSG','8807','False northing',0.006,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103401','NAD_1983_HARN_WISCRS_Ashland_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103401','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103402','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.13333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.85,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000486665,'EPSG','9201','EPSG','8806','False easting',305609.625,'EPSG','9003','EPSG','8807','False northing',0.01,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103402','NAD_1983_HARN_WISCRS_Barron_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103402','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103403','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.66964837722222,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.15277777777779,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000331195,'EPSG','9201','EPSG','8806','False easting',750000.001,'EPSG','9003','EPSG','8807','False northing',487372.659,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103403','NAD_1983_HARN_WISCRS_Bayfield_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103403','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103404','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00002,'EPSG','9201','EPSG','8806','False easting',103674.333,'EPSG','9003','EPSG','8807','False northing',15091.833,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103404','NAD_1983_HARN_WISCRS_Brown_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103404','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103405','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.48138888888889,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.79722222222222,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000382778,'EPSG','9201','EPSG','8806','False easting',574999.999,'EPSG','9003','EPSG','8807','False northing',0.016,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103405','NAD_1983_HARN_WISCRS_Buffalo_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103405','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103406','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.89871486583333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.45777777777778,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000383841,'EPSG','9201','EPSG','8806','False easting',209999.999,'EPSG','9003','EPSG','8807','False northing',195032.104,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103406','NAD_1983_HARN_WISCRS_Burnett_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103406','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103407','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.71944444444445,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000286569,'EPSG','9201','EPSG','8806','False easting',802999.999,'EPSG','9003','EPSG','8807','False northing',0.016,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103407','NAD_1983_HARN_WISCRS_Calumet_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103407','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103408','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.97785689861112,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.29444444444444,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000391127,'EPSG','9201','EPSG','8806','False easting',197000.0,'EPSG','9003','EPSG','8807','False northing',144656.648,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103408','NAD_1983_HARN_WISCRS_Chippewa_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103408','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103409','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.6,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.70833333333334,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000463003,'EPSG','9201','EPSG','8806','False easting',655999.997,'EPSG','9003','EPSG','8807','False northing',0.028,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103409','NAD_1983_HARN_WISCRS_Clark_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103409','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103410','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.46254664583333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.39444444444445,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00003498,'EPSG','9201','EPSG','8806','False easting',554999.999,'EPSG','9003','EPSG','8807','False northing',366041.307,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103410','NAD_1983_HARN_WISCRS_Columbia_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103410','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103411','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.200055605,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.9388888888889,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000349151,'EPSG','9201','EPSG','8806','False easting',373000.0,'EPSG','9003','EPSG','8807','False northing',176190.987,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103411','NAD_1983_HARN_WISCRS_Crawford_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103411','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103412','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.0695160375,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.42222222222223,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000384786,'EPSG','9201','EPSG','8806','False easting',811000.0,'EPSG','9003','EPSG','8807','False northing',480943.886,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103412','NAD_1983_HARN_WISCRS_Dane_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103412','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103413','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.47222222222222,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.775,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000346418,'EPSG','9201','EPSG','8806','False easting',863999.999,'EPSG','9003','EPSG','8807','False northing',0.025,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103413','NAD_1983_HARN_WISCRS_Dodge_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103413','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103414','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.4,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.27222222222223,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000187521,'EPSG','9201','EPSG','8806','False easting',521000.0,'EPSG','9003','EPSG','8807','False northing',0.008,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103414','NAD_1983_HARN_WISCRS_Door_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103414','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103415','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.88333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.91666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000385418,'EPSG','9201','EPSG','8806','False easting',194000.0,'EPSG','9003','EPSG','8807','False northing',0.013,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103415','NAD_1983_HARN_WISCRS_Douglas_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103415','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103416','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.40833333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.89444444444445,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000410324,'EPSG','9201','EPSG','8806','False easting',170000.001,'EPSG','9003','EPSG','8807','False northing',0.01,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103416','NAD_1983_HARN_WISCRS_Dunn_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103416','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103417','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.87228112638889,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.28888888888889,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000035079,'EPSG','9201','EPSG','8806','False easting',394000.0,'EPSG','9003','EPSG','8807','False northing',300812.797,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103417','NAD_1983_HARN_WISCRS_EauClaire_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103417','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103418','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.43888888888888,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.14166666666668,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000552095,'EPSG','9201','EPSG','8806','False easting',438000.004,'EPSG','9003','EPSG','8807','False northing',0.021,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103418','NAD_1983_HARN_WISCRS_Florence_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103418','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103419','NAD_1983_HARN_WISCRS_Fond_du_Lac_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103407','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103420','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.00555555555555,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.63333333333334,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000673004,'EPSG','9201','EPSG','8806','False easting',905000.005,'EPSG','9003','EPSG','8807','False northing',0.052,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103420','NAD_1983_HARN_WISCRS_Forest_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103420','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103421','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.41111111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.8,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000349452,'EPSG','9201','EPSG','8806','False easting',794999.998,'EPSG','9003','EPSG','8807','False northing',0.033,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103421','NAD_1983_HARN_WISCRS_Grant_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103421','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103422','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',42.63756227694444,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.83888888888889,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000390487,'EPSG','9201','EPSG','8806','False easting',558000.0,'EPSG','9003','EPSG','8807','False northing',150361.559,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103422','NAD_1983_HARN_WISCRS_Green_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103422','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103423','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.80700011777778,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.24166666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000344057,'EPSG','9201','EPSG','8806','False easting',495000.0,'EPSG','9003','EPSG','8807','False northing',259746.132,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103423','NAD_1983_HARN_WISCRS_GreenLake_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103423','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103424','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.53888888888888,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.16111111111111,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000394961,'EPSG','9201','EPSG','8806','False easting',371000.0,'EPSG','9003','EPSG','8807','False northing',0.015,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103424','NAD_1983_HARN_WISCRS_Iowa_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103424','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103425','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.43333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.25555555555556,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000677153,'EPSG','9201','EPSG','8806','False easting',725000.0,'EPSG','9003','EPSG','8807','False northing',0.028,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103425','NAD_1983_HARN_WISCRS_Iron_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103425','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103426','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.25333512777778,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.84429651944444,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000353,'EPSG','9201','EPSG','8806','False easting',88582.5,'EPSG','9003','EPSG','8807','False northing',82020.833,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103426','NAD_1983_HARN_WISCRS_Jackson_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103426','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103427','NAD_1983_HARN_WISCRS_Jefferson_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103413','EPSG','1418',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103428','NAD_1983_HARN_WISCRS_Juneau_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103400','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103429','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.21666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.89444444444445,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000260649,'EPSG','9201','EPSG','8806','False easting',610000.003,'EPSG','9003','EPSG','8807','False northing',0.003,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103429','NAD_1983_HARN_WISCRS_Kenosha_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103429','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103430','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.26666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.55,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000233704,'EPSG','9201','EPSG','8806','False easting',262000.006,'EPSG','9003','EPSG','8807','False northing',0.004,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103430','NAD_1983_HARN_WISCRS_Kewaunee_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103430','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103431','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.45111111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.31666666666666,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000319985,'EPSG','9201','EPSG','8806','False easting',427999.996,'EPSG','9003','EPSG','8807','False northing',0.011,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103431','NAD_1983_HARN_WISCRS_LaCrosse_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103431','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103432','NAD_1983_HARN_WISCRS_Lafayette_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103422','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103433','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.15423710527778,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.03333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000627024,'EPSG','9201','EPSG','8806','False easting',651000.0,'EPSG','9003','EPSG','8807','False northing',345405.421,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103433','NAD_1983_HARN_WISCRS_Langlade_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103433','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103434','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.84444444444445,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.73333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000599003,'EPSG','9201','EPSG','8806','False easting',381000.0,'EPSG','9003','EPSG','8807','False northing',0.019,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103434','NAD_1983_HARN_WISCRS_Lincoln_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103434','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103435','NAD_1983_HARN_WISCRS_Manitowoc_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103430','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103436','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.90090442361111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.77,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000053289,'EPSG','9201','EPSG','8806','False easting',245000.0,'EPSG','9003','EPSG','8807','False northing',180607.47,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103436','NAD_1983_HARN_WISCRS_Marathon_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103436','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103437','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.69166666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.71111111111111,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000234982,'EPSG','9201','EPSG','8806','False easting',783000.007,'EPSG','9003','EPSG','8807','False northing',0.01,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103437','NAD_1983_HARN_WISCRS_Marinette_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103437','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103438','NAD_1983_HARN_WISCRS_Marquette_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103423','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103439','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.71666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.41666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000362499,'EPSG','9201','EPSG','8806','False easting',346000.004,'EPSG','9003','EPSG','8807','False northing',0.01,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103439','NAD_1983_HARN_WISCRS_Menominee_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103439','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103440','NAD_1983_HARN_WISCRS_Milwaukee_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103429','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103441','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.00007392861111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.64166666666668,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000434122,'EPSG','9201','EPSG','8806','False easting',671000.0,'EPSG','9003','EPSG','8807','False northing',400012.278,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103441','NAD_1983_HARN_WISCRS_Monroe_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103441','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103442','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.39722222222222,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.90833333333335,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000236869,'EPSG','9201','EPSG','8806','False easting',600000.006,'EPSG','9003','EPSG','8807','False northing',0.011,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103442','NAD_1983_HARN_WISCRS_Oconto_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103442','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103443','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.70422377027778,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.54444444444444,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000686968,'EPSG','9201','EPSG','8806','False easting',230000.0,'EPSG','9003','EPSG','8807','False northing',188936.744,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103443','NAD_1983_HARN_WISCRS_Oneida_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103443','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103444','NAD_1983_HARN_WISCRS_Outagamie_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103407','EPSG','1418',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103445','NAD_1983_HARN_WISCRS_Ozaukee_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103429','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103446','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.63614887194444,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.22777777777777,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000362977,'EPSG','9201','EPSG','8806','False easting',550000.0,'EPSG','9003','EPSG','8807','False northing',282260.222,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103446','NAD_1983_HARN_WISCRS_Pepin_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103446','EPSG','1418',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103447','NAD_1983_HARN_WISCRS_Pierce_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103446','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103448','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.66111111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.63333333333334,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000433849,'EPSG','9201','EPSG','8806','False easting',464999.996,'EPSG','9003','EPSG','8807','False northing',0.019,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103448','NAD_1983_HARN_WISCRS_Polk_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103448','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103449','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.41682397527777,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000039936,'EPSG','9201','EPSG','8806','False easting',185000.0,'EPSG','9003','EPSG','8807','False northing',164114.46,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103449','NAD_1983_HARN_WISCRS_Portage_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103449','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103450','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.55555555555555,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.48888888888889,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000649554,'EPSG','9201','EPSG','8806','False easting',747999.995,'EPSG','9003','EPSG','8807','False northing',0.036,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103450','NAD_1983_HARN_WISCRS_Price_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103450','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103451','NAD_1983_HARN_WISCRS_Racine_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103429','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103452','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.3223129275,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.43055555555556,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000375653,'EPSG','9201','EPSG','8806','False easting',664000.0,'EPSG','9003','EPSG','8807','False northing',440469.675,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103452','NAD_1983_HARN_WISCRS_Richland_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103452','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103453','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.94444444444444,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.07222222222222,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000337311,'EPSG','9201','EPSG','8806','False easting',480000.0,'EPSG','9003','EPSG','8807','False northing',0.022,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103453','NAD_1983_HARN_WISCRS_Rock_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103453','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103454','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.91944444444444,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.06666666666666,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000495976,'EPSG','9201','EPSG','8806','False easting',822000.001,'EPSG','9003','EPSG','8807','False northing',0.077,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103454','NAD_1983_HARN_WISCRS_Rusk_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103454','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103455','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.81944444444445,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.9,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000373868,'EPSG','9201','EPSG','8806','False easting',609000.001,'EPSG','9003','EPSG','8807','False northing',0.017,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103455','NAD_1983_HARN_WISCRS_Sauk_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103455','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103456','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.90009913138888,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.11666666666666,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000573461,'EPSG','9201','EPSG','8806','False easting',711000.001,'EPSG','9003','EPSG','8807','False northing',396108.667,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103456','NAD_1983_HARN_WISCRS_Sawyer_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103456','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103457','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.03611111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.60555555555555,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000032144,'EPSG','9201','EPSG','8806','False easting',861000.001,'EPSG','9003','EPSG','8807','False northing',0.031,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103457','NAD_1983_HARN_WISCRS_Shawano_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103457','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103458','NAD_1983_HARN_WISCRS_Sheboygan_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103430','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103459','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.03611111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.63333333333334,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000381803,'EPSG','9201','EPSG','8806','False easting',542999.997,'EPSG','9003','EPSG','8807','False northing',0.034,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103459','NAD_1983_HARN_WISCRS_St_Croix_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103459','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103460','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.17782208583333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.48333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000597566,'EPSG','9201','EPSG','8806','False easting',614000.0,'EPSG','9003','EPSG','8807','False northing',353499.136,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103460','NAD_1983_HARN_WISCRS_Taylor_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103460','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103461','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.16111111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.36666666666666,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000361538,'EPSG','9201','EPSG','8806','False easting',843000.0,'EPSG','9003','EPSG','8807','False northing',0.013,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103461','NAD_1983_HARN_WISCRS_Trempealeau_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103461','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103462','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',43.57503293972223,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.78333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000408158,'EPSG','9201','EPSG','8806','False easting',730000.0,'EPSG','9003','EPSG','8807','False northing',155944.768,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103462','NAD_1983_HARN_WISCRS_Vernon_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103462','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103463','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',46.07784409055556,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.48888888888889,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000730142,'EPSG','9201','EPSG','8806','False easting',441000.0,'EPSG','9003','EPSG','8807','False northing',165147.666,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103463','NAD_1983_HARN_WISCRS_Vilas_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103463','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103464','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',42.66946209694444,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.54166666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000367192,'EPSG','9201','EPSG','8806','False easting',763000.0,'EPSG','9003','EPSG','8807','False northing',364461.943,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103464','NAD_1983_HARN_WISCRS_Walworth_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103464','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103465','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',45.96121983333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.78333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000475376,'EPSG','9201','EPSG','8806','False easting',768000.0,'EPSG','9003','EPSG','8807','False northing',617973.193,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103465','NAD_1983_HARN_WISCRS_Washburn_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103465','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103466','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.91805555555555,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.06388888888888,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00003738,'EPSG','9201','EPSG','8806','False easting',394000.004,'EPSG','9003','EPSG','8807','False northing',0.01,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103466','NAD_1983_HARN_WISCRS_Washington_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103466','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103467','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.56944444444445,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.225,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000346179,'EPSG','9201','EPSG','8806','False easting',685000.001,'EPSG','9003','EPSG','8807','False northing',0.011,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103467','NAD_1983_HARN_WISCRS_Waukesha_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103467','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103468','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.42027777777778,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.81666666666666,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000333645,'EPSG','9201','EPSG','8806','False easting',607000.003,'EPSG','9003','EPSG','8807','False northing',0.023,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103468','NAD_1983_HARN_WISCRS_Waupaca_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103468','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103469','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.11394404583334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.24166666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000392096,'EPSG','9201','EPSG','8806','False easting',394000.0,'EPSG','9003','EPSG','8807','False northing',147866.367,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103469','NAD_1983_HARN_WISCRS_Waushara_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103469','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103470','NAD_1983_HARN_WISCRS_Winnebago_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103407','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103471','unnamed',NULL,NULL,'EPSG','1418','EPSG','9801','Lambert Conic Conformal (1SP)','EPSG','8801','Latitude of natural origin',44.36259546944444,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0000421209,'EPSG','9201','EPSG','8806','False easting',684000.001,'EPSG','9003','EPSG','8807','False northing',441566.551,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103471','NAD_1983_HARN_WISCRS_Wood_County_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103471','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103472','unnamed',NULL,NULL,'EPSG','1395','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.25,'EPSG','9102','EPSG','8822','Longitude of false origin',-109.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',49.0,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103472','NAD_1983_CORS96_StatePlane_Montana_FIPS_2500',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103472','EPSG','1395',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103473','unnamed',NULL,NULL,'EPSG','1395','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.25,'EPSG','9102','EPSG','8822','Longitude of false origin',-109.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',49.0,'EPSG','9102','EPSG','8826','Easting at false origin',1968503.937007874,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103473','NAD_1983_CORS96_StatePlane_Montana_FIPS_2500_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','103473','EPSG','1395',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103474','unnamed',NULL,NULL,'EPSG','1396','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.0,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103474','NAD_1983_CORS96_StatePlane_Nebraska_FIPS_2600',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103474','EPSG','1396',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103475','unnamed',NULL,NULL,'EPSG','1396','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.0,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103475','NAD_1983_CORS96_StatePlane_Nebraska_FIPS_2600_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103475','EPSG','1396',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103476','unnamed',NULL,NULL,'EPSG','2224','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-115.5833333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',8000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103476','NAD_1983_CORS96_StatePlane_Nevada_East_FIPS_2701',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103476','EPSG','2224',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103477','unnamed',NULL,NULL,'EPSG','2223','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-116.6666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',6000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103477','NAD_1983_CORS96_StatePlane_Nevada_Central_FIPS_2702',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103477','EPSG','2223',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103478','unnamed',NULL,NULL,'EPSG','2225','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-118.5833333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',800000.0,'EPSG','9001','EPSG','8807','False northing',4000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103478','NAD_1983_CORS96_StatePlane_Nevada_West_FIPS_2703',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103478','EPSG','2225',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103479','unnamed',NULL,NULL,'EPSG','2224','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-115.5833333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',656166.6666666665,'EPSG','9003','EPSG','8807','False northing',26246666.66666666,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103479','NAD_1983_CORS96_StatePlane_Nevada_East_FIPS_2701_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103479','EPSG','2224',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103480','unnamed',NULL,NULL,'EPSG','2223','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-116.6666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',19685000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103480','NAD_1983_CORS96_StatePlane_Nevada_Central_FIPS_2702_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103480','EPSG','2223',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103481','unnamed',NULL,NULL,'EPSG','2225','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',34.75,'EPSG','9102','EPSG','8802','Longitude of natural origin',-118.5833333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',2624666.666666666,'EPSG','9003','EPSG','8807','False northing',13123333.33333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103481','NAD_1983_CORS96_StatePlane_Nevada_West_FIPS_2703_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103481','EPSG','2225',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103482','unnamed',NULL,NULL,'EPSG','1398','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-71.66666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',300000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103482','NAD_1983_CORS96_StatePlane_New_Hampshire_FIPS_2800',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103482','EPSG','1398',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103483','unnamed',NULL,NULL,'EPSG','1398','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-71.66666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999666666666667,'EPSG','9201','EPSG','8806','False easting',984250.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103483','NAD_1983_CORS96_StatePlane_New_Hampshire_FIPS_2800_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103483','EPSG','1398',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103484','unnamed',NULL,NULL,'EPSG','1399','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-74.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103484','NAD_1983_CORS96_StatePlane_New_Jersey_FIPS_2900',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103484','EPSG','1399',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103485','unnamed',NULL,NULL,'EPSG','1399','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-74.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',492125.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103485','NAD_1983_CORS96_StatePlane_New_Jersey_FIPS_2900_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103485','EPSG','1399',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103486','unnamed',NULL,NULL,'EPSG','2228','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-104.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999090909090909,'EPSG','9201','EPSG','8806','False easting',165000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103486','NAD_1983_CORS96_StatePlane_New_Mexico_East_FIPS_3001',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103486','EPSG','2228',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103487','unnamed',NULL,NULL,'EPSG','2231','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-106.25,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103487','NAD_1983_CORS96_StatePlane_New_Mexico_Central_FIPS_3002',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103487','EPSG','2231',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103488','unnamed',NULL,NULL,'EPSG','2232','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-107.8333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999166666666667,'EPSG','9201','EPSG','8806','False easting',830000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103488','NAD_1983_CORS96_StatePlane_New_Mexico_West_FIPS_3003',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103488','EPSG','2232',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103489','unnamed',NULL,NULL,'EPSG','2228','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-104.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999090909090909,'EPSG','9201','EPSG','8806','False easting',541337.5,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103489','NAD_1983_CORS96_StatePlane_New_Mexico_East_FIPS_3001_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103489','EPSG','2228',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103490','unnamed',NULL,NULL,'EPSG','2231','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-106.25,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',1640416.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103490','NAD_1983_CORS96_StatePlane_New_Mexico_Central_FIPS_3002_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103490','EPSG','2231',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103491','unnamed',NULL,NULL,'EPSG','2232','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',31.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-107.8333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999166666666667,'EPSG','9201','EPSG','8806','False easting',2723091.666666666,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103491','NAD_1983_CORS96_StatePlane_New_Mexico_West_FIPS_3003_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103491','EPSG','2232',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103492','unnamed',NULL,NULL,'EPSG','2234','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-74.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',150000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103492','NAD_1983_CORS96_StatePlane_New_York_East_FIPS_3101',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103492','EPSG','2234',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103493','unnamed',NULL,NULL,'EPSG','2233','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-76.58333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',250000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103493','NAD_1983_CORS96_StatePlane_New_York_Central_FIPS_3102',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103493','EPSG','2233',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103494','unnamed',NULL,NULL,'EPSG','2236','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-78.58333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',350000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103494','NAD_1983_CORS96_StatePlane_New_York_West_FIPS_3103',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103494','EPSG','2236',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103495','unnamed',NULL,NULL,'EPSG','2235','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.16666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-74.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.66666666666666,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.03333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',300000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103495','NAD_1983_CORS96_StatePlane_New_York_Long_Island_FIPS_3104',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103495','EPSG','2235',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103496','unnamed',NULL,NULL,'EPSG','2234','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',38.83333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-74.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999,'EPSG','9201','EPSG','8806','False easting',492125.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103496','NAD_1983_CORS96_StatePlane_New_York_East_FIPS_3101_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103496','EPSG','2234',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103497','unnamed',NULL,NULL,'EPSG','2233','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-76.58333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',820208.3333333333,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103497','NAD_1983_CORS96_StatePlane_New_York_Central_FIPS_3102_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103497','EPSG','2233',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103498','unnamed',NULL,NULL,'EPSG','2236','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-78.58333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',1148291.666666667,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103498','NAD_1983_CORS96_StatePlane_New_York_West_FIPS_3103_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103498','EPSG','2236',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103499','unnamed',NULL,NULL,'EPSG','2235','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.16666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-74.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.66666666666666,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.03333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',984250.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103499','NAD_1983_CORS96_StatePlane_New_York_Long_Isl_FIPS_3104_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103499','EPSG','2235',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103500','unnamed',NULL,NULL,'EPSG','1402','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.75,'EPSG','9102','EPSG','8822','Longitude of false origin',-79.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.16666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',609601.2192024384,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103500','NAD_1983_CORS96_StatePlane_North_Carolina_FIPS_3200',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103500','EPSG','1402',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103501','unnamed',NULL,NULL,'EPSG','1402','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.75,'EPSG','9102','EPSG','8822','Longitude of false origin',-79.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.16666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103501','NAD_1983_CORS96_StatePlane_North_Carolina_FIPS_3200_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103501','EPSG','1402',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103502','unnamed',NULL,NULL,'EPSG','2237','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.43333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.73333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103502','NAD_1983_CORS96_StatePlane_North_Dakota_North_FIPS_3301',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103502','EPSG','2237',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103503','unnamed',NULL,NULL,'EPSG','2238','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.18333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.48333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103503','NAD_1983_CORS96_StatePlane_North_Dakota_South_FIPS_3302',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103503','EPSG','2238',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103504','unnamed',NULL,NULL,'EPSG','2237','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.43333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.73333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1968503.937007874,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103504','NAD_1983_CORS96_StatePlane_North_Dakota_North_FIPS_3301_FtI',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','103504','EPSG','2237',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103505','unnamed',NULL,NULL,'EPSG','2238','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.18333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.48333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1968503.937007874,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103505','NAD_1983_CORS96_StatePlane_North_Dakota_South_FIPS_3302_FtI',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','103505','EPSG','2238',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103506','unnamed',NULL,NULL,'EPSG','2239','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-82.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.43333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.7,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103506','NAD_1983_CORS96_StatePlane_Ohio_North_FIPS_3401',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103506','EPSG','2239',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103507','unnamed',NULL,NULL,'EPSG','2240','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-82.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.73333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.03333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103507','NAD_1983_CORS96_StatePlane_Ohio_South_FIPS_3402',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103507','EPSG','2240',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103508','unnamed',NULL,NULL,'EPSG','2239','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-82.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.43333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.7,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103508','NAD_1983_CORS96_StatePlane_Ohio_North_FIPS_3401_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103508','EPSG','2239',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103509','unnamed',NULL,NULL,'EPSG','2240','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-82.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.73333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.03333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103509','NAD_1983_CORS96_StatePlane_Ohio_South_FIPS_3402_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103509','EPSG','2240',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103510','unnamed',NULL,NULL,'EPSG','2241','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',35.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',35.56666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.76666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103510','NAD_1983_CORS96_StatePlane_Oklahoma_North_FIPS_3501',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103510','EPSG','2241',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103511','unnamed',NULL,NULL,'EPSG','2242','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',33.93333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',35.23333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103511','NAD_1983_CORS96_StatePlane_Oklahoma_South_FIPS_3502',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103511','EPSG','2242',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103512','unnamed',NULL,NULL,'EPSG','2241','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',35.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',35.56666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.76666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103512','NAD_1983_CORS96_StatePlane_Oklahoma_North_FIPS_3501_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103512','EPSG','2241',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103513','unnamed',NULL,NULL,'EPSG','2242','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',33.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',33.93333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',35.23333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103513','NAD_1983_CORS96_StatePlane_Oklahoma_South_FIPS_3502_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103513','EPSG','2242',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103514','unnamed',NULL,NULL,'EPSG','2245','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.16666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-77.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.88333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.95,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103514','NAD_1983_CORS96_StatePlane_Pennsylvania_North_FIPS_3701',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103514','EPSG','2245',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103515','unnamed',NULL,NULL,'EPSG','2245','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.16666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-77.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.88333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.95,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103515','NAD_1983_CORS96_StatePlane_Pennsylvania_North_FIPS_3701_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103515','EPSG','2245',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103516','unnamed',NULL,NULL,'EPSG','2246','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-77.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',39.93333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.96666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103516','NAD_1983_CORS96_StatePlane_Pennsylvania_South_FIPS_3702',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103516','EPSG','2246',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103517','unnamed',NULL,NULL,'EPSG','2246','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',39.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-77.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',39.93333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.96666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103517','NAD_1983_CORS96_StatePlane_Pennsylvania_South_FIPS_3702_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103517','EPSG','2246',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103518','unnamed',NULL,NULL,'EPSG','1408','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.08333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-71.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99999375,'EPSG','9201','EPSG','8806','False easting',100000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103518','NAD_1983_CORS96_StatePlane_Rhode_Island_FIPS_3800',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103518','EPSG','1408',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103519','unnamed',NULL,NULL,'EPSG','1408','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.08333333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-71.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99999375,'EPSG','9201','EPSG','8806','False easting',328083.3333333333,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103519','NAD_1983_CORS96_StatePlane_Rhode_Island_FIPS_3800_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103519','EPSG','1408',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103520','unnamed',NULL,NULL,'EPSG','1409','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.83333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',32.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',34.83333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',609600.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103520','NAD_1983_CORS96_StatePlane_South_Carolina_FIPS_3900',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103520','EPSG','1409',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103521','unnamed',NULL,NULL,'EPSG','1409','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.83333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',32.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',34.83333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',2000000.0,'EPSG','9002','EPSG','8827','Northing at false origin',0.0,'EPSG','9002',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103521','NAD_1983_CORS96_StatePlane_South_Carolina_FIPS_3900_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','103521','EPSG','1409',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103522','unnamed',NULL,NULL,'EPSG','2249','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.41666666666666,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.68333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103522','NAD_1983_CORS96_StatePlane_South_Dakota_North_FIPS_4001',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103522','EPSG','2249',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103523','unnamed',NULL,NULL,'EPSG','2250','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.3333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.83333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.4,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103523','NAD_1983_CORS96_StatePlane_South_Dakota_South_FIPS_4002',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103523','EPSG','2250',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103524','unnamed',NULL,NULL,'EPSG','2249','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.41666666666666,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.68333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103524','NAD_1983_CORS96_StatePlane_South_Dakota_North_FIPS_4001_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103524','EPSG','2249',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103525','unnamed',NULL,NULL,'EPSG','2250','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.3333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.83333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.4,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103525','NAD_1983_CORS96_StatePlane_South_Dakota_South_FIPS_4002_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103525','EPSG','2250',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103526','unnamed',NULL,NULL,'EPSG','1411','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-86.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',35.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.41666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103526','NAD_1983_CORS96_StatePlane_Tennessee_FIPS_4100',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103526','EPSG','1411',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103527','unnamed',NULL,NULL,'EPSG','1411','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-86.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',35.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.41666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103527','NAD_1983_CORS96_StatePlane_Tennessee_FIPS_4100_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103527','EPSG','1411',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103528','ETRF_1989_UTM_Zone_28N',NULL,NULL,'EPSG','4400','ESRI','104258','EPSG','16028','EPSG','2122',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103529','ETRF_1989_UTM_Zone_29N',NULL,NULL,'EPSG','4400','ESRI','104258','EPSG','16029','EPSG','2123',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103530','ETRF_1989_UTM_Zone_30N',NULL,NULL,'EPSG','4400','ESRI','104258','EPSG','16030','EPSG','2124',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103531','ETRF_1989_UTM_Zone_31N',NULL,NULL,'EPSG','4400','ESRI','104258','EPSG','16031','EPSG','2125',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103532','ETRF_1989_UTM_Zone_32N',NULL,NULL,'EPSG','4400','ESRI','104258','EPSG','16032','EPSG','2126',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103533','ETRF_1989_UTM_Zone_33N',NULL,NULL,'EPSG','4400','ESRI','104258','EPSG','16033','EPSG','2127',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103534','ETRF_1989_UTM_Zone_34N',NULL,NULL,'EPSG','4400','ESRI','104258','EPSG','16034','EPSG','2128',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103535','ETRF_1989_UTM_Zone_35N',NULL,NULL,'EPSG','4400','ESRI','104258','EPSG','16035','EPSG','2129',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103536','ETRF_1989_UTM_Zone_36N',NULL,NULL,'EPSG','4400','ESRI','104258','EPSG','16036','EPSG','2130',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103537','ETRF_1989_UTM_Zone_37N',NULL,NULL,'EPSG','4400','ESRI','104258','EPSG','16037','EPSG','2131',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103538','ETRF_1989_UTM_Zone_38N',NULL,NULL,'EPSG','4400','ESRI','104258','EPSG','16038','EPSG','2132',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103539','unnamed',NULL,NULL,'EPSG','2253','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-101.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.65,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.18333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',200000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103539','NAD_1983_CORS96_StatePlane_Texas_North_FIPS_4201',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103539','EPSG','2253',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103540','unnamed',NULL,NULL,'EPSG','2254','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.66666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',32.13333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',33.96666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103540','NAD_1983_CORS96_StatePlane_Texas_North_Central_FIPS_4202',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103540','EPSG','2254',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103541','unnamed',NULL,NULL,'EPSG','2252','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',29.66666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.3333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',30.11666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',31.88333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',700000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103541','NAD_1983_CORS96_StatePlane_Texas_Central_FIPS_4203',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103541','EPSG','2252',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103542','unnamed',NULL,NULL,'EPSG','2527','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',27.83333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-99.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',28.38333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',30.28333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',4000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103542','NAD_1983_CORS96_StatePlane_Texas_South_Central_FIPS_4204',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103542','EPSG','2527',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103543','unnamed',NULL,NULL,'EPSG','2528','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',25.66666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',26.16666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',27.83333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',300000.0,'EPSG','9001','EPSG','8827','Northing at false origin',5000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103543','NAD_1983_CORS96_StatePlane_Texas_South_FIPS_4205',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103543','EPSG','2528',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103544','unnamed',NULL,NULL,'EPSG','2253','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',34.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-101.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',34.65,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',36.18333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',656166.6666666665,'EPSG','9003','EPSG','8827','Northing at false origin',3280833.333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103544','NAD_1983_CORS96_StatePlane_Texas_North_FIPS_4201_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103544','EPSG','2253',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103545','unnamed',NULL,NULL,'EPSG','2254','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',31.66666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',32.13333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',33.96666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',6561666.666666666,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103545','NAD_1983_CORS96_StatePlane_Texas_North_Central_FIPS_4202_FtUS',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103545','EPSG','2254',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103546','unnamed',NULL,NULL,'EPSG','2252','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',29.66666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-100.3333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',30.11666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',31.88333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',2296583.333333333,'EPSG','9003','EPSG','8827','Northing at false origin',9842500.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103546','NAD_1983_CORS96_StatePlane_Texas_Central_FIPS_4203_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103546','EPSG','2252',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103547','unnamed',NULL,NULL,'EPSG','2527','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',27.83333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-99.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',28.38333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',30.28333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',13123333.33333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103547','NAD_1983_CORS96_StatePlane_Texas_South_Central_FIPS_4204_FtUS',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103547','EPSG','2527',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103548','unnamed',NULL,NULL,'EPSG','2528','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',25.66666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-98.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',26.16666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',27.83333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',984250.0,'EPSG','9003','EPSG','8827','Northing at false origin',16404166.66666666,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103548','NAD_1983_CORS96_StatePlane_Texas_South_FIPS_4205_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103548','EPSG','2528',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103549','unnamed',NULL,NULL,'EPSG','2258','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-111.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.71666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103549','NAD_1983_CORS96_StatePlane_Utah_North_FIPS_4301',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103549','EPSG','2258',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103550','unnamed',NULL,NULL,'EPSG','2257','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-111.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',39.01666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.65,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103550','NAD_1983_CORS96_StatePlane_Utah_Central_FIPS_4302',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103550','EPSG','2257',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103551','unnamed',NULL,NULL,'EPSG','2259','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-111.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.21666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.35,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',3000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103551','NAD_1983_CORS96_StatePlane_Utah_South_FIPS_4303',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103551','EPSG','2259',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103552','NAD_1983_CORS96_StatePlane_Utah_North_FIPS_4301_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','103166','EPSG','2258',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103553','NAD_1983_CORS96_StatePlane_Utah_Central_FIPS_4302_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','103167','EPSG','2257',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103554','NAD_1983_CORS96_StatePlane_Utah_South_FIPS_4303_Ft_Intl',NULL,NULL,'ESRI','Foot','EPSG','6783','ESRI','103168','EPSG','2259',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103555','unnamed',NULL,NULL,'EPSG','2258','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',40.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-111.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',40.71666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',41.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',3280833.333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103555','NAD_1983_CORS96_StatePlane_Utah_North_FIPS_4301_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103555','EPSG','2258',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103556','unnamed',NULL,NULL,'EPSG','2257','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-111.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',39.01666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.65,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',6561666.666666666,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103556','NAD_1983_CORS96_StatePlane_Utah_Central_FIPS_4302_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103556','EPSG','2257',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103557','unnamed',NULL,NULL,'EPSG','2259','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-111.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.21666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.35,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',9842500.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103557','NAD_1983_CORS96_StatePlane_Utah_South_FIPS_4303_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103557','EPSG','2259',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103558','unnamed',NULL,NULL,'EPSG','1414','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-72.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999642857142857,'EPSG','9201','EPSG','8806','False easting',500000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103558','NAD_1983_CORS96_StatePlane_Vermont_FIPS_4400',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103558','EPSG','1414',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103559','unnamed',NULL,NULL,'EPSG','2260','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-78.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.2,'EPSG','9102','EPSG','8826','Easting at false origin',3500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',2000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103559','NAD_1983_CORS96_StatePlane_Virginia_North_FIPS_4501',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103559','EPSG','2260',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103560','unnamed',NULL,NULL,'EPSG','2261','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-78.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',36.76666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',37.96666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',3500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103560','NAD_1983_CORS96_StatePlane_Virginia_South_FIPS_4502',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103560','EPSG','2261',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103561','unnamed',NULL,NULL,'EPSG','2260','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.66666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-78.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',38.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',39.2,'EPSG','9102','EPSG','8826','Easting at false origin',11482916.66666666,'EPSG','9003','EPSG','8827','Northing at false origin',6561666.666666666,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103561','NAD_1983_CORS96_StatePlane_Virginia_North_FIPS_4501_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103561','EPSG','2260',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103562','unnamed',NULL,NULL,'EPSG','2261','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',36.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-78.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',36.76666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',37.96666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',11482916.66666666,'EPSG','9003','EPSG','8827','Northing at false origin',3280833.333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103562','NAD_1983_CORS96_StatePlane_Virginia_South_FIPS_4502_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103562','EPSG','2261',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103563','unnamed',NULL,NULL,'EPSG','2273','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.8333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.73333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103563','NAD_1983_CORS96_StatePlane_Washington_North_FIPS_4601',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103563','EPSG','2273',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103564','unnamed',NULL,NULL,'EPSG','2274','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.83333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.33333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103564','NAD_1983_CORS96_StatePlane_Washington_South_FIPS_4602',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103564','EPSG','2274',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103565','unnamed',NULL,NULL,'EPSG','2273','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.8333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.73333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103565','NAD_1983_CORS96_StatePlane_Washington_North_FIPS_4601_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103565','EPSG','2273',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103566','unnamed',NULL,NULL,'EPSG','2274','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-120.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.83333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.33333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',1640416.666666667,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103566','NAD_1983_CORS96_StatePlane_Washington_South_FIPS_4602_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103566','EPSG','2274',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103567','unnamed',NULL,NULL,'EPSG','2264','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-79.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',39.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.25,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103567','NAD_1983_CORS96_StatePlane_West_Virginia_North_FIPS_4701',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103567','EPSG','2264',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103568','unnamed',NULL,NULL,'EPSG','2265','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.48333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.88333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103568','NAD_1983_CORS96_StatePlane_West_Virginia_South_FIPS_4702',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103568','EPSG','2265',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103569','unnamed',NULL,NULL,'EPSG','2264','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',38.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-79.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',39.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',40.25,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103569','NAD_1983_CORS96_StatePlane_West_Virginia_North_FIPS_4701_FtUS',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103569','EPSG','2264',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103570','unnamed',NULL,NULL,'EPSG','2265','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',37.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-81.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',37.48333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',38.88333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103570','NAD_1983_CORS96_StatePlane_West_Virginia_South_FIPS_4702_FtUS',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103570','EPSG','2265',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103571','unnamed',NULL,NULL,'EPSG','2267','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.16666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.56666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.76666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103571','NAD_1983_CORS96_StatePlane_Wisconsin_North_FIPS_4801',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103571','EPSG','2267',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103572','unnamed',NULL,NULL,'EPSG','2266','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.5,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103572','NAD_1983_CORS96_StatePlane_Wisconsin_Central_FIPS_4802',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103572','EPSG','2266',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103573','unnamed',NULL,NULL,'EPSG','2268','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.73333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.06666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',600000.0,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103573','NAD_1983_CORS96_StatePlane_Wisconsin_South_FIPS_4803',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103573','EPSG','2268',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103574','unnamed',NULL,NULL,'EPSG','2267','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.16666666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.56666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.76666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103574','NAD_1983_CORS96_StatePlane_Wisconsin_North_FIPS_4801_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103574','EPSG','2267',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103575','unnamed',NULL,NULL,'EPSG','2266','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.5,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103575','NAD_1983_CORS96_StatePlane_Wisconsin_Central_FIPS_4802_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103575','EPSG','2266',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103576','unnamed',NULL,NULL,'EPSG','2268','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.0,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.73333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.06666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',1968500.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103576','NAD_1983_CORS96_StatePlane_Wisconsin_South_FIPS_4803_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103576','EPSG','2268',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103577','unnamed',NULL,NULL,'EPSG','2269','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-105.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',200000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103577','NAD_1983_CORS96_StatePlane_Wyoming_East_FIPS_4901',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103577','EPSG','2269',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103578','unnamed',NULL,NULL,'EPSG','2270','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-107.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',400000.0,'EPSG','9001','EPSG','8807','False northing',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103578','NAD_1983_CORS96_StatePlane_Wyoming_East_Central_FIPS_4902',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103578','EPSG','2270',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103579','unnamed',NULL,NULL,'EPSG','2272','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-108.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103579','NAD_1983_CORS96_StatePlane_Wyoming_West_Central_FIPS_4903',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103579','EPSG','2272',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103580','unnamed',NULL,NULL,'EPSG','2271','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-110.0833333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',800000.0,'EPSG','9001','EPSG','8807','False northing',100000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103580','NAD_1983_CORS96_StatePlane_Wyoming_West_FIPS_4904',NULL,NULL,'EPSG','4400','EPSG','6783','ESRI','103580','EPSG','2271',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103581','unnamed',NULL,NULL,'EPSG','2269','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-105.1666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',656166.6666666665,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103581','NAD_1983_CORS96_StatePlane_Wyoming_East_FIPS_4901_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103581','EPSG','2269',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103582','unnamed',NULL,NULL,'EPSG','2270','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-107.3333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',1312333.333333333,'EPSG','9003','EPSG','8807','False northing',328083.3333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103582','NAD_1983_CORS96_StatePlane_Wyoming_E_Central_FIPS_4902_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103582','EPSG','2270',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103583','unnamed',NULL,NULL,'EPSG','2272','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-108.75,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',1968500.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103583','NAD_1983_CORS96_StatePlane_Wyoming_W_Central_FIPS_4903_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103583','EPSG','2272',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103584','ETRF_1989_TM_Baltic_1993',NULL,NULL,'EPSG','4400','ESRI','104258','EPSG','19930','EPSG','1646',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103585','unnamed',NULL,NULL,'EPSG','2271','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',40.5,'EPSG','9102','EPSG','8802','Longitude of natural origin',-110.0833333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.9999375,'EPSG','9201','EPSG','8806','False easting',2624666.666666666,'EPSG','9003','EPSG','8807','False northing',328083.3333333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103585','NAD_1983_CORS96_StatePlane_Wyoming_West_FIPS_4904_Ft_US',NULL,NULL,'ESRI','Foot_US','EPSG','6783','ESRI','103585','EPSG','2271',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103600','unnamed',NULL,NULL,'EPSG','1392','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',46.15416666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-93.4325,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000059152669,'EPSG','9201','EPSG','8806','False easting',152409.319685395,'EPSG','9001','EPSG','8807','False northing',30481.86393707899,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103600','NAD_1983_HARN_Adj_MN_Aitkin_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103600','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103601','unnamed',NULL,NULL,'EPSG','1392','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',46.63,'EPSG','9102','EPSG','8802','Longitude of natural origin',-96.7,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000045317862,'EPSG','9201','EPSG','8806','False easting',152407.2112565913,'EPSG','9001','EPSG','8807','False northing',30481.44225131827,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103601','NAD_1983_HARN_Adj_MN_Clay_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103601','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103602','unnamed',NULL,NULL,'EPSG','1392','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',47.15166666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-95.37583333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000072505661,'EPSG','9201','EPSG','8806','False easting',152411.3546854458,'EPSG','9001','EPSG','8807','False northing',30482.27093708916,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103602','NAD_1983_HARN_Adj_MN_Clearwater_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103602','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103603','unnamed',NULL,NULL,'EPSG','1392','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',46.80361111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-94.92055555555557,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000071553661,'EPSG','9201','EPSG','8806','False easting',152411.2096003556,'EPSG','9001','EPSG','8807','False northing',30482.24192007113,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103603','NAD_1983_HARN_Adj_MN_Hubbard_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103603','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103604','unnamed',NULL,NULL,'EPSG','1392','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',47.06666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.40916666666668,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000075844621,'EPSG','9201','EPSG','8806','False easting',152411.8635439675,'EPSG','9001','EPSG','8807','False northing',30482.3727087935,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103604','NAD_1983_HARN_Adj_MN_Lake_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103604','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103605','unnamed',NULL,NULL,'EPSG','1392','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.55888888888889,'EPSG','9102','EPSG','8802','Longitude of natural origin',-93.62055555555555,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000054146138,'EPSG','9201','EPSG','8806','False easting',152408.5566885446,'EPSG','9001','EPSG','8807','False northing',30481.71133770892,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103605','NAD_1983_HARN_Adj_MN_Mille_Lacs_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103605','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103606','unnamed',NULL,NULL,'EPSG','1392','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.74583333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.83333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000039836799,'EPSG','9201','EPSG','8806','False easting',152406.3759409195,'EPSG','9001','EPSG','8807','False northing',30481.2751881839,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103606','NAD_1983_HARN_Adj_MN_Washington_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103606','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103607','unnamed',NULL,NULL,'EPSG','1392','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',46.02166666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-96.52444444444444,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000048901066,'EPSG','9201','EPSG','8806','False easting',152407.7573379731,'EPSG','9001','EPSG','8807','False northing',30481.55146759462,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103607','NAD_1983_HARN_Adj_MN_Wilkin_Meters',NULL,NULL,'EPSG','4400','EPSG','4152','ESRI','103607','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103608','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.03527777777778,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.26666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.06666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.36666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103608','NAD_1983_HARN_Adj_MN_Anoka_Meters',NULL,NULL,'EPSG','4400','ESRI','104700','ESRI','103608','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103609','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.71777777777778,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.68333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.78333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.08333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103609','NAD_1983_HARN_Adj_MN_Becker_Meters',NULL,NULL,'EPSG','4400','ESRI','104701','ESRI','103609','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103610','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',48.02,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.01666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',48.11666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.46666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103610','NAD_1983_HARN_Adj_MN_Beltrami_North_Meters',NULL,NULL,'EPSG','4400','ESRI','104702','ESRI','103610','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103611','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.4125,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.85,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.91666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103611','NAD_1983_HARN_Adj_MN_Beltrami_South_Meters',NULL,NULL,'EPSG','4400','ESRI','104703','ESRI','103611','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103612','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.55916666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.05,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.58333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103612','NAD_1983_HARN_Adj_MN_Benton_Meters',NULL,NULL,'EPSG','4400','ESRI','104704','ESRI','103612','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103613','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.15222222222222,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.05,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.21666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.53333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103613','NAD_1983_HARN_Adj_MN_Big_Stone_Meters',NULL,NULL,'EPSG','4400','ESRI','104705','ESRI','103613','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103614','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.84805555555556,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.26666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.93333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.36666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103614','NAD_1983_HARN_Adj_MN_Blue_Earth_Meters',NULL,NULL,'EPSG','4400','ESRI','104706','ESRI','103614','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103615','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.10805555555556,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.73333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.16666666666666,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.46666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103615','NAD_1983_HARN_Adj_MN_Brown_Meters',NULL,NULL,'EPSG','4400','ESRI','104707','ESRI','103615','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103616','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.41722222222222,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.68333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.46666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.73333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103616','NAD_1983_HARN_Adj_MN_Carlton_Meters',NULL,NULL,'EPSG','4400','ESRI','104708','ESRI','103616','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103617','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.63972222222222,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.76666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.68333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.9,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103617','NAD_1983_HARN_Adj_MN_Carver_Meters',NULL,NULL,'EPSG','4400','ESRI','104709','ESRI','103617','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103618','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.80361111111111,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.21666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.91666666666666,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.31666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103618','NAD_1983_HARN_Adj_MN_Cass_North_Meters',NULL,NULL,'EPSG','4400','ESRI','104710','ESRI','103618','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103619','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.15638888888888,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.46666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.26666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.73333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103619','NAD_1983_HARN_Adj_MN_Cass_South_Meters',NULL,NULL,'EPSG','4400','ESRI','104711','ESRI','103619','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103620','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.75277777777778,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.85,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.83333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.2,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103620','NAD_1983_HARN_Adj_MN_Chippewa_Meters',NULL,NULL,'EPSG','4400','ESRI','104712','ESRI','103620','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103621','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.29638888888888,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.08333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103621','NAD_1983_HARN_Adj_MN_Chisago_Meters',NULL,NULL,'EPSG','4400','ESRI','104713','ESRI','103621','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103622','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.88333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.25,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.93333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.16666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103622','NAD_1983_HARN_Adj_MN_Cook_North_Meters',NULL,NULL,'EPSG','4400','ESRI','104714','ESRI','103622','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103623','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.43888888888888,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.25,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.55,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.81666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103623','NAD_1983_HARN_Adj_MN_Cook_South_Meters',NULL,NULL,'EPSG','4400','ESRI','104715','ESRI','103623','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103624','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.84805555555556,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.91666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.9,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.16666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103624','NAD_1983_HARN_Adj_MN_Cottonwood_Meters',NULL,NULL,'EPSG','4400','ESRI','104716','ESRI','103624','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103625','NAD_1983_HARN_Adj_MN_Crow_Wing_Meters',NULL,NULL,'EPSG','4400','ESRI','104717','ESRI','103619','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103626','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.47194444444445,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.31666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.51666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.91666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103626','NAD_1983_HARN_Adj_MN_Dakota_Meters',NULL,NULL,'EPSG','4400','ESRI','104718','ESRI','103626','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103627','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.83388888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.91666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.88333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.13333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103627','NAD_1983_HARN_Adj_MN_Dodge_Meters',NULL,NULL,'EPSG','4400','ESRI','104719','ESRI','103627','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103628','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.75888888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.05,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.8,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.05,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103628','NAD_1983_HARN_Adj_MN_Douglas_Meters',NULL,NULL,'EPSG','4400','ESRI','104720','ESRI','103628','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103629','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.95,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.56666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.8,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103629','NAD_1983_HARN_Adj_MN_Faribault_Meters',NULL,NULL,'EPSG','4400','ESRI','104721','ESRI','103629','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103630','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.08333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.55,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.8,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103630','NAD_1983_HARN_Adj_MN_Fillmore_Meters',NULL,NULL,'EPSG','4400','ESRI','104722','ESRI','103630','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103631','NAD_1983_HARN_Adj_MN_Freeborn_Meters',NULL,NULL,'EPSG','4400','ESRI','104723','ESRI','103629','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103632','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.19472222222222,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.13333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.3,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103632','NAD_1983_HARN_Adj_MN_Goodhue_Meters',NULL,NULL,'EPSG','4400','ESRI','104724','ESRI','103632','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103633','NAD_1983_HARN_Adj_MN_Grant_Meters',NULL,NULL,'EPSG','4400','ESRI','104725','ESRI','103628','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103634','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.79111111111111,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.38333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.88333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.13333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103634','NAD_1983_HARN_Adj_MN_Hennepin_Meters',NULL,NULL,'EPSG','4400','ESRI','104726','ESRI','103634','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103635','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.46666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.56666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.8,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103635','NAD_1983_HARN_Adj_MN_Houston_Meters',NULL,NULL,'EPSG','4400','ESRI','104727','ESRI','103635','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103636','NAD_1983_HARN_Adj_MN_Isanti_Meters',NULL,NULL,'EPSG','4400','ESRI','104728','ESRI','103621','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103637','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.73333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.56666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.81666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103637','NAD_1983_HARN_Adj_MN_Itasca_North_Meters',NULL,NULL,'EPSG','4400','ESRI','104729','ESRI','103637','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103638','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.02638888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.73333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.08333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.41666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103638','NAD_1983_HARN_Adj_MN_Itasca_South_Meters',NULL,NULL,'EPSG','4400','ESRI','104730','ESRI','103638','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103639','NAD_1983_HARN_Adj_MN_Jackson_Meters',NULL,NULL,'EPSG','4400','ESRI','104731','ESRI','103629','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103640','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.73,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.9,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.81666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.33333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103640','NAD_1983_HARN_Adj_MN_Kanabec_Meters',NULL,NULL,'EPSG','4400','ESRI','104732','ESRI','103640','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103641','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.89138888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.96666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.33333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103641','NAD_1983_HARN_Adj_MN_Kandiyohi_Meters',NULL,NULL,'EPSG','4400','ESRI','104733','ESRI','103641','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103642','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',48.54388888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.15,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',48.6,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.93333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103642','NAD_1983_HARN_Adj_MN_Kittson_Meters',NULL,NULL,'EPSG','4400','ESRI','104734','ESRI','103642','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103643','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.84583333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',48.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.61666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103643','NAD_1983_HARN_Adj_MN_Koochiching_Meters',NULL,NULL,'EPSG','4400','ESRI','104735','ESRI','103643','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103644','NAD_1983_HARN_Adj_MN_Lac_Qui_Parle_Meters',NULL,NULL,'EPSG','4400','ESRI','104736','ESRI','103620','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103645','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',49.15,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.98333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',49.18333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',49.33333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103645','NAD_1983_HARN_Adj_MN_Lake_of_the_Woods_North_Meters',NULL,NULL,'EPSG','4400','ESRI','104737','ESRI','103645','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103646','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',48.36611111111111,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.88333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',48.45,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.88333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103646','NAD_1983_HARN_Adj_MN_Lake_of_the_Woods_South_Meters',NULL,NULL,'EPSG','4400','ESRI','104738','ESRI','103646','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103647','NAD_1983_HARN_Adj_MN_Le_Sueur_Meters',NULL,NULL,'EPSG','4400','ESRI','104739','ESRI','103632','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103648','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.19666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.26666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.28333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.61666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103648','NAD_1983_HARN_Adj_MN_Lincoln_Meters',NULL,NULL,'EPSG','4400','ESRI','104740','ESRI','103648','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103649','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.19555555555555,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.85,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.58333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103649','NAD_1983_HARN_Adj_MN_Lyon_Meters',NULL,NULL,'EPSG','4400','ESRI','104741','ESRI','103649','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103650','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.45611111111111,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.63333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.53333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.91666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103650','NAD_1983_HARN_Adj_MN_McLeod_Meters',NULL,NULL,'EPSG','4400','ESRI','104742','ESRI','103650','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103651','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.15166666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.81666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.2,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.45,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103651','NAD_1983_HARN_Adj_MN_Mahnomen_Meters',NULL,NULL,'EPSG','4400','ESRI','104743','ESRI','103651','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103652','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',48.17305555555555,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.38333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',48.23333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.48333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103652','NAD_1983_HARN_Adj_MN_Marshall_Meters',NULL,NULL,'EPSG','4400','ESRI','104744','ESRI','103652','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103653','NAD_1983_HARN_Adj_MN_Martin_Meters',NULL,NULL,'EPSG','4400','ESRI','104745','ESRI','103629','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103654','NAD_1983_HARN_Adj_MN_Meeker_Meters',NULL,NULL,'EPSG','4400','ESRI','104746','ESRI','103641','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103655','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.77388888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.2,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.85,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.26666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103655','NAD_1983_HARN_Adj_MN_Morrison_Meters',NULL,NULL,'EPSG','4400','ESRI','104747','ESRI','103655','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103656','NAD_1983_HARN_Adj_MN_Mower_Meters',NULL,NULL,'EPSG','4400','ESRI','104748','ESRI','103629','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103657','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.84805555555556,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.76666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.91666666666666,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.16666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103657','NAD_1983_HARN_Adj_MN_Murray_Meters',NULL,NULL,'EPSG','4400','ESRI','104749','ESRI','103657','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103658','NAD_1983_HARN_Adj_MN_Nicollet_Meters',NULL,NULL,'EPSG','4400','ESRI','104750','ESRI','103614','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103659','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.95,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.56666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.8,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103659','NAD_1983_HARN_Adj_MN_Nobles_Meters',NULL,NULL,'EPSG','4400','ESRI','104751','ESRI','103659','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103660','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.15055555555556,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.45,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.2,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.45,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103660','NAD_1983_HARN_Adj_MN_Norman_Meters',NULL,NULL,'EPSG','4400','ESRI','104752','ESRI','103660','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103661','NAD_1983_HARN_Adj_MN_Olmsted_Meters',NULL,NULL,'EPSG','4400','ESRI','104753','ESRI','103627','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103662','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.10638888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.71666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.18333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.65,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103662','NAD_1983_HARN_Adj_MN_Ottertail_Meters',NULL,NULL,'EPSG','4400','ESRI','104754','ESRI','103662','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103663','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.49888888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.36666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.6,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.08333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103663','NAD_1983_HARN_Adj_MN_Pennington_Meters',NULL,NULL,'EPSG','4400','ESRI','104755','ESRI','103663','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103664','NAD_1983_HARN_Adj_MN_Pine_Meters',NULL,NULL,'EPSG','4400','ESRI','104756','ESRI','103640','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103665','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.84916666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.25,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.88333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.15,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103665','NAD_1983_HARN_Adj_MN_Pipestone_Meters',NULL,NULL,'EPSG','4400','ESRI','104757','ESRI','103665','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103666','NAD_1983_HARN_Adj_MN_Polk_Meters',NULL,NULL,'EPSG','4400','ESRI','104758','ESRI','103663','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103667','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.28277777777777,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.15,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.35,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.7,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103667','NAD_1983_HARN_Adj_MN_Pope_Meters',NULL,NULL,'EPSG','4400','ESRI','104759','ESRI','103667','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103668','NAD_1983_HARN_Adj_MN_Ramsey_Meters',NULL,NULL,'EPSG','4400','ESRI','104760','ESRI','103634','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103669','NAD_1983_HARN_Adj_MN_Red_Lake_Meters',NULL,NULL,'EPSG','4400','ESRI','104761','ESRI','103663','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103670','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.19472222222222,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.23333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.26666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.56666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103670','NAD_1983_HARN_Adj_MN_Redwood_Meters',NULL,NULL,'EPSG','4400','ESRI','104762','ESRI','103670','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103671','NAD_1983_HARN_Adj_MN_Renville_Meters',NULL,NULL,'EPSG','4400','ESRI','104763','ESRI','103650','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103672','NAD_1983_HARN_Adj_MN_Rice_Meters',NULL,NULL,'EPSG','4400','ESRI','104764','ESRI','103632','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103673','NAD_1983_HARN_Adj_MN_Rock_Meters',NULL,NULL,'EPSG','4400','ESRI','104765','ESRI','103659','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103674','NAD_1983_HARN_Adj_MN_Roseau_Meters',NULL,NULL,'EPSG','4400','ESRI','104766','ESRI','103642','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103675','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.45,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.98333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.53333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103675','NAD_1983_HARN_Adj_MN_St_Louis_North_Meters',NULL,NULL,'EPSG','4400','ESRI','104767','ESRI','103675','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103676','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.25,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.45,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.75,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103676','NAD_1983_HARN_Adj_MN_St_Louis_Central_Meters',NULL,NULL,'EPSG','4400','ESRI','104768','ESRI','103676','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103677','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.65,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.45,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.78333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.13333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103677','NAD_1983_HARN_Adj_MN_St_Louis_South_Meters',NULL,NULL,'EPSG','4400','ESRI','104769','ESRI','103677','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103678','NAD_1983_HARN_Adj_MN_Scott_Meters',NULL,NULL,'EPSG','4400','ESRI','104770','ESRI','103626','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103679','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.9775,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.88333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.46666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103679','NAD_1983_HARN_Adj_MN_Sherburne_Meters',NULL,NULL,'EPSG','4400','ESRI','104771','ESRI','103679','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103680','NAD_1983_HARN_Adj_MN_Sibley_Meters',NULL,NULL,'EPSG','4400','ESRI','104772','ESRI','103650','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103681','NAD_1983_HARN_Adj_MN_Stearns_Meters',NULL,NULL,'EPSG','4400','ESRI','104773','ESRI','103667','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103682','NAD_1983_HARN_Adj_MN_Steele_Meters',NULL,NULL,'EPSG','4400','ESRI','104774','ESRI','103627','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103683','NAD_1983_HARN_Adj_MN_Stevens_Meters',NULL,NULL,'EPSG','4400','ESRI','104775','ESRI','103667','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103684','NAD_1983_HARN_Adj_MN_Swift_Meters',NULL,NULL,'EPSG','4400','ESRI','104776','ESRI','103613','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103685','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.77333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.9,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.86666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.28333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103685','NAD_1983_HARN_Adj_MN_Todd_Meters',NULL,NULL,'EPSG','4400','ESRI','104777','ESRI','103685','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103686','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.58555555555556,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.55,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.63333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.96666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103686','NAD_1983_HARN_Adj_MN_Traverse_Meters',NULL,NULL,'EPSG','4400','ESRI','104778','ESRI','103686','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103687','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.10694444444444,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.26666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.15,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.41666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103687','NAD_1983_HARN_Adj_MN_Wabasha_Meters',NULL,NULL,'EPSG','4400','ESRI','104779','ESRI','103687','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103688','NAD_1983_HARN_Adj_MN_Wadena_Meters',NULL,NULL,'EPSG','4400','ESRI','104780','ESRI','103619','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103689','NAD_1983_HARN_Adj_MN_Waseca_Meters',NULL,NULL,'EPSG','4400','ESRI','104781','ESRI','103627','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103690','NAD_1983_HARN_Adj_MN_Watonwan_Meters',NULL,NULL,'EPSG','4400','ESRI','104782','ESRI','103624','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103691','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.84722222222222,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.61666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.9,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.13333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103691','NAD_1983_HARN_Adj_MN_Winona_Meters',NULL,NULL,'EPSG','4400','ESRI','104783','ESRI','103691','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103692','NAD_1983_HARN_Adj_MN_Wright_Meters',NULL,NULL,'EPSG','4400','ESRI','104784','ESRI','103679','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103693','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.54166666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.9,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.66666666666666,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.95,'EPSG','9102','EPSG','8826','Easting at false origin',152400.3048006096,'EPSG','9001','EPSG','8827','Northing at false origin',30480.06096012193,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103693','NAD_1983_HARN_Adj_MN_Yellow_Medicine_Meters',NULL,NULL,'EPSG','4400','ESRI','104785','ESRI','103693','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103694','unnamed',NULL,NULL,'EPSG','1392','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',46.61666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.45,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99998529,'EPSG','9201','EPSG','8806','False easting',1450000.0,'EPSG','9001','EPSG','8807','False northing',1000000.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103694','NAD_1983_HARN_Adj_MN_St_Louis_CS96_Meters',NULL,NULL,'EPSG','4400','ESRI','104786','ESRI','103694','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103695','unnamed',NULL,NULL,'EPSG','1392','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',46.61666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.45,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99998529,'EPSG','9201','EPSG','8806','False easting',4757208.333333,'EPSG','9003','EPSG','8807','False northing',3280833.333333,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103695','NAD_1983_HARN_Adj_MN_St_Louis_CS96_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104786','ESRI','103695','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103700','unnamed',NULL,NULL,'EPSG','1392','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',46.15416666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-93.4325,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000059152669,'EPSG','9201','EPSG','8806','False easting',500029.5763345,'EPSG','9003','EPSG','8807','False northing',100005.9152669,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103700','NAD_1983_HARN_Adj_MN_Aitkin_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103700','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103701','unnamed',NULL,NULL,'EPSG','1392','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',46.63,'EPSG','9102','EPSG','8802','Longitude of natural origin',-96.7,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000045317862,'EPSG','9201','EPSG','8806','False easting',500022.658931,'EPSG','9003','EPSG','8807','False northing',100004.5317862,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103701','NAD_1983_HARN_Adj_MN_Clay_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103701','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103702','unnamed',NULL,NULL,'EPSG','1392','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',47.15166666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-95.37583333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000072505661,'EPSG','9201','EPSG','8806','False easting',500036.2528305,'EPSG','9003','EPSG','8807','False northing',100007.2505661,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103702','NAD_1983_HARN_Adj_MN_Clearwater_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103702','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103703','unnamed',NULL,NULL,'EPSG','1392','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',46.80361111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-94.92055555555557,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000071553661,'EPSG','9201','EPSG','8806','False easting',500035.7768305,'EPSG','9003','EPSG','8807','False northing',100007.1553661,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103703','NAD_1983_HARN_Adj_MN_Hubbard_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103703','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103704','unnamed',NULL,NULL,'EPSG','1392','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',47.06666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.40916666666668,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000075844621,'EPSG','9201','EPSG','8806','False easting',500037.9223105,'EPSG','9003','EPSG','8807','False northing',100007.5844621,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103704','NAD_1983_HARN_Adj_MN_Lake_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103704','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103705','unnamed',NULL,NULL,'EPSG','1392','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.55888888888889,'EPSG','9102','EPSG','8802','Longitude of natural origin',-93.62055555555555,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000054146138,'EPSG','9201','EPSG','8806','False easting',500027.073069,'EPSG','9003','EPSG','8807','False northing',100005.4146138,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103705','NAD_1983_HARN_Adj_MN_Mille_Lacs_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103705','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103706','unnamed',NULL,NULL,'EPSG','1392','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.74583333333334,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.83333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000039836799,'EPSG','9201','EPSG','8806','False easting',500019.9183995,'EPSG','9003','EPSG','8807','False northing',100003.9836799,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103706','NAD_1983_HARN_Adj_MN_Washington_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103706','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103707','unnamed',NULL,NULL,'EPSG','1392','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',46.02166666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-96.52444444444444,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.000048901066,'EPSG','9201','EPSG','8806','False easting',500024.450533,'EPSG','9003','EPSG','8807','False northing',100004.8901066,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103707','NAD_1983_HARN_Adj_MN_Wilkin_Feet',NULL,NULL,'ESRI','Foot_US','EPSG','4152','ESRI','103707','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103708','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.03527777777778,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.26666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.06666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.36666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103708','NAD_1983_HARN_Adj_MN_Anoka_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104700','ESRI','103708','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103709','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.71777777777778,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.68333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.78333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.08333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103709','NAD_1983_HARN_Adj_MN_Becker_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104701','ESRI','103709','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103710','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',48.02,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.01666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',48.11666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.46666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103710','NAD_1983_HARN_Adj_MN_Beltrami_North_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104702','ESRI','103710','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103711','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.4125,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.85,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.5,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.91666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103711','NAD_1983_HARN_Adj_MN_Beltrami_South_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104703','ESRI','103711','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103712','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.55916666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.05,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.58333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.78333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103712','NAD_1983_HARN_Adj_MN_Benton_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104704','ESRI','103712','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103713','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.15222222222222,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.05,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.21666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.53333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103713','NAD_1983_HARN_Adj_MN_Big_Stone_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104705','ESRI','103713','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103714','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.84805555555556,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.26666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.93333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.36666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103714','NAD_1983_HARN_Adj_MN_Blue_Earth_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104706','ESRI','103714','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103715','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.10805555555556,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.73333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.16666666666666,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.46666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103715','NAD_1983_HARN_Adj_MN_Brown_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104707','ESRI','103715','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103716','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.41722222222222,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.68333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.46666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.73333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103716','NAD_1983_HARN_Adj_MN_Carlton_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104708','ESRI','103716','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103717','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.63972222222222,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.76666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.68333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.9,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103717','NAD_1983_HARN_Adj_MN_Carver_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104709','ESRI','103717','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103718','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.80361111111111,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.21666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.91666666666666,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.31666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103718','NAD_1983_HARN_Adj_MN_Cass_North_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104710','ESRI','103718','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103719','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.15638888888888,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.46666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.26666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.73333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103719','NAD_1983_HARN_Adj_MN_Cass_South_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104711','ESRI','103719','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103720','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.75277777777778,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.85,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.83333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.2,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103720','NAD_1983_HARN_Adj_MN_Chippewa_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104712','ESRI','103720','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103721','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.29638888888888,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.08333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103721','NAD_1983_HARN_Adj_MN_Chisago_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104713','ESRI','103721','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103722','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.88333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.25,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.93333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.16666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103722','NAD_1983_HARN_Adj_MN_Cook_North_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104714','ESRI','103722','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103723','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.43888888888888,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.25,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.55,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.81666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103723','NAD_1983_HARN_Adj_MN_Cook_South_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104715','ESRI','103723','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103724','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.84805555555556,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.91666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.9,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.16666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103724','NAD_1983_HARN_Adj_MN_Cottonwood_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104716','ESRI','103724','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103725','NAD_1983_HARN_Adj_MN_Crow_Wing_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104717','ESRI','103719','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103726','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.47194444444445,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.31666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.51666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.91666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103726','NAD_1983_HARN_Adj_MN_Dakota_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104718','ESRI','103726','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103727','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.83388888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.91666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.88333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.13333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103727','NAD_1983_HARN_Adj_MN_Dodge_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104719','ESRI','103727','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103728','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.75888888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.05,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.8,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.05,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103728','NAD_1983_HARN_Adj_MN_Douglas_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104720','ESRI','103728','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103729','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.95,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.56666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.8,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103729','NAD_1983_HARN_Adj_MN_Faribault_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104721','ESRI','103729','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103730','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.08333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.55,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.8,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103730','NAD_1983_HARN_Adj_MN_Fillmore_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104722','ESRI','103730','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103731','NAD_1983_HARN_Adj_MN_Freeborn_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104723','ESRI','103729','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103732','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.19472222222222,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.13333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.3,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.66666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103732','NAD_1983_HARN_Adj_MN_Goodhue_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104724','ESRI','103732','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103733','NAD_1983_HARN_Adj_MN_Grant_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104725','ESRI','103728','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103734','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.79111111111111,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.38333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.88333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.13333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103734','NAD_1983_HARN_Adj_MN_Hennepin_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104726','ESRI','103734','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103735','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.46666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.56666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.8,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103735','NAD_1983_HARN_Adj_MN_Houston_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104727','ESRI','103735','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103736','NAD_1983_HARN_Adj_MN_Isanti_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104728','ESRI','103721','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103737','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.73333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.56666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.81666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103737','NAD_1983_HARN_Adj_MN_Itasca_North_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104729','ESRI','103737','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103738','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.02638888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.73333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.08333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.41666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103738','NAD_1983_HARN_Adj_MN_Itasca_South_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104730','ESRI','103738','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103739','NAD_1983_HARN_Adj_MN_Jackson_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104731','ESRI','103729','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103740','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.73,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.9,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.81666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.33333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103740','NAD_1983_HARN_Adj_MN_Kanabec_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104732','ESRI','103740','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103741','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.89138888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.96666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.33333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103741','NAD_1983_HARN_Adj_MN_Kandiyohi_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104733','ESRI','103741','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103742','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',48.54388888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.15,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',48.6,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.93333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103742','NAD_1983_HARN_Adj_MN_Kittson_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104734','ESRI','103742','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103743','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.84583333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.75,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',48.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.61666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103743','NAD_1983_HARN_Adj_MN_Koochiching_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104735','ESRI','103743','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103744','NAD_1983_HARN_Adj_MN_Lac_Qui_Parle_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104736','ESRI','103720','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103745','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',49.15,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.98333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',49.18333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',49.33333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103745','NAD_1983_HARN_Adj_MN_Lake_of_the_Woods_North_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104737','ESRI','103745','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103746','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',48.36611111111111,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.88333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',48.45,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.88333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103746','NAD_1983_HARN_Adj_MN_Lake_of_the_Woods_South_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104738','ESRI','103746','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103747','NAD_1983_HARN_Adj_MN_Le_Sueur_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104739','ESRI','103732','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103748','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.19666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.26666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.28333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.61666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103748','NAD_1983_HARN_Adj_MN_Lincoln_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104740','ESRI','103748','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103749','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.19555555555555,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.85,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.25,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.58333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103749','NAD_1983_HARN_Adj_MN_Lyon_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104741','ESRI','103749','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103750','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.45611111111111,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.63333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.53333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.91666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103750','NAD_1983_HARN_Adj_MN_McLeod_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104742','ESRI','103750','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103751','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.15166666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.81666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.2,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.45,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103751','NAD_1983_HARN_Adj_MN_Mahnomen_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104743','ESRI','103751','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103752','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',48.17305555555555,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.38333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',48.23333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.48333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103752','NAD_1983_HARN_Adj_MN_Marshall_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104744','ESRI','103752','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103753','NAD_1983_HARN_Adj_MN_Martin_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104745','ESRI','103729','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103754','NAD_1983_HARN_Adj_MN_Meeker_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104746','ESRI','103741','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103755','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.77388888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.2,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.85,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.26666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103755','NAD_1983_HARN_Adj_MN_Morrison_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104747','ESRI','103755','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103756','NAD_1983_HARN_Adj_MN_Mower_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104748','ESRI','103729','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103757','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.84805555555556,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.76666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.91666666666666,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.16666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103757','NAD_1983_HARN_Adj_MN_Murray_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104749','ESRI','103757','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103758','NAD_1983_HARN_Adj_MN_Nicollet_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104750','ESRI','103714','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103759','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.5,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.95,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.56666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.8,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103759','NAD_1983_HARN_Adj_MN_Nobles_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104751','ESRI','103759','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103760','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.15055555555556,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.45,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.2,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.45,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103760','NAD_1983_HARN_Adj_MN_Norman_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104752','ESRI','103760','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103761','NAD_1983_HARN_Adj_MN_Olmsted_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104753','ESRI','103727','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103762','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.10638888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.71666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.18333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.65,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103762','NAD_1983_HARN_Adj_MN_Ottertail_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104754','ESRI','103762','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103763','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.49888888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.36666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.6,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.08333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103763','NAD_1983_HARN_Adj_MN_Pennington_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104755','ESRI','103763','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103764','NAD_1983_HARN_Adj_MN_Pine_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104756','ESRI','103740','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103765','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.84916666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.25,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.88333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.15,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103765','NAD_1983_HARN_Adj_MN_Pipestone_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104757','ESRI','103765','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103766','NAD_1983_HARN_Adj_MN_Polk_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104758','ESRI','103763','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103767','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.28277777777777,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.15,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.35,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.7,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103767','NAD_1983_HARN_Adj_MN_Pope_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104759','ESRI','103767','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103768','NAD_1983_HARN_Adj_MN_Ramsey_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104760','ESRI','103734','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103769','NAD_1983_HARN_Adj_MN_Red_Lake_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104761','ESRI','103763','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103770','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.19472222222222,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.23333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.26666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.56666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103770','NAD_1983_HARN_Adj_MN_Redwood_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104762','ESRI','103770','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103771','NAD_1983_HARN_Adj_MN_Renville_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104763','ESRI','103750','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103772','NAD_1983_HARN_Adj_MN_Rice_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104764','ESRI','103732','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103773','NAD_1983_HARN_Adj_MN_Rock_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104765','ESRI','103759','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103774','NAD_1983_HARN_Adj_MN_Roseau_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104766','ESRI','103742','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103775','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.83333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.45,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.98333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',48.53333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103775','NAD_1983_HARN_Adj_MN_St_Louis_North_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104767','ESRI','103775','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103776','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',47.25,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.45,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',47.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.75,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103776','NAD_1983_HARN_Adj_MN_St_Louis_Central_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104768','ESRI','103776','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103777','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',46.65,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.45,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.78333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',47.13333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103777','NAD_1983_HARN_Adj_MN_St_Louis_South_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104769','ESRI','103777','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103778','NAD_1983_HARN_Adj_MN_Scott_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104770','ESRI','103726','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103779','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.9775,'EPSG','9102','EPSG','8822','Longitude of false origin',-93.88333333333334,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.03333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.46666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103779','NAD_1983_HARN_Adj_MN_Sherburne_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104771','ESRI','103779','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103780','NAD_1983_HARN_Adj_MN_Sibley_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104772','ESRI','103750','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103781','NAD_1983_HARN_Adj_MN_Stearns_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104773','ESRI','103767','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103782','NAD_1983_HARN_Adj_MN_Steele_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104774','ESRI','103727','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103783','NAD_1983_HARN_Adj_MN_Stevens_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104775','ESRI','103767','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103784','NAD_1983_HARN_Adj_MN_Swift_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104776','ESRI','103713','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103785','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.77333333333333,'EPSG','9102','EPSG','8822','Longitude of false origin',-94.9,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.86666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.28333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103785','NAD_1983_HARN_Adj_MN_Todd_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104777','ESRI','103785','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103786','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.58555555555556,'EPSG','9102','EPSG','8822','Longitude of false origin',-96.55,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.63333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.96666666666667,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103786','NAD_1983_HARN_Adj_MN_Traverse_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104778','ESRI','103786','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103787','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.10694444444444,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.26666666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.15,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.41666666666666,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103787','NAD_1983_HARN_Adj_MN_Wabasha_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104779','ESRI','103787','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103788','NAD_1983_HARN_Adj_MN_Wadena_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104780','ESRI','103719','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103789','NAD_1983_HARN_Adj_MN_Waseca_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104781','ESRI','103727','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103790','NAD_1983_HARN_Adj_MN_Watonwan_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104782','ESRI','103724','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103791','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.84722222222222,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.61666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.9,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.13333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103791','NAD_1983_HARN_Adj_MN_Winona_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104783','ESRI','103791','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103792','NAD_1983_HARN_Adj_MN_Wright_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104784','ESRI','103779','EPSG','1392',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103793','unnamed',NULL,NULL,'EPSG','1392','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.54166666666666,'EPSG','9102','EPSG','8822','Longitude of false origin',-95.9,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.66666666666666,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.95,'EPSG','9102','EPSG','8826','Easting at false origin',500000.0,'EPSG','9003','EPSG','8827','Northing at false origin',100000.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103793','NAD_1983_HARN_Adj_MN_Yellow_Medicine_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104785','ESRI','103793','EPSG','1392',NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103794','Mexican_Datum_1993_UTM_Zone_11N',NULL,NULL,'EPSG','4400','EPSG','4483','EPSG','16011','EPSG','3423',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103795','Mexican_Datum_1993_UTM_Zone_12N',NULL,NULL,'EPSG','4400','EPSG','4483','EPSG','16012','EPSG','3424',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103796','Mexican_Datum_1993_UTM_Zone_13N',NULL,NULL,'EPSG','4400','EPSG','4483','EPSG','16013','EPSG','3425',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103797','Mexican_Datum_1993_UTM_Zone_14N',NULL,NULL,'EPSG','4400','EPSG','4483','EPSG','16014','EPSG','3426',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103798','Mexican_Datum_1993_UTM_Zone_15N',NULL,NULL,'EPSG','4400','EPSG','4483','EPSG','16015','EPSG','3633',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103799','Mexican_Datum_1993_UTM_Zone_16N',NULL,NULL,'EPSG','4400','EPSG','4483','EPSG','16016','EPSG','3635',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103800','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.36666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999999,'EPSG','9201','EPSG','8806','False easting',147218.6944373889,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103800','NAD_1983_HARN_Adj_WI_Adams_Meters',NULL,NULL,'EPSG','4400','ESRI','104800','ESRI','103800','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103801','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.70611111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.62222222222222,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999997,'EPSG','9201','EPSG','8806','False easting',172821.9456438913,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103801','NAD_1983_HARN_Adj_WI_Ashland_Meters',NULL,NULL,'EPSG','4400','ESRI','104801','ESRI','103801','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103802','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.13333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.85,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999996,'EPSG','9201','EPSG','8806','False easting',93150.0,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103802','NAD_1983_HARN_Adj_WI_Barron_Meters',NULL,NULL,'EPSG','4400','ESRI','104802','ESRI','103802','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103803','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00002,'EPSG','9201','EPSG','8806','False easting',31599.99998984,'EPSG','9001','EPSG','8807','False northing',4599.98983997968,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103803','NAD_1983_HARN_Adj_WI_Brown_Meters',NULL,NULL,'EPSG','4400','ESRI','104804','ESRI','103803','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103804','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.48138888888889,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.79722222222222,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',175260.3505207011,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103804','NAD_1983_HARN_Adj_WI_Buffalo_Meters',NULL,NULL,'EPSG','4400','ESRI','104805','ESRI','103804','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103805','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.71944444444445,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999996,'EPSG','9201','EPSG','8806','False easting',244754.8895097791,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103805','NAD_1983_HARN_Adj_WI_Calumet_Meters',NULL,NULL,'EPSG','4400','ESRI','104807','ESRI','103805','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103806','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.6,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.70833333333334,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999994,'EPSG','9201','EPSG','8806','False easting',199949.1998984,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103806','NAD_1983_HARN_Adj_WI_Clark_Meters',NULL,NULL,'EPSG','4400','ESRI','104809','ESRI','103806','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103807','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.47222222222222,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.775,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999997,'EPSG','9201','EPSG','8806','False easting',263347.7266954534,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103807','NAD_1983_HARN_Adj_WI_Dodge_Meters',NULL,NULL,'EPSG','4400','ESRI','104813','ESRI','103807','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103808','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.4,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.27222222222223,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999991,'EPSG','9201','EPSG','8806','False easting',158801.1176022352,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103808','NAD_1983_HARN_Adj_WI_Door_Meters',NULL,NULL,'EPSG','4400','ESRI','104814','ESRI','103808','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103809','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.88333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.91666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999995,'EPSG','9201','EPSG','8806','False easting',59131.31826263653,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103809','NAD_1983_HARN_Adj_WI_Douglas_Meters',NULL,NULL,'EPSG','4400','ESRI','104815','ESRI','103809','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103810','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.40833333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.89444444444445,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999998,'EPSG','9201','EPSG','8806','False easting',51816.10363220727,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103810','NAD_1983_HARN_Adj_WI_Dunn_Meters',NULL,NULL,'EPSG','4400','ESRI','104816','ESRI','103810','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103811','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.43888888888888,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.14166666666668,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999993,'EPSG','9201','EPSG','8806','False easting',133502.667005334,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103811','NAD_1983_HARN_Adj_WI_Florence_Meters',NULL,NULL,'EPSG','4400','ESRI','104818','ESRI','103811','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103812','NAD_1983_HARN_Adj_WI_Fond_du_Lac_Meters',NULL,NULL,'EPSG','4400','ESRI','104819','ESRI','103805','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103813','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.00555555555555,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.63333333333334,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999996,'EPSG','9201','EPSG','8806','False easting',275844.5516891034,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103813','NAD_1983_HARN_Adj_WI_Forest_Meters',NULL,NULL,'EPSG','4400','ESRI','104820','ESRI','103813','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103814','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.41111111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.8,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999997,'EPSG','9201','EPSG','8806','False easting',242316.4846329693,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103814','NAD_1983_HARN_Adj_WI_Grant_Meters',NULL,NULL,'EPSG','4400','ESRI','104821','ESRI','103814','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103815','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.53888888888888,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.16111111111111,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999997,'EPSG','9201','EPSG','8806','False easting',113081.0261620523,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103815','NAD_1983_HARN_Adj_WI_Iowa_Meters',NULL,NULL,'EPSG','4400','ESRI','104824','ESRI','103815','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103816','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.43333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.25555555555556,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999996,'EPSG','9201','EPSG','8806','False easting',220980.4419608839,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103816','NAD_1983_HARN_Adj_WI_Iron_Meters',NULL,NULL,'EPSG','4400','ESRI','104825','ESRI','103816','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103817','NAD_1983_HARN_Adj_WI_Jefferson_Meters',NULL,NULL,'EPSG','4400','ESRI','104827','ESRI','103807','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103818','NAD_1983_HARN_Adj_WI_Juneau_Meters',NULL,NULL,'EPSG','4400','ESRI','104828','ESRI','103800','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103819','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.21666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.89444444444445,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999998,'EPSG','9201','EPSG','8806','False easting',185928.3718567437,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103819','NAD_1983_HARN_Adj_WI_Kenosha_Meters',NULL,NULL,'EPSG','4400','ESRI','104829','ESRI','103819','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103820','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.26666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.55,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',79857.75971551944,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103820','NAD_1983_HARN_Adj_WI_Kewaunee_Meters',NULL,NULL,'EPSG','4400','ESRI','104830','ESRI','103820','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103821','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.45111111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.31666666666666,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999994,'EPSG','9201','EPSG','8806','False easting',130454.6609093218,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103821','NAD_1983_HARN_Adj_WI_LaCrosse_Meters',NULL,NULL,'EPSG','4400','ESRI','104831','ESRI','103821','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103822','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.84444444444445,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.73333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999998,'EPSG','9201','EPSG','8806','False easting',116129.0322580645,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103822','NAD_1983_HARN_Adj_WI_Lincoln_Meters',NULL,NULL,'EPSG','4400','ESRI','104834','ESRI','103822','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103823','NAD_1983_HARN_Adj_WI_Manitowoc_Meters',NULL,NULL,'EPSG','4400','ESRI','104835','ESRI','103820','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103824','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.69166666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.71111111111111,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999986,'EPSG','9201','EPSG','8806','False easting',238658.8773177547,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103824','NAD_1983_HARN_Adj_WI_Marinette_Meters',NULL,NULL,'EPSG','4400','ESRI','104837','ESRI','103824','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103825','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.71666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.41666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999994,'EPSG','9201','EPSG','8806','False easting',105461.0109220219,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103825','NAD_1983_HARN_Adj_WI_Menominee_Meters',NULL,NULL,'EPSG','4400','ESRI','104839','ESRI','103825','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103826','NAD_1983_HARN_Adj_WI_Milwaukee_Meters',NULL,NULL,'EPSG','4400','ESRI','104840','ESRI','103819','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103827','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.39722222222222,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.90833333333335,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999991,'EPSG','9201','EPSG','8806','False easting',182880.3657607315,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103827','NAD_1983_HARN_Adj_WI_Oconto_Meters',NULL,NULL,'EPSG','4400','ESRI','104842','ESRI','103827','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103828','NAD_1983_HARN_Adj_WI_Outagamie_Meters',NULL,NULL,'EPSG','4400','ESRI','104844','ESRI','103805','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103829','NAD_1983_HARN_Adj_WI_Ozaukee_Meters',NULL,NULL,'EPSG','4400','ESRI','104845','ESRI','103819','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103830','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.66111111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.63333333333334,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',141732.283464567,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103830','NAD_1983_HARN_Adj_WI_Polk_Meters',NULL,NULL,'EPSG','4400','ESRI','104848','ESRI','103830','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103831','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.55555555555555,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.48888888888889,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999998,'EPSG','9201','EPSG','8806','False easting',227990.855981712,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103831','NAD_1983_HARN_Adj_WI_Price_Meters',NULL,NULL,'EPSG','4400','ESRI','104850','ESRI','103831','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103832','NAD_1983_HARN_Adj_WI_Racine_Meters',NULL,NULL,'EPSG','4400','ESRI','104851','ESRI','103819','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103833','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.94444444444444,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.07222222222222,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999996,'EPSG','9201','EPSG','8806','False easting',146304.2926085852,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103833','NAD_1983_HARN_Adj_WI_Rock_Meters',NULL,NULL,'EPSG','4400','ESRI','104853','ESRI','103833','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103834','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.91944444444444,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.06666666666666,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999997,'EPSG','9201','EPSG','8806','False easting',250546.1010922022,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103834','NAD_1983_HARN_Adj_WI_Rusk_Meters',NULL,NULL,'EPSG','4400','ESRI','104854','ESRI','103834','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103835','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.03611111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.63333333333334,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999995,'EPSG','9201','EPSG','8806','False easting',165506.731013462,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103835','NAD_1983_HARN_Adj_WI_St_Croix_Meters',NULL,NULL,'EPSG','4400','ESRI','104855','ESRI','103835','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103836','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.81944444444445,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.9,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999995,'EPSG','9201','EPSG','8806','False easting',185623.5712471425,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103836','NAD_1983_HARN_Adj_WI_Sauk_Meters',NULL,NULL,'EPSG','4400','ESRI','104856','ESRI','103836','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103837','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.03611111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.60555555555555,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99999,'EPSG','9201','EPSG','8806','False easting',262433.3248666498,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103837','NAD_1983_HARN_Adj_WI_Shawano_Meters',NULL,NULL,'EPSG','4400','ESRI','104858','ESRI','103837','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103838','NAD_1983_HARN_Adj_WI_Sheboygan_Meters',NULL,NULL,'EPSG','4400','ESRI','104859','ESRI','103820','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103839','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.16111111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.36666666666666,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999998,'EPSG','9201','EPSG','8806','False easting',256946.9138938278,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103839','NAD_1983_HARN_Adj_WI_Trempealeau_Meters',NULL,NULL,'EPSG','4400','ESRI','104861','ESRI','103839','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103840','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.91805555555555,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.06388888888888,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999995,'EPSG','9201','EPSG','8806','False easting',120091.4401828804,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103840','NAD_1983_HARN_Adj_WI_Washington_Meters',NULL,NULL,'EPSG','4400','ESRI','104866','ESRI','103840','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103841','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.56944444444445,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.225,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999997,'EPSG','9201','EPSG','8806','False easting',208788.4175768352,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103841','NAD_1983_HARN_Adj_WI_Waukesha_Meters',NULL,NULL,'EPSG','4400','ESRI','104867','ESRI','103841','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103842','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.42027777777778,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.81666666666666,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999996,'EPSG','9201','EPSG','8806','False easting',185013.9700279401,'EPSG','9001','EPSG','8807','False northing',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103842','NAD_1983_HARN_Adj_WI_Waupaca_Meters',NULL,NULL,'EPSG','4400','ESRI','104868','ESRI','103842','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103843','NAD_1983_HARN_Adj_WI_Winnebago_Meters',NULL,NULL,'EPSG','4400','ESRI','104870','ESRI','103805','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103844','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.15277777777779,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.41388888888888,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.925,'EPSG','9102','EPSG','8826','Easting at false origin',228600.4572009144,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103844','NAD_1983_HARN_Adj_WI_Bayfield_Meters',NULL,NULL,'EPSG','4400','ESRI','104803','ESRI','103844','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103845','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.36388888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.45777777777778,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.71388888888889,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.08333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',64008.12801625604,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103845','NAD_1983_HARN_Adj_WI_Burnett_Meters',NULL,NULL,'EPSG','4400','ESRI','104806','ESRI','103845','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103846','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.58111111111111,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.29444444444444,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.81388888888888,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.14166666666667,'EPSG','9102','EPSG','8826','Easting at false origin',60045.72009144019,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103846','NAD_1983_HARN_Adj_WI_Chippewa_Meters',NULL,NULL,'EPSG','4400','ESRI','104808','ESRI','103846','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103847','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.45833333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.39444444444445,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.59166666666667,'EPSG','9102','EPSG','8826','Easting at false origin',169164.3383286767,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103847','NAD_1983_HARN_Adj_WI_Columbia_Meters',NULL,NULL,'EPSG','4400','ESRI','104810','ESRI','103847','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103848','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.71666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.9388888888889,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.05833333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.34166666666667,'EPSG','9102','EPSG','8826','Easting at false origin',113690.6273812548,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103848','NAD_1983_HARN_Adj_WI_Crawford_Meters',NULL,NULL,'EPSG','4400','ESRI','104811','ESRI','103848','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103849','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.75,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.42222222222223,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.90833333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.23055555555555,'EPSG','9102','EPSG','8826','Easting at false origin',247193.2943865888,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103849','NAD_1983_HARN_Adj_WI_Dane_Meters',NULL,NULL,'EPSG','4400','ESRI','104812','ESRI','103849','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103850','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.04722222222222,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.28888888888889,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.73055555555555,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.01388888888889,'EPSG','9102','EPSG','8826','Easting at false origin',120091.4401828804,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103850','NAD_1983_HARN_Adj_WI_EauClaire_Meters',NULL,NULL,'EPSG','4400','ESRI','104817','ESRI','103850','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103851','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.225,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.83888888888889,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.48611111111111,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',42.78888888888888,'EPSG','9102','EPSG','8826','Easting at false origin',170078.7401574803,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103851','NAD_1983_HARN_Adj_WI_Green_Meters',NULL,NULL,'EPSG','4400','ESRI','104822','ESRI','103851','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103852','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.09444444444445,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.24166666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.66666666666666,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.94722222222222,'EPSG','9102','EPSG','8826','Easting at false origin',150876.3017526035,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103852','NAD_1983_HARN_Adj_WI_GreenLake_Meters',NULL,NULL,'EPSG','4400','ESRI','104823','ESRI','103852','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103853','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.79444444444444,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.73888888888889,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.16388888888888,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.41944444444444,'EPSG','9102','EPSG','8826','Easting at false origin',125882.6517653035,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103853','NAD_1983_HARN_Adj_WI_Jackson_Meters',NULL,NULL,'EPSG','4400','ESRI','104826','ESRI','103853','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103854','NAD_1983_HARN_Adj_WI_Lafayette_Meters',NULL,NULL,'EPSG','4400','ESRI','104832','ESRI','103851','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103855','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.20694444444445,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.03333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.30833333333333,'EPSG','9102','EPSG','8826','Easting at false origin',198425.1968503937,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103855','NAD_1983_HARN_Adj_WI_Langlade_Meters',NULL,NULL,'EPSG','4400','ESRI','104833','ESRI','103855','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103856','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.40555555555555,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.77,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.74527777777778,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.05638888888888,'EPSG','9102','EPSG','8826','Easting at false origin',74676.14935229871,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103856','NAD_1983_HARN_Adj_WI_Marathon_Meters',NULL,NULL,'EPSG','4400','ESRI','104836','ESRI','103856','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103857','NAD_1983_HARN_Adj_WI_Marquette_Meters',NULL,NULL,'EPSG','4400','ESRI','104838','ESRI','103852','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103858','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.90277777777778,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.64166666666668,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.83888888888889,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.16111111111111,'EPSG','9102','EPSG','8826','Easting at false origin',204521.2090424181,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103858','NAD_1983_HARN_Adj_WI_Monroe_Meters',NULL,NULL,'EPSG','4400','ESRI','104841','ESRI','103858','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103859','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.18611111111111,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.54444444444444,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.56666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.84166666666667,'EPSG','9102','EPSG','8826','Easting at false origin',70104.14020828043,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103859','NAD_1983_HARN_Adj_WI_Oneida_Meters',NULL,NULL,'EPSG','4400','ESRI','104843','ESRI','103859','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103860','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.86194444444445,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.22777777777777,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.52222222222222,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.75,'EPSG','9102','EPSG','8826','Easting at false origin',167640.3352806706,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103860','NAD_1983_HARN_Adj_WI_Pepin_Meters',NULL,NULL,'EPSG','4400','ESRI','104846','ESRI','103860','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103861','NAD_1983_HARN_Adj_WI_Pierce_Meters',NULL,NULL,'EPSG','4400','ESRI','104847','ESRI','103860','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103862','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.96666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.18333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.65,'EPSG','9102','EPSG','8826','Easting at false origin',56388.11277622556,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103862','NAD_1983_HARN_Adj_WI_Portage_Meters',NULL,NULL,'EPSG','4400','ESRI','104849','ESRI','103862','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103863','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.11388888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.43055555555556,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.14166666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.50277777777778,'EPSG','9102','EPSG','8826','Easting at false origin',202387.6047752096,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103863','NAD_1983_HARN_Adj_WI_Richland_Meters',NULL,NULL,'EPSG','4400','ESRI','104852','ESRI','103863','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103864','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.81388888888888,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.11666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.71944444444445,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.08055555555556,'EPSG','9102','EPSG','8826','Easting at false origin',216713.2334264669,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103864','NAD_1983_HARN_Adj_WI_Sawyer_Meters',NULL,NULL,'EPSG','4400','ESRI','104857','ESRI','103864','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103865','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.20833333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.48333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.05555555555555,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.3,'EPSG','9102','EPSG','8826','Easting at false origin',187147.5742951486,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103865','NAD_1983_HARN_Adj_WI_Taylor_Meters',NULL,NULL,'EPSG','4400','ESRI','104860','ESRI','103865','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103866','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.14722222222222,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.78333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.46666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.68333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',222504.44500889,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103866','NAD_1983_HARN_Adj_WI_Vernon_Meters',NULL,NULL,'EPSG','4400','ESRI','104862','ESRI','103866','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103867','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.625,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.48888888888889,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.93055555555555,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.225,'EPSG','9102','EPSG','8826','Easting at false origin',134417.0688341377,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103867','NAD_1983_HARN_Adj_WI_Vilas_Meters',NULL,NULL,'EPSG','4400','ESRI','104863','ESRI','103867','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103868','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.66944444444444,'EPSG','9102','EPSG','8822','Longitude of false origin',-88.54166666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.58888888888889,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',42.75,'EPSG','9102','EPSG','8826','Easting at false origin',232562.8651257303,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103868','NAD_1983_HARN_Adj_WI_Walworth_Meters',NULL,NULL,'EPSG','4400','ESRI','104864','ESRI','103868','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103869','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.26666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.78333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.77222222222222,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.15,'EPSG','9102','EPSG','8826','Easting at false origin',234086.8681737364,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103869','NAD_1983_HARN_Adj_WI_Washburn_Meters',NULL,NULL,'EPSG','4400','ESRI','104865','ESRI','103869','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103870','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.70833333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.24166666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.975,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.25277777777778,'EPSG','9102','EPSG','8826','Easting at false origin',120091.4401828804,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103870','NAD_1983_HARN_Adj_WI_Waushara_Meters',NULL,NULL,'EPSG','4400','ESRI','104869','ESRI','103870','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103871','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.15138888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.18055555555555,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.54444444444444,'EPSG','9102','EPSG','8826','Easting at false origin',208483.616967234,'EPSG','9001','EPSG','8827','Northing at false origin',0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103871','NAD_1983_HARN_Adj_WI_Wood_Meters',NULL,NULL,'EPSG','4400','ESRI','104871','ESRI','103871','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103900','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.36666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999999,'EPSG','9201','EPSG','8806','False easting',483000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103900','NAD_1983_HARN_Adj_WI_Adams_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104800','ESRI','103900','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103901','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.70611111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.62222222222222,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999997,'EPSG','9201','EPSG','8806','False easting',567000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103901','NAD_1983_HARN_Adj_WI_Ashland_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104801','ESRI','103901','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103902','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.13333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.85,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999996,'EPSG','9201','EPSG','8806','False easting',305609.625,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103902','NAD_1983_HARN_Adj_WI_Barron_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104802','ESRI','103902','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103903','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.0,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.0,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.00002,'EPSG','9201','EPSG','8806','False easting',103674.3333,'EPSG','9003','EPSG','8807','False northing',15091.8,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103903','NAD_1983_HARN_Adj_WI_Brown_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104804','ESRI','103903','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103904','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.48138888888889,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.79722222222222,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',575000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103904','NAD_1983_HARN_Adj_WI_Buffalo_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104805','ESRI','103904','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103905','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.71944444444445,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.5,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999996,'EPSG','9201','EPSG','8806','False easting',803000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103905','NAD_1983_HARN_Adj_WI_Calumet_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104807','ESRI','103905','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103906','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.6,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.70833333333334,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999994,'EPSG','9201','EPSG','8806','False easting',656000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103906','NAD_1983_HARN_Adj_WI_Clark_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104809','ESRI','103906','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103907','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.47222222222222,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.775,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999997,'EPSG','9201','EPSG','8806','False easting',864000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103907','NAD_1983_HARN_Adj_WI_Dodge_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104813','ESRI','103907','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103908','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.4,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.27222222222223,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999991,'EPSG','9201','EPSG','8806','False easting',521000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103908','NAD_1983_HARN_Adj_WI_Door_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104814','ESRI','103908','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103909','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.88333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.91666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999995,'EPSG','9201','EPSG','8806','False easting',194000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103909','NAD_1983_HARN_Adj_WI_Douglas_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104815','ESRI','103909','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103910','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.40833333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.89444444444445,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999998,'EPSG','9201','EPSG','8806','False easting',170000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103910','NAD_1983_HARN_Adj_WI_Dunn_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104816','ESRI','103910','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103911','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.43888888888888,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.14166666666668,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999993,'EPSG','9201','EPSG','8806','False easting',438000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103911','NAD_1983_HARN_Adj_WI_Florence_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104818','ESRI','103911','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103912','NAD_1983_HARN_Adj_WI_Fond_du_Lac_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104819','ESRI','103905','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103913','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.00555555555555,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.63333333333334,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999996,'EPSG','9201','EPSG','8806','False easting',905000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103913','NAD_1983_HARN_Adj_WI_Forest_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104820','ESRI','103913','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103914','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.41111111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.8,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999997,'EPSG','9201','EPSG','8806','False easting',795000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103914','NAD_1983_HARN_Adj_WI_Grant_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104821','ESRI','103914','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103915','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.53888888888888,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.16111111111111,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999997,'EPSG','9201','EPSG','8806','False easting',371000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103915','NAD_1983_HARN_Adj_WI_Iowa_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104824','ESRI','103915','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103916','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',45.43333333333333,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.25555555555556,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999996,'EPSG','9201','EPSG','8806','False easting',725000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103916','NAD_1983_HARN_Adj_WI_Iron_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104825','ESRI','103916','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103917','NAD_1983_HARN_Adj_WI_Jefferson_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104827','ESRI','103907','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103918','NAD_1983_HARN_Adj_WI_Juneau_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104828','ESRI','103900','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103919','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.21666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.89444444444445,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999998,'EPSG','9201','EPSG','8806','False easting',610000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103919','NAD_1983_HARN_Adj_WI_Kenosha_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104829','ESRI','103919','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103920','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.26666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.55,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',262000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103920','NAD_1983_HARN_Adj_WI_Kewaunee_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104830','ESRI','103920','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103921','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.45111111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.31666666666666,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999994,'EPSG','9201','EPSG','8806','False easting',428000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103921','NAD_1983_HARN_Adj_WI_LaCrosse_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104831','ESRI','103921','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103922','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.84444444444445,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.73333333333333,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999998,'EPSG','9201','EPSG','8806','False easting',381000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103922','NAD_1983_HARN_Adj_WI_Lincoln_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104834','ESRI','103922','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103923','NAD_1983_HARN_Adj_WI_Manitowoc_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104835','ESRI','103920','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103924','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.69166666666666,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.71111111111111,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999986,'EPSG','9201','EPSG','8806','False easting',783000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103924','NAD_1983_HARN_Adj_WI_Marinette_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104837','ESRI','103924','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103925','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.71666666666667,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.41666666666667,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999994,'EPSG','9201','EPSG','8806','False easting',346000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103925','NAD_1983_HARN_Adj_WI_Menominee_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104839','ESRI','103925','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103926','NAD_1983_HARN_Adj_WI_Milwaukee_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104840','ESRI','103919','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103927','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.39722222222222,'EPSG','9102','EPSG','8802','Longitude of natural origin',-87.90833333333335,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999991,'EPSG','9201','EPSG','8806','False easting',600000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103927','NAD_1983_HARN_Adj_WI_Oconto_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104842','ESRI','103927','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103928','NAD_1983_HARN_Adj_WI_Outagamie_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104844','ESRI','103905','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103929','NAD_1983_HARN_Adj_WI_Ozaukee_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104845','ESRI','103919','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103930','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.66111111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.63333333333334,'EPSG','9102','EPSG','8805','Scale factor at natural origin',1.0,'EPSG','9201','EPSG','8806','False easting',465000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103930','NAD_1983_HARN_Adj_WI_Polk_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104848','ESRI','103930','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103931','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.55555555555555,'EPSG','9102','EPSG','8802','Longitude of natural origin',-90.48888888888889,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999998,'EPSG','9201','EPSG','8806','False easting',748000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103931','NAD_1983_HARN_Adj_WI_Price_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104850','ESRI','103931','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103932','NAD_1983_HARN_Adj_WI_Racine_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104851','ESRI','103919','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103933','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',41.94444444444444,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.07222222222222,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999996,'EPSG','9201','EPSG','8806','False easting',480000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103933','NAD_1983_HARN_Adj_WI_Rock_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104853','ESRI','103933','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103934','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.91944444444444,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.06666666666666,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999997,'EPSG','9201','EPSG','8806','False easting',822000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103934','NAD_1983_HARN_Adj_WI_Rusk_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104854','ESRI','103934','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103935','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.03611111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-92.63333333333334,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999995,'EPSG','9201','EPSG','8806','False easting',543000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103935','NAD_1983_HARN_Adj_WI_St_Croix_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104855','ESRI','103935','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103936','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.81944444444445,'EPSG','9102','EPSG','8802','Longitude of natural origin',-89.9,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999995,'EPSG','9201','EPSG','8806','False easting',609000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103936','NAD_1983_HARN_Adj_WI_Sauk_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104856','ESRI','103936','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103937','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',44.03611111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.60555555555555,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.99999,'EPSG','9201','EPSG','8806','False easting',861000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103937','NAD_1983_HARN_Adj_WI_Shawano_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104858','ESRI','103937','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103938','NAD_1983_HARN_Adj_WI_Sheboygan_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104859','ESRI','103920','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103939','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.16111111111111,'EPSG','9102','EPSG','8802','Longitude of natural origin',-91.36666666666666,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999998,'EPSG','9201','EPSG','8806','False easting',843000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103939','NAD_1983_HARN_Adj_WI_Trempealeau_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104861','ESRI','103939','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103940','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.91805555555555,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.06388888888888,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999995,'EPSG','9201','EPSG','8806','False easting',394000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103940','NAD_1983_HARN_Adj_WI_Washington_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104866','ESRI','103940','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103941','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',42.56944444444445,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.225,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999997,'EPSG','9201','EPSG','8806','False easting',685000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103941','NAD_1983_HARN_Adj_WI_Waukesha_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104867','ESRI','103941','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103942','unnamed',NULL,NULL,'EPSG','1418','EPSG','9807','Transverse Mercator','EPSG','8801','Latitude of natural origin',43.42027777777778,'EPSG','9102','EPSG','8802','Longitude of natural origin',-88.81666666666666,'EPSG','9102','EPSG','8805','Scale factor at natural origin',0.999996,'EPSG','9201','EPSG','8806','False easting',607000.0,'EPSG','9003','EPSG','8807','False northing',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103942','NAD_1983_HARN_Adj_WI_Waupaca_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104868','ESRI','103942','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103943','NAD_1983_HARN_Adj_WI_Winnebago_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104870','ESRI','103905','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103944','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.33333333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.15277777777779,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',46.41388888888888,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.925,'EPSG','9102','EPSG','8826','Easting at false origin',750000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103944','NAD_1983_HARN_Adj_WI_Bayfield_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104803','ESRI','103944','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103945','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.36388888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.45777777777778,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.71388888888889,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.08333333333334,'EPSG','9102','EPSG','8826','Easting at false origin',210000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103945','NAD_1983_HARN_Adj_WI_Burnett_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104806','ESRI','103945','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103946','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.58111111111111,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.29444444444444,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.81388888888888,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.14166666666667,'EPSG','9102','EPSG','8826','Easting at false origin',197000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "projected_crs" VALUES('ESRI','103946','NAD_1983_HARN_Adj_WI_Chippewa_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104808','ESRI','103946','EPSG','1418',NULL,0);
INSERT INTO "conversion" VALUES('ESRI','103947','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.45833333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.39444444444445,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.33333333333334,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.59166666666667,'EPSG','9102','EPSG','8826','Easting at false origin',555000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103947','NAD_1983_HARN_Adj_WI_Columbia_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104810','ESRI','103947','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103948','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.71666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.9388888888889,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.05833333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.34166666666667,'EPSG','9102','EPSG','8826','Easting at false origin',373000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103948','NAD_1983_HARN_Adj_WI_Crawford_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104811','ESRI','103948','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103949','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.75,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.42222222222223,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.90833333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.23055555555555,'EPSG','9102','EPSG','8826','Easting at false origin',811000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103949','NAD_1983_HARN_Adj_WI_Dane_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104812','ESRI','103949','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103950','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.04722222222222,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.28888888888889,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.73055555555555,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.01388888888889,'EPSG','9102','EPSG','8826','Easting at false origin',394000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103950','NAD_1983_HARN_Adj_WI_EauClaire_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104817','ESRI','103950','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103951','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.225,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.83888888888889,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.48611111111111,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',42.78888888888888,'EPSG','9102','EPSG','8826','Easting at false origin',558000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103951','NAD_1983_HARN_Adj_WI_Green_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104822','ESRI','103951','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103952','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.09444444444445,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.24166666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.66666666666666,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.94722222222222,'EPSG','9102','EPSG','8826','Easting at false origin',495000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103952','NAD_1983_HARN_Adj_WI_GreenLake_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104823','ESRI','103952','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103953','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.79444444444444,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.73888888888889,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.16388888888888,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.41944444444444,'EPSG','9102','EPSG','8826','Easting at false origin',413000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103953','NAD_1983_HARN_Adj_WI_Jackson_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104826','ESRI','103953','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103954','NAD_1983_HARN_Adj_WI_Lafayette_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104832','ESRI','103951','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103955','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.20694444444445,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.03333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.0,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.30833333333333,'EPSG','9102','EPSG','8826','Easting at false origin',651000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103955','NAD_1983_HARN_Adj_WI_Langlade_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104833','ESRI','103955','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103956','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.40555555555555,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.77,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.74527777777778,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.05638888888888,'EPSG','9102','EPSG','8826','Easting at false origin',245000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103956','NAD_1983_HARN_Adj_WI_Marathon_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104836','ESRI','103956','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103957','NAD_1983_HARN_Adj_WI_Marquette_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104838','ESRI','103952','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103958','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.90277777777778,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.64166666666668,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.83888888888889,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.16111111111111,'EPSG','9102','EPSG','8826','Easting at false origin',671000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103958','NAD_1983_HARN_Adj_WI_Monroe_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104841','ESRI','103958','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103959','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.18611111111111,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.54444444444444,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.56666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.84166666666667,'EPSG','9102','EPSG','8826','Easting at false origin',230000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103959','NAD_1983_HARN_Adj_WI_Oneida_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104843','ESRI','103959','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103960','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.86194444444445,'EPSG','9102','EPSG','8822','Longitude of false origin',-92.22777777777777,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.52222222222222,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.75,'EPSG','9102','EPSG','8826','Easting at false origin',550000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103960','NAD_1983_HARN_Adj_WI_Pepin_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104846','ESRI','103960','EPSG','1418',NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103961','NAD_1983_HARN_Adj_WI_Pierce_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104847','ESRI','103960','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103962','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.96666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.5,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.18333333333333,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.65,'EPSG','9102','EPSG','8826','Easting at false origin',185000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103962','NAD_1983_HARN_Adj_WI_Portage_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104849','ESRI','103962','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103963','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',42.11388888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.43055555555556,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.14166666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.50277777777778,'EPSG','9102','EPSG','8826','Easting at false origin',664000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103963','NAD_1983_HARN_Adj_WI_Richland_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104852','ESRI','103963','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103964','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.81388888888888,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.11666666666666,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.71944444444445,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.08055555555556,'EPSG','9102','EPSG','8826','Easting at false origin',711000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103964','NAD_1983_HARN_Adj_WI_Sawyer_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104857','ESRI','103964','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103965','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.20833333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.48333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.05555555555555,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',45.3,'EPSG','9102','EPSG','8826','Easting at false origin',614000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103965','NAD_1983_HARN_Adj_WI_Taylor_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104860','ESRI','103965','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103966','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.14722222222222,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.78333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.46666666666667,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',43.68333333333333,'EPSG','9102','EPSG','8826','Easting at false origin',730000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103966','NAD_1983_HARN_Adj_WI_Vernon_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104862','ESRI','103966','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103967','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',45.625,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.48888888888889,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.93055555555555,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.225,'EPSG','9102','EPSG','8826','Easting at false origin',441000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103967','NAD_1983_HARN_Adj_WI_Vilas_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104863','ESRI','103967','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103968','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',41.66944444444444,'EPSG','9102','EPSG','8822','Longitude of false origin',-88.54166666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',42.58888888888889,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',42.75,'EPSG','9102','EPSG','8826','Easting at false origin',763000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103968','NAD_1983_HARN_Adj_WI_Walworth_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104864','ESRI','103968','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103969','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',44.26666666666667,'EPSG','9102','EPSG','8822','Longitude of false origin',-91.78333333333333,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',45.77222222222222,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',46.15,'EPSG','9102','EPSG','8826','Easting at false origin',768000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103969','NAD_1983_HARN_Adj_WI_Washburn_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104865','ESRI','103969','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103970','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.70833333333334,'EPSG','9102','EPSG','8822','Longitude of false origin',-89.24166666666667,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',43.975,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.25277777777778,'EPSG','9102','EPSG','8826','Easting at false origin',394000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103970','NAD_1983_HARN_Adj_WI_Waushara_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104869','ESRI','103970','EPSG','1418',NULL,1);
INSERT INTO "conversion" VALUES('ESRI','103971','unnamed',NULL,NULL,'EPSG','1418','EPSG','9802','Lambert Conic Conformal (2SP)','EPSG','8821','Latitude of false origin',43.15138888888889,'EPSG','9102','EPSG','8822','Longitude of false origin',-90.0,'EPSG','9102','EPSG','8823','Latitude of 1st standard parallel',44.18055555555555,'EPSG','9102','EPSG','8824','Latitude of 2nd standard parallel',44.54444444444444,'EPSG','9102','EPSG','8826','Easting at false origin',684000.0,'EPSG','9003','EPSG','8827','Northing at false origin',0.0,'EPSG','9003',NULL,NULL,NULL,NULL,NULL,NULL,1);
INSERT INTO "projected_crs" VALUES('ESRI','103971','NAD_1983_HARN_Adj_WI_Wood_Feet',NULL,NULL,'ESRI','Foot_US','ESRI','104871','ESRI','103971','EPSG','1418',NULL,1);
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102340','projected_crs','EPSG','2847','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102341','projected_crs','EPSG','2848','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102342','projected_crs','EPSG','2849','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102343','projected_crs','EPSG','2850','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102344','projected_crs','EPSG','2851','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102345','projected_crs','EPSG','2852','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102346','projected_crs','EPSG','2853','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102347','projected_crs','EPSG','2854','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102348','projected_crs','EPSG','2855','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102349','projected_crs','EPSG','2856','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102065','projected_crs','EPSG','5513','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102067','projected_crs','EPSG','5514','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102066','projected_crs','EPSG','5221','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102744','projected_crs','EPSG','3567','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102745','projected_crs','EPSG','5646','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102746','projected_crs','EPSG','2283','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102747','projected_crs','EPSG','2284','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102740','projected_crs','EPSG','2278','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102741','projected_crs','EPSG','2279','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102742','projected_crs','EPSG','3560','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102743','projected_crs','EPSG','3566','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102748','projected_crs','EPSG','2285','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102724','projected_crs','EPSG','2267','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102986','projected_crs','EPSG','6403','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102987','projected_crs','EPSG','6406','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102984','projected_crs','EPSG','6401','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102725','projected_crs','EPSG','2268','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102982','projected_crs','EPSG','6399','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102983','projected_crs','EPSG','6400','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102669','projected_crs','EPSG','2242','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102668','projected_crs','EPSG','2241','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102667','projected_crs','EPSG','2240','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102050','projected_crs','EPSG','6332','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102663','projected_crs','EPSG','3759','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102988','projected_crs','EPSG','6404','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102660','projected_crs','EPSG','2238','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102111','projected_crs','EPSG','5519','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102110','projected_crs','EPSG','2154','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102113','projected_crs','EPSG','3785','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102112','projected_crs','EPSG','3764','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102119','projected_crs','EPSG','3080','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102966','projected_crs','EPSG','6393','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102788','projected_crs','EPSG','6251','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103426','projected_crs','EPSG','8162','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103214','projected_crs','EPSG','4082','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','31917','projected_crs','EPSG','31986','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103165','projected_crs','EPSG','6621','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','31919','projected_crs','EPSG','31988','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','31918','projected_crs','EPSG','31987','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102059','projected_crs','EPSG','6341','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102989','projected_crs','EPSG','6408','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102188','projected_crs','EPSG','3777','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102189','projected_crs','EPSG','3801','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102186','projected_crs','EPSG','3775','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102187','projected_crs','EPSG','3776','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102184','projected_crs','EPSG','3400','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102185','projected_crs','EPSG','3401','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102182','projected_crs','EPSG','3773','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102183','projected_crs','EPSG','3800','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102180','projected_crs','EPSG','3771','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102181','projected_crs','EPSG','3772','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','54035','projected_crs','ESRI','8857','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','54037','projected_crs','ESRI','8859','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','54036','projected_crs','ESRI','8858','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103048','projected_crs','EPSG','6468','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103049','projected_crs','EPSG','6467','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103161','projected_crs','EPSG','6588','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103160','projected_crs','EPSG','6578','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103044','projected_crs','EPSG','6464','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103045','projected_crs','EPSG','6463','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103046','projected_crs','EPSG','6465','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103047','projected_crs','EPSG','6466','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103040','projected_crs','EPSG','6460','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103041','projected_crs','EPSG','6459','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103042','projected_crs','EPSG','6461','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103043','projected_crs','EPSG','6462','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102304','projected_crs','EPSG','2819','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103163','projected_crs','EPSG','6620','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102657','projected_crs','EPSG','2235','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102307','projected_crs','EPSG','2820','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102300','projected_crs','EPSG','2818','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103162','projected_crs','EPSG','6586','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102718','projected_crs','EPSG','2263','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103082','projected_crs','EPSG','6504','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103148','projected_crs','EPSG','6573','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102444','projected_crs','EPSG','3825','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102443','projected_crs','EPSG','3826','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102442','projected_crs','EPSG','3827','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102441','projected_crs','EPSG','3828','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102524','projected_crs','EPSG','6632','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102713','projected_crs','EPSG','2258','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102527','projected_crs','EPSG','6633','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102520','projected_crs','EPSG','6628','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102521','projected_crs','EPSG','6629','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102522','projected_crs','EPSG','6630','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102523','projected_crs','EPSG','6631','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103448','projected_crs','EPSG','8136','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103449','projected_crs','EPSG','8134','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103198','projected_crs','EPSG','6618','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103111','projected_crs','EPSG','6529','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102711','projected_crs','EPSG','3424','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103412','projected_crs','EPSG','8193','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103192','projected_crs','EPSG','6611','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103193','projected_crs','EPSG','6613','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103190','projected_crs','EPSG','6605','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102710','projected_crs','EPSG','3437','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103196','projected_crs','EPSG','6612','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103197','projected_crs','EPSG','6614','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103194','projected_crs','EPSG','6617','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102768','projected_crs','EPSG','6257','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103410','projected_crs','EPSG','8200','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103417','projected_crs','EPSG','8093','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102749','projected_crs','EPSG','2286','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103415','projected_crs','EPSG','8182','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103414','projected_crs','EPSG','8185','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102769','projected_crs','EPSG','6244','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102623','projected_crs','EPSG','6682','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102622','projected_crs','EPSG','6681','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102621','projected_crs','EPSG','6680','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102620','projected_crs','EPSG','6679','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102627','projected_crs','EPSG','6686','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102626','projected_crs','EPSG','6685','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102625','projected_crs','EPSG','6684','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102624','projected_crs','EPSG','6683','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102780','projected_crs','EPSG','6260','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102781','projected_crs','EPSG','6254','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102782','projected_crs','EPSG','6269','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102628','projected_crs','EPSG','6687','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102784','projected_crs','EPSG','6267','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102785','projected_crs','EPSG','6270','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102786','projected_crs','EPSG','6274','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102607','projected_crs','EPSG','3463','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102985','projected_crs','EPSG','6402','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103349','projected_crs','EPSG','8133','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103348','projected_crs','EPSG','8135','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102230','projected_crs','EPSG','2760','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102234','projected_crs','EPSG','3158','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102235','projected_crs','EPSG','3159','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102236','projected_crs','EPSG','3160','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102980','projected_crs','EPSG','6397','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102151','projected_crs','EPSG','3092','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102153','projected_crs','EPSG','3094','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102152','projected_crs','EPSG','3093','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102155','projected_crs','EPSG','3096','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102154','projected_crs','EPSG','3095','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103334','projected_crs','EPSG','8151','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102666','projected_crs','EPSG','2239','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103087','projected_crs','EPSG','6509','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103025','projected_crs','EPSG','6444','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102656','projected_crs','EPSG','2234','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102305','projected_crs','EPSG','5367','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102654','projected_crs','EPSG','2232','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102655','projected_crs','EPSG','2233','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102652','projected_crs','EPSG','3434','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102653','projected_crs','EPSG','2231','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102719','projected_crs','EPSG','2264','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102651','projected_crs','EPSG','3433','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102717','projected_crs','EPSG','2262','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102716','projected_crs','EPSG','2261','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102715','projected_crs','EPSG','2260','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102714','projected_crs','EPSG','2259','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102308','projected_crs','EPSG','2821','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102309','projected_crs','EPSG','2822','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102658','projected_crs','EPSG','2236','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102659','projected_crs','EPSG','2237','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103129','projected_crs','EPSG','6549','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103128','projected_crs','EPSG','6550','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103326','projected_crs','EPSG','8161','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103122','projected_crs','EPSG','6543','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103123','projected_crs','EPSG','6544','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102783','projected_crs','EPSG','6261','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103121','projected_crs','EPSG','6542','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103120','projected_crs','EPSG','6539','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103127','projected_crs','EPSG','6548','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103126','projected_crs','EPSG','6547','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103125','projected_crs','EPSG','6545','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103124','projected_crs','EPSG','6546','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103350','projected_crs','EPSG','8131','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103354','projected_crs','EPSG','8125','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103355','projected_crs','EPSG','8123','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103169','projected_crs','EPSG','6626','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103017','projected_crs','EPSG','6435','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103016','projected_crs','EPSG','6434','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102979','projected_crs','EPSG','6396','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102978','projected_crs','EPSG','6395','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103013','projected_crs','EPSG','6428','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103012','projected_crs','EPSG','6430','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103011','projected_crs','EPSG','6431','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103010','projected_crs','EPSG','6427','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102973','projected_crs','EPSG','6610','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102972','projected_crs','EPSG','6580','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102971','projected_crs','EPSG','6579','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102970','projected_crs','EPSG','6557','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102977','projected_crs','EPSG','6394','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102976','projected_crs','EPSG','6356','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102975','projected_crs','EPSG','6355','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103018','projected_crs','EPSG','6436','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103212','projected_crs','EPSG','4063','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103408','projected_crs','EPSG','8204','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102500','projected_crs','EPSG','6785','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103158','projected_crs','EPSG','6582','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103159','projected_crs','EPSG','6584','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103156','projected_crs','EPSG','6587','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103157','projected_crs','EPSG','6585','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103154','projected_crs','EPSG','6583','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103155','projected_crs','EPSG','6577','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103152','projected_crs','EPSG','6576','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103153','projected_crs','EPSG','6581','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103150','projected_crs','EPSG','6574','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103151','projected_crs','EPSG','6575','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103217','projected_crs','EPSG','4094','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103216','projected_crs','EPSG','4093','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102259','projected_crs','EPSG','2778','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103367','projected_crs','EPSG','8101','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103303','projected_crs','EPSG','8214','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103080','projected_crs','EPSG','6502','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103301','projected_crs','EPSG','8222','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102278','projected_crs','EPSG','2797','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102279','projected_crs','EPSG','2798','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103305','projected_crs','EPSG','8209','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103081','projected_crs','EPSG','6500','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102274','projected_crs','EPSG','2793','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102275','projected_crs','EPSG','2794','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102276','projected_crs','EPSG','2795','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102277','projected_crs','EPSG','2796','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102270','projected_crs','EPSG','2789','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102271','projected_crs','EPSG','2790','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102272','projected_crs','EPSG','2791','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102273','projected_crs','EPSG','2792','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103083','projected_crs','EPSG','6503','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103070','projected_crs','EPSG','6491','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103443','projected_crs','EPSG','8140','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103084','projected_crs','EPSG','6501','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103202','projected_crs','EPSG','4049','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102296','projected_crs','EPSG','2815','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102297','projected_crs','EPSG','2816','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102294','projected_crs','EPSG','2813','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102295','projected_crs','EPSG','2814','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102292','projected_crs','EPSG','2811','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102293','projected_crs','EPSG','2812','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102290','projected_crs','EPSG','2809','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102358','projected_crs','EPSG','2865','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','65163','projected_crs','EPSG','3088','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102356','projected_crs','EPSG','2863','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102355','projected_crs','EPSG','2862','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102354','projected_crs','EPSG','2861','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102353','projected_crs','EPSG','2860','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102352','projected_crs','EPSG','2859','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102298','projected_crs','EPSG','2817','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102350','projected_crs','EPSG','2857','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103321','projected_crs','EPSG','8171','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102268','projected_crs','EPSG','2787','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103089','projected_crs','EPSG','6510','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102753','projected_crs','EPSG','2288','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102752','projected_crs','EPSG','2287','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102751','projected_crs','EPSG','26854','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102750','projected_crs','EPSG','26853','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102757','projected_crs','EPSG','3738','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102756','projected_crs','EPSG','3737','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102755','projected_crs','EPSG','3736','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102754','projected_crs','EPSG','2289','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102758','projected_crs','EPSG','3739','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102995','projected_crs','EPSG','6411','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102994','projected_crs','EPSG','6412','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102618','projected_crs','EPSG','6677','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102619','projected_crs','EPSG','6678','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102991','projected_crs','EPSG','6405','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102990','projected_crs','EPSG','6407','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102993','projected_crs','EPSG','6410','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102992','projected_crs','EPSG','6409','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102612','projected_crs','EPSG','6671','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102613','projected_crs','EPSG','6672','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102610','projected_crs','EPSG','6669','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102611','projected_crs','EPSG','6670','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102616','projected_crs','EPSG','6675','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102617','projected_crs','EPSG','6676','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102614','projected_crs','EPSG','6673','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102615','projected_crs','EPSG','6674','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102260','projected_crs','EPSG','2779','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102124','projected_crs','EPSG','26701','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102125','projected_crs','EPSG','26702','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102126','projected_crs','EPSG','3370','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102127','projected_crs','EPSG','3371','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102128','projected_crs','EPSG','26901','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102129','projected_crs','EPSG','26902','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103201','projected_crs','EPSG','4048','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102054','projected_crs','EPSG','6336','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102055','projected_crs','EPSG','6337','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102056','projected_crs','EPSG','6338','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102057','projected_crs','EPSG','6339','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102199','projected_crs','EPSG','3812','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102051','projected_crs','EPSG','6333','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102052','projected_crs','EPSG','6334','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102053','projected_crs','EPSG','6335','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102058','projected_crs','EPSG','6340','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102190','projected_crs','EPSG','3005','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102728','projected_crs','EPSG','2271','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102729','projected_crs','EPSG','2272','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102357','projected_crs','EPSG','2864','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103455','projected_crs','EPSG','8124','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103112','projected_crs','EPSG','6533','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103113','projected_crs','EPSG','6536','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103059','projected_crs','EPSG','6477','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103058','projected_crs','EPSG','6478','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103116','projected_crs','EPSG','6538','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102508','projected_crs','EPSG','6817','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103114','projected_crs','EPSG','6534','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103115','projected_crs','EPSG','6540','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103053','projected_crs','EPSG','6472','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103052','projected_crs','EPSG','6471','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103051','projected_crs','EPSG','6470','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103050','projected_crs','EPSG','6469','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103057','projected_crs','EPSG','6476','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103056','projected_crs','EPSG','6475','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103055','projected_crs','EPSG','6474','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103054','projected_crs','EPSG','6473','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103339','projected_crs','EPSG','8145','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102466','projected_crs','EPSG','26857','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103450','projected_crs','EPSG','8132','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103015','projected_crs','EPSG','6433','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103204','projected_crs','EPSG','4051','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103026','projected_crs','EPSG','6446','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102722','projected_crs','EPSG','3734','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103460','projected_crs','EPSG','8116','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103027','projected_crs','EPSG','6445','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103024','projected_crs','EPSG','6441','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102439','projected_crs','EPSG','4462','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103022','projected_crs','EPSG','6438','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103205','projected_crs','EPSG','4056','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103023','projected_crs','EPSG','6443','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102723','projected_crs','EPSG','3735','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103020','projected_crs','EPSG','6442','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103021','projected_crs','EPSG','6440','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103457','projected_crs','EPSG','8120','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103456','projected_crs','EPSG','8122','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102539','projected_crs','EPSG','6820','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102538','projected_crs','EPSG','6816','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103453','projected_crs','EPSG','8128','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103452','projected_crs','EPSG','8130','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103028','projected_crs','EPSG','6447','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103029','projected_crs','EPSG','6450','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102533','projected_crs','EPSG','6792','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102532','projected_crs','EPSG','6788','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102531','projected_crs','EPSG','6796','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102530','projected_crs','EPSG','6784','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102537','projected_crs','EPSG','6812','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102536','projected_crs','EPSG','6808','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102535','projected_crs','EPSG','6804','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102534','projected_crs','EPSG','6800','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103189','projected_crs','EPSG','6607','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103188','projected_crs','EPSG','6608','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103369','projected_crs','EPSG','8097','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103019','projected_crs','EPSG','6437','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103181','projected_crs','EPSG','6599','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103180','projected_crs','EPSG','6597','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103183','projected_crs','EPSG','6602','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103182','projected_crs','EPSG','6600','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103185','projected_crs','EPSG','6603','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103184','projected_crs','EPSG','6601','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103187','projected_crs','EPSG','6879','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103186','projected_crs','EPSG','6606','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102326','projected_crs','EPSG','2838','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102327','projected_crs','EPSG','2839','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102797','projected_crs','EPSG','6258','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102796','projected_crs','EPSG','6249','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102795','projected_crs','EPSG','6253','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102794','projected_crs','EPSG','6271','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102793','projected_crs','EPSG','6248','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102792','projected_crs','EPSG','6268','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102791','projected_crs','EPSG','6263','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102790','projected_crs','EPSG','6245','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102798','projected_crs','EPSG','6265','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102388','projected_crs','EPSG','6348','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102384','projected_crs','EPSG','6344','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102385','projected_crs','EPSG','6345','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102386','projected_crs','EPSG','6346','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102387','projected_crs','EPSG','6347','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102380','projected_crs','EPSG','6867','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102381','projected_crs','EPSG','6868','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102382','projected_crs','EPSG','6342','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102383','projected_crs','EPSG','6343','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103404','projected_crs','EPSG','8213','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103164','projected_crs','EPSG','6619','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102548','projected_crs','EPSG','6856','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102549','projected_crs','EPSG','6860','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102546','projected_crs','EPSG','6844','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102547','projected_crs','EPSG','6852','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102544','projected_crs','EPSG','6840','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102545','projected_crs','EPSG','6848','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102542','projected_crs','EPSG','6832','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102543','projected_crs','EPSG','6836','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102540','projected_crs','EPSG','6824','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102541','projected_crs','EPSG','6828','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102362','projected_crs','EPSG','4647','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102363','projected_crs','EPSG','3090','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102361','projected_crs','EPSG','2866','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102006','projected_crs','EPSG','3338','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103401','projected_crs','EPSG','8224','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103402','projected_crs','EPSG','8220','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103403','projected_crs','EPSG','8216','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102779','projected_crs','EPSG','6266','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103439','projected_crs','EPSG','8146','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102778','projected_crs','EPSG','6273','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102645','projected_crs','EPSG','2229','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102644','projected_crs','EPSG','2228','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102311','projected_crs','EPSG','2824','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102646','projected_crs','EPSG','2230','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102317','projected_crs','EPSG','2830','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102316','projected_crs','EPSG','2829','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102315','projected_crs','EPSG','2828','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102314','projected_crs','EPSG','2827','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102090','projected_crs','EPSG','3770','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102091','projected_crs','EPSG','3003','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102092','projected_crs','EPSG','3004','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102318','projected_crs','EPSG','2831','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102095','projected_crs','EPSG','3448','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102764','projected_crs','EPSG','4417','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102765','projected_crs','EPSG','4434','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102771','projected_crs','EPSG','6247','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102770','projected_crs','EPSG','6246','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103213','projected_crs','EPSG','4071','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102167','projected_crs','EPSG','2942','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103138','projected_crs','EPSG','6561','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102169','projected_crs','EPSG','2943','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103139','projected_crs','EPSG','6562','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103062','projected_crs','EPSG','6485','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103063','projected_crs','EPSG','6484','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103060','projected_crs','EPSG','6479','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103061','projected_crs','EPSG','6483','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103066','projected_crs','EPSG','6480','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103067','projected_crs','EPSG','6482','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103064','projected_crs','EPSG','6486','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103065','projected_crs','EPSG','6481','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103068','projected_crs','EPSG','6487','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103069','projected_crs','EPSG','6488','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103365','projected_crs','EPSG','8105','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103418','projected_crs','EPSG','8091','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103149','projected_crs','EPSG','6572','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103117','projected_crs','EPSG','6537','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103364','projected_crs','EPSG','8107','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103145','projected_crs','EPSG','6569','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103144','projected_crs','EPSG','6568','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103147','projected_crs','EPSG','6571','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103146','projected_crs','EPSG','6570','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103141','projected_crs','EPSG','6564','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103140','projected_crs','EPSG','6563','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103143','projected_crs','EPSG','6567','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103142','projected_crs','EPSG','6565','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103366','projected_crs','EPSG','8103','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103200','projected_crs','EPSG','6566','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103310','projected_crs','EPSG','8198','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102593','projected_crs','EPSG','6688','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103362','projected_crs','EPSG','8111','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102595','projected_crs','EPSG','6690','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102594','projected_crs','EPSG','6689','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102597','projected_crs','EPSG','6692','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102596','projected_crs','EPSG','6691','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102692','projected_crs','EPSG','26850','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102693','projected_crs','EPSG','26851','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102691','projected_crs','EPSG','26849','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102694','projected_crs','EPSG','2254','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102695','projected_crs','EPSG','2255','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103311','projected_crs','EPSG','8196','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102214','projected_crs','EPSG','4826','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102502','projected_crs','EPSG','6789','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102503','projected_crs','EPSG','6793','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102269','projected_crs','EPSG','2788','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102501','projected_crs','EPSG','6797','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102506','projected_crs','EPSG','6809','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102507','projected_crs','EPSG','6813','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102504','projected_crs','EPSG','6801','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102505','projected_crs','EPSG','6805','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102263','projected_crs','EPSG','2784','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102262','projected_crs','EPSG','2783','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102261','projected_crs','EPSG','2782','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102509','projected_crs','EPSG','6821','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102267','projected_crs','EPSG','2781','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102266','projected_crs','EPSG','2780','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102265','projected_crs','EPSG','2786','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102264','projected_crs','EPSG','2785','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102469','projected_crs','EPSG','3815','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102468','projected_crs','EPSG','26859','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103468','projected_crs','EPSG','8100','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103469','projected_crs','EPSG','8098','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103466','projected_crs','EPSG','8104','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103467','projected_crs','EPSG','8102','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102467','projected_crs','EPSG','26858','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102211','projected_crs','EPSG','3748','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103462','projected_crs','EPSG','8112','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103463','projected_crs','EPSG','8110','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102463','projected_crs','EPSG','3760','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103461','projected_crs','EPSG','8114','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102285','projected_crs','EPSG','2804','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102284','projected_crs','EPSG','2803','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102287','projected_crs','EPSG','2806','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102286','projected_crs','EPSG','2805','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102281','projected_crs','EPSG','2800','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102280','projected_crs','EPSG','2799','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102283','projected_crs','EPSG','2802','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102282','projected_crs','EPSG','2801','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102322','projected_crs','EPSG','2834','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102323','projected_crs','EPSG','2835','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102320','projected_crs','EPSG','2832','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102321','projected_crs','EPSG','2833','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102289','projected_crs','EPSG','2808','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102288','projected_crs','EPSG','2807','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102324','projected_crs','EPSG','2836','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102325','projected_crs','EPSG','2837','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102229','projected_crs','EPSG','2759','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103309','projected_crs','EPSG','8201','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102609','projected_crs','EPSG','3814','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102608','projected_crs','EPSG','3074','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103208','projected_crs','EPSG','4059','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103209','projected_crs','EPSG','4060','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103361','projected_crs','EPSG','8113','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103360','projected_crs','EPSG','8115','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103363','projected_crs','EPSG','8109','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102712','projected_crs','EPSG','2257','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102601','projected_crs','EPSG','3083','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103203','projected_crs','EPSG','4050','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102603','projected_crs','EPSG','3081','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102602','projected_crs','EPSG','3082','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103206','projected_crs','EPSG','4057','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103207','projected_crs','EPSG','4058','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102210','projected_crs','EPSG','3077','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102606','projected_crs','EPSG','3072','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102139','projected_crs','EPSG','3067','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103302','projected_crs','EPSG','8218','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102131','projected_crs','EPSG','3373','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102130','projected_crs','EPSG','3372','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103333','projected_crs','EPSG','8153','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103306','projected_crs','EPSG','8207','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103331','projected_crs','EPSG','8155','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103336','projected_crs','EPSG','8149','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103304','projected_crs','EPSG','8212','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103337','projected_crs','EPSG','8147','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102735','projected_crs','EPSG','3455','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102734','projected_crs','EPSG','4457','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102737','projected_crs','EPSG','2275','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102040','projected_crs','EPSG','5178','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102047','projected_crs','EPSG','6329','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102046','projected_crs','EPSG','6328','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103411','projected_crs','EPSG','8197','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103454','projected_crs','EPSG','8126','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102049','projected_crs','EPSG','6331','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102048','projected_crs','EPSG','6330','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102739','projected_crs','EPSG','2277','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102738','projected_crs','EPSG','2276','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103308','projected_crs','EPSG','8203','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103371','projected_crs','EPSG','8095','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103215','projected_crs','EPSG','4083','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103101','projected_crs','EPSG','6519','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103100','projected_crs','EPSG','6521','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103103','projected_crs','EPSG','6524','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103102','projected_crs','EPSG','6523','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103105','projected_crs','EPSG','6526','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103104','projected_crs','EPSG','6525','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103107','projected_crs','EPSG','6530','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103106','projected_crs','EPSG','6527','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103109','projected_crs','EPSG','6532','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103108','projected_crs','EPSG','6528','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103199','projected_crs','EPSG','6616','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102420','projected_crs','EPSG','5325','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103420','projected_crs','EPSG','8177','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103421','projected_crs','EPSG','8172','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103039','projected_crs','EPSG','6458','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103038','projected_crs','EPSG','6457','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103424','projected_crs','EPSG','8166','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103425','projected_crs','EPSG','8164','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103035','projected_crs','EPSG','6454','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103034','projected_crs','EPSG','6453','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103037','projected_crs','EPSG','6455','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103036','projected_crs','EPSG','6456','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103031','projected_crs','EPSG','6452','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103030','projected_crs','EPSG','6448','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103033','projected_crs','EPSG','6449','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103032','projected_crs','EPSG','6451','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103464','projected_crs','EPSG','8108','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102310','projected_crs','EPSG','2823','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102252','projected_crs','EPSG','2765','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102253','projected_crs','EPSG','2772','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102250','projected_crs','EPSG','2763','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102251','projected_crs','EPSG','2764','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102256','projected_crs','EPSG','2775','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102257','projected_crs','EPSG','2776','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102254','projected_crs','EPSG','2773','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102255','projected_crs','EPSG','2774','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102258','projected_crs','EPSG','2777','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102291','projected_crs','EPSG','2810','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102494','projected_crs','EPSG','6635','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102495','projected_crs','EPSG','6637','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102496','projected_crs','EPSG','6636','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102736','projected_crs','EPSG','2274','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102490','projected_crs','EPSG','5247','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103085','projected_crs','EPSG','6505','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103086','projected_crs','EPSG','6506','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102493','projected_crs','EPSG','6634','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103088','projected_crs','EPSG','6507','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102981','projected_crs','EPSG','6398','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103325','projected_crs','EPSG','8163','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103324','projected_crs','EPSG','8165','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102730','projected_crs','EPSG','3438','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103431','projected_crs','EPSG','8156','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102377','projected_crs','EPSG','6886','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102376','projected_crs','EPSG','6884','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102379','projected_crs','EPSG','6887','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102378','projected_crs','EPSG','6885','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102351','projected_crs','EPSG','2858','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103441','projected_crs','EPSG','8144','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103442','projected_crs','EPSG','8142','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102087','projected_crs','EPSG','5175','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102086','projected_crs','EPSG','5174','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102085','projected_crs','EPSG','5173','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102084','projected_crs','EPSG','5188','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102083','projected_crs','EPSG','5187','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102082','projected_crs','EPSG','5186','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102081','projected_crs','EPSG','5185','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102080','projected_crs','EPSG','5179','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103409','projected_crs','EPSG','8202','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102089','projected_crs','EPSG','5177','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102088','projected_crs','EPSG','5176','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102670','projected_crs','EPSG','2243','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102671','projected_crs','EPSG','3435','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102672','projected_crs','EPSG','3436','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102673','projected_crs','EPSG','2965','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102674','projected_crs','EPSG','2966','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102675','projected_crs','EPSG','3417','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102676','projected_crs','EPSG','3418','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102677','projected_crs','EPSG','3419','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102678','projected_crs','EPSG','3420','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102679','projected_crs','EPSG','2246','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102773','projected_crs','EPSG','6272','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102772','projected_crs','EPSG','6250','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102775','projected_crs','EPSG','6252','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102774','projected_crs','EPSG','6256','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102777','projected_crs','EPSG','6264','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102776','projected_crs','EPSG','6275','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102100','projected_crs','EPSG','3857','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103076','projected_crs','EPSG','6498','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103320','projected_crs','EPSG','8173','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102313','projected_crs','EPSG','2826','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','31922','projected_crs','EPSG','31991','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103465','projected_crs','EPSG','8106','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','31920','projected_crs','EPSG','31989','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','31921','projected_crs','EPSG','31990','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102647','projected_crs','EPSG','4437','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102172','projected_crs','EPSG','3107','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102171','projected_crs','EPSG','3111','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102170','projected_crs','EPSG','3110','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103191','projected_crs','EPSG','6609','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102641','projected_crs','EPSG','2225','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103459','projected_crs','EPSG','8118','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102643','projected_crs','EPSG','2227','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102642','projected_crs','EPSG','2226','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103071','projected_crs','EPSG','6489','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102762','projected_crs','EPSG','4415','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103073','projected_crs','EPSG','6490','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103072','projected_crs','EPSG','6492','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103075','projected_crs','EPSG','6493','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103074','projected_crs','EPSG','6495','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103077','projected_crs','EPSG','6496','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102763','projected_crs','EPSG','3089','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103079','projected_crs','EPSG','6499','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103078','projected_crs','EPSG','6494','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103178','projected_crs','EPSG','6596','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103179','projected_crs','EPSG','6598','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103405','projected_crs','EPSG','8210','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103170','projected_crs','EPSG','6625','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103171','projected_crs','EPSG','6627','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103172','projected_crs','EPSG','6589','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103173','projected_crs','EPSG','6590','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103174','projected_crs','EPSG','6592','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103175','projected_crs','EPSG','6594','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103176','projected_crs','EPSG','6593','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102767','projected_crs','EPSG','6255','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103406','projected_crs','EPSG','8208','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102681','projected_crs','EPSG','3451','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102680','projected_crs','EPSG','2247','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102683','projected_crs','EPSG','26847','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102682','projected_crs','EPSG','3452','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102685','projected_crs','EPSG','2248','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102684','projected_crs','EPSG','26848','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102687','projected_crs','EPSG','2250','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102686','projected_crs','EPSG','2249','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103177','projected_crs','EPSG','6595','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102511','projected_crs','EPSG','6829','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102510','projected_crs','EPSG','6825','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102513','projected_crs','EPSG','6837','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102512','projected_crs','EPSG','6833','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102515','projected_crs','EPSG','6849','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102514','projected_crs','EPSG','6841','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102517','projected_crs','EPSG','6853','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102516','projected_crs','EPSG','6845','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102519','projected_crs','EPSG','6861','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102518','projected_crs','EPSG','6857','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102997','projected_crs','EPSG','6415','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103195','projected_crs','EPSG','6615','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102996','projected_crs','EPSG','6413','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103471','projected_crs','EPSG','8096','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102339','projected_crs','EPSG','2846','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102338','projected_crs','EPSG','2845','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102789','projected_crs','EPSG','6259','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102331','projected_crs','EPSG','5014','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102330','projected_crs','EPSG','2840','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102333','projected_crs','EPSG','5016','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102332','projected_crs','EPSG','5015','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102335','projected_crs','EPSG','2842','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102334','projected_crs','EPSG','2841','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102337','projected_crs','EPSG','2844','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102336','projected_crs','EPSG','2843','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103118','projected_crs','EPSG','6535','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102999','projected_crs','EPSG','6419','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102998','projected_crs','EPSG','6417','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103219','projected_crs','EPSG','4096','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103218','projected_crs','EPSG','4095','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103352','projected_crs','EPSG','8129','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103353','projected_crs','EPSG','8127','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102209','projected_crs','EPSG','3464','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102208','projected_crs','EPSG','3075','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103356','projected_crs','EPSG','8121','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103357','projected_crs','EPSG','8119','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102205','projected_crs','EPSG','3741','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103210','projected_crs','EPSG','4061','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102207','projected_crs','EPSG','3743','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102206','projected_crs','EPSG','3742','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102201','projected_crs','EPSG','4414','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102200','projected_crs','EPSG','2195','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102203','projected_crs','EPSG','3751','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102202','projected_crs','EPSG','3750','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102148','projected_crs','EPSG','3100','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102149','projected_crs','EPSG','3101','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103119','projected_crs','EPSG','6541','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102140','projected_crs','EPSG','2326','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102146','projected_crs','EPSG','3098','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102147','projected_crs','EPSG','3099','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102145','projected_crs','EPSG','3097','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103359','projected_crs','EPSG','8117','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102123','projected_crs','EPSG','3078','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103110','projected_crs','EPSG','6531','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102787','projected_crs','EPSG','6262','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103416','projected_crs','EPSG','8180','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102704','projected_crs','EPSG','26852','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102706','projected_crs','EPSG','7142','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102707','projected_crs','EPSG','3421','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102708','projected_crs','EPSG','3422','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102709','projected_crs','EPSG','3423','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103314','projected_crs','EPSG','8184','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103368','projected_crs','EPSG','8099','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103316','projected_crs','EPSG','8179','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103014','projected_crs','EPSG','6432','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','2183','projected_crs','ESRI','102552','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','2182','projected_crs','ESRI','102551','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','2181','projected_crs','ESRI','102550','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103317','projected_crs','EPSG','8092','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','2187','projected_crs','ESRI','102556','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','2186','projected_crs','ESRI','102555','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','2185','projected_crs','ESRI','102554','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','2184','projected_crs','ESRI','102553','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103134','projected_crs','EPSG','6555','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103135','projected_crs','EPSG','6558','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103136','projected_crs','EPSG','6560','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103137','projected_crs','EPSG','6559','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103130','projected_crs','EPSG','6551','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103131','projected_crs','EPSG','6552','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103132','projected_crs','EPSG','6554','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103133','projected_crs','EPSG','6553','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103343','projected_crs','EPSG','8139','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103342','projected_crs','EPSG','8141','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103341','projected_crs','EPSG','8143','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102968','projected_crs','EPSG','6497','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102969','projected_crs','EPSG','6556','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102965','projected_crs','EPSG','6350','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102312','projected_crs','EPSG','2825','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102967','projected_crs','EPSG','6439','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102962','projected_crs','EPSG','6414','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102963','projected_crs','EPSG','6508','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103008','projected_crs','EPSG','6426','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103009','projected_crs','EPSG','6429','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103433','projected_crs','EPSG','8154','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103434','projected_crs','EPSG','8152','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103437','projected_crs','EPSG','8148','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103436','projected_crs','EPSG','8150','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103000','projected_crs','EPSG','6421','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103001','projected_crs','EPSG','6423','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103002','projected_crs','EPSG','6425','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103003','projected_crs','EPSG','6416','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103004','projected_crs','EPSG','6418','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103005','projected_crs','EPSG','6420','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103006','projected_crs','EPSG','6422','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103007','projected_crs','EPSG','6424','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103794','projected_crs','EPSG','4484','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103795','projected_crs','EPSG','4485','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103796','projected_crs','EPSG','4486','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103797','projected_crs','EPSG','4487','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103798','projected_crs','EPSG','4488','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103799','projected_crs','EPSG','4489','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103211','projected_crs','EPSG','4062','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102241','projected_crs','EPSG','2766','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103315','projected_crs','EPSG','8181','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102243','projected_crs','EPSG','2768','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102242','projected_crs','EPSG','2767','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102245','projected_crs','EPSG','2770','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102244','projected_crs','EPSG','2769','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103312','projected_crs','EPSG','8191','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102246','projected_crs','EPSG','2771','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102249','projected_crs','EPSG','2762','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','102248','projected_crs','EPSG','2761','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103318','projected_crs','EPSG','8090','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103099','projected_crs','EPSG','6522','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103098','projected_crs','EPSG','6518','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103097','projected_crs','EPSG','6520','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103096','projected_crs','EPSG','6880','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103095','projected_crs','EPSG','6516','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103094','projected_crs','EPSG','6515','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103093','projected_crs','EPSG','6514','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103092','projected_crs','EPSG','6513','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103091','projected_crs','EPSG','6511','ESRI');
INSERT INTO "supersession" VALUES('projected_crs','ESRI','103090','projected_crs','EPSG','6512','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1027','EGM2008_Geoid','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1028','Fao_1979','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1039','New_Zealand_Vertical_Datum_2009','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1040','Dunedin_Bluff_1960','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1054','Sri_Lanka_Vertical_Datum','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1059','Faroe_Islands_Vertical_Reference_2009','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1079','Fehmarnbelt_Vertical_Reference_2010','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1080','Lowest_Astronomic_Tide','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1082','Highest_Astronomic_Tide','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1083','Lower_Low_Water_Large_Tide','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1084','Higher_High_Water_Large_Tide','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1085','Indian_Spring_Low_Water','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1086','Mean_Lower_Low_Water_Spring_Tides','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1087','Mean_Low_Water_Spring_Tides','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1088','Mean_High_Water_Spring_Tides','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1089','Mean_Lower_Low_Water','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1090','Mean_Higher_High_Water','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1091','Mean_Low_Water','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1092','Mean_High_Water','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1093','Low_Water','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1094','High_Water','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1096','Norway_Normal_Null_2000','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1097','Grand_Cayman_Vertical_Datum_1954','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1098','Little_Cayman_Vertical_Datum_1961','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1099','Cayman_Brac_Vertical_Datum_1961','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1101','Cais_da_Pontinha-Funchal','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1102','Cais_da_Vila-Porto_Santo','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1103','Cais_das_Velas','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1105','Cais_da_Madalena','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1106','Santa_Cruz_da_Graciosa','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1107','Cais_da_Figueirinha-Angra_do_Heroismo','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1108','Santa_Cruz_das_Flores','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1109','Cais_da_Vila_do_Porto','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1110','Ponta_Delgada','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1119','Northern_Marianas_Vertical_Datum_of_2003','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1121','Tutuila_Vertical_Datum_of_1962','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1122','Guam_Vertical_Datum_of_1963','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1123','Puerto_Rico_Vertical_Datum_of_2002','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1124','Virgin_Islands_Vertical_Datum_of_2009','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1125','American_Samoa_Vertical_Datum_of_2002','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1126','Guam_Vertical_Datum_of_2004','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1127','Canadian_Geodetic_Vertical_Datum_of_2013','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1129','Japanese_Standard_Levelling_Datum_1972','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1130','Japanese_Geodetic_Datum_2000_vertical','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1131','Japanese_Geodetic_Datum_2011_vertical','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1140','Singapore_Height_Datum','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1146','Ras_Ghumays','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1148','Famagusta_1960','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1149','Papua_New_Guinea_2008','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1150','Kumul_34','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1161','Deutsches_Haupthoehennetz_1912','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1162','Latvian_Height_System_2000','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1164','Ordnance_Datum_Newlyn_(Offshore)','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1169','New_Zealand_Vertical_Datum_2016','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1170','Deutsches_Haupthoehennetz_2016','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1171','Port_Moresby_1996','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1172','Port_Moresby_2008','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1175','Jamestown_1971','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1176','St_Helena_Tritan_Vertical_Datum_2011','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1177','St_Helena_Vertical_Datum_2015','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','1190','Landshaedarkerfi_Islands_2004','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5100','Mean_Sea_Level','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5101','Ordnance_Datum_Newlyn','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5102','National_Geodetic_Vertical_Datum_1929','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5103','North_American_Vertical_Datum_1988','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5104','Yellow_Sea_1956','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5105','Baltic_Sea','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5106','Caspian_Sea','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5109','Normaal_Amsterdams_Peil','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5110','Oostende','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5111','Australian_Height_Datum','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5112','Australian_Height_Datum_Tasmania','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5113','Sea_Level','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5114','Canadian_Geodetic_Vertical_Datum_of_1928','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5115','Piraeus_Harbour_1986','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5116','Helsinki_1960','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5117','Rikets_Hojdsystem_1970','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5118','Nivellement_General_de_la_France_Lallemand','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5119','Nivellement_General_de_la_France_IGN69','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5120','Nivellement_General_de_la_France_IGN78','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5122','Japanese_Standard_Levelling_Datum_1969','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5123','PDO_Height_Datum_1993','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5124','Fahud_Height_Datum','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5125','Ha_Tien_1960','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5126','Hon_Dau_1992','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5127','Landesnivellement_1902','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5128','Landeshohennetz_1995','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5129','European_Vertical_Reference_Frame_2000','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5130','Malin_Head','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5131','Belfast','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5132','Dansk_Normal_Nul','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5133','AIOC_1995','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5134','Black_Sea','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5135','Hong_Kong_Principal_Datum','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5136','Hong_Kong_Chart_Datum','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5137','Yellow_Sea_1985','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5138','Ordnance_Datum_Newlyn_Orkney_Isles','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5139','Fair_Isle','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5142','Sule_Skerry','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5143','North_Rona','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5145','St_Kilda','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5146','Flannan_Isles','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5147','St_Marys','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5150','Bandar_Abbas','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5151','Nivellement_General_de_Nouvelle_Caledonie','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5153','Nivellement_General_Guyanais_1977','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5154','IGN_1987','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5155','IGN_1988','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5156','IGN_1989','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5157','Auckland','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5158','Bluff','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5159','Dunedin','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5160','Gisborne','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5161','Lyttelton','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5162','Moturiki','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5163','Napier','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5164','Nelson','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5165','One_Tree_Point','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5166','Tararu','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5167','Taranaki','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5168','Wellington','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5169','Chatham_Island','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5170','Stewart_Island','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5171','EGM96_Geoid','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5172','Nivellement_General_du_Luxembourg','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5174','Norway_Normal_Null_1954','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5176','Gebrauchshohen_Adria','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5177','National_Vertical_Network_1999','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5181','Deutches_Haupthoehennetz_1992','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5182','Deutches_Haupthoehennetz_1985','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5183','SNN76','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5184','Baltic_1982','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5185','Baltic_1980','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5186','Kuwait_PWD','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5187','KOC_Well_Datum','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5188','KOC_Construction_Datum','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5189','Nivellement_General_de_la_Corse_1948','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5190','Danger_1950','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5191','Mayotte_1950','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5192','Martinique_1955','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5193','Guadeloupe_1951','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5194','Lagos_1955','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5195','Nivellement_General_de_Polynesie_Francaise','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5196','IGN_1966','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5197','Moorea_SAU_1981','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5198','Raiatea_SAU_2001','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5199','Maupiti_SAU_2001','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5200','Huahine_SAU_2001','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5201','Tahaa_SAU_2001','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5202','Bora_Bora_SAU_2001','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5203','EGM84_Geoid','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5204','International_Great_Lakes_Datum_1955','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5205','International_Great_Lakes_Datum_1985','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5206','Dansk_Vertikal_Reference_1990','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5207','Croatian_Vertical_Reference_System_1971','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5208','Rikets_Hojdsystem_2000','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5209','Rikets_Hojdsystem_1900','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5210','IGN_1988_LS','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5211','IGN_1988_MG','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5212','IGN_1992_LD','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5213','IGN_1988_SB','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5214','IGN_1988_SM','ESRI');
INSERT INTO alias_name VALUES('vertical_datum','EPSG','5215','European_Vertical_Reference_Frame_2007','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','3855','EGM2008_Geoid','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','3886','Fao_1979','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','3900','N2000_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','4440','NZVD2009_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','4458','Dunedin_Bluff_1960_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5193','Incheon_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5195','Trieste_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5214','Genoa_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5237','SLVD_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5317','FVR09_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5336','Black_Sea_Depth','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5597','FCSVR10_Height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5600','NGPF','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5601','IGN_1966','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5602','Moorea_SAU_1981','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5603','Raiatea_SAU_2001','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5604','Maupiti_SAU_2001','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5605','Huahine_SAU_2001','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5606','Tahaa_SAU_2001','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5607','Bora_Bora_SAU_2001','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5608','IGLD_1955','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5609','IGLD_1985','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5610','HVRS_1971','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5611','Caspian_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5612','Baltic_depth','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5613','RH2000','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5614','KOC_WD_depth_ft','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5615','RH1900','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5616','IGN_1988_LS','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5617','IGN_1988_MG','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5618','IGN_1992_LD','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5619','IGN_1988_SB','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5620','IGN_1988_SM','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5621','EVRF_2007','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5701','Newlyn','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5702','NGVD_1929','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5703','NAVD_1988','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5704','Yellow_Sea_1956','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5705','Baltic','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5706','Caspian','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5709','NAP','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5710','Oostende','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5711','AHD','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5712','AHD_Tasmania','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5713','CGVD_1928','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5714','MSL_Height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5715','MSL_Depth','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5716','Piraeus','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5717','N60','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5718','RH70','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5719','NGF_Lallemand','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5720','NGF_IGN69','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5721','NGF_IGN78','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5722','Maputo','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5723','Japanese_Standard_Levelling_Datum_1969','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5724','PDO_Height_Datum_1993','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5725','Fahud_Height_Datum_1993','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5726','Ha_Tien_1960','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5727','Hon_Dau_1992','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5728','LN_1902','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5729','LHN95','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5730','EVRS_2000','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5731','Malin_Head','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5732','Belfast','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5733','Dansk_Normal_Nul','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5734','AIOC95_Depth','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5735','Black_Sea','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5736','Yellow_Sea_1956','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5737','Yellow_Sea_1985','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5738','Hong_Kong_Principal_Datum','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5739','Hong_Kong_Chart_Datum','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5740','Newlyn_Orkney_Isles','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5741','Fair_Isle','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5742','Lerwick','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5743','Foula','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5744','Sule_Skerry','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5745','North_Rona','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5746','Stornoway','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5747','St_Kilda','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5748','Flannan_Isles','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5749','St_Marys','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5750','Douglas','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5751','Fao','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5752','Bandar_Abbas','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5753','NGNC','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5754','Poolbeg','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5755','NGG_1977','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5756','IGN_1987','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5757','IGN_1988','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5758','IGN_1989','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5759','Auckland','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5760','Bluff','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5761','Dunedin','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5762','Gisborne','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5763','Lyttelton','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5764','Moturiki','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5765','Napier','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5766','Nelson','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5767','One_Tree_Point','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5768','Tararu','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5769','Taranaki','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5770','Wellington','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5771','Chatham_Island','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5772','Stewart_Island','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5773','EGM96_Geoid','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5774','NG_L','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5775','Antalya','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5776','NN54','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5777','Durres','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5778','GHA','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5779','NVN99','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5780','Cascais','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5781','Constanta','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5782','Alicante','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5783','DHHN92','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5784','DHHN85','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5785','SNN76','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5786','Baltic_1982','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5787','EOMA_1980','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5788','Kuwait_PWD','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5789','KOC_Well_Datum','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5790','KOC_Construction_Datum','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5791','NGC_1948','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5792','Danger_1950','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5793','Mayotte_1950','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5794','Martinique_1955','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5795','Guadeloupe_1951','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5796','Lagos_1955','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5797','AIOC95_Height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5798','EGM84_Geoid','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5799','DVR90','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5829','Instantaneous_Water_Level_Height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5831','Instantaneous_Water_Level_Depth','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5843','Ras_Ghumays_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5861','LAT_Depth','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5862','LLWLT_Depth','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5863','ISLW_Depth','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5864','MLLWS_Depth','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5865','MLWS_Depth','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5866','MLLW_Depth','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5867','MLW_Depth','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5868','MHW_Height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5869','MHHW_Height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5870','MHWS_Height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5871','HHWLT_Height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5872','HAT_Height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5873','Low_Water_Depth','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5874','High_Water_Height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','5941','NN2000_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6130','GCVD54_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6131','LCVD61_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6132','CBVD61_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6178','Cais_da_Pontinha-Funchal_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6179','Cais_da_Vila-Porto_Santo_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6180','Cais_das_Velas_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6181','Horta_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6182','Cais_da_Madalena_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6183','Santa_Cruz_da_Graciosa_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6184','Cais_da_Figueirinha-Angra_do_Heroismo_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6185','Santa_Cruz_das_Flores_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6186','Cais_da_Vila_do_Porto_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6187','Ponta_Delgada_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6357','NAVD88_depth','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6358','NAVD88_depth_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6359','NGVD29_depth','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6360','NAVD88_height_(ftUS)','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6638','Tutuila_1962_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6639','Guam_1963_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6640','NMVD03_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6641','PRVD02_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6642','VIVD09_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6643','ASVD02_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6644','GUVD04_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6647','CGVD2013_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6693','JSLD72_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6694','JGD2000_vertical_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6695','JGD2011_vertical_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','6916','SHD_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','7446','Famagusta_1960_(height)','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','7447','PNG08_(height)','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','7651','Kumul_34_(height)','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','7652','Kiunga_(height)','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','7699','DHHN12_(height)','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','7700','Latvia_2000_(height)','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','7707','ODN_(Offshore)_(height)','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','7832','POM96_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','7837','DHHN2016_(height)','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','7839','NZVD2016_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','7841','POM08_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','7888','Jamestown_1971_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','7889','St_Helena_Tritan_2011_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','7890','SHVD2015_height','ESRI');
INSERT INTO alias_name VALUES('vertical_crs','EPSG','8089','ISH2004_height','ESRI');
INSERT INTO "vertical_datum" VALUES('ESRI','105103','Red_Espanola_de_Nivelacion_de_Alta_Precision',NULL,NULL,'EPSG','3429',0);
INSERT INTO "vertical_crs" VALUES('ESRI','105603','REDNAP_height',NULL,NULL,'EPSG','6499','ESRI','105103','EPSG','3429',0);
INSERT INTO "vertical_datum" VALUES('ESRI','105100','WGS_1984_Geoid',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('ESRI','105700','WGS_1984_Geoid',NULL,NULL,'EPSG','6499','ESRI','105100','EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('ESRI','105101','Dansk_Vertikal_Reference_1990',NULL,NULL,'EPSG','3237',1);
INSERT INTO "vertical_crs" VALUES('ESRI','105701','DVR90',NULL,NULL,'EPSG','6499','ESRI','105101','EPSG','3237',1);
INSERT INTO "supersession" VALUES('vertical_crs','ESRI','105701','vertical_crs','EPSG','5799','ESRI');
INSERT INTO "vertical_datum" VALUES('ESRI','105102','Rikets_Hojdsystem_2000',NULL,NULL,'EPSG','3313',1);
INSERT INTO "vertical_crs" VALUES('ESRI','105702','RH2000',NULL,NULL,'EPSG','6499','ESRI','105102','EPSG','3313',1);
INSERT INTO "supersession" VALUES('vertical_crs','ESRI','105702','vertical_crs','EPSG','5613','ESRI');
INSERT INTO "vertical_crs" VALUES('ESRI','105703','NAVD88_height_(ftUS)',NULL,NULL,'EPSG','6497','EPSG','5103','EPSG','3664',1);
INSERT INTO "supersession" VALUES('vertical_crs','ESRI','105703','vertical_crs','EPSG','6360','ESRI');
INSERT INTO "vertical_datum" VALUES('ESRI','105104','LAS07',NULL,NULL,'EPSG','3272',0);
INSERT INTO "vertical_crs" VALUES('ESRI','105704','LAS07_height',NULL,NULL,'EPSG','6499','ESRI','105104','EPSG','3272',0);
INSERT INTO "vertical_datum" VALUES('ESRI','105290','EGM2008_Geoid',NULL,NULL,'EPSG','1262',1);
INSERT INTO "vertical_crs" VALUES('ESRI','105790','EGM2008_Geoid',NULL,NULL,'EPSG','6499','ESRI','105290','EPSG','1262',1);
INSERT INTO "supersession" VALUES('vertical_crs','ESRI','105790','vertical_crs','EPSG','3855','ESRI');
INSERT INTO "vertical_datum" VALUES('ESRI','105291','Fao_1979',NULL,NULL,'EPSG','3625',1);
INSERT INTO "vertical_crs" VALUES('ESRI','105791','Fao_1979',NULL,NULL,'EPSG','6499','ESRI','105291','EPSG','3625',1);
INSERT INTO "supersession" VALUES('vertical_crs','ESRI','105791','vertical_crs','EPSG','3886','ESRI');
INSERT INTO "vertical_datum" VALUES('ESRI','105292','New_Zealand_Vertical_Datum_2009',NULL,NULL,'EPSG','1175',1);
INSERT INTO "vertical_crs" VALUES('ESRI','105792','NZVD2009_height',NULL,NULL,'EPSG','6499','ESRI','105292','EPSG','1175',1);
INSERT INTO "supersession" VALUES('vertical_crs','ESRI','105792','vertical_crs','EPSG','4440','ESRI');
INSERT INTO "vertical_datum" VALUES('ESRI','105293','N2000',NULL,NULL,'EPSG','3333',1);
INSERT INTO "vertical_crs" VALUES('ESRI','105793','N2000_height',NULL,NULL,'EPSG','6499','ESRI','105293','EPSG','3333',1);
INSERT INTO "supersession" VALUES('vertical_crs','ESRI','105793','vertical_crs','EPSG','3900','ESRI');
INSERT INTO "vertical_datum" VALUES('ESRI','105294','Dunedin_Bluff_1960',NULL,NULL,'EPSG','3806',1);
INSERT INTO "vertical_crs" VALUES('ESRI','105794','Dunedin_Bluff_1960_height',NULL,NULL,'EPSG','6499','ESRI','105294','EPSG','3806',1);
INSERT INTO "supersession" VALUES('vertical_crs','ESRI','105794','vertical_crs','EPSG','4458','ESRI');
-- Skipping WGS_1984. Should be a CompoundCRS
-- Skipping ETRS_1989. Should be a CompoundCRS
-- Skipping NAD_1983. Should be a CompoundCRS
-- Skipping Australian_Antarctic_1998. Should be a CompoundCRS
-- Skipping Cadastre_1997. Should be a CompoundCRS
-- Skipping China_Geodetic_Coordinate_System_2000. Should be a CompoundCRS
-- Skipping Swiss_TRF_1995. Should be a CompoundCRS
-- Skipping CIGD11. Should be a CompoundCRS
-- Skipping CR05. Should be a CompoundCRS
-- Skipping DB_REF. Should be a CompoundCRS
-- Skipping DGN_1995. Should be a CompoundCRS
-- Skipping DRUKREF_03. Should be a CompoundCRS
-- Skipping Estonia_1997. Should be a CompoundCRS
-- Skipping EUREF_FIN. Should be a CompoundCRS
-- Skipping FEH2010. Should be a CompoundCRS
-- Skipping GDA_1994. Should be a CompoundCRS
-- Skipping GDBD2009. Should be a CompoundCRS
-- Skipping GDM_2000. Should be a CompoundCRS
-- Skipping Greenland_1996. Should be a CompoundCRS
-- Skipping Hartebeesthoek_1994. Should be a CompoundCRS
-- Skipping IGD05. Should be a CompoundCRS
-- Skipping IG05_Intermediate_CRS. Should be a CompoundCRS
-- Skipping IGD05(2012). Should be a CompoundCRS
-- Skipping IG05(2012)_Intermediate_CRS. Should be a CompoundCRS
-- Skipping IGM_1995. Should be a CompoundCRS
-- Skipping IGRS. Should be a CompoundCRS
-- Skipping IRENET95. Should be a CompoundCRS
-- Skipping ISN_1993. Should be a CompoundCRS
-- Skipping ISN_2004. Should be a CompoundCRS
-- Skipping ITRF_1988. Should be a CompoundCRS
-- Skipping ITRF_1989. Should be a CompoundCRS
-- Skipping ITRF_1990. Should be a CompoundCRS
-- Skipping ITRF_1991. Should be a CompoundCRS
-- Skipping ITRF_1992. Should be a CompoundCRS
-- Skipping ITRF_1993. Should be a CompoundCRS
-- Skipping ITRF_1996. Should be a CompoundCRS
-- Skipping ITRF_1997. Should be a CompoundCRS
-- Skipping ITRF_2000. Should be a CompoundCRS
-- Skipping ITRF_2005. Should be a CompoundCRS
-- Skipping JAD_2001. Should be a CompoundCRS
-- Skipping JGD_2000. Should be a CompoundCRS
-- Skipping JGD_2011. Should be a CompoundCRS
-- Skipping Korea_2000. Should be a CompoundCRS
-- Skipping Lao_1997. Should be a CompoundCRS
-- Skipping LGD2006. Should be a CompoundCRS
-- Skipping LKS_1992. Should be a CompoundCRS
-- Skipping LKS_1994. Should be a CompoundCRS
-- Skipping MACAO_2008. Should be a CompoundCRS
-- Skipping MAGNA. Should be a CompoundCRS
-- Skipping MARCARIO_SOLIS. Should be a CompoundCRS
-- Skipping MARGEN. Should be a CompoundCRS
-- Skipping Mexico_ITRF2008. Should be a CompoundCRS
-- Skipping MOLDREF99. Should be a CompoundCRS
-- Skipping MONREF_1997. Should be a CompoundCRS
-- Skipping Moznet. Should be a CompoundCRS
-- Skipping NAD_1983_2011. Should be a CompoundCRS
-- Skipping NAD_1983_CORS96. Should be a CompoundCRS
-- Skipping North_American_1983_CSRS. Should be a CompoundCRS
-- Skipping North_American_1983_HARN. Should be a CompoundCRS
-- Skipping NAD_1983_MA11. Should be a CompoundCRS
-- Skipping NAD_1983_MARP00. Should be a CompoundCRS
-- Skipping NAD_1983_NSRS2007. Should be a CompoundCRS
-- Skipping NAD_1983_PA11. Should be a CompoundCRS
-- Skipping NAD_1983_PACP00. Should be a CompoundCRS
-- Skipping Nepal_Nagarkot. Should be a CompoundCRS
-- Skipping NZGD_2000. Should be a CompoundCRS
-- Skipping Peru96. Should be a CompoundCRS
-- Skipping PNG94. Should be a CompoundCRS
-- Skipping POSGAR. Should be a CompoundCRS
-- Skipping POSGAR_1994. Should be a CompoundCRS
-- Skipping POSGAR_1998. Should be a CompoundCRS
-- Skipping PRS_1992. Should be a CompoundCRS
-- Skipping PTRA08. Should be a CompoundCRS
-- Skipping PZ_1990. Should be a CompoundCRS
-- Skipping RDN2008. Should be a CompoundCRS
-- Skipping REGCAN95. Should be a CompoundCRS
-- Skipping REGVEN. Should be a CompoundCRS
-- Skipping RGAF09. Should be a CompoundCRS
-- Skipping RGF_1993. Should be a CompoundCRS
-- Skipping RGFG_1995. Should be a CompoundCRS
-- Skipping RGM_2004. Should be a CompoundCRS
-- Skipping RGNC_1991. Should be a CompoundCRS
-- Skipping RGNC_1991-93. Should be a CompoundCRS
-- Skipping RGPF. Should be a CompoundCRS
-- Skipping RGR_1992. Should be a CompoundCRS
-- Skipping RGRDC_2005. Should be a CompoundCRS
-- Skipping RGSPM_2006. Should be a CompoundCRS
-- Skipping RRAF_1991. Should be a CompoundCRS
-- Skipping RSRGD2000. Should be a CompoundCRS
-- Skipping SIRGAS_2000. Should be a CompoundCRS
-- Skipping SIRGAS-Chile. Should be a CompoundCRS
-- Skipping SIRGAS_ES2007.8. Should be a CompoundCRS
-- Skipping SIRGAS-ROU98. Should be a CompoundCRS
-- Skipping SLD99. Should be a CompoundCRS
-- Skipping Slovenia_1996. Should be a CompoundCRS
-- Skipping SREF98. Should be a CompoundCRS
-- Skipping S_JTSK/05. Should be a CompoundCRS
-- Skipping S_JTSK/05_Ferro. Should be a CompoundCRS
-- Skipping SWEREF99. Should be a CompoundCRS
-- Skipping TGD2005. Should be a CompoundCRS
-- Skipping TWD_1997. Should be a CompoundCRS
-- Skipping Ukraine_2000. Should be a CompoundCRS
-- Skipping Yemen_NGN_1996. Should be a CompoundCRS
-- Skipping ITRF_2008. Should be a CompoundCRS
-- Skipping TUREF. Should be a CompoundCRS
-- Skipping GDA2020. Should be a CompoundCRS
-- Skipping BGS2005. Should be a CompoundCRS
INSERT INTO "vertical_datum" VALUES('ESRI','105110','Unknown_height_system_(meters)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('ESRI','115807','Unknown_height_system_(meters)',NULL,NULL,'EPSG','6499','ESRI','105110','EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('ESRI','105111','Unknown_height_system_(US_survey_feet)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('ESRI','115808','Unknown_height_system_(US_survey_feet)',NULL,NULL,'EPSG','6497','ESRI','105111','EPSG','1262',0);
INSERT INTO "vertical_datum" VALUES('ESRI','105112','Unknown_height_system_(Intl_feet)',NULL,NULL,'EPSG','1262',0);
INSERT INTO "vertical_crs" VALUES('ESRI','115809','Unknown_height_system_(Intl_Feet)',NULL,NULL,'EPSG','1030','ESRI','105112','EPSG','1262',0);
-- Skipping ITRF2014. Should be a CompoundCRS
-- Skipping SHGD2015. Should be a CompoundCRS
-- Skipping St_Helena_Tritan. Should be a CompoundCRS
-- Skipping GSK-2011. Should be a CompoundCRS
-- Skipping PZ-90.11. Should be a CompoundCRS
-- Skipping PZ-90.02. Should be a CompoundCRS
-- Skipping WGS_1984_(Transit). Should be a CompoundCRS
-- Skipping WGS_1984_(G1762). Should be a CompoundCRS
-- Skipping WGS_1984_(G1674). Should be a CompoundCRS
-- Skipping WGS_1984_(G1150). Should be a CompoundCRS
-- Skipping WGS_1984_(G873). Should be a CompoundCRS
-- Skipping WGS_1984_(G730). Should be a CompoundCRS
-- Skipping ETRF90. Should be a CompoundCRS
-- Skipping ETRF91. Should be a CompoundCRS
-- Skipping ETRF92. Should be a CompoundCRS
-- Skipping ETRF93. Should be a CompoundCRS
-- Skipping ETRF94. Should be a CompoundCRS
-- Skipping ETRF96. Should be a CompoundCRS
-- Skipping ETRF97. Should be a CompoundCRS
-- Skipping ETRF2000. Should be a CompoundCRS
-- Skipping NAD83(CSRS96). Should be a CompoundCRS
-- Skipping NAD83(CSRS)V2. Should be a CompoundCRS
-- Skipping NAD83(CSRS)V3. Should be a CompoundCRS
-- Skipping NAD83(CSRS)V4. Should be a CompoundCRS
-- Skipping NAD83(CSRS)V5. Should be a CompoundCRS
-- Skipping NAD83(CSRS)V6. Should be a CompoundCRS
-- Skipping NAD83(CSRS)V7. Should be a CompoundCRS
-- Skipping IGS14. Should be a CompoundCRS
-- Skipping ISN2016. Should be a CompoundCRS
-- Skipping Hong_Kong_Geodetic_CS. Should be a CompoundCRS
-- Skipping NAD_1983_(FBN). Should be a CompoundCRS
-- Skipping NAD_1983_(HARN_Corrected). Should be a CompoundCRS
-- Skipping SRB_ETRS89. Should be a CompoundCRS
-- Skipping MTRF-2000. Should be a CompoundCRS
-- Skipping California_SRS_Epoch_2017.50_(NAD83). Should be a CompoundCRS
-- Skipping GGD. Should be a CompoundCRS
INSERT INTO alias_name VALUES('compound_crs','EPSG','5554','HVC_ETRS_1989_UTM_Zone_31N_and_DHHN92_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','5555','HVC_ETRS_1989_UTM_Zone_32N_and_DHHN92_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','5556','HVC_ETRS_1989_UTM_Zone_33N_and_DHHN92_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','5598','HVC_FEH2010_Fehmarnbelt_TM_and_FCSVR10_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','5698','HVC_RGF_1993_Lambert_93_and_NGF_IGN69_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','5699','HVC_RGF_1993_Lambert_93_and_NGF_IGN78_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','5707','HVC_NTF_Paris_Lambert_Zone_I_and_NGF_IGN69_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','5708','HVC_NTF_Paris_Lambert_Zone_IV_and_NGF_IGN78_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','5832','HVC_DB_REF_3_Degree_GK_Zone_2_E-N_and_DHHN92','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','5833','HVC_DB_REF_3_Degree_GK_Zone_3_E-N_and_DHHN92','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','5834','HVC_DB_REF_3_Degree_GK_Zone_4_E-N_and_DHHN92','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','5835','HVC_DB_REF_3_Degree_GK_Zone_5_E-N_and_DHHN92','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','7400','HVC_NTF_Paris_and_NGF_IGN69_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','7404','HVC_RT90_and_RH70_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','7405','HVC_OSGB36_British_National_Grid_and_ODN_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','7406','HVC_NAD27_and_NGVD29_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','7407','HVC_NAD27_Texas_North_and_NGVD29_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','7409','HVC_ETRF89_and_EVRF2000_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','7410','HVC_PSD93_and_PHD93','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','7411','HVC_NTF_Paris_Lambert_Zone_II_and_NGF_Lallemand_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','7414','HVC_Tokyo_and_JSLD_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','7415','HVC_Amersfoort_RD_New_and_NAP_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','7416','HVC_ETRF89_UTM_Zone_32N_and_DVR90_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','7417','HVC_ETRF89_UTM_Zone_33N_and_DVR90_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','7418','HVC_ETRF89_KP2000_Jutland_and_DVR90_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','7419','HVC_ETRF89_KP2000_Zealand_and_DVR90_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','7420','HVC_ETRF89_KP2000_Bornholm_and_DVR90_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','7421','HVC_NTF_Paris_Lambert_Zone_II_and_NGF_IGN69_Height','ESRI');
INSERT INTO alias_name VALUES('compound_crs','EPSG','7422','HVC_NTF_Paris_Lambert_Zone_III_and_NGF_IGN69_Height','ESRI');
INSERT INTO "helmert_transformation" VALUES('ESRI','7377','ONGD14_To_WGS_1984_1',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','7373','EPSG','4326','EPSG','1183',0.1,0.819,-0.5762,-1.6446,'EPSG','9001',0.00378,0.03317,-0.00318,'EPSG','9104',0.0693,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','8688','MGI_1901_To_WGS_1984_12',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4326','EPSG','3307',1.3,476.08,125.947,417.81,'EPSG','9001',-4.610862,-2.388137,11.942335,'EPSG','9104',9.896638,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','8689','MGI_1901_To_Slovenia_1996_12',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','3906','EPSG','4765','EPSG','3307',1.07,476.08,125.947,417.81,'EPSG','9001',-4.610862,-2.388137,11.942335,'EPSG','9104',9.896638,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','8822','MTRF-2000_to_WGS_1984_(G1150)',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','8818','ESRI','104013','EPSG','1206',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','8824','Ain_el_Abd_1970_to_MTRF-2000_1',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4204','ESRI','8818','EPSG','3303',5.0,-61.65,-315.86,-3.51,'EPSG','9001',0.41,0.74,-3.52,'EPSG','9104',1.36,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108003','NAD_1927_To_NAD_1983_PR_VI',NULL,NULL,'EPSG','9615','NTv2','EPSG','4267','EPSG','4269','EPSG','1335',0.05,'EPSG','8656','Latitude and longitude difference file','prvi',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108013','CR05_To_Ocotepeque_1935_MB',NULL,NULL,'EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','5365','EPSG','5451','EPSG','3232',0.5,-213.116,-9.358,74.946,'EPSG','9001',2.3514188,-0.0614669,6.394209,'EPSG','9104',5.22,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,617749.7118,-6250547.7336,1102063.6099,'EPSG','9001',NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108014','WGS_1984_To_Ocotepeque_1935_MB',NULL,NULL,'EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4326','EPSG','5451','EPSG','3232',0.5,-213.116,-9.358,74.946,'EPSG','9001',2.3514188,-0.0614669,6.394209,'EPSG','9104',5.22,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,617749.7118,-6250547.7336,1102063.6099,'EPSG','9001',NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108015','Nepal_Nagarkot_TO_WGS_1984_1',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','6207','EPSG','4326','EPSG','1171',10.0,296.0,732.0,273.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108016','Nepal_Nagarkot_TO_WGS_1984_2',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','6207','EPSG','4326','EPSG','1171',5.0,296.207,731.545,273.001,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108017','NAD_1983_PACP00_To_WGS_1984',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','104259','EPSG','4326','EPSG','4162',0.1,-0.9102,2.0141,0.5602,'EPSG','9001',-0.029039,-0.010065,-0.010101,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108018','NAD_1983_MARP00_To_WGS_1984',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','104260','EPSG','4326','EPSG','4167',0.1,-0.9102,2.0141,0.5602,'EPSG','9001',-0.029039,-0.010065,-0.010101,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "area" VALUES('ESRI','143','Israel, Palestine Territory, and Jordan','Israel, Palestine Territory, and Jordan',29.19,33.53,32.99,39.3,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108021','WGS_1984_To_Israel_CoordFrame',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4326','EPSG','4141','ESRI','143',1.0,-24.0024,-17.1032,-17.8444,'EPSG','9001',-0.33009,-1.85269,1.66969,'EPSG','9104',5.4248,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "other_transformation" VALUES('ESRI','108022','NTF_Paris_RGF_To_NTF_2',NULL,NULL,'EPSG','9619','Geographic2D offsets','EPSG','4807','EPSG','4275','EPSG','3694',0.0,'EPSG','8601','Latitude offset',0.0,'EPSG','9104','EPSG','8602','Longitude offset',8413.095,'EPSG','9104',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108023','Datum_Lisboa_Hayford_To_WGS_1984_NTv2',NULL,NULL,'EPSG','9615','NTv2','ESRI','104106','EPSG','4326','EPSG','1294',0.1,'EPSG','8656','Latitude and longitude difference file','portugal/DLX_ETRS89_geo',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108024','Datum_Lisboa_Hayford_To_ETRS_1989_NTv2',NULL,NULL,'EPSG','9615','NTv2','ESRI','104106','EPSG','4258','EPSG','1294',0.1,'EPSG','8656','Latitude and longitude difference file','portugal/DLX_ETRS89_geo',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108025','Datum_73_To_WGS_1984_NTv2',NULL,NULL,'EPSG','9615','NTv2','EPSG','4274','EPSG','4326','EPSG','1294',0.1,'EPSG','8656','Latitude and longitude difference file','portugal/D73_ETRS89_geo',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108026','ITRF_1997_To_ITRF_2000_1',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','104123','ESRI','104124','EPSG','1262',0.01,-0.0067,-0.0061,0.0185,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',-0.00155,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108027','ITRF_1996_To_ITRF_2000_1',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','104122','ESRI','104124','EPSG','1262',0.01,-0.0067,-0.0061,0.0185,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',-0.00155,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108028','ITRF_1994_To_ITRF_2000_1',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','104121','ESRI','104124','EPSG','1262',0.01,-0.0067,-0.0061,0.0185,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',-0.00155,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108029','ITRF_1993_To_ITRF_2000_1',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','104120','ESRI','104124','EPSG','1262',0.01,-0.0127,-0.0065,0.0209,'EPSG','9001',0.00039,-0.0008,0.00114,'EPSG','9104',-0.00195,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108030','ITRF_1992_To_ITRF_2000_1',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','104119','ESRI','104124','EPSG','1262',0.01,-0.0147,-0.0135,0.0139,'EPSG','9001',0.0,0.0,0.00018,'EPSG','9104',-0.00075,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108031','ITRF_1991_To_ITRF_2000_1',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','104118','ESRI','104124','EPSG','1262',0.01,-0.0267,-0.0275,0.0199,'EPSG','9001',0.0,0.0,0.00018,'EPSG','9104',-0.00215,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108032','ITRF_1990_To_ITRF_2000_1',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','104117','ESRI','104124','EPSG','1262',0.01,-0.0247,-0.0235,0.0359,'EPSG','9001',0.0,0.0,0.00018,'EPSG','9104',-0.00245,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108033','ITRF_1989_To_ITRF_2000_1',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','104116','ESRI','104124','EPSG','1262',0.01,-0.0297,-0.0475,0.0739,'EPSG','9001',0.0,0.0,0.00018,'EPSG','9104',0.00585,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108034','ITRF_1988_To_ITRF_2000_1',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','104115','ESRI','104124','EPSG','1262',0.01,-0.0247,-0.0115,0.0979,'EPSG','9001',-0.0001,0.0,0.00018,'EPSG','9104',-0.00895,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108035','Ukraine_2000_To_ITRF_2005_1',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','5561','ESRI','104896','EPSG','1242',1.0,24.0,-121.0,-76.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108036','ITRF_2000_To_ITRF_2005_1',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','104124','ESRI','104896','EPSG','1262',0.01,-0.0001,0.0008,0.0058,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',-0.0004,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108037','Macao_2008_To_WGS_1984',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104248','EPSG','4326','ESRI','42',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108038','Macao_2008_To_ITRF_2005',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104248','ESRI','104896','ESRI','42',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108039','Macao_2008_To_Observatorio_Meteorologico_1965_1',NULL,NULL,'EPSG','9636','Molodensky-Badekas (CF geog2D domain)','ESRI','104248','ESRI','104126','ESRI','42',3.0,202.865,303.99,155.873,'EPSG','9001',34.067,-76.126,-32.647,'EPSG','9104',-6.096,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,-2361757.652,5417232.187,2391453.053,'EPSG','9001',NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108042','Amersfoort_To_WGS_1984_NTv2',NULL,NULL,'EPSG','9615','NTv2','EPSG','4289','EPSG','4326','EPSG','1275',0.2,'EPSG','8656','Latitude and longitude difference file','netherlands/rdtrans2008',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108043','Egypt_1907_To_WGS_1984_2',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4229','EPSG','4326','EPSG','1086',5.0,-121.8,98.1,-10.7,'EPSG','9001',0.0,0.0,0.554,'EPSG','9104',0.2263,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108044','NAD_1983_HARN_To_NSRS2007_GEOCON_CONUS',NULL,NULL,'EPSG','9615','NTv2','EPSG','4152','EPSG','4759','EPSG','1323',0.05,'EPSG','8656','Latitude and longitude difference file','gc_nad83_harn_2007_conus_shifts',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108045','NAD_1983_HARN_To_NSRS2007_GEOCON_Alaska',NULL,NULL,'EPSG','9615','NTv2','EPSG','4152','EPSG','4759','EPSG','1330',0.05,'EPSG','8656','Latitude and longitude difference file','gc_nad83_harn_2007_alaska_shifts',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108046','NAD_1983_HARN_To_NSRS2007_GEOCON_Puerto_Rico_Virgin_Islands',NULL,NULL,'EPSG','9615','NTv2','EPSG','4152','EPSG','4759','EPSG','3634',0.05,'EPSG','8656','Latitude and longitude difference file','gc_nad83_harn_2007_prvi_shifts',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108047','NAD_1983_NSRS2007_To_2011_GEOCON11_CONUS',NULL,NULL,'EPSG','9615','NTv2','EPSG','4759','EPSG','6318','EPSG','1323',0.05,'EPSG','8656','Latitude and longitude difference file','gc_nad83_2007_2011_conus_shifts',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108048','NAD_1983_NSRS2007_To_2011_GEOCON11_Alaska',NULL,NULL,'EPSG','9615','NTv2','EPSG','4759','EPSG','6318','EPSG','1330',0.05,'EPSG','8656','Latitude and longitude difference file','gc_nad83_2007_2011_alaska_shifts',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108049','NAD_1983_NSRS2007_To_2011_GEOCON11_Puerto_Rico_Virgin_Islands',NULL,NULL,'EPSG','9615','NTv2','EPSG','4759','EPSG','6318','EPSG','2251',0.05,'EPSG','8656','Latitude and longitude difference file','gc_nad83_2007_2011_prvi_shifts',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108050','ETRS_1989_To_Xrail84_1',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4258','ESRI','104050','ESRI','2',0.5,19.019,115.122,-97.287,'EPSG','9001',3.577824,-3.484437,-2.767646,'EPSG','9104',18.6084754,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108051','WGS_1984_To_Xrail84_1',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4326','ESRI','104050','ESRI','2',0.5,19.019,115.122,-97.287,'EPSG','9001',3.577824,-3.484437,-2.767646,'EPSG','9104',18.6084754,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108052','ITRF_2005_To_ITRF_2008_2',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','104896','ESRI','104257','EPSG','1262',0.01,0.002,0.0009,0.0047,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',-0.00094,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "other_transformation" VALUES('ESRI','108053','JGD_2011_To_WGS_1984',NULL,NULL,'EPSG','9619','Geographic2D offsets','EPSG','6668','EPSG','4326','EPSG','3957',0.0,'EPSG','8601','Latitude offset',0,'EPSG','9104','EPSG','8602','Longitude offset',0,'EPSG','9104',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "other_transformation" VALUES('ESRI','108054','MONREF_1997_To_WGS_1984',NULL,NULL,'EPSG','9619','Geographic2D offsets','ESRI','104134','EPSG','4326','EPSG','1164',1.0,'EPSG','8601','Latitude offset',0,'EPSG','9104','EPSG','8602','Longitude offset',0,'EPSG','9104',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108055','WGS_1984_To_MSK_1942',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4326','ESRI','104135','EPSG','1164',999.0,78.0421780299,204.5186132514,77.449861533,'EPSG','9001',-1.7736709695,3.3197917322,-1.0426077127,'EPSG','9104',-4.95105766,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108056','WGS_1984_To_Pulkovo_1942',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4326','EPSG','4284','EPSG','1164',999.0,78.0421780299,204.5186132514,77.449861533,'EPSG','9001',-1.7736709695,3.3197917322,-1.0426077127,'EPSG','9104',-4.95105766,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108057','ETRS_1989_To_OSGB_1936_OSTN15',NULL,NULL,'EPSG','9615','NTv2','EPSG','4258','EPSG','4277','EPSG','4390',0.03,'EPSG','8656','Latitude and longitude difference file','uk/OSTN15_NTv2',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108058','WGS_1984_To_OSGB_1936_OSTN15',NULL,NULL,'EPSG','9615','NTv2','EPSG','4326','EPSG','4277','EPSG','4390',1.0,'EPSG','8656','Latitude and longitude difference file','uk/OSTN15_NTv2',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108059','OSGB_1936_To_Xrail84_NTv2',NULL,NULL,'EPSG','9615','NTv2','EPSG','4277','ESRI','104050','ESRI','2',0.5,'EPSG','8656','Latitude and longitude difference file','uk/osgb36_xrail84',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108060','GDA_1994_To_GDA2020_1',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4283','EPSG','7844','EPSG','4177',0.01,0.06155,-0.01087,-0.04019,'EPSG','9001',-0.0394924,-0.0327221,-0.0328979,'EPSG','9104',-0.009994,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "other_transformation" VALUES('ESRI','108061','ITRF2014_To_GDA2020_Null',NULL,NULL,'EPSG','9619','Geographic2D offsets','ESRI','104019','EPSG','7844','EPSG','4177',0.005,'EPSG','8601','Latitude offset',0,'EPSG','9104','EPSG','8602','Longitude offset',0,'EPSG','9104',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108062','NAD_1927_to_SIRGAS_2000_7Par_Panama',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4267','EPSG','4674','EPSG','3290',1.0,-32.3841359,180.4090461,120.8442577,'EPSG','9001',2.1545854,0.1498782,-0.5742915,'EPSG','9104',8.1049164,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "other_transformation" VALUES('ESRI','108063','NAD_1983_HARN_To_HARN_Adjusted_WCCS_Chippewa',NULL,NULL,'EPSG','9619','Geographic2D offsets','EPSG','4152','ESRI','104808','EPSG','1418',0.0,'EPSG','8601','Latitude offset',0,'EPSG','9104','EPSG','8602','Longitude offset',0,'EPSG','9104',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "area" VALUES('ESRI','144','Spain - Peninsula - NTv2 grid','Spain - Peninsula - NTv2 grid',35.5555555555556,44.4444444444444,-10.1833333333333,4.15,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108066','ED_1950_To_ETRS_1989_NTv2_PENR2009',NULL,NULL,'EPSG','9615','NTv2','EPSG','4230','EPSG','4258','ESRI','144',0.1,'EPSG','8656','Latitude and longitude difference file','spain/PENR2009',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "area" VALUES('ESRI','145','Spain - Balearic Islands - NTv2 grid','Spain - Balearic Islands - NTv2 grid',38.0,40.7916666666667,0.833333333333333,4.66666666666667,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108067','ED_1950_To_ETRS_1989_NTv2_BALR2009',NULL,NULL,'EPSG','9615','NTv2','EPSG','4230','EPSG','4258','ESRI','145',0.2,'EPSG','8656','Latitude and longitude difference file','spain/BALR2009',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108068','ED_1950_To_WGS_1984_NTv2_PENR2009',NULL,NULL,'EPSG','9615','NTv2','EPSG','4230','EPSG','4326','ESRI','144',0.9,'EPSG','8656','Latitude and longitude difference file','spain/PENR2009',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108069','ED_1950_To_WGS_1984_NTv2_BALR2009',NULL,NULL,'EPSG','9615','NTv2','EPSG','4230','EPSG','4326','ESRI','145',0.9,'EPSG','8656','Latitude and longitude difference file','spain/BALR2009',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108070','PD/83_To_WGS_1984_7PAR',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4746','EPSG','4326','EPSG','2544',0.5,599.4,72.4,419.2,'EPSG','9001',-0.062,-0.022,-2.723,'EPSG','9104',6.46,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108071','RD/83_To_WGS_1984_7PAR',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4745','EPSG','4326','EPSG','2545',0.5,612.4,77.0,440.2,'EPSG','9001',-0.054,0.057,-2.797,'EPSG','9104',2.55,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108072','MGI_To_ETRS_1989_Serbia',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4312','EPSG','4258','EPSG','3534',0.5,577.88891,165.22205,391.18289,'EPSG','9001',-4.9145,0.94729,13.05098,'EPSG','9104',7.78664,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108073','MGI_To_WGS_1984_Serbia',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4312','EPSG','4326','EPSG','3534',1.0,577.88891,165.22205,391.18289,'EPSG','9001',-4.9145,0.94729,13.05098,'EPSG','9104',7.78664,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108074','ITRF_2008_To_ITRF2014_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','104257','ESRI','104019','EPSG','1262',0.01,-0.0016,-0.0019,-0.0024,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',0.00002,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108075','ITRF2014_To_NAD_1983_CSRS_v7_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','104019','EPSG','8255','EPSG','1061',0.0,1.0053,-1.9092,-0.5416,'EPSG','9001',-0.0267814,0.0004203,-0.0109321,'EPSG','9104',0.00037,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108076','D48_To_D96_2010_GI',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','104131','EPSG','4765','EPSG','3307',1.07,476.08,125.947,417.81,'EPSG','9001',-4.610862,-2.388137,11.942335,'EPSG','9104',9.896638,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108077','D96_To_D48_Zahodna_Slovenija',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4765','ESRI','104131','EPSG','3564',0.357,-453.674,-112.561,-388.287,'EPSG','9001',5.343297,2.485394,-10.836743,'EPSG','9104',-15.958238,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108078','D96_To_D48_Severovzhodna_Slovenija',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4765','ESRI','104131','EPSG','3565',0.504,-491.556,-135.972,-440.4,'EPSG','9001',3.683681,2.232141,-13.171698,'EPSG','9104',-5.421926,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108079','D96_To_D48_Jugovzhodna_Slovenija',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4765','ESRI','104131','EPSG','3566',0.388,-485.018,-129.747,-423.199,'EPSG','9001',4.880531,2.348721,-11.745346,'EPSG','9104',-8.231637,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108080','D96_To_D48_Juzna_Slovenija',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4765','ESRI','104131','EPSG','3567',0.137,-502.101,-131.516,-433.704,'EPSG','9001',6.054862,2.498236,-10.429331,'EPSG','9104',-5.188197,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108081','D96_To_D48_Dolenjska',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4765','ESRI','104131','EPSG','3568',0.308,-481.871,-129.173,-420.608,'EPSG','9001',5.096868,2.423927,-11.524756,'EPSG','9104',-8.872387,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108082','D96_To_D48_Stajerska',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4765','ESRI','104131','EPSG','3569',0.368,-477.73,-130.719,-424.46,'EPSG','9001',3.790572,2.246488,-12.99207,'EPSG','9104',-8.828735,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108083','D96_To_D48_Pomurje',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4765','ESRI','104131','EPSG','3570',0.21,-523.882,-151.289,-480.592,'EPSG','9001',3.706371,2.315828,-13.400341,'EPSG','9104',2.972511,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108084','D96_To_D48_Gorenjska',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4765','ESRI','104131','EPSG','3571',0.249,-438.775,-109.403,-377.696,'EPSG','9001',4.933923,2.503267,-11.26993,'EPSG','9104',-18.814763,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108085','D96_To_D48_Primorska',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4765','ESRI','104131','EPSG','3572',0.27,-465.715,-115.127,-397.622,'EPSG','9001',5.743906,2.510737,-10.415817,'EPSG','9104',-13.558204,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108086','D96_To_D48_Osrednja_Slovenija',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4765','ESRI','104131','EPSG','3573',0.185,-465.328,-122.305,-403.609,'EPSG','9001',4.387757,2.265582,-12.157415,'EPSG','9104',-12.73019,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108087','Nord_Sahara_1959_To_WGS_1984_3',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4307','EPSG','4326','EPSG','2393',10.0,-156.5,-87.2,287.8,'EPSG','9001',0.0,0.0,0.814,'EPSG','9104',-0.38,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108088','Saint_Pierre_et_Miquelon_1950_to_RGSPM_2006',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4638','EPSG','4463','EPSG','3299',1.0,-95.593,573.763,173.442,'EPSG','9001',-0.9602,1.251,-1.3918,'EPSG','9104',42.6265,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108094','MGI_Ferro_To_WGS_1984',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4805','EPSG','4326','EPSG','2370',5.0,682.0,-203.0,480.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108095','MGI_To_WGS_1984_2',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4312','EPSG','4326','EPSG','1037',1.5,577.326,90.129,463.919,'EPSG','9001',5.1365988,1.4742,5.2970436,'EPSG','9104',2.4232,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108096','Chos_Malal_1914_To_WGS_1984',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4160','EPSG','4326','EPSG','2325',10.5,5.5,176.7,141.4,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108097','Indian_1960_To_WGS_1984_1',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4131','EPSG','4326','EPSG','1495',27.0,199.0,931.0,318.9,'EPSG','9001',0.0,0.0,0.814,'EPSG','9104',-0.38,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108099','Palestine_1923_To_WGS_1984_2',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4281','EPSG','4326','EPSG','2603',3.5,-229.0,-67.0,277.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108102','NTF_Paris_To_RGF_1993_1',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4807','EPSG','4171','EPSG','3694',2.0,-168.0,-60.0,320.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108106','Tokyo_To_WGS_1984_2001',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4301','EPSG','4326','EPSG','3957',4.0,-147.54,507.26,680.47,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108107','JGD_2000_To_WGS_1984',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4612','EPSG','4326','EPSG','1135',4.0,-1.126,-0.077,-0.037,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "area" VALUES('ESRI','146','Japan - NTv2','Japan - NTv2',20.0,47.0,121.0,154.0,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108109','Tokyo_To_WGS_1984_NTv2',NULL,NULL,'EPSG','9615','NTv2','EPSG','4301','EPSG','4326','ESRI','146',1.0,'EPSG','8656','Latitude and longitude difference file','japan/tky2jgd',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108110','Datum_73_To_WGS_1984_1',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4274','EPSG','4326','EPSG','1294',5.0,-223.237,110.193,36.649,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108111','ED_1950_To_WGS_1984_PT3',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','1294',999.0,-86.277,-108.879,-120.181,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108112','Graciosa_Base_SW_1948_To_WGS_1984_1',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37241','EPSG','4326','EPSG','1301',5.0,-106.226,166.366,-37.893,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108113','Datum_Lisboa_Bessel_To_WGS_1984_1',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104105','EPSG','4326','EPSG','1294',5.0,508.088,-191.042,565.223,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108114','Datum_Lisboa_Hayford_To_WGS_1984_1',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104106','EPSG','4326','EPSG','1294',5.0,-304.046,-60.576,103.64,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108115','Porto_Santo_1936_To_WGS_1984_1_IGP',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4615','EPSG','4326','EPSG','2870',5.0,-502.862,-247.438,312.724,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108116','Observatorio_Meteorologico_1939_To_WGS_1984_1',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37245','EPSG','4326','EPSG','1344',5.0,-422.651,-172.995,84.02,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108117','Sao_Braz_To_WGS_1984_1',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37249','EPSG','4326','EPSG','1345',5.0,-204.619,140.176,55.226,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108118','ED_1950_To_ETRS_1989_NTv2_Baleares',NULL,NULL,'EPSG','9615','NTv2','EPSG','4230','EPSG','4258','ESRI','145',0.5,'EPSG','8656','Latitude and longitude difference file','spain/baleares',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108119','ED_1950_To_WGS_1984_NTv2_Baleares',NULL,NULL,'EPSG','9615','NTv2','EPSG','4230','EPSG','4326','ESRI','145',1.0,'EPSG','8656','Latitude and longitude difference file','spain/baleares',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108120','Datum_73_To_WGS_1984_2',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4274','EPSG','4326','EPSG','1294',1.0,-239.749,88.181,30.488,'EPSG','9001',-0.26,-0.08,-1.21,'EPSG','9104',2.23,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108121','ED_1950_To_WGS_1984_PT7',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','1294',999.0,-68.863,-134.888,-111.49,'EPSG','9001',0.53,0.14,-0.57,'EPSG','9104',-3.4,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108122','Graciosa_Base_SW_1948_To_WGS_1984_2',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','37241','EPSG','4326','EPSG','1301',1.0,-103.088,162.481,-28.276,'EPSG','9001',-0.17,-0.08,-0.17,'EPSG','9104',-1.5,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108123','Datum_Lisboa_Bessel_To_WGS_1984_2',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','104105','EPSG','4326','EPSG','1294',1.0,631.392,-66.551,481.442,'EPSG','9001',-1.09,4.445,4.487,'EPSG','9104',-4.43,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108124','Datum_Lisboa_Hayford_To_WGS_1984_2',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','104106','EPSG','4326','EPSG','1294',2.0,-288.885,-91.744,126.244,'EPSG','9001',1.69,-0.41,0.21,'EPSG','9104',-4.6,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108125','Porto_Santo_1936_To_WGS_1984_2',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4615','EPSG','4326','EPSG','2870',1.0,-210.502,-66.902,-48.476,'EPSG','9001',-2.094,15.067,5.817,'EPSG','9104',0.485,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108126','ED_1950_To_ETRS_1989_NTv2_Peninsula',NULL,NULL,'EPSG','9615','NTv2','EPSG','4230','EPSG','4258','ESRI','144',0.5,'EPSG','8656','Latitude and longitude difference file','spain/peninsula',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108127','Sao_Braz_To_WGS_1984_2',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','37249','EPSG','4326','EPSG','1345',1.0,-208.719,129.685,52.092,'EPSG','9001',0.2,0.01,-0.33,'EPSG','9104',0.2,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108128','CGRS_1993_To_ETRS_1989',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','6311','EPSG','4258','EPSG','3236',0.5,8.846,-4.394,-1.122,'EPSG','9001',-0.00237,-0.146528,0.130428,'EPSG','9104',0.783926,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108129','CGRS_1993_To_WGS_1984',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','6311','EPSG','4326','EPSG','3236',1.0,8.846,-4.394,-1.122,'EPSG','9001',-0.00237,-0.146528,0.130428,'EPSG','9104',0.783926,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108130','NTF_To_RGF_1993_1',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4275','EPSG','4171','EPSG','3694',2.0,-168.0,-60.0,320.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108136','ED_1950_To_WGS_1984_NTv2_Peninsula',NULL,NULL,'EPSG','9615','NTv2','EPSG','4230','EPSG','4326','ESRI','144',1.0,'EPSG','8656','Latitude and longitude difference file','spain/peninsula',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "area" VALUES('ESRI','147','Northern Marianas - Rota','Northern Marianas - Rota',14.0,14.75,145.0,146.0,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108137','Guam_1963_To_HARN_Marianas_Rota',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4675','EPSG','4152','ESRI','147',999.0,-96.234,-252.601,258.222,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "area" VALUES('ESRI','148','Northern Marianas - Saipan','Northern Marianas - Saipan',14.75,15.5,145.0,146.0,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108138','Guam_1963_To_HARN_Marianas_Saipan',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4675','EPSG','4152','ESRI','148',999.0,-91.766,-255.817,255.702,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "area" VALUES('ESRI','149','Northern Marianas - Tinian and Aguijan','Northern Marianas - Tinian and Aguijan',14.75,15.13333333333333,145.5,145.75,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108139','Guam_1963_To_HARN_Marianas_Tinian_Aguijan',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4675','EPSG','4152','ESRI','149',999.0,-93.062,-255.309,256.696,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108145','NGO_1948_Oslo_To_WGS_1984',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4817','EPSG','4326','EPSG','1352',5.0,319.08,37.81,463.57,'EPSG','9001',-6.2970588,1.2903926,5.712916338,'EPSG','9104',10.819,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108146','NGO_1948_Oslo_To_ETRS_1989_1',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4817','EPSG','4258','EPSG','1352',3.0,278.3,93.0,474.5,'EPSG','9001',7.889,0.05,-6.61,'EPSG','9104',6.21,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108147','NGO_1948_Oslo_To_WGS_1984_1',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4817','EPSG','4326','EPSG','1352',3.0,278.3,93.0,474.5,'EPSG','9001',7.889,0.05,-6.61,'EPSG','9104',6.21,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108148','NAD_1983_CORS96_To_NAD_1983_HARN',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','6783','EPSG','4152','EPSG','1324',0.1,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108149','NAD_1983_CORS96_To_NAD_1983_NSRS2007',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','6783','EPSG','4759','EPSG','1324',0.1,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108150','ITRF_2000_To_NAD_1983_CORS96',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','104124','EPSG','6783','EPSG','1511',0.1,0.9956,-1.9013,-0.5215,'EPSG','9001',0.025915,0.009426,0.011599,'EPSG','9104',0.00062,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108151','WGS_1984_(ITRF00)_To_NAD_1983_CORS96',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4326','EPSG','6783','EPSG','1511',0.1,0.9956,-1.9013,-0.5215,'EPSG','9001',0.025915,0.009426,0.011599,'EPSG','9104',0.00062,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108153','Datum_73_To_WGS_1984_2009_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4274','EPSG','4326','EPSG','1294',0.4,-230.994,102.591,25.199,'EPSG','9001',0.633,-0.239,0.9,'EPSG','9104',1.95,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108155','Datum_73_To_WGS_1984_2009_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4274','EPSG','4326','EPSG','1294',0.9,-223.15,110.132,36.711,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108156','Datum_Lisboa_Hayford_To_ETRS_1989_2009_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','104106','EPSG','4258','EPSG','1294',1.5,-283.088,-70.693,117.445,'EPSG','9001',-1.157,0.059,-0.652,'EPSG','9104',-4.058,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108157','Datum_Lisboa_Hayford_To_WGS_1984_2009_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','104106','EPSG','4326','EPSG','1294',1.5,-283.088,-70.693,117.445,'EPSG','9001',-1.157,0.059,-0.652,'EPSG','9104',-4.058,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108158','Datum_Lisboa_Hayford_To_ETRS_1989_2009_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104106','EPSG','4258','EPSG','1294',1.7,-303.861,-60.693,103.607,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108159','Datum_Lisboa_Hayford_To_WGS_1984_2009_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104106','EPSG','4326','EPSG','1294',1.7,-303.861,-60.693,103.607,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108160','Porto_Santo_1936_To_PTRA08_1_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4615','EPSG','5013','EPSG','1314',0.05,-160.41,-21.066,-99.282,'EPSG','9001',2.437,-17.25,-7.446,'EPSG','9104',0.168,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108161','Porto_Santo_1936_To_PTRA08_2_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4615','EPSG','5013','EPSG','3679',0.05,-303.956,224.556,214.306,'EPSG','9001',9.405,-6.626,-12.583,'EPSG','9104',1.327,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108162','Porto_Santo_1936_To_PTRA08_3_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4615','EPSG','5013','EPSG','3680',0.002,-494.088,-312.129,279.877,'EPSG','9001',-1.423,-1.013,1.59,'EPSG','9104',-0.748,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108163','Porto_Santo_1936_To_PTRA08_1_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4615','EPSG','5013','EPSG','1314',0.3,-503.229,-247.375,312.582,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108164','Porto_Santo_1936_To_PTRA08_2_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4615','EPSG','5013','EPSG','3679',0.14,-503.174,-247.255,312.316,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108165','Porto_Santo_1936_To_PTRA08_3_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4615','EPSG','5013','EPSG','3680',0.12,-503.3,-247.574,313.025,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108166','Porto_Santo_1936_To_WGS_1984_1_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4615','EPSG','4326','EPSG','1314',0.1,-160.41,-21.066,-99.282,'EPSG','9001',2.437,-17.25,-7.446,'EPSG','9104',0.168,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108167','Porto_Santo_1936_To_WGS_1984_2_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4615','EPSG','4326','EPSG','3679',0.1,-303.956,224.556,214.306,'EPSG','9001',9.405,-6.626,-12.583,'EPSG','9104',1.327,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108168','Porto_Santo_1936_To_WGS_1984_3_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4615','EPSG','4326','EPSG','3680',0.01,-494.088,-312.129,279.877,'EPSG','9001',-1.423,-1.013,1.59,'EPSG','9104',-0.748,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108169','Porto_Santo_1936_To_WGS_1984_1_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4615','EPSG','4326','EPSG','1314',0.5,-503.229,-247.375,312.582,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108170','Porto_Santo_1936_To_WGS_1984_2_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4615','EPSG','4326','EPSG','3679',0.3,-503.174,-247.255,312.316,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108171','Porto_Santo_1936_To_WGS_1984_3_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4615','EPSG','4326','EPSG','3680',0.3,-503.3,-247.574,313.025,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108172','Sao_Braz_To_PTRA08_1_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37249','EPSG','5013','EPSG','1345',0.025,-269.089,186.247,155.667,'EPSG','9001',2.005,3.606,-0.366,'EPSG','9104',0.097,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108173','Sao_Braz_To_PTRA08_2_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37249','EPSG','5013','EPSG','2871',0.03,-249.507,179.302,119.92,'EPSG','9001',1.406,2.423,-0.479,'EPSG','9104',0.952,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "area" VALUES('ESRI','150','Azores - Santa Maria Island','Azores - Santa Maria Island',36.9,37.1,-25.25,-24.95,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108174','Sao_Braz_To_PTRA08_3_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37249','EPSG','5013','ESRI','150',0.01,-440.296,58.548,296.265,'EPSG','9001',1.128,10.202,4.559,'EPSG','9104',-0.438,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108175','Sao_Braz_To_PTRA08_1_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37249','EPSG','5013','EPSG','1345',0.8,-204.926,140.353,55.063,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108176','Sao_Braz_To_PTRA08_2_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37249','EPSG','5013','EPSG','2871',0.8,-204.519,140.159,55.404,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108177','Sao_Braz_To_PTRA08_3_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37249','EPSG','5013','ESRI','150',0.8,-205.808,140.771,54.326,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108178','Sao_Braz_To_WGS_1984_1_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37249','EPSG','4326','EPSG','1345',0.035,-269.089,186.247,155.667,'EPSG','9001',2.005,3.606,-0.366,'EPSG','9104',0.097,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108179','Sao_Braz_To_WGS_1984_2_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37249','EPSG','4326','EPSG','2871',0.04,-249.507,179.302,119.92,'EPSG','9001',1.406,2.423,-0.479,'EPSG','9104',0.952,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108180','Sao_Braz_To_WGS_1984_3_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37249','EPSG','4326','ESRI','150',0.03,-440.296,58.548,296.265,'EPSG','9001',1.128,10.202,4.559,'EPSG','9104',-0.438,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108181','Sao_Braz_To_WGS_1984_1_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37249','EPSG','4326','EPSG','1345',0.9,-204.926,140.353,55.063,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108182','Sao_Braz_To_WGS_1984_2_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37249','EPSG','4326','EPSG','2871',0.9,-204.519,140.159,55.404,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108183','Sao_Braz_To_WGS_1984_3_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37249','EPSG','4326','ESRI','150',0.9,-205.808,140.771,54.326,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108184','Graciosa_1948_To_PTRA08_1_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37241','EPSG','5013','EPSG','1301',0.18,-185.391,122.266,35.989,'EPSG','9001',0.12,3.18,2.046,'EPSG','9104',-1.053,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108185','Graciosa_1948_To_PTRA08_2_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37241','EPSG','5013','EPSG','2873',0.005,-76.822,257.457,-12.817,'EPSG','9001',2.136,-0.033,-2.392,'EPSG','9104',-0.031,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108186','Graciosa_1948_To_PTRA08_3_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37241','EPSG','5013','EPSG','3681',0.004,-210.371,49.768,0.808,'EPSG','9001',-2.036,3.046,3.709,'EPSG','9104',0.934,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108187','Graciosa_1948_To_PTRA08_4_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37241','EPSG','5013','EPSG','2874',0.4,-364.422,243.651,274.822,'EPSG','9001',5.477,12.092,1.538,'EPSG','9104',2.243,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108188','Graciosa_1948_To_PTRA08_5_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37241','EPSG','5013','EPSG','2875',0.007,-201.545,109.048,32.218,'EPSG','9001',-0.286,3.471,2.443,'EPSG','9104',0.309,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108189','Graciosa_1948_To_PTRA08_6_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37241','EPSG','5013','EPSG','2872',0.005,-216.355,107.044,48.015,'EPSG','9001',-0.204,4.158,2.605,'EPSG','9104',0.297,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108190','WGS_1984_(ITRF00)_To_NAD_1983',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4326','EPSG','4269','EPSG','1511',0.1,0.9956,-1.9013,-0.5215,'EPSG','9001',0.025915,0.009426,0.011599,'EPSG','9104',0.00062,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108192','DHDN_To_ETRF_1989',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4314','ESRI','104258','EPSG','2326',5.0,582.0,105.0,414.0,'EPSG','9001',-1.04,-0.35,3.08,'EPSG','9104',8.3,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108193','ED_1950_To_ETRF_1989_1',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4230','ESRI','104258','EPSG','2601',1.0,-116.641,-56.931,-110.559,'EPSG','9001',0.893,0.921,-0.917,'EPSG','9104',-3.52,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108194','Estonia_1992_To_ETRF_1989',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4133','ESRI','104258','EPSG','3246',0.1,0.0,0.0,0.0,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108195','ETRF_1989_To_WGS_1984',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','104258','EPSG','4326','EPSG','1298',1.0,0.0,0.0,0.0,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108196','Hungarian_1972_To_ETRF_1989_1',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4237','ESRI','104258','EPSG','1119',1.0,56.0,-75.77,-15.31,'EPSG','9001',0.37,0.2,0.21,'EPSG','9104',1.01,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108197','IRENET95_To_ETRF_1989',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4173','ESRI','104258','EPSG','1305',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108198','Pulkovo_1942_To_ETRF_1989',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4284','ESRI','104258','EPSG','1343',2.0,24.0,-123.0,-94.0,'EPSG','9001',-0.02,0.25,0.13,'EPSG','9104',1.1,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108199','RGF_1993_To_ETRF_1989_1',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4171','ESRI','104258','EPSG','1096',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108201','NGO_1948_To_WGS_1984',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4273','EPSG','4326','EPSG','1352',5.0,319.08,37.81,463.57,'EPSG','9001',-6.2970588,1.2903926,5.712916338,'EPSG','9104',10.819,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108202','S_JTSK_To_Pulkovo_1942',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4156','EPSG','4284','EPSG','1079',1.0,544.8,206.7,540.8,'EPSG','9001',4.998,1.587,5.261,'EPSG','9104',3.56,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108206','DHDN_To_WGS_1984_3x',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4314','EPSG','4326','EPSG','2543',0.1,597.1,71.4,412.1,'EPSG','9001',0.894,0.068,-1.563,'EPSG','9104',7.58,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108207','DHDN_To_WGS_1984_4x',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4314','EPSG','4326','EPSG','2542',0.1,584.8,67.0,400.3,'EPSG','9001',0.105,0.013,-2.378,'EPSG','9104',10.29,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108208','DHDN_To_WGS_1984_5x',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4314','EPSG','4326','EPSG','2541',0.1,590.5,69.5,411.6,'EPSG','9001',-0.796,-0.052,-3.601,'EPSG','9104',8.3,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108209','DHDN_To_WGS_1984_6x',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4314','EPSG','4326','EPSG','2544',0.1,599.4,72.4,419.2,'EPSG','9001',-0.062,-0.022,-2.723,'EPSG','9104',6.46,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108210','DHDN_To_WGS_1984_7x',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','4314','EPSG','4326','EPSG','2545',0.1,612.4,77.0,440.2,'EPSG','9001',-0.054,0.057,-2.797,'EPSG','9104',2.55,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108211','WGS_1984_To_Observatorio_Meteorologico_1965_1',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4326','ESRI','104126','EPSG','1147',999.0,148.635396,339.470115,157.265381,'EPSG','9001',32.87685,-76.963371,-32.622853,'EPSG','9104',-8.204889,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108212','SWEREF99_To_RT90',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4619','EPSG','4124','EPSG','1225',999.0,-414.1055246174168,-41.3265500041888,-603.0582474221075,'EPSG','9001',-0.8551163376151379,2.141317405481035,-7.022729828586432,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108213','WGS_1984_To_RT90',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4326','EPSG','4124','EPSG','1225',999.0,-414.0978567149,-41.3381489658,-603.0627177516,'EPSG','9001',-0.8550434314,2.1413465185,-7.0227209516,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "area" VALUES('ESRI','151','Iceland - NADCON','Iceland - NADCON',63.2700005,66.6600003,-24.6499996,-13.2499999,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108214','ISN_1993_To_ISN_2004',NULL,NULL,'EPSG','9615','NTv2','EPSG','4659','EPSG','5324','ESRI','151',0.05,'EPSG','8656','Latitude and longitude difference file','icegrid2004',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108216','ISN_2004_To_ISN_1993',NULL,NULL,'EPSG','9615','NTv2','EPSG','5324','EPSG','4659','ESRI','151',0.05,'EPSG','8656','Latitude and longitude difference file','ICEGRID93',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108217','La_Canoa_To_SIRGAS',NULL,NULL,'EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4247','EPSG','4170','EPSG','3327',15.0,-270.933,115.599,-360.226,'EPSG','9001',-5.266,-1.238,2.381,'EPSG','9104',-5.109,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,2464351.594,-5783466.613,974809.808,'EPSG','9001',NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108220','Palestine_1923_To_WGS_1984_1X',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4281','EPSG','4326','EPSG','1126',1.5,-181.0,-122.0,225.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108222','Datum_Lisboa_Hayford_To_Datum_73_1',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104106','EPSG','4274','EPSG','1294',5.0,-80.809,-170.77,66.991,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108223','Datum_Lisboa_Hayford_To_Datum_73_2',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','104106','EPSG','4274','EPSG','1294',5.0,-49.137,-179.924,95.757,'EPSG','9001',1.955,-0.328,1.423,'EPSG','9104',-6.827,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108224','Datum_Lisboa_Hayford_To_Datum_Lisboa_Bessel_1',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104106','ESRI','104105','EPSG','1294',5.0,-812.134,130.465,-461.583,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108225','Datum_Lisboa_Hayford_To_Datum_Lisboa_Bessel_2',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','104106','ESRI','104105','EPSG','1294',5.0,-920.281,-25.191,-355.2,'EPSG','9001',2.781,-4.855,-4.276,'EPSG','9104',-0.168,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108226','EUREF_FIN_To_ETRS_1989',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','104129','EPSG','4258','EPSG','1095',1.0,0.0,0.0,0.0,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108227','EUREF_FIN_To_WGS_1984',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','104129','EPSG','4326','EPSG','1095',1.0,0.0,0.0,0.0,'EPSG','9001',0.0,0.0,0.0,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108229','KKJ_To_EUREF_FIN',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4123','ESRI','104129','EPSG','3333',1.0,-96.0617,-82.4278,-121.7535,'EPSG','9001',-4.80107,-0.34543,1.37646,'EPSG','9104',1.4964,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108232','Palestine_1923_To_WGS_1984_2X',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4281','EPSG','4326','EPSG','2602',999.0,-219.247,-73.802,269.529,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108233','Jordan_To_WGS_1984',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104130','EPSG','4326','EPSG','1130',999.0,-86.0,-98.0,-119.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108234','Observatorio_Meteorologico_1965_To_WGS_1984_2',NULL,NULL,'EPSG','9636','Molodensky-Badekas (CF geog2D domain)','ESRI','104126','EPSG','4326','EPSG','1147',999.0,-203.35,-302.66,-155.23,'EPSG','9001',-33.338,76.825,32.412,'EPSG','9104',7.926,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,-2361564.77,5417538.39,2391581.09,'EPSG','9001',NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108235','WGS_1984_To_Observatorio_Meteorologico_1965_2',NULL,NULL,'EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4326','ESRI','104126','EPSG','1147',999.0,203.35,302.66,155.23,'EPSG','9001',33.326,-76.831,-32.4,'EPSG','9104',-7.926,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,-2361768.11,5417235.73,2391425.86,'EPSG','9001',NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108237','Amersfoort_To_WGS_1984_4X',NULL,NULL,'EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4289','EPSG','4326','EPSG','1275',0.75,593.0297,26.0038,478.7534,'EPSG','9001',0.4068573303223975,-0.3507326765425626,1.870347383606796,'EPSG','9104',4.0812,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,3903453.1482,368135.3134,5012970.3051,'EPSG','9001',NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108240','Graciosa_1948_To_PTRA08_1_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37241','EPSG','5013','EPSG','1301',0.19,-105.679,166.1,-37.322,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108241','Graciosa_1948_To_PTRA08_2_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37241','EPSG','5013','EPSG','2873',0.068,-105.377,165.769,-36.965,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108242','Graciosa_1948_To_PTRA08_3_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37241','EPSG','5013','EPSG','3681',0.064,-105.359,165.804,-37.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108243','Graciosa_1948_To_PTRA08_4_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37241','EPSG','5013','EPSG','2874',0.1,-105.531,166.39,-37.326,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108244','Graciosa_1948_To_PTRA08_5_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37241','EPSG','5013','EPSG','2875',0.7,-105.756,165.972,-37.313,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108245','Graciosa_1948_To_PTRA08_6_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37241','EPSG','5013','EPSG','2872',0.07,-106.235,166.236,-37.768,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108246','Graciosa_1948_To_WGS_1984_1_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37241','EPSG','4326','EPSG','1301',0.5,-185.391,122.266,35.989,'EPSG','9001',0.12,3.18,2.046,'EPSG','9104',-1.053,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108247','Graciosa_1948_To_WGS_1984_2_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37241','EPSG','4326','EPSG','2873',0.01,-76.822,257.457,-12.817,'EPSG','9001',2.136,-0.033,-2.392,'EPSG','9104',-0.031,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108248','Graciosa_1948_To_WGS_1984_3_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37241','EPSG','4326','EPSG','3681',0.01,-210.371,49.768,0.808,'EPSG','9001',-2.036,3.046,3.709,'EPSG','9104',0.934,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108249','Graciosa_1948_To_WGS_1984_4_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37241','EPSG','4326','EPSG','2874',0.5,-364.422,243.651,274.822,'EPSG','9001',5.477,12.092,1.538,'EPSG','9104',2.243,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108250','Graciosa_1948_To_WGS_1984_5_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37241','EPSG','4326','EPSG','2875',0.01,-201.545,109.048,32.218,'EPSG','9001',-0.286,3.471,2.443,'EPSG','9104',0.309,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108251','Graciosa_1948_To_WGS_1984_6_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37241','EPSG','4326','EPSG','2872',0.01,-216.355,107.044,48.015,'EPSG','9001',-0.204,4.158,2.605,'EPSG','9104',0.297,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108259','DOS_1968_To_WGS_1984',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37218','EPSG','4326','EPSG','3198',44.0,230.0,-199.0,-752.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108261','Estonia_1937_To_WGS_1984_NGA',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104101','EPSG','4326','EPSG','1090',0.1,374.0,150.0,588.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108262','Fort_Thomas_1955_To_WGS_1984',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37240','EPSG','4326','EPSG','1200',44.0,-7.0,215.0,225.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108263','GUX_1_To_WGS_1984',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37221','EPSG','4326','EPSG','3197',44.0,252.0,-209.0,-751.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108264','Hermannskogel_To_WGS_1984',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104102','EPSG','4326','EPSG','2370',999.0,682.0,-203.0,480.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108265','Voirol_Unifie_1960_Grad_To_WGS_1984',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','4305','EPSG','4326','EPSG','1365',44.0,-123.0,-206.0,219.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108269','South_Asia_Singapore_To_WGS_1984',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37207','EPSG','4326','EPSG','1210',999.0,7.0,-10.0,-26.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108272','Estonia_1937_To_ETRS_1989',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104101','EPSG','4258','EPSG','1090',0.1,372.87,149.23,585.29,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108276','D48_To_ETRS_1989',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','104131','EPSG','4258','EPSG','1212',3.0,426.62,142.62,460.09,'EPSG','9001',4.98,4.49,-12.42,'EPSG','9104',-17.1,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108277','D48_To_WGS_1984',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','104131','EPSG','4326','EPSG','1212',3.0,426.62,142.62,460.09,'EPSG','9001',4.98,4.49,-12.42,'EPSG','9104',-17.1,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108278','Voirol_1875_Grad_To_WGS_1984',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104139','EPSG','4326','EPSG','1365',44.0,-73.0,-247.0,227.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108279','Merchich_Degree_To_WGS_1984',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104261','EPSG','4326','EPSG','3280',7.0,31.0,146.0,47.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108280','ITRF_2000_To_WGS_1984',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104124','EPSG','4326','EPSG','1262',0.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108281','ITRF_2000_To_NAD_1983_HARN',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','104124','EPSG','4152','EPSG','1324',0.1,0.9956,-1.9013,-0.5215,'EPSG','9001',0.025915,0.009426,0.011599,'EPSG','9104',0.00062,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108282','WGS_1984_(ITRF00)_To_NAD_1983_HARN',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4326','EPSG','4152','EPSG','1324',0.1,0.9956,-1.9013,-0.5215,'EPSG','9001',0.025915,0.009426,0.011599,'EPSG','9104',0.00062,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108283','Ocotepeque_1935_To_WGS_1984_RN',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','EPSG','5451','EPSG','4326','EPSG','3232',999.0,6.41,-49.05,-11.28,'EPSG','9001',1.5657,0.5242,6.9718,'EPSG','9104',-5.7649,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108286','MONREF_1997_To_MSK_1942_1',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','104134','ESRI','104135','EPSG','1164',999.0,78.0421780299,204.5186132514,77.449861533,'EPSG','9001',-1.7736709695,3.3197917322,-1.0426077127,'EPSG','9104',-4.95105766,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108287','MONREF_1997_To_MSK_1942_2',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104134','ESRI','104135','EPSG','1164',999.0,-12.6212134867,138.667639968,73.9961390849,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108288','MONREF_1997_To_Pulkovo_1942_1',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','104134','EPSG','4284','EPSG','1164',999.0,78.0421780299,204.5186132514,77.449861533,'EPSG','9001',-1.7736709695,3.3197917322,-1.0426077127,'EPSG','9104',-4.95105766,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108289','MONREF_1997_To_Pulkovo_1942_2',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104134','EPSG','4284','EPSG','1164',999.0,-12.6212134867,138.667639968,73.9961390849,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108290','MAGNA_To_SIRGAS',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4686','EPSG','4170','EPSG','1070',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108292','Graciosa_1948_To_WGS_1984_1_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37241','EPSG','4326','EPSG','1301',0.3,-105.679,166.1,-37.322,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108293','Graciosa_1948_To_WGS_1984_2_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37241','EPSG','4326','EPSG','2873',0.2,-105.377,165.769,-36.965,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108294','Graciosa_1948_To_WGS_1984_3_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37241','EPSG','4326','EPSG','3681',0.1,-105.359,165.804,-37.05,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108295','Graciosa_1948_To_WGS_1984_4_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37241','EPSG','4326','EPSG','2874',0.3,-105.531,166.39,-37.326,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108296','Graciosa_1948_To_WGS_1984_5_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37241','EPSG','4326','EPSG','2875',0.9,-105.756,165.972,-37.313,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108297','Graciosa_1948_To_WGS_1984_6_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37241','EPSG','4326','EPSG','2872',0.2,-106.235,166.236,-37.768,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "area" VALUES('ESRI','152','USA - Idaho and Montana','USA - Idaho and Montana',41.0,49.38,-119.0,-104.0,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108298','NAD_1983_To_HARN_Montana_Idaho',NULL,NULL,'EPSG','9615','NTv2','EPSG','4269','EPSG','4152','ESRI','152',0.05,'EPSG','8656','Latitude and longitude difference file','imhpgn',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108299','Guam_1963_To_WGS_1984_Saipan',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4675','EPSG','4326','ESRI','148',999.0,59.935,118.4,-10.871,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108300','NAD_1983_HARN_To_WGS_1984_Saipan',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4152','EPSG','4326','ESRI','148',999.0,1.2,0.4,0.55,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108302','ATS_1977_To_NAD_1983_CSRS_NTv2_Maritimes',NULL,NULL,'EPSG','9615','NTv2','EPSG','4122','EPSG','4617','EPSG','1283',999.0,'EPSG','8656','Latitude and longitude difference file','canada/GS7783',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108303','Pohnpei_To_WGS_1984',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104109','EPSG','4326','EPSG','1161',999.0,-89.121,-348.182,260.871,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108304','Guam_1963_To_NAD_1983_HARN_Saipan',NULL,NULL,'EPSG','9615','NTv2','EPSG','4675','EPSG','4152','ESRI','148',999.0,'EPSG','8656','Latitude and longitude difference file','c1hpgn',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO grid_alternatives VALUES ('c1hpgn', 'c1hpgn.gsb', 'NTv2', 'hgridshift', 0, 'proj-datumgrid-north-america', NULL, NULL, NULL, NULL);
INSERT INTO "grid_transformation" VALUES('ESRI','108305','Guam_1963_To_NAD_1983_HARN_Rota',NULL,NULL,'EPSG','9615','NTv2','EPSG','4675','EPSG','4152','ESRI','147',999.0,'EPSG','8656','Latitude and longitude difference file','c2hpgn',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO grid_alternatives VALUES ('c2hpgn', 'c2hpgn.gsb', 'NTv2', 'hgridshift', 0, 'proj-datumgrid-north-america', NULL, NULL, NULL, NULL);
INSERT INTO "grid_transformation" VALUES('ESRI','108306','Old_Hawaiian_To_NAD_1983_HARN_Hawaii',NULL,NULL,'EPSG','9615','NTv2','EPSG','4135','EPSG','4152','EPSG','1334',0.05,'EPSG','8656','Latitude and longitude difference file','ohdhihpgn',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "area" VALUES('ESRI','153','Pacific - USA interests Pacific and Mariana plates','Pacific - USA interests Pacific and Mariana plates',-17.56,31.8,129.48,-151.27,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108307','NAD_1983_HARN_PACP00_MARP00_To_WGS_1984',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4152','EPSG','4326','ESRI','153',999.0,-0.9102,2.0141,0.5602,'EPSG','9001',-0.029039,-0.010065,-0.010101,'EPSG','9104',0.0,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108330','Old_Hawaiian_Intl_1924_To_WGS_1984_Mean',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104138','EPSG','4326','EPSG','1334',38.0,201.0,-228.0,-346.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108331','Old_Hawaiian_Intl_1924_To_WGS_1984_Hawaii',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104138','EPSG','4326','EPSG','1546',44.0,229.0,-222.0,-348.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108332','Old_Hawaiian_Intl_1924_To_WGS_1984_Kauai',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104138','EPSG','4326','EPSG','1549',35.0,185.0,-233.0,-337.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108333','Old_Hawaiian_Intl_1924_To_WGS_1984_Maui',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104138','EPSG','4326','EPSG','1547',44.0,205.0,-233.0,-355.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108334','Old_Hawaiian_Intl_1924_To_WGS_1984_Oahu',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104138','EPSG','4326','EPSG','1548',14.0,198.0,-226.0,-347.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108335','ED_1950_To_WGS_1984_NGA_7PAR',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4230','EPSG','4326','EPSG','2420',10.0,-102.0,-102.0,-129.0,'EPSG','9001',0.413,-0.184,0.385,'EPSG','9104',2.4664,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108336','OSGB_1936_To_WGS_1984_NGA_7PAR',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4277','EPSG','4326','EPSG','1264',21.0,446.0,-99.0,544.0,'EPSG','9001',-0.945,-0.261,-0.435,'EPSG','9104',-20.8927,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108337','Hong_Kong_1980_To_ITRF_1996',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4611','ESRI','104122','EPSG','1118',1.0,-162.619,-276.959,-161.764,'EPSG','9001',-0.067753,2.243648,1.158828,'EPSG','9104',-1.094246,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108341','Observatorio_Meteorologico_1939_To_PTRA08_1_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37245','EPSG','5013','EPSG','1344',0.03,-487.978,-226.275,102.787,'EPSG','9001',-0.743,1.677,2.087,'EPSG','9104',1.485,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "area" VALUES('ESRI','154','Azores - Flores Island','Azores - Flores Island',39.35,39.5,-31.3,-31.1,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108342','Observatorio_Meteorologico_1939_To_PTRA08_2_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37245','EPSG','5013','ESRI','154',0.02,-511.151,-181.269,139.609,'EPSG','9001',1.05,2.703,1.798,'EPSG','9104',3.071,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108343','Observatorio_Meteorologico_1939_To_PTRA08_3_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37245','EPSG','5013','EPSG','3685',0.07,-1333.976,-487.235,945.031,'EPSG','9001',6.674,35.963,20.438,'EPSG','9104',-11.187,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108344','Observatorio_Meteorologico_1939_To_PTRA08_1_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37245','EPSG','5013','EPSG','1344',0.06,-423.058,-172.868,83.772,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108345','Observatorio_Meteorologico_1939_To_PTRA08_2_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37245','EPSG','5013','ESRI','154',0.056,-423.053,-172.871,83.771,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108346','Observatorio_Meteorologico_1939_To_PTRA08_3_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37245','EPSG','5013','EPSG','3685',0.064,-423.024,-172.923,83.83,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108347','Observatorio_Meteorologico_1939_To_WGS_1984_1_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37245','EPSG','4326','EPSG','1344',0.06,-487.978,-226.275,102.787,'EPSG','9001',-0.743,1.677,2.087,'EPSG','9104',1.485,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108348','Observatorio_Meteorologico_1939_To_WGS_1984_2_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37245','EPSG','4326','ESRI','154',0.05,-511.151,-181.269,139.609,'EPSG','9001',1.05,2.703,1.798,'EPSG','9104',3.071,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108349','Observatorio_Meteorologico_1939_To_WGS_1984_3_7par',NULL,NULL,'EPSG','9606','Position Vector transformation (geog2D domain)','ESRI','37245','EPSG','4326','EPSG','3685',0.1,-1333.976,-487.235,945.031,'EPSG','9001',6.674,35.963,20.438,'EPSG','9104',-11.187,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108350','Observatorio_Meteorologico_1939_To_WGS_1984_1_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37245','EPSG','4326','EPSG','1344',0.1,-423.058,-172.868,83.772,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108351','Observatorio_Meteorologico_1939_To_WGS_1984_2_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37245','EPSG','4326','ESRI','154',0.08,-423.053,-172.871,83.771,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108352','Observatorio_Meteorologico_1939_To_WGS_1984_3_3par',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','37245','EPSG','4326','EPSG','3685',0.085,-423.024,-172.923,83.83,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108353','ITRF_2000_To_NAD_1983_2011',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','104124','EPSG','6318','EPSG','1511',0.1,0.9956,-1.9013,-0.5215,'EPSG','9001',0.025915,0.009426,0.011599,'EPSG','9104',0.00062,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108354','WGS_1984_(ITRF00)_To_NAD_1983_2011',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4326','EPSG','6318','EPSG','1511',0.1,0.9956,-1.9013,-0.5215,'EPSG','9001',0.025915,0.009426,0.011599,'EPSG','9104',0.00062,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108355','NAD_1983_HARN_To_NAD_1983_2011',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4152','EPSG','6318','EPSG','1324',0.1,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108356','NAD_1983_NSRS2007_To_NAD_1983_2011',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4759','EPSG','6318','EPSG','1324',0.1,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108357','NAD_1983_CORS96_To_NAD_1983_2011',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','6783','EPSG','6318','EPSG','1324',0.1,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108359','ED_1950_To_WGS_1984_NTv2_Catalonia',NULL,NULL,'EPSG','9615','NTv2','EPSG','4230','EPSG','4326','EPSG','3732',0.05,'EPSG','8656','Latitude and longitude difference file','spain/100800401',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108360','ITRF_2008_To_NAD_1983_2011',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','104257','EPSG','6318','EPSG','1511',0.03,0.99343,-1.90331,-0.52655,'EPSG','9001',0.02591467,0.00942645,0.01159935,'EPSG','9104',0.00171504,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108361','ITRF_2008_To_NAD_1983_MA11',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','104257','EPSG','6325','EPSG','4167',0.05,0.908,-2.0161,-0.5653,'EPSG','9001',0.028971,0.01042,0.008928,'EPSG','9104',0.0011,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108362','ITRF_2008_To_NAD_1983_PA11',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','ESRI','104257','EPSG','6322','EPSG','4162',0.05,0.908,-2.0161,-0.5653,'EPSG','9001',0.027741,0.013469,0.002712,'EPSG','9104',0.0011,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108363','WGS_1984_(ITRF08)_To_NAD_1983_2011',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4326','EPSG','6318','EPSG','1511',0.03,0.99343,-1.90331,-0.52655,'EPSG','9001',0.02591467,0.00942645,0.01159935,'EPSG','9104',0.00171504,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108364','WGS_1984_(ITRF08)_To_NAD_1983_MA11',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4326','EPSG','6325','EPSG','4167',0.05,0.908,-2.0161,-0.5653,'EPSG','9001',0.028971,0.01042,0.008928,'EPSG','9104',0.0011,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108365','WGS_1984_(ITRF08)_To_NAD_1983_PA11',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4326','EPSG','6322','EPSG','4162',0.05,0.908,-2.0161,-0.5653,'EPSG','9001',0.027741,0.013469,0.002712,'EPSG','9104',0.0011,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108366','WGS_1984_To_Ain_El_Abd_1970_MB',NULL,NULL,'EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4326','EPSG','4204','EPSG','1040',0.1,151.9082,251.0907,-0.2276,'EPSG','9001',-0.91646,-1.0469,3.21042,'EPSG','9104',-5.2723,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,3641909.2287,4425312.2897,2789434.9636,'EPSG','9001',NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108367','GGD_To_Pulkovo_1942',NULL,NULL,'EPSG','9636','Molodensky-Badekas (CF geog2D domain)','ESRI','104022','EPSG','4284','EPSG','3251',0.11,-15.626,126.0343,79.3775,'EPSG','9001',-1.2753,-1.42112,2.69445,'EPSG','9104',4.5284,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,3445619.6689,3275369.7555,4236015.9558,'EPSG','9001',NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108368','GGD_To_ITRF_1993',NULL,NULL,'EPSG','9636','Molodensky-Badekas (CF geog2D domain)','ESRI','104022','ESRI','104120','EPSG','3251',0.03,0.3452,-0.1805,-0.206,'EPSG','9001',-0.05465,0.06718,-0.06143,'EPSG','9104',0.0181,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,3419202.2774,3284301.1262,4251887.7897,'EPSG','9001',NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108369','CH1903+_To_ETRS_1989_NTv2',NULL,NULL,'EPSG','9615','NTv2','EPSG','4150','EPSG','4258','EPSG','1286',0.1,'EPSG','8656','Latitude and longitude difference file','switzerland/ntv2-ch03p-etrs',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108370','CH1903+_To_CHTRF95_NTv2',NULL,NULL,'EPSG','9615','NTv2','EPSG','4150','EPSG','4151','EPSG','1286',0.1,'EPSG','8656','Latitude and longitude difference file','switzerland/ntv2-ch03p-etrs',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108374','Dealul_Piscului_1970_To_WGS_1984_3X',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4317','EPSG','4326','EPSG','1197',3.0,2.3287,-147.0425,-92.0802,'EPSG','9001',0.3092483,-0.32482185,-0.49729934,'EPSG','9104',5.68906266,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108375','Dealul_Piscului_1970_To_ETRS_1989_1X',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4317','EPSG','4258','EPSG','1197',3.0,2.3287,-147.0425,-92.0802,'EPSG','9001',0.3092483,-0.32482185,-0.49729934,'EPSG','9104',5.68906266,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108376','Barbados_1938_To_WGS_1984_2X',NULL,NULL,'EPSG','9607','Coordinate Frame rotation (geog2D domain)','EPSG','4212','EPSG','4326','EPSG','3218',0.15,-267.434,173.496,181.814,'EPSG','9001',13.4704,-8.7154,-7.3926,'EPSG','9104',14.7492,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108377','NAD_1983_HARN_To_NAD_1983_MA11',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4152','EPSG','6325','EPSG','4167',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108448','Bab_South_To_WGS_1984',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104112','EPSG','4326','EPSG','1185',999.0,-185.583,-230.096,281.361,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108449','Majuro_To_WGS_1984',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','ESRI','104113','EPSG','4326','EPSG','1155',999.0,25.1,-275.6,222.6,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108450','NAD_1983_HARN_To_NAD_1983_PA11_1',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4152','EPSG','6322','EPSG','4162',1.0,0.0,0.0,0.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108452','Padang_To_WGS_1984_1',NULL,NULL,'EPSG','9603','Geocentric translations (geog2D domain)','EPSG','4280','EPSG','4326','EPSG','1355',6.0,-377.0,681.0,-50.0,'EPSG','9001',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108453','AGD_1984_To_GDA_1994_NTv2_Queensland',NULL,NULL,'EPSG','9615','NTv2','EPSG','4203','EPSG','4283','EPSG','4021',0.1,'EPSG','8656','Latitude and longitude difference file','australia/QLD_0900',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "helmert_transformation" VALUES('ESRI','108457','Amersfoort_To_WGS_1984_2008_MB',NULL,NULL,'EPSG','9636','Molodensky-Badekas (CF geog2D domain)','EPSG','4289','EPSG','4326','EPSG','1275',0.5,593.0248,25.9984,478.7459,'EPSG','9001',0.3989573882431337,-0.3439878173782826,1.877401639980446,'EPSG','9104',4.0725,'EPSG','9202',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,3903453.1482,368135.3134,5012970.3051,'EPSG','9001',NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108471','RGNC_1991_To_IGN72_Grande_Terre_NTv2',NULL,NULL,'EPSG','9615','NTv2','EPSG','4645','EPSG','4662','EPSG','2822',0.1,'EPSG','8656','Latitude and longitude difference file','france/RGNC1991_IGN72GrandeTerre',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
INSERT INTO "grid_transformation" VALUES('ESRI','108472','RGNC_1991_To_NEA74_Noumea_NTv2',NULL,NULL,'EPSG','9615','NTv2','EPSG','4645','EPSG','4644','EPSG','2823',999.0,'EPSG','8656','Latitude and longitude difference file','france/RGNC1991_NEA74Noumea',NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
